(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   3969765,     105726]
NotebookOptionsPosition[   3678000,     101044]
NotebookOutlinePosition[   3679441,     101079]
CellTagsIndexPosition[   3679251,     101072]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Horn Problem library\n    ",
 StyleBox["Andrew J. Hanson, 1 November 2017 - 7 August 2018",
  FontSize->24,
  FontSlant->"Italic"]
}], "Subchapter",
 CellChangeTimes->{{3.718549367729002*^9, 3.7185493916652737`*^9}, {
  3.7401571809596167`*^9, 3.7401571863196497`*^9}, {3.741707613742916*^9, 
  3.741707614428994*^9}, {3.742603322943331*^9, 
  3.742603329598147*^9}},ExpressionUUID->"748b753e-4146-4d83-9f41-\
de817b6938ac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NotebookDirectory", "[", "]"}]], "Input",
 CellChangeTimes->{{3.724508642629655*^9, 3.7245086492612534`*^9}, {
  3.7420795429999228`*^9, 3.742079543836525*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"0d3e2780-4c83-4dfe-bd7a-9a2ae99dbd24"],

Cell[BoxData["\<\"/home/hanson/Dropbox/Articles/Horn-soln-dir/000MAKE-FIGURES/\
\"\>"], "Output",
 CellChangeTimes->{3.724508652458494*^9, 3.740146589508342*^9, 
  3.740157175875379*^9, 3.7417076076823883`*^9},
 CellLabel->
  "Out[123]=",ExpressionUUID->"3eb14825-5a27-4364-9a07-d000a578597c"]
}, Open  ]],

Cell[TextData[{
 "Description: In order to find the optimal rotation to match two sets of\n   \
3D spatial data described by matching lists of points, one can convert\n   \
the problem to finding the (maximal) eigenvectors of a 4x4 matrix involving\n \
  the two lists of points.   ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "ab"], TraditionalForm]],ExpressionUUID->
  "418eceda-6a63-491d-bb3c-275ea349cf8e"],
 " and  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "ab"], TraditionalForm]],ExpressionUUID->
  "8985c61e-bb3a-4e0d-bbd1-b790298619b5"],
 " give the  X[a].Y[b] values for two 3D vector lists\n   X and Y, with a,b \
in {x,y,z}."
}], "Subsubsection",
 CellChangeTimes->{{3.718549399808909*^9, 3.718549573328327*^9}, {
  3.742603374327388*^9, 
  3.742603404630683*^9}},ExpressionUUID->"86f1d35a-8a35-4b0a-9499-\
f3fe147ad035"],

Cell[CellGroupData[{

Cell["\<\
Generic Utilities - sym, quaternions, polar coords, ginv.dg in Pauli\
\>", "Section",
 CellChangeTimes->{{3.706144720115918*^9, 3.706144727715445*^9}, {
  3.7061447874115543`*^9, 3.706144789875288*^9}, {3.706146616724567*^9, 
  3.706146624747994*^9}, {3.707662418145602*^9, 
  3.7076624192177267`*^9}},ExpressionUUID->"d3d6a088-9b74-4797-834f-\
c2ea66697417"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sym", "[", "args__", "]"}], " ", ":=", " ", 
  RowBox[{"ToExpression", "[", 
   RowBox[{"StringJoin", "@@", 
    RowBox[{"Map", "[", 
     RowBox[{"ToString", ",", 
      RowBox[{"List", "[", "args", "]"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.496227339423546*^9, 3.496227352846005*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"14650e04-f9a9-49ee-8226-13e251efd9fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"str", "[", "args__", "]"}], " ", ":=", "  ", 
  RowBox[{"StringJoin", "@@", 
   RowBox[{"Map", "[", 
    RowBox[{"ToString", ",", 
     RowBox[{"List", "[", "args", "]"}]}], "]"}], " "}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.496227339423546*^9, 3.496227352846005*^9}, {
  3.573314963690791*^9, 
  3.573314971522242*^9}},ExpressionUUID->"83ae9efe-71d5-4467-80be-\
442d4c1e79d2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"normalizeN", "[", "v_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sqr", "=", 
      RowBox[{"v", ".", "v"}]}], "}"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"sqr", "\[Equal]", "0"}], ",", "v", ",", 
      RowBox[{"v", "/", 
       RowBox[{"Sqrt", "[", "sqr", "]"}]}], ",", 
      RowBox[{"v", "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"v", ".", "v"}], "]"}]}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.515785309110012*^9, 3.515785380800979*^9}, {
  3.593177816069806*^9, 3.593177830779051*^9}, {3.598960836559938*^9, 
  3.598960840864402*^9}},ExpressionUUID->"685cdace-df77-407e-812f-\
c290ccd7f67c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Problem", " ", "with", " ", "symbolic", " ", 
    RowBox[{"args", ":"}]}], " ", "*)"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"normalize", "[", "v_", "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sqr", "=", 
        RowBox[{"v", ".", "v"}]}], "}"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"sqr", "\[Equal]", "0"}], ",", "v", ",", 
        RowBox[{"v", "/", 
         RowBox[{"Sqrt", "[", "sqr", "]"}]}]}], "]"}]}], "]"}]}], 
   "*)"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.515785309110012*^9, 3.515785380800979*^9}, {
   3.5931778912665167`*^9, 3.593177914343862*^9}, 
   3.721608384578846*^9},ExpressionUUID->"53d5ac48-a39b-44d5-9226-\
8872cb7a2299"],

Cell[BoxData[
 RowBox[{
  RowBox[{"normalize", "[", "lst_List", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"norm", " ", "=", " ", 
       RowBox[{"lst", " ", ".", " ", "lst"}]}], ",", 
      RowBox[{"eps", "=", 
       RowBox[{"10", "^", 
        RowBox[{"(", 
         RowBox[{"-", "14"}], ")"}]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"NumberQ", "[", "norm", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"norm", "<", "eps"}], ",", " ", "lst", ",", " ", 
        RowBox[{"N", "[", 
         RowBox[{"lst", "/", 
          RowBox[{"Sqrt", "[", "norm", "]"}]}], "]"}]}], " ", "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"lst", "/", 
       RowBox[{"Sqrt", "[", "norm", "]"}]}]}], "]"}]}], "]"}], 
  "  "}]], "Input",
 InitializationCell->True,
 CellLabel->"In[38]:=",ExpressionUUID->"abb174c0-13ff-40fe-8263-73135a6d4611"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"TeXForm", " ", "utility", " ", "template"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"StringReplace", "[", 
   RowBox[{
    RowBox[{"ToString", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"p3", "/.", "the4DPRule"}], "//", "Expand"}], "//", 
      "TeXForm"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<\\\\text{aa}\>\"", "\[Rule]", " ", "\"\<A\>\""}], ",", 
      RowBox[{"\"\<\\\\text{bb}\>\"", "\[Rule]", " ", "\"\<B\>\""}], ",", 
      RowBox[{"\"\<\\\\text{cc}\>\"", "\[Rule]", " ", "\"\<C\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<\\\\text{aaw}\>\"", "\[Rule]", " ", "\"\<A_w\>\""}], ",", 
      RowBox[{"\"\<\\\\text{bbw}\>\"", "\[Rule]", " ", "\"\<B_w\>\""}], ",", 
      RowBox[{"\"\<\\\\text{ccw}\>\"", "\[Rule]", " ", "\"\<C_w\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<\\\\text{aw}\>\"", "\[Rule]", " ", "\"\<a_w\>\""}], ",", 
      RowBox[{"\"\<\\\\text{bw}\>\"", "\[Rule]", " ", "\"\<b_w\>\""}], ",", 
      RowBox[{"\"\<\\\\text{cw}\>\"", "\[Rule]", " ", "\"\<c_w\>\""}]}], 
     "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.722127758015676*^9, 3.722127793956093*^9}, {
  3.722127860339203*^9, 3.7221279707394943`*^9}, {3.7263442891197863`*^9, 
  3.726344309255432*^9}},ExpressionUUID->"0a8d1987-5c5e-48e7-a597-\
85b066129f2f"],

Cell[CellGroupData[{

Cell["Matrix from form extraction", "Subsubsection",
 CellChangeTimes->{{3.706146222943119*^9, 3.706146224263074*^9}, {
  3.726344650610126*^9, 
  3.726344677609537*^9}},ExpressionUUID->"ae332e6e-cdd7-4ccd-9ee5-\
d1a7e07aa149"],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrixFromCoeff", "[", 
   RowBox[{"matrix_", ",", "coeffvars_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", "\[Equal]", "j"}], ",", 
        RowBox[{"Coefficient", "[", 
         RowBox[{"matrix", ",", 
          RowBox[{
           RowBox[{"coeffvars", "[", 
            RowBox[{"[", "i", "]"}], "]"}], 
           RowBox[{"coeffvars", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], 
         RowBox[{"Coefficient", "[", 
          RowBox[{"matrix", ",", 
           RowBox[{
            RowBox[{"coeffvars", "[", 
             RowBox[{"[", "i", "]"}], "]"}], 
            RowBox[{"coeffvars", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "coeffvars", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"Length", "[", "coeffvars", "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.579459582468239*^9, 3.579459667342526*^9}, {
  3.585241514895875*^9, 3.58524153062543*^9}, {3.5852415996189404`*^9, 
  3.5852416077305*^9}, {3.720236810918689*^9, 3.720236853534974*^9}, {
  3.7202369206354647`*^9, 
  3.720236946683612*^9}},ExpressionUUID->"c45cb2ee-ade6-4943-896c-\
6f20d73f1a8c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixFromCoeff", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"aa", " ", "q0", " ", "q0"}], " ", "+", " ", 
    RowBox[{"2", " ", "ab", " ", "q0", " ", "q1"}], " ", "+", " ", 
    RowBox[{"bb", " ", "q1", " ", "q1"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.720236866438757*^9, 
  3.72023691206634*^9}},ExpressionUUID->"db5aa688-2651-484c-8d37-\
15b81a4aea5d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aa", ",", "ab"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ab", ",", "bb"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.720236953500669*^9, 
  3.7216973488567247`*^9},ExpressionUUID->"ba3c5dd7-27fe-4a37-9997-\
d2d0fb3fa8ae"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrixFromLRCoeff", "[", 
   RowBox[{"matrix_", ",", "coeffLeft_", ",", "coeffRight_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"matrix", ",", 
        RowBox[{
         RowBox[{"coeffLeft", "[", 
          RowBox[{"[", "i", "]"}], "]"}], 
         RowBox[{"coeffRight", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "coeffLeft", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"Length", "[", "coeffRight", "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.579459582468239*^9, 3.579459667342526*^9}, {
  3.585241514895875*^9, 3.58524153062543*^9}, {3.5852415996189404`*^9, 
  3.5852416077305*^9}, {3.720236810918689*^9, 3.720236853534974*^9}, {
  3.7202369206354647`*^9, 3.720236946683612*^9}, {3.7202387283394117`*^9, 
  3.720238728442024*^9}, {3.72023879378239*^9, 3.72023882936033*^9}, {
  3.720238878378092*^9, 3.720238882560565*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"df6fc853-e4ea-4d84-a40a-27a5053d122c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixFromLRCoeff", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"aa", " ", "q0", " ", "p0"}], " ", "+", "   ", 
    RowBox[{"ab", " ", "q0", " ", "p1"}], " ", "+", " ", 
    RowBox[{"ba", " ", "q1", " ", "p0"}], "+", 
    RowBox[{"bb", " ", "q1", " ", "p1"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.720236866438757*^9, 3.72023691206634*^9}, {
  3.720238732170865*^9, 
  3.720238782357254*^9}},ExpressionUUID->"4faf3200-ceab-4b16-af71-\
c4e69f6a3c15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aa", ",", "ab"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ba", ",", "bb"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.720238889477089*^9, 
  3.721697348897221*^9},ExpressionUUID->"4cbca77f-32a5-4a30-83ac-\
068f3faefd83"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"metricFromForm", "[", 
   RowBox[{"metExpr_", ",", "dvars_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", "\[Equal]", "j"}], ",", 
        RowBox[{"Coefficient", "[", 
         RowBox[{"metExpr", ",", 
          RowBox[{
           RowBox[{"dvars", "[", 
            RowBox[{"[", "i", "]"}], "]"}], 
           RowBox[{"dvars", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], 
         RowBox[{"Coefficient", "[", 
          RowBox[{"metExpr", ",", 
           RowBox[{
            RowBox[{"dvars", "[", 
             RowBox[{"[", "i", "]"}], "]"}], 
            RowBox[{"dvars", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "dvars", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"Length", "[", "dvars", "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.579459582468239*^9, 3.579459667342526*^9}, {
  3.585241514895875*^9, 3.58524153062543*^9}, {3.5852415996189404`*^9, 
  3.5852416077305*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"58ce8dd4-1c51-4e82-adfa-c65d5b35cda8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"ONE", " ", "ROW", " ", "AT", " ", "A", " ", "TIME"}], "*)"}], 
  RowBox[{
   RowBox[{"vectorFromForm", "[", 
    RowBox[{"vecExpr_", ",", "dvars_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "i", "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"vecExpr", ",", 
         RowBox[{"dvars", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "dvars", "]"}]}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.581079510983577*^9, 3.581079510987411*^9}, {
  3.585241614004931*^9, 3.5852416234048*^9}},
 CellLabel->
  "In[254]:=",ExpressionUUID->"823e64a1-1ccf-4a20-951c-f28bd49ac925"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"WHOLE", " ", "vierbein"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"vectorsFromFormList", "[", 
    RowBox[{"vecExprs_", ",", "dvars_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"vecExprs", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"dvars", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"Length", "[", "dvars", "]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "vecExprs", "]"}]}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.58107954999606*^9, 3.5810795499987383`*^9}, 
   3.581079592156287*^9, {3.581373950098948*^9, 3.581373951056637*^9}, {
   3.58524163145378*^9, 3.585241635662773*^9}},
 CellLabel->
  "In[255]:=",ExpressionUUID->"3eb97bde-78c7-4df3-9c37-6ee9198eceec"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quaternions", "Subsubsection",
 CellChangeTimes->{{3.706146222943119*^9, 
  3.706146224263074*^9}},ExpressionUUID->"db71da26-9329-45f8-acd7-\
26db90dfe6ac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x1", "+", 
     RowBox[{"I", " ", "y1"}]}], ")"}], 
   RowBox[{"(", 
    RowBox[{"x2", " ", "+", " ", 
     RowBox[{"I", " ", "y2"}]}], ")"}]}], "//", "ComplexExpand"}]], "Input",
 CellChangeTimes->{{3.740596682203372*^9, 3.740596700815576*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"6ed01f54-f897-4279-bbd1-edac5de65cd9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x1", " ", "x2"}], "-", 
  RowBox[{"y1", " ", "y2"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"x2", " ", "y1"}], "+", 
     RowBox[{"x1", " ", "y2"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.74059670166463*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"204f53f5-bc42-4767-ab99-96d45e256ef2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x1_", ",", "y1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x2_", ",", "y2_"}], "}"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"x1", " ", "x2"}], "-", 
     RowBox[{"y1", " ", "y2"}]}], ",", 
    RowBox[{
     RowBox[{"x1", " ", "y2"}], " ", "+", " ", 
     RowBox[{"y1", " ", "x2"}]}]}], "  ", "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.607335165998993*^9, 3.607335166805889*^9}, {
  3.7216083845808773`*^9, 3.721608384585897*^9}, {3.740596654616102*^9, 
  3.740596678232183*^9}, {3.740596718955402*^9, 3.740596785534597*^9}, {
  3.740597102004189*^9, 3.740597106611924*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"87ef30c6-2a04-4375-a307-5c16f065de84"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"y", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", "-", " ", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{"y", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"y", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{"y", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x1", ",", "y1"}], "}"}]}], ",", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x2", ",", " ", "y2"}], "}"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.740597113491383*^9, 3.740597151307664*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"b1385f34-7d59-4297-8850-b9193b5f3ccd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"x1", " ", "x2"}], "-", 
    RowBox[{"y1", " ", "y2"}]}], ",", 
   RowBox[{
    RowBox[{"x2", " ", "y1"}], "+", 
    RowBox[{"x1", " ", "y2"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7405971516988277`*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"f8b8eb7f-79a6-4a21-a7c0-d1fea2969620"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cinverse", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_"}], "}"}], "]"}], " ", ":=", 
  RowBox[{"{", 
   RowBox[{"x", ",", 
    RowBox[{"-", "y"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6010504058267193`*^9, 3.60105047264388*^9}, {
  3.60733516021141*^9, 3.6073351609632874`*^9}, {3.740596635783741*^9, 
  3.7405966495755444`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"3cd3795d-ffee-4a9f-9074-1ff2fcdeba6f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qprod", "[", 
   RowBox[{"q_List", ",", "p_List"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
      "-", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
      "-", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
      "-", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{
       "p", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}], 
      "-", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{
       "p", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
      "-", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{
       "p", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{"p", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
      "-", 
      RowBox[{
       RowBox[{"q", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
       " ", 
       RowBox[{
       "p", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}]}], 
    "}"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", "q", "]"}], "==", 
    RowBox[{"Length", "[", "p", "]"}], "==", "4"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[38]:=",ExpressionUUID->"02b93f40-7208-40ba-bc64-465a5f8aa2f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qinverse", "[", 
   RowBox[{"{", 
    RowBox[{"w_", ",", "x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", " ", 
  
  RowBox[{"{", 
   RowBox[{"w", ",", 
    RowBox[{"-", "x"}], ",", 
    RowBox[{"-", "y"}], ",", 
    RowBox[{"-", "z"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7027554904319153`*^9, 3.7027555115954933`*^9}, {
  3.706369162010539*^9, 3.706369162426161*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"d52ec479-6515-4a0d-82a5-e31eadf617b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"su2Mat", "[", 
   RowBox[{"{", 
    RowBox[{"w_", ",", "x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", " ", 
  
  RowBox[{
   RowBox[{"w", " ", 
    RowBox[{"IdentityMatrix", "[", "2", "]"}]}], " ", "-", " ", 
   RowBox[{"I", " ", 
    RowBox[{"PauliMatrix", "[", "1", "]"}], "x"}], "-", " ", 
   RowBox[{"I", " ", 
    RowBox[{"PauliMatrix", "[", "2", "]"}], "y"}], "-", " ", 
   RowBox[{"I", " ", 
    RowBox[{"PauliMatrix", "[", "3", "]"}], "z"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.70230460894407*^9, 3.7023046997605658`*^9}, {
  3.706382519195228*^9, 3.706382523899104*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"e15aa61d-869b-47b9-82c7-c1222f8843f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"wxyzFromSu2", "[", "su2_", "]"}], ":=", " ", 
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"su2", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "+", " ", 
      RowBox[{"su2", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", " ", 
     RowBox[{"I", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"su2", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"su2", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"su2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "+", 
      RowBox[{"su2", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", " ", 
     RowBox[{"I", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"su2", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"su2", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], 
    "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.702305936253581*^9, 3.702306115481564*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"ee5959e4-427f-4753-b449-bfb8bb8f1e18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"slerp", "[", 
   RowBox[{"p0_List", ",", "p1_List", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"costh", " ", "=", " ", 
       RowBox[{
        RowBox[{"p0", " ", ".", " ", "p1"}], "//", "Chop"}]}], ",", " ", "th",
       ",", " ", "sinth"}], "}"}], ",", "\[IndentingNewLine]", "  ", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"costh", " ", ">", " ", "0.0"}], ",", 
       RowBox[{"costh", " ", "=", " ", 
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{"costh", " ", "-", "1."}], "]"}], " ", "+", "1."}]}]}], 
      "]"}], ";", "\[IndentingNewLine]", "  ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"costh", " ", "<", " ", "0.0"}], ",", 
       RowBox[{"costh", " ", "=", " ", 
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{"costh", " ", "+", "1."}], "]"}], " ", "-", "1."}]}]}], 
      "]"}], ";", "\[IndentingNewLine]", " ", 
     RowBox[{"th", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"ArcCos", "[", "costh", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"sinth", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"Sin", "[", "th", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"sinth", " ", "==", " ", "0"}], ",", " ", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "t"}], ")"}], "*", "p0"}], " ", "+", " ", 
        RowBox[{"t", "*", "p1"}]}], ",", "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"th", "*", 
             RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}]}], "]"}], "/", "sinth"}], ")"}], 
         "*", "p0"}], " ", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"th", "*", "t"}], "]"}], "/", "sinth"}], ")"}], "*", 
         "p1"}]}]}], " ", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.721745118486598*^9},
 CellLabel->"In[42]:=",ExpressionUUID->"c600e65a-7d41-423b-b8f5-29e82b96c80f"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["How you get ginv.dg in Pauli form:  Curious that 4x4 form is \
\[OpenCurlyDoubleQuote]self-dual\[CloseCurlyDoubleQuote] dG[w,i] = dG[j,k].\n \
  - useful calculation for ginv.dg  cached  ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["here...",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox["\n-----------------------------------------------",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.706369968556184*^9, 3.706369983099846*^9}, {
  3.706444379299036*^9, 3.706444401808895*^9}, {3.7064446182602463`*^9, 
  3.706444659860828*^9}, {3.726324146148785*^9, 
  3.726324169677517*^9}},ExpressionUUID->"e3a52ec5-3c08-44b3-9cce-\
bd8f4f37bc2d"],

Cell[BoxData[
 RowBox[{"dgExpr", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dt", "[", 
            RowBox[{
             RowBox[{"su2Mat", "[", 
              RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "]"}], "/", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox["w", "2"], "+", 
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"], "+", 
               SuperscriptBox["z", "2"]}], "]"}]}], "]"}], "/.", "dtwRule"}], 
          "//", "Simplify"}], ")"}], "/.", "w2rRule"}], "/.", 
       RowBox[{
        SuperscriptBox["w", "2"], "\[Rule]", 
        RowBox[{
         SuperscriptBox["r", "2"], "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"], "-", 
         SuperscriptBox["z", "2"]}]}]}], "/.", "w2rRule"}], "//", " ", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"#", ",", 
        RowBox[{"r", ">", "0"}]}], "]"}], "&"}]}], ")"}], "//", 
   "Together"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.706369997157256*^9, 3.706370022349059*^9}, {
   3.706370055614194*^9, 3.706370078147889*^9}, {3.706370118693338*^9, 
   3.7063701355752077`*^9}, {3.706370195308888*^9, 3.706370287730805*^9}, 
   3.706444379299487*^9},ExpressionUUID->"313ab1c8-e19f-4744-8136-\
f35d85faa684"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"dw", " ", 
        SuperscriptBox["r", "2"]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "dz", " ", 
        SuperscriptBox["r", "2"]}], "-", 
       RowBox[{"dw", " ", 
        SuperscriptBox["w", "2"]}], "-", 
       RowBox[{"dx", " ", "w", " ", "x"}], "-", 
       RowBox[{"dy", " ", "w", " ", "y"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dw", " ", "w", " ", "z"}], "-", 
       RowBox[{"dz", " ", "w", " ", "z"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dx", " ", "x", " ", "z"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dy", " ", "y", " ", "z"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dz", " ", 
        SuperscriptBox["z", "2"]}]}], 
      SuperscriptBox["r", "3"]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "dx", " ", 
        SuperscriptBox["r", "2"]}], "-", 
       RowBox[{"dy", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dw", " ", "w", " ", "x"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dx", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"dw", " ", "w", " ", "y"}], "+", 
       RowBox[{"dx", " ", "x", " ", "y"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dy", " ", "x", " ", "y"}], "+", 
       RowBox[{"dy", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dz", " ", "x", " ", "z"}], "+", 
       RowBox[{"dz", " ", "y", " ", "z"}]}], 
      SuperscriptBox["r", "3"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "dx", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"dy", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dw", " ", "w", " ", "x"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dx", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"dw", " ", "w", " ", "y"}], "-", 
       RowBox[{"dx", " ", "x", " ", "y"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dy", " ", "x", " ", "y"}], "-", 
       RowBox[{"dy", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dz", " ", "x", " ", "z"}], "-", 
       RowBox[{"dz", " ", "y", " ", "z"}]}], 
      SuperscriptBox["r", "3"]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"dw", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "dz", " ", 
        SuperscriptBox["r", "2"]}], "-", 
       RowBox[{"dw", " ", 
        SuperscriptBox["w", "2"]}], "-", 
       RowBox[{"dx", " ", "w", " ", "x"}], "-", 
       RowBox[{"dy", " ", "w", " ", "y"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "dw", " ", "w", " ", "z"}], "-", 
       RowBox[{"dz", " ", "w", " ", "z"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "dx", " ", "x", " ", "z"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "dy", " ", "y", " ", "z"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "dz", " ", 
        SuperscriptBox["z", "2"]}]}], 
      SuperscriptBox["r", "3"]]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7063700070867968`*^9, 3.706370023535597*^9}, {
   3.706370058274374*^9, 3.7063700789028997`*^9}, {3.706370130223847*^9, 
   3.706370136241194*^9}, 3.7063702282695007`*^9, {3.7063702628423567`*^9, 
   3.7063702881956053`*^9}, 
   3.70644437929984*^9},ExpressionUUID->"c82ad0dd-a769-46b2-b271-\
bb5eb9895bf6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"ginverse", " ", ".", " ", "dg"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sigmaGG", " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"su2Mat", "[", 
            RowBox[{"w", ",", 
             RowBox[{"-", "x"}], ",", 
             RowBox[{"-", "y"}], ",", 
             RowBox[{"-", "z"}]}], "]"}], "/", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             SuperscriptBox["w", "2"], "+", 
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "+", 
             SuperscriptBox["z", "2"]}], "]"}]}], ")"}], ".", "dgExpr"}], "//",
         "Simplify"}], ")"}], "/.", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["w", "2"], "+", 
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["z", "2"]}], ")"}], "\[Rule]", 
       SuperscriptBox["r", "2"]}]}], "//", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"#", ",", 
        RowBox[{"r", ">", "0"}]}], "]"}], "&"}]}]}], ";"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.70230572170103*^9, 3.702305824573441*^9}, {
   3.702308152998006*^9, 3.7023081636031446`*^9}, 3.706373811219389*^9, 
   3.706444379300185*^9},ExpressionUUID->"59726641-82d3-4482-97fe-\
76e1a7681b34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"THIS", " ", "is", " ", "the", " ", "Cartan", " ", 
    RowBox[{"matrix", ":"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"wxyzFromSu2", "[", "sigmaGG", "]"}], "//", "Simplify"}], ")"}], 
   "/.", "w2rRule"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.706373821817959*^9, 3.7063738560048027`*^9}, {
   3.706374161873597*^9, 3.706374184261359*^9}, 
   3.706444379300502*^9},ExpressionUUID->"d64d477a-d745-4291-bec9-\
c9226f61c55b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"dx", " ", "w"}], "-", 
     RowBox[{"dw", " ", "x"}], "-", 
     RowBox[{"dz", " ", "y"}], "+", 
     RowBox[{"dy", " ", "z"}]}], 
    SuperscriptBox["r", "2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"dy", " ", "w"}], "+", 
     RowBox[{"dz", " ", "x"}], "-", 
     RowBox[{"dw", " ", "y"}], "-", 
     RowBox[{"dx", " ", "z"}]}], 
    SuperscriptBox["r", "2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"dz", " ", "w"}], "-", 
     RowBox[{"dy", " ", "x"}], "+", 
     RowBox[{"dx", " ", "y"}], "-", 
     RowBox[{"dw", " ", "z"}]}], 
    SuperscriptBox["r", "2"]]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.706373822875849*^9, 3.706373856980118*^9}, 
   3.7064443793008347`*^9},ExpressionUUID->"966ec782-74b7-47ae-b4c7-\
a669232d18e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", 
   RowBox[{"quatmat4", "[", 
    RowBox[{"{", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}], "]"}], "//", 
  "Rest"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7063742577797127`*^9, 3.7063742897344427`*^9}, 
   3.7064443793011713`*^9},ExpressionUUID->"712bf6f3-b95b-4471-9eaf-\
3f7092d89fc5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "x"}], ",", "w", ",", "z", ",", 
     RowBox[{"-", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "y"}], ",", 
     RowBox[{"-", "z"}], ",", "w", ",", "x"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "z"}], ",", "y", ",", 
     RowBox[{"-", "x"}], ",", "w"}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.706374290635689*^9, 
  3.706444379301497*^9},ExpressionUUID->"c6e5a649-e307-4600-b4ad-\
d76da56b7042"],

Cell[BoxData[
 RowBox[{"%", ".", 
  RowBox[{"{", 
   RowBox[{"dw", ",", "dx", ",", "dy", ",", "dz"}], "}"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.706374271486794*^9, 3.70637430613447*^9}, 
   3.706444379301832*^9},ExpressionUUID->"cd24a97b-ec94-4ad7-aaa4-\
3b8018ae7082"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"dx", " ", "w"}], "-", 
    RowBox[{"dw", " ", "x"}], "-", 
    RowBox[{"dz", " ", "y"}], "+", 
    RowBox[{"dy", " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{"dy", " ", "w"}], "+", 
    RowBox[{"dz", " ", "x"}], "-", 
    RowBox[{"dw", " ", "y"}], "-", 
    RowBox[{"dx", " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{"dz", " ", "w"}], "-", 
    RowBox[{"dy", " ", "x"}], "+", 
    RowBox[{"dx", " ", "y"}], "-", 
    RowBox[{"dw", " ", "z"}]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.706374306663931*^9, 
  3.706444379302164*^9},ExpressionUUID->"5aee4ea4-e639-48e2-a149-\
abef2009d8b5"],

Cell[TextData[StyleBox[" You can also get it from the quaternion algebra4x4 \
matrix, but the 4x4 matrices are TRANSPOSES",
 FontSize->16,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.706374200878018*^9, 3.706374234119012*^9}, 
   3.70644437930233*^9},ExpressionUUID->"c0f21a23-23eb-478b-b89b-\
36c8da924e1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Transpose", "[", 
     FractionBox[
      RowBox[{"quatmat4", "[", 
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}], 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox["w", "2"], "+", 
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], "]"}]], "]"}], ".", " ", 
    RowBox[{"Dt", "[", 
     FractionBox[
      RowBox[{"quatmat4", "[", 
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}], 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox["w", "2"], "+", 
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], "]"}]], "]"}]}], "/.", "dtwRule"}], "//", 
  "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.706374340423551*^9, 3.706374380653737*^9}, {
   3.70637464522171*^9, 3.706374677502248*^9}, {3.706374753711286*^9, 
   3.706374775845232*^9}, 
   3.70644437930263*^9},ExpressionUUID->"d5d4ecdf-3d0e-49b5-a836-\
381915f67d69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "dx"}], " ", "w"}], "+", 
       RowBox[{"dw", " ", "x"}], "+", 
       RowBox[{"dz", " ", "y"}], "-", 
       RowBox[{"dy", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "dy"}], " ", "w"}], "-", 
       RowBox[{"dz", " ", "x"}], "+", 
       RowBox[{"dw", " ", "y"}], "+", 
       RowBox[{"dx", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "dz"}], " ", "w"}], "+", 
       RowBox[{"dy", " ", "x"}], "-", 
       RowBox[{"dx", " ", "y"}], "+", 
       RowBox[{"dw", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"dx", " ", "w"}], "-", 
       RowBox[{"dw", " ", "x"}], "-", 
       RowBox[{"dz", " ", "y"}], "+", 
       RowBox[{"dy", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "dz"}], " ", "w"}], "+", 
       RowBox[{"dy", " ", "x"}], "-", 
       RowBox[{"dx", " ", "y"}], "+", 
       RowBox[{"dw", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"dy", " ", "w"}], "+", 
       RowBox[{"dz", " ", "x"}], "-", 
       RowBox[{"dw", " ", "y"}], "-", 
       RowBox[{"dx", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"dy", " ", "w"}], "+", 
       RowBox[{"dz", " ", "x"}], "-", 
       RowBox[{"dw", " ", "y"}], "-", 
       RowBox[{"dx", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"dz", " ", "w"}], "-", 
       RowBox[{"dy", " ", "x"}], "+", 
       RowBox[{"dx", " ", "y"}], "-", 
       RowBox[{"dw", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "dx"}], " ", "w"}], "+", 
       RowBox[{"dw", " ", "x"}], "+", 
       RowBox[{"dz", " ", "y"}], "-", 
       RowBox[{"dy", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"dz", " ", "w"}], "-", 
       RowBox[{"dy", " ", "x"}], "+", 
       RowBox[{"dx", " ", "y"}], "-", 
       RowBox[{"dw", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "dy"}], " ", "w"}], "-", 
       RowBox[{"dz", " ", "x"}], "+", 
       RowBox[{"dw", " ", "y"}], "+", 
       RowBox[{"dx", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"dx", " ", "w"}], "-", 
       RowBox[{"dw", " ", "x"}], "-", 
       RowBox[{"dz", " ", "y"}], "+", 
       RowBox[{"dy", " ", "z"}]}], 
      RowBox[{
       SuperscriptBox["w", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.706374369011723*^9, 3.7063743810093203`*^9}, 
   3.706374680815029*^9, 3.7063747791723423`*^9, 
   3.706444379302959*^9},ExpressionUUID->"b54bbded-4854-4946-84cb-\
b4f1ac6ea972"]
}, Open  ]],

Cell[TextData[StyleBox[" Quaternion Square Root and 4x4 matrix equivalent to \
qprod[p,q]=mat.q",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.70637034553728*^9, 3.706370349641616*^9}, {
  3.7064444647537317`*^9, 3.706444474178091*^9}, {3.726324179445141*^9, 
  3.726324202133089*^9}},ExpressionUUID->"3af17cd1-3833-4524-85e3-\
8cc7394f41cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qsqrt", "[", 
   RowBox[{"{", 
    RowBox[{"w_", ",", "x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox["w", "2"], "+", 
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], "]"}], "+", "w"}], ",", "x", ",", "y", 
     ",", "z"}], "}"}], "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox["w", "2"], "+", 
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["z", "2"]}], "]"}], "+", "w"}], ")"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7058558571898746`*^9, 3.705855871629642*^9}, {
   3.705856022992113*^9, 3.70585609643364*^9}, {3.705857349461767*^9, 
   3.705857373734161*^9}, {3.706370405715294*^9, 3.70637040958636*^9}, 
   3.7063712838714447`*^9},ExpressionUUID->"a8d2c8a1-a1b6-4f54-9bc8-\
b5374e3be367"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"qprod", "[", 
   RowBox[{
    RowBox[{"qsqrt", "[", 
     RowBox[{"{", 
      RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}], ",", 
    RowBox[{"qsqrt", "[", 
     RowBox[{"{", 
      RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}]}], "]"}], "//",
   "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.706370365576667*^9, 3.7063703745220823`*^9}, 
   3.7063713023565474`*^9, {3.7064444246254253`*^9, 
   3.706444428161553*^9}},ExpressionUUID->"3010849a-3b37-4fd3-b91d-\
d07677847819"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]], "Output",
 CellChangeTimes->{
  3.706371304117846*^9},ExpressionUUID->"b235437c-2273-49bd-bce3-\
e952b210960d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "This", " ", "is", " ", "the", " ", "quaternion", " ", "algebra", " ", 
     "matrix"}], ",", " ", 
    RowBox[{"NOT", " ", "the", " ", "Cartan", " ", "matrix"}]}], " ", "*)"}], 
  
  RowBox[{
   RowBox[{"quatmat4", "[", "q_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"w", "=", 
        RowBox[{"q", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"x", "=", 
        RowBox[{"q", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", 
       RowBox[{"y", "=", 
        RowBox[{"q", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ",", 
       RowBox[{"z", "=", 
        RowBox[{"q", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"w", ",", 
         RowBox[{"-", "x"}], ",", 
         RowBox[{"-", "y"}], ",", 
         RowBox[{"-", "z"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "w", ",", 
         RowBox[{"-", "z"}], ",", "y"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "z", ",", "w", ",", 
         RowBox[{"-", "x"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         RowBox[{"-", "y"}], ",", "x", ",", "w"}], "}"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.706145606027413*^9, 3.706145705757617*^9}, {
  3.706374126809566*^9, 3.706374142728066*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"4729d88a-ae2c-44a9-93dd-831e1d438474"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"quatmat4", "[", 
   RowBox[{"{", 
    RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.7061457333771877`*^9, 
  3.706145747248426*^9}},ExpressionUUID->"05fb42c6-6db5-4061-a493-\
4daf109d40f3"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"w", 
      RowBox[{"-", "x"}], 
      RowBox[{"-", "y"}], 
      RowBox[{"-", "z"}]},
     {"x", "w", 
      RowBox[{"-", "z"}], "y"},
     {"y", "z", "w", 
      RowBox[{"-", "x"}]},
     {"z", 
      RowBox[{"-", "y"}], "x", "w"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.706145747965873*^9},ExpressionUUID->"90aa1f45-17fe-4615-81d8-\
164cca898da4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "quaternion", " ", "algebra"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"quatmat4", "[", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "qx", ",", "qy", ",", "qz"}], "}"}], "]"}], ".", 
     RowBox[{"quatmat4", "[", 
      RowBox[{"{", 
       RowBox[{"p0", ",", "px", ",", "py", ",", "pz"}], "}"}], "]"}]}], " ", 
    "-", " ", 
    RowBox[{"quatmat4", "[", 
     RowBox[{"{", 
      RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}]}], "/.", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"qprod", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"q0", ",", "qx", ",", "qy", ",", "qz"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"p0", ",", "px", ",", "py", ",", "pz"}], "}"}]}], "]"}], 
       "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.706373947489629*^9, 3.706374107687336*^9}, {
  3.7064445447229652`*^9, 
  3.706444553650879*^9}},ExpressionUUID->"53b3c949-d43b-4684-b078-\
18e19f5205e2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.70637411613975*^9},ExpressionUUID->"d649776a-eb38-4099-866d-9f84689ba05f"]
}, Open  ]],

Cell[TextData[{
 StyleBox[" 4D  p*X*qbar version:   this is consistent, uncorrected quatbook \
is ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["INCONSISTENT",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.726367551764452*^9, 3.726367554300931*^9}, {
  3.72636909029069*^9, 3.726369095731022*^9}, {3.726369126906068*^9, 
  3.726369150801709*^9}, {3.740597307217979*^9, 
  3.740597309657567*^9}},ExpressionUUID->"94086087-c539-4056-9bde-\
423c381abf9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "is", " ", "the", " ", "\"\<new correct\>\"", " ", 
      "version", " ", "of", " ", "SO", 
      RowBox[{"(", "4", ")"}]}], " ", "=", " ", "SU2xSU2"}], ",", "  ", 
    RowBox[{
    "p", "*", "X", "*", "qbar", "\[IndentingNewLine]", "     ", "and", " ", 
     "is", " ", "PRECISELY", " ", "Eq", " ", "29.2"}], ",", "  ", 
    RowBox[{
    "so", " ", "29.2", " ", "is", " ", "NOT", " ", "matching", " ", "the", 
     " ", "preceding", " ", "q", "*", "V", "*", "pbar", " ", 
     RowBox[{"eqn", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"PQbTo4DRot", "[", 
    RowBox[{"p_List", ",", "q_List"}], "]"}], " ", ":=", "\n", "  ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p0", "=", " ", 
        RowBox[{"p", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
       RowBox[{"p1", "=", 
        RowBox[{"p", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
       RowBox[{"p2", " ", "=", " ", 
        RowBox[{"p", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ",", " ", 
       RowBox[{"p3", " ", "=", " ", 
        RowBox[{"p", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"q0", "=", " ", 
        RowBox[{"q", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
       RowBox[{"q1", "=", 
        RowBox[{"q", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
       RowBox[{"q2", " ", "=", " ", 
        RowBox[{"q", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ",", " ", 
       RowBox[{"q3", " ", "=", " ", 
        RowBox[{"q", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", "\n", "        ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"p0", " ", "q0"}], "+", 
          RowBox[{"p1", " ", "q1"}], "+", 
          RowBox[{"p2", " ", "q2"}], "+", 
          RowBox[{"p3", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], " ", "q0"}], "+", 
          RowBox[{"p0", " ", "q1"}], "+", 
          RowBox[{"p3", " ", "q2"}], "-", 
          RowBox[{"p2", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p2"}], " ", "q0"}], "-", 
          RowBox[{"p3", " ", "q1"}], "+", 
          RowBox[{"p0", " ", "q2"}], "+", 
          RowBox[{"p1", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p3"}], " ", "q0"}], "+", 
          RowBox[{"p2", " ", "q1"}], "-", 
          RowBox[{"p1", " ", "q2"}], "+", 
          RowBox[{"p0", " ", "q3"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"p1", " ", "q0"}], "-", 
          RowBox[{"p0", " ", "q1"}], "+", 
          RowBox[{"p3", " ", "q2"}], "-", 
          RowBox[{"p2", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{"p0", " ", "q0"}], "+", 
          RowBox[{"p1", " ", "q1"}], "-", 
          RowBox[{"p2", " ", "q2"}], "-", 
          RowBox[{"p3", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p3"}], " ", "q0"}], "+", 
          RowBox[{"p2", " ", "q1"}], "+", 
          RowBox[{"p1", " ", "q2"}], "-", 
          RowBox[{"p0", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{"p2", " ", "q0"}], "+", 
          RowBox[{"p3", " ", "q1"}], "+", 
          RowBox[{"p0", " ", "q2"}], "+", 
          RowBox[{"p1", " ", "q3"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"p2", " ", "q0"}], "-", 
          RowBox[{"p3", " ", "q1"}], "-", 
          RowBox[{"p0", " ", "q2"}], "+", 
          RowBox[{"p1", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{"p3", " ", "q0"}], "+", 
          RowBox[{"p2", " ", "q1"}], "+", 
          RowBox[{"p1", " ", "q2"}], "+", 
          RowBox[{"p0", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{"p0", " ", "q0"}], "-", 
          RowBox[{"p1", " ", "q1"}], "+", 
          RowBox[{"p2", " ", "q2"}], "-", 
          RowBox[{"p3", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], " ", "q0"}], "-", 
          RowBox[{"p0", " ", "q1"}], "+", 
          RowBox[{"p3", " ", "q2"}], "+", 
          RowBox[{"p2", " ", "q3"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"p3", " ", "q0"}], "+", 
          RowBox[{"p2", " ", "q1"}], "-", 
          RowBox[{"p1", " ", "q2"}], "-", 
          RowBox[{"p0", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p2"}], " ", "q0"}], "+", 
          RowBox[{"p3", " ", "q1"}], "-", 
          RowBox[{"p0", " ", "q2"}], "+", 
          RowBox[{"p1", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{"p1", " ", "q0"}], "+", 
          RowBox[{"p0", " ", "q1"}], "+", 
          RowBox[{"p3", " ", "q2"}], "+", 
          RowBox[{"p2", " ", "q3"}]}], ",", 
         RowBox[{
          RowBox[{"p0", " ", "q0"}], "-", 
          RowBox[{"p1", " ", "q1"}], "-", 
          RowBox[{"p2", " ", "q2"}], "+", 
          RowBox[{"p3", " ", "q3"}]}]}], "}"}]}], "}"}]}], "]"}]}]}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.726367301148354*^9, 3.7263673339817343`*^9}, {
  3.726368675528162*^9, 3.726368740479024*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"b386e61c-41ed-4b66-97ae-23235a6e2efc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PQbTo4DRot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], " ", "-", " ", 
   RowBox[{"qprod", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
     RowBox[{"qprod", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", 
         RowBox[{"-", "q1"}], ",", 
         RowBox[{"-", "q2"}], ",", 
         RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.726367357994883*^9, 
  3.7263674083188963`*^9}},ExpressionUUID->"3d06ba70-a6bf-4263-b908-\
a5e255b970a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.726367408881938*^9},ExpressionUUID->"92c0ae0b-4791-48f6-8561-\
445b205c9e9c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["What are the eigenvectors of SO4 matrix?  {q1,q2,q3} \
is the SO3 eigenvector, eigenvalue \[OpenCurlyDoubleQuote]1\
\[CloseCurlyDoubleQuote].\n=======================================",
 FontSize->18,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739289327752029*^9, 3.739289358316525*^9}, 
   3.7405972560261097`*^9, {3.740597291609174*^9, 
   3.7405972950744247`*^9}},ExpressionUUID->"9eaeb7c8-c247-429f-85de-\
fad15bd67612"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Eigensystem", "[", 
       RowBox[{"QuatToRot", "[", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], "]"}],
       "//", "Simplify"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q0", "2"], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", " ", 
       RowBox[{"1", " ", "-", " ", 
        SuperscriptBox["q0", "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q1", "2"]}], "-", 
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["q3", "2"]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", " ", "1"}], " ", "+", " ", 
        SuperscriptBox["q0", "2"]}]}]}], "}"}]}], "/.", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", " ", 
    RowBox[{"1", " ", "-", " ", 
     SuperscriptBox["q0", "2"]}]}]}], "//", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"#", ",", 
     RowBox[{"q0", ">", "0"}]}], "]"}], "&"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739289398715255*^9, 3.739289553110538*^9}, 
   3.740597256026773*^9},
 CellLabel->"In[44]:=",ExpressionUUID->"d8039ebd-1804-460f-b335-9f97966598f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["q0", "2"]}], "-", 
      RowBox[{"2", " ", "q0", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["q0", "2"]}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["q0", "2"]}], "+", 
      RowBox[{"2", " ", "q0", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["q0", "2"]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["q1", "q3"], ",", 
       FractionBox["q2", "q3"], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "q0"}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["q0", "2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["q2", "2"], "+", 
           SuperscriptBox["q3", "2"]}], ")"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["q0", "2"], "+", 
            RowBox[{"q0", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["q0", "2"]}]]}]}], ")"}], " ", "q2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"q0", "-", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["q0", "2"]}]]}], ")"}], " ", "q1", " ", 
          "q3"}]}]], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "q0"}], " ", "q1", " ", "q2"}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["q0", "2"]}]], " ", "q1", " ", "q2"}], "+", "q3", 
          "-", 
          RowBox[{
           SuperscriptBox["q0", "2"], " ", "q3"}], "+", 
          RowBox[{"q0", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["q0", "2"]}]], " ", "q3"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["q0", "2"], "+", 
             RowBox[{"q0", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["q0", "2"]}]]}]}], ")"}], " ", "q2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q0", "-", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["q0", "2"]}]]}], ")"}], " ", "q1", " ", 
           "q3"}]}]]}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"q0", "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["q0", "2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["q2", "2"], "+", 
           SuperscriptBox["q3", "2"]}], ")"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["q0", "2"], "+", 
            RowBox[{"q0", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["q0", "2"]}]]}]}], ")"}], " ", "q2"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"q0", "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["q0", "2"]}]]}], ")"}], " ", "q1", " ", 
          "q3"}]}]], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"q0", " ", "q1", " ", "q2"}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["q0", "2"]}]], " ", "q1", " ", "q2"}], "-", "q3", 
          "+", 
          RowBox[{
           SuperscriptBox["q0", "2"], " ", "q3"}], "+", 
          RowBox[{"q0", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["q0", "2"]}]], " ", "q3"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["q0", "2"], "+", 
             RowBox[{"q0", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["q0", "2"]}]]}]}], ")"}], " ", "q2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q0", "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["q0", "2"]}]]}], ")"}], " ", "q1", " ", 
           "q3"}]}]]}], ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.739289409974841*^9, 3.739289472107456*^9, {3.739289526582899*^9, 
   3.739289556191893*^9}, 3.740597256027443*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"7d38776d-cdf7-4b4a-8102-eb206276ebe8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"SO3", " ", "is", " ", "easy"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"QuatToRot", "[", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], ".", 
      RowBox[{"{", 
       RowBox[{"q1", ",", "q2", ",", "q3"}], "}"}]}], "//", "Simplify"}], 
    ")"}], "/.", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739288860614254*^9, 3.7392889207208633`*^9}, {
   3.739289371975585*^9, 3.739289375606674*^9}, 
   3.740597256028083*^9},ExpressionUUID->"ec686e09-4e03-4863-bd9f-\
af3af7fe6b4f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"q1", ",", "q2", ",", "q3"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7392888877923317`*^9, 3.739288921645935*^9}, 
   3.7405972560287027`*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"7d26e16d-c532-414c-a99c-df9ed51b1ae1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"SO4", " ", "Intractable"}], " ", "-", " ", 
    RowBox[{"4", "th", " ", "roots"}]}], "  ", "*)"}], " ", 
  RowBox[{
   RowBox[{"Eigenvalues", "[", 
    RowBox[{"PQbTo4DRot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "]"}],
    "//", "Simplify"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739288772310657*^9, 3.739288783784615*^9}, {
   3.739288823350067*^9, 3.73928884019191*^9}, {3.739289388148382*^9, 
   3.73928938950034*^9}, 
   3.740597256029357*^9},ExpressionUUID->"ecd5792a-6168-4032-a039-\
f421283cd23e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Root", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["p0", "3"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}]}], ")"}], " ", "#1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q3", "2"]}]}], ")"}], " ", 
        SuperscriptBox["#1", "2"]}], "-", 
       RowBox[{"4", " ", "p0", " ", "q0", " ", 
        SuperscriptBox["#1", "3"]}], "+", 
       SuperscriptBox["#1", "4"]}], "&"}], ",", "1"}], "]"}], ",", 
   RowBox[{"Root", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["p0", "3"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}]}], ")"}], " ", "#1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q3", "2"]}]}], ")"}], " ", 
        SuperscriptBox["#1", "2"]}], "-", 
       RowBox[{"4", " ", "p0", " ", "q0", " ", 
        SuperscriptBox["#1", "3"]}], "+", 
       SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}], ",", 
   RowBox[{"Root", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["p0", "3"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}]}], ")"}], " ", "#1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q3", "2"]}]}], ")"}], " ", 
        SuperscriptBox["#1", "2"]}], "-", 
       RowBox[{"4", " ", "p0", " ", "q0", " ", 
        SuperscriptBox["#1", "3"]}], "+", 
       SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], ",", 
   RowBox[{"Root", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q0", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q1", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q2", "2"], " ", 
        SuperscriptBox["q3", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p0", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "4"], " ", 
        SuperscriptBox["q3", "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["p0", "3"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q0", "3"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["p0", "3"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p1", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p2", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"4", " ", "p0", " ", 
           SuperscriptBox["p3", "2"], " ", "q0", " ", 
           SuperscriptBox["q3", "2"]}]}], ")"}], " ", "#1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q0", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q1", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p0", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["q3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["p3", "2"], " ", 
           SuperscriptBox["q3", "2"]}]}], ")"}], " ", 
        SuperscriptBox["#1", "2"]}], "-", 
       RowBox[{"4", " ", "p0", " ", "q0", " ", 
        SuperscriptBox["#1", "3"]}], "+", 
       SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], 
  "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.739288787706852*^9, 3.740597256029991*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"2670487b-3385-4219-8c42-5fedd8269f3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"PQbTo4DRot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".", 
     
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "//", 
    "Simplify"}], ")"}], "/.", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["q0", "2"], "+", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7392889497440987`*^9, 3.739288964880068*^9}, 
   3.740597256030221*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"d03a8885-e85f-4f6b-832e-39b4d0d0db0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7392889687927923`*^9, 3.740597256030447*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"72431feb-5f40-4851-a045-c3e04e3839a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PQbTo4DRot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], 
       ".", 
       RowBox[{"{", 
        RowBox[{"p0", ",", 
         RowBox[{"-", "p1"}], ",", 
         RowBox[{"-", "p2"}], ",", 
         RowBox[{"-", "p3"}]}], "}"}]}], "//", "Simplify"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       SuperscriptBox["p1", "2"], "+", 
       SuperscriptBox["p2", "2"], "+", 
       SuperscriptBox["p3", "2"]}], ")"}], "\[Rule]", 
     RowBox[{"1", "-", 
      SuperscriptBox["p0", "2"]}]}]}], "//", "Expand"}], "//", 
  "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7392889890605392`*^9, {3.73928902978065*^9, 3.739289087550159*^9}, 
   3.740597256030674*^9},
 CellLabel->"In[38]:=",ExpressionUUID->"30392f69-dbfd-493a-8e5e-148203044a13"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"q0", ",", 
   RowBox[{"-", "q1"}], ",", 
   RowBox[{"-", "q2"}], ",", 
   RowBox[{"-", "q3"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7392889936291027`*^9, {3.739289036849551*^9, 3.739289089078376*^9}, 
   3.740597256030908*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"1dc9496e-3261-4c8f-a6ab-0c7d0672e4ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ".", 
     RowBox[{"PQbTo4DRot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}]}], "//",
     "Simplify"}], ")"}], "/.", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     SuperscriptBox["p0", "2"], "+", 
     SuperscriptBox["p1", "2"], "+", 
     SuperscriptBox["p2", "2"], "+", 
     SuperscriptBox["p3", "2"]}], ")"}], "\[Rule]", "1"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.73928913474293*^9, 3.7392891765789223`*^9}, 
   3.7405972560311337`*^9},
 CellLabel->"In[40]:=",ExpressionUUID->"04ff1977-2449-4edf-9a9e-0cdacff2ffdd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.739289177028461*^9, 3.7405972560313597`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"88ed134e-2da5-454f-aa80-41baa8d2d91a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Replace", " ", "paper", " ", "text"}], " ", "*)"}], 
  RowBox[{"StringReplace", "[", 
   RowBox[{
    RowBox[{"ToString", "[", 
     RowBox[{
      RowBox[{"PQbTo4DRot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//",
       "TeXForm"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<\\\\text{p0}\>\"", "\[Rule]", " ", "\"\<p_0\>\""}], ",", 
      RowBox[{"\"\<\\\\text{p1}\>\"", "\[Rule]", " ", "\"\<p_1\>\""}], ",", 
      RowBox[{"\"\<\\\\text{p2}\>\"", "\[Rule]", "\"\<p_2\>\""}], ",", 
      RowBox[{"\"\<\\\\text{p3}\>\"", "\[Rule]", "\"\<p_3\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<\\\\text{q0}\>\"", "\[Rule]", " ", "\"\<q_0\>\""}], ",", 
      RowBox[{"\"\<\\\\text{q1}\>\"", "\[Rule]", " ", "\"\<q_1\>\""}], ",", 
      RowBox[{"\"\<\\\\text{q2}\>\"", "\[Rule]", "\"\<q_2\>\""}], ",", 
      RowBox[{"\"\<\\\\text{q3}\>\"", "\[Rule]", "\"\<q_3\>\""}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.72636806820463*^9, 3.726368175639557*^9}, {
   3.726369054863927*^9, 3.726369063941592*^9}, 
   3.7405972560315857`*^9},ExpressionUUID->"54fe3d21-183d-43ce-aeac-\
bc186495a0c9"],

Cell[BoxData["\<\"\\\\left(\\n\\\\begin{array}{cccc}\\n p_0 q_0+p_1 q_1+p_2 \
q_2+p_3 q_3 & -p_1 q_0+p_0 q_1+p_3 q_2-p_2 q_3 & -p_2 q_0-p_3 q_1+p_0 q_2+p_1 \
q_3 & -p_3 q_0+p_2 q_1-p_1 q_2+p_0 q_3 \\\\\\\\\\n p_1 q_0-p_0 q_1+p_3 \
q_2-p_2 q_3 & p_0 q_0+p_1 q_1-p_2 q_2-p_3 q_3 & -p_3 q_0+p_2 q_1+p_1 q_2-p_0 \
q_3 & p_2 q_0+p_3 q_1+p_0 q_2+p_1 q_3 \\\\\\\\\\n p_2 q_0-p_3 q_1-p_0 q_2+p_1 \
q_3 & p_3 q_0+p_2 q_1+p_1 q_2+p_0 q_3 & p_0 q_0-p_1 q_1+p_2 q_2-p_3 q_3 & \
-p_1 q_0-p_0 q_1+p_3 q_2+p_2 q_3 \\\\\\\\\\n p_3 q_0+p_2 q_1-p_1 q_2-p_0 q_3 \
& -p_2 q_0+p_3 q_1-p_0 q_2+p_1 q_3 & p_1 q_0+p_0 q_1+p_3 q_2+p_2 q_3 & p_0 \
q_0-p_1 q_1-p_2 q_2+p_3 q_3 \\\\\\\\\\n\\\\end{array}\\n\\\\right)\"\>"], \
"Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.726369037165016*^9, 3.726369065937458*^9}, 
   3.7405972560318127`*^9},ExpressionUUID->"e9c61812-4dbc-47ad-9fd4-\
5450c8eef737"],

Cell[BoxData[" "], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7263690764230757`*^9, 
  3.740597256032053*^9},ExpressionUUID->"c7536897-61ad-4c43-a90e-\
727ea342a540"],

Cell[TextData[StyleBox["WRONG...",
 FontSize->18,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7392896986492033`*^9, 3.7392897025690193`*^9}, 
   3.740597256032199*^9},ExpressionUUID->"c2618caa-ede1-4660-8233-\
ba134ac90890"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Derive", " ", "the", " ", "wrong"}], "-", "arg", "-", 
      RowBox[{"order", " ", "quaternion", " ", "SO", 
       RowBox[{"(", "4", ")"}]}]}], " ", "=", " ", 
     RowBox[{
     "SU2xSU2", "\[IndentingNewLine]", "  ", "This", " ", "is", " ", "the", 
      " ", "QuatBook", " ", "Table", " ", "29.1", " ", "version"}]}], ",", 
    " ", 
    RowBox[{"but", " ", "the", " ", "form", " ", "has", " ", "p"}], ",", 
    RowBox[{"q", " ", "REVERSED"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"qprod", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q0", ",", "qx", ",", "qy", ",", "qz"}], "}"}], ",", 
     RowBox[{"qprod", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"p0", ",", 
         RowBox[{"-", "px"}], ",", 
         RowBox[{"-", "py"}], ",", 
         RowBox[{"-", "pz"}]}], "}"}]}], "]"}]}], "]"}], ";"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.705626424103835*^9, 3.705626479651483*^9}, {
   3.70636922331435*^9, 3.706369242817824*^9}, 3.706369283505323*^9, {
   3.706444579764145*^9, 3.706444582163825*^9}, {3.726367247313779*^9, 
   3.726367266880848*^9}, {3.726367509462207*^9, 3.726367516973921*^9}, {
   3.726368661179084*^9, 
   3.726368665047956*^9}},ExpressionUUID->"c9e59cb5-490a-44a6-ab5d-\
ccb074754947"],

Cell[BoxData[
 RowBox[{"mat4", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"xp", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", "#"}], "]"}], "&"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.705626493447507*^9, 3.7056265372997828`*^9}, 
   3.70636928350581*^9},ExpressionUUID->"9b8db173-f303-4672-99c9-\
df41e03a9a8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "+", 
      RowBox[{"px", " ", "qx"}], "+", 
      RowBox[{"py", " ", "qy"}], "+", 
      RowBox[{"pz", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"px", " ", "q0"}], "-", 
      RowBox[{"p0", " ", "qx"}], "-", 
      RowBox[{"pz", " ", "qy"}], "+", 
      RowBox[{"py", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"py", " ", "q0"}], "+", 
      RowBox[{"pz", " ", "qx"}], "-", 
      RowBox[{"p0", " ", "qy"}], "-", 
      RowBox[{"px", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"pz", " ", "q0"}], "-", 
      RowBox[{"py", " ", "qx"}], "+", 
      RowBox[{"px", " ", "qy"}], "-", 
      RowBox[{"p0", " ", "qz"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "px"}], " ", "q0"}], "+", 
      RowBox[{"p0", " ", "qx"}], "-", 
      RowBox[{"pz", " ", "qy"}], "+", 
      RowBox[{"py", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "+", 
      RowBox[{"px", " ", "qx"}], "-", 
      RowBox[{"py", " ", "qy"}], "-", 
      RowBox[{"pz", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "pz"}], " ", "q0"}], "+", 
      RowBox[{"py", " ", "qx"}], "+", 
      RowBox[{"px", " ", "qy"}], "-", 
      RowBox[{"p0", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"py", " ", "q0"}], "+", 
      RowBox[{"pz", " ", "qx"}], "+", 
      RowBox[{"p0", " ", "qy"}], "+", 
      RowBox[{"px", " ", "qz"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "py"}], " ", "q0"}], "+", 
      RowBox[{"pz", " ", "qx"}], "+", 
      RowBox[{"p0", " ", "qy"}], "-", 
      RowBox[{"px", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"pz", " ", "q0"}], "+", 
      RowBox[{"py", " ", "qx"}], "+", 
      RowBox[{"px", " ", "qy"}], "+", 
      RowBox[{"p0", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "-", 
      RowBox[{"px", " ", "qx"}], "+", 
      RowBox[{"py", " ", "qy"}], "-", 
      RowBox[{"pz", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "px"}], " ", "q0"}], "-", 
      RowBox[{"p0", " ", "qx"}], "+", 
      RowBox[{"pz", " ", "qy"}], "+", 
      RowBox[{"py", " ", "qz"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "pz"}], " ", "q0"}], "-", 
      RowBox[{"py", " ", "qx"}], "+", 
      RowBox[{"px", " ", "qy"}], "+", 
      RowBox[{"p0", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "py"}], " ", "q0"}], "+", 
      RowBox[{"pz", " ", "qx"}], "-", 
      RowBox[{"p0", " ", "qy"}], "+", 
      RowBox[{"px", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"px", " ", "q0"}], "+", 
      RowBox[{"p0", " ", "qx"}], "+", 
      RowBox[{"pz", " ", "qy"}], "+", 
      RowBox[{"py", " ", "qz"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "-", 
      RowBox[{"px", " ", "qx"}], "-", 
      RowBox[{"py", " ", "qy"}], "+", 
      RowBox[{"pz", " ", "qz"}]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.705626538067398*^9, 
  3.706369283506343*^9},ExpressionUUID->"d7e9bb88-0021-4757-af1b-\
eb964628d323"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "questionable", " ", "*)"}], " ", 
  RowBox[{
   RowBox[{"QQTo4DRot", "[", 
    RowBox[{"p_List", ",", "q_List"}], "]"}], " ", ":=", "\n", "  ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q0", "=", " ", 
        RowBox[{"q", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
       RowBox[{"q1", "=", 
        RowBox[{"q", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
       RowBox[{"q2", " ", "=", " ", 
        RowBox[{"q", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ",", " ", 
       RowBox[{"q3", " ", "=", " ", 
        RowBox[{"q", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], ",", "\n", "         ", 
       RowBox[{"p0", "=", " ", 
        RowBox[{"p", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
       RowBox[{"p1", "=", 
        RowBox[{"p", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
       RowBox[{"p2", " ", "=", " ", 
        RowBox[{"p", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ",", " ", 
       RowBox[{"p3", " ", "=", " ", 
        RowBox[{"p", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", "\n", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"p0", "*", "q0"}], " ", "+", " ", 
          RowBox[{"p1", "*", "q1"}], " ", "+", " ", 
          RowBox[{"p2", "*", "q2"}], " ", "+", " ", 
          RowBox[{"p3", "*", "q3"}]}], ",", " ", 
         RowBox[{
          RowBox[{"p1", "*", "q0"}], " ", "-", " ", 
          RowBox[{"p0", "*", "q1"}], " ", "-", " ", 
          RowBox[{"p3", "*", "q2"}], " ", "+", " ", 
          RowBox[{"p2", "*", "q3"}]}], ",", " ", "\n", "            ", 
         RowBox[{
          RowBox[{"p2", "*", "q0"}], " ", "+", " ", 
          RowBox[{"p3", "*", "q1"}], " ", "-", " ", 
          RowBox[{"p0", "*", "q2"}], " ", "-", " ", 
          RowBox[{"p1", "*", "q3"}]}], ",", " ", 
         RowBox[{
          RowBox[{"p3", "*", "q0"}], " ", "-", " ", 
          RowBox[{"p2", "*", "q1"}], " ", "+", " ", 
          RowBox[{"p1", "*", "q2"}], " ", "-", " ", 
          RowBox[{"p0", "*", "q3"}]}]}], "}"}], ",", " ", "\n", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"p1", "*", "q0"}], ")"}]}], " ", "+", " ", 
           RowBox[{"p0", "*", "q1"}], " ", "-", " ", 
           RowBox[{"p3", "*", "q2"}], " ", "+", " ", 
           RowBox[{"p2", "*", "q3"}]}], ")"}], ",", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p0", "*", "q0"}], " ", "+", " ", 
           RowBox[{"p1", "*", "q1"}], " ", "-", " ", 
           RowBox[{"p2", "*", "q2"}], " ", "-", " ", 
           RowBox[{"p3", "*", "q3"}]}], ")"}], ",", " ", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"p3", "*", "q0"}], ")"}]}], " ", "+", " ", 
           RowBox[{"p2", "*", "q1"}], " ", "+", " ", 
           RowBox[{"p1", "*", "q2"}], " ", "-", " ", 
           RowBox[{"p0", "*", "q3"}]}], ")"}], ",", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2", "*", "q0"}], " ", "+", " ", 
           RowBox[{"p3", "*", "q1"}], " ", "+", " ", 
           RowBox[{"p0", "*", "q2"}], " ", "+", " ", 
           RowBox[{"p1", "*", "q3"}]}], ")"}]}], "}"}], ",", " ", "\n", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"p2", "*", "q0"}], ")"}]}], " ", "+", " ", 
           RowBox[{"p3", "*", "q1"}], " ", "+", " ", 
           RowBox[{"p0", "*", "q2"}], " ", "-", " ", 
           RowBox[{"p1", "*", "q3"}]}], ")"}], ",", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p3", "*", "q0"}], " ", "+", " ", 
           RowBox[{"p2", "*", "q1"}], " ", "+", " ", 
           RowBox[{"p1", "*", "q2"}], " ", "+", " ", 
           RowBox[{"p0", "*", "q3"}]}], ")"}], ",", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p0", "*", "q0"}], " ", "-", " ", 
           RowBox[{"p1", "*", "q1"}], " ", "+", " ", 
           RowBox[{"p2", "*", "q2"}], " ", "-", " ", 
           RowBox[{"p3", "*", "q3"}]}], ")"}], ",", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"p1", "*", "q0"}], ")"}]}], " ", "-", " ", 
           RowBox[{"p0", "*", "q1"}], " ", "+", " ", 
           RowBox[{"p3", "*", "q2"}], " ", "+", " ", 
           RowBox[{"p2", "*", "q3"}]}], ")"}]}], "}"}], ",", " ", "\n", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"p3", "*", "q0"}], ")"}]}], " ", "-", " ", 
           RowBox[{"p2", "*", "q1"}], " ", "+", " ", 
           RowBox[{"p1", "*", "q2"}], " ", "+", " ", 
           RowBox[{"p0", "*", "q3"}]}], ")"}], ",", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"p2", "*", "q0"}], ")"}]}], " ", "+", " ", 
           RowBox[{"p3", "*", "q1"}], " ", "-", " ", 
           RowBox[{"p0", "*", "q2"}], " ", "+", " ", 
           RowBox[{"p1", "*", "q3"}]}], ")"}], ",", " ", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", "*", "q0"}], " ", "+", " ", 
           RowBox[{"p0", "*", "q1"}], " ", "+", " ", 
           RowBox[{"p3", "*", "q2"}], " ", "+", " ", 
           RowBox[{"p2", "*", "q3"}]}], ")"}], ",", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p0", "*", "q0"}], " ", "-", " ", 
           RowBox[{"p1", "*", "q1"}], " ", "-", " ", 
           RowBox[{"p2", "*", "q2"}], " ", "+", " ", 
           RowBox[{"p3", "*", "q3"}]}], ")"}]}], "}"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.584377109633025*^9, 3.584377109634099*^9}, {
   3.7263674900842743`*^9, 3.726367498978282*^9}, 
   3.740597256032406*^9},ExpressionUUID->"b75942f0-ab45-4de6-832a-\
976c1700b16f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"QQTo4DRot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], " ", "-", "  ", 
   RowBox[{"qprod", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
     RowBox[{"qprod", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"p0", ",", 
         RowBox[{"-", "p1"}], ",", 
         RowBox[{"-", "p2"}], ",", 
         RowBox[{"-", "p3"}]}], "}"}]}], "]"}]}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.726367357994883*^9, 3.726367427042651*^9}, {
   3.726367462275023*^9, 3.726367470295368*^9}, 
   3.74059725603262*^9},ExpressionUUID->"bdc4bd6a-80d3-4f77-8dbd-\
94a61b6e530f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.726367434697905*^9, 3.726367479679865*^9, 
  3.740597256032858*^9},ExpressionUUID->"e0c1dbb6-fa54-4672-b594-\
7f429e10e108"]
}, Open  ]],

Cell[TextData[StyleBox[" 3D version: this is consistent.",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726367551764452*^9, 3.726367554300931*^9}, {
  3.72636909029069*^9, 
  3.726369095731022*^9}},ExpressionUUID->"b7b2c110-6e58-421e-8469-\
db16d2735ee4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuatToRot", "[", "q_List", "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q0", "=", " ", 
       RowBox[{"q", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
      RowBox[{"q1", "=", 
       RowBox[{"q", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
      RowBox[{"q2", " ", "=", " ", 
       RowBox[{"q", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ",", " ", 
      RowBox[{"q3", " ", "=", " ", 
       RowBox[{"q", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", "\n", "   ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"d23", " ", "=", " ", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ",", " ", 
        RowBox[{"d1", " ", "=", " ", 
         RowBox[{"2", " ", "q0", " ", "q1"}]}], ",", "\n", "          ", 
        RowBox[{"d31", " ", "=", " ", 
         RowBox[{"2", " ", "q3", " ", "q1"}]}], ",", " ", 
        RowBox[{"d2", " ", "=", " ", 
         RowBox[{"2", " ", "q0", " ", "q2"}]}], ",", "\n", "          ", 
        RowBox[{"d12", " ", "=", " ", 
         RowBox[{"2", " ", "q1", " ", "q2"}]}], ",", " ", 
        RowBox[{"d3", " ", "=", " ", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", "\n", "          ", 
        RowBox[{"q0sq", " ", "=", " ", 
         RowBox[{"q0", "^", "2"}]}], ",", " ", 
        RowBox[{"q1sq", " ", "=", " ", 
         RowBox[{"q1", "^", "2"}]}], ",", " ", 
        RowBox[{"q2sq", " ", "=", " ", 
         RowBox[{"q2", "^", "2"}]}], ",", " ", 
        RowBox[{"q3sq", " ", "=", " ", 
         RowBox[{"q3", "^", "2"}]}]}], "}"}], ",", "\n", "          ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "q0sq", " ", "+", " ", "q1sq", " ", "-", " ", "q2sq", " ", "-", " ",
            "q3sq"}], ",", " ", 
          RowBox[{"d12", " ", "-", " ", "d3"}], ",", " ", 
          RowBox[{"d31", " ", "+", " ", "d2"}]}], "}"}], ",", "\n", 
        "           ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"d12", " ", "+", " ", "d3"}], ",", " ", 
          RowBox[{
          "q0sq", " ", "-", " ", "q1sq", " ", "+", " ", "q2sq", " ", "-", " ",
            "q3sq"}], ",", " ", 
          RowBox[{"d23", " ", "-", " ", "d1"}]}], "}"}], ",", "\n", 
        "           ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"d31", " ", "-", " ", "d2"}], ",", " ", 
          RowBox[{"d23", " ", "+", " ", "d1"}], ",", " ", 
          RowBox[{
          "q0sq", " ", "-", " ", "q1sq", " ", "-", " ", "q2sq", " ", "+", " ",
            "q3sq"}]}], "}"}]}], "}"}]}], " ", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.584375516593762*^9, 3.584375516595628*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"aeef4b89-aac9-4416-ba20-4c37d3f66fd2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qprod", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.728732226588317*^9, 
  3.72873224031117*^9}},ExpressionUUID->"0b333c87-1c40-41bf-874a-\
dac61eefd811"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"p0", " ", "q0"}], "-", 
    RowBox[{"p1", " ", "q1"}], "-", 
    RowBox[{"p2", " ", "q2"}], "-", 
    RowBox[{"p3", " ", "q3"}]}], ",", 
   RowBox[{
    RowBox[{"p1", " ", "q0"}], "+", 
    RowBox[{"p0", " ", "q1"}], "-", 
    RowBox[{"p3", " ", "q2"}], "+", 
    RowBox[{"p2", " ", "q3"}]}], ",", 
   RowBox[{
    RowBox[{"p2", " ", "q0"}], "+", 
    RowBox[{"p3", " ", "q1"}], "+", 
    RowBox[{"p0", " ", "q2"}], "-", 
    RowBox[{"p1", " ", "q3"}]}], ",", 
   RowBox[{
    RowBox[{"p3", " ", "q0"}], "-", 
    RowBox[{"p2", " ", "q1"}], "+", 
    RowBox[{"p1", " ", "q2"}], "+", 
    RowBox[{"p0", " ", "q3"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7287322413383017`*^9},ExpressionUUID->"6a29b381-644e-433a-a3fe-\
89b456d93830"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuatToRot", "[", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.7287319034263*^9, 3.72873191286615*^9}, 
   3.728732021363777*^9},ExpressionUUID->"dd5a830d-cee2-4cdf-9e0b-\
443c2867a93c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.728731915294813*^9, 
  3.728732021871133*^9},ExpressionUUID->"9425af53-d180-4335-8196-\
a7865f1cbf99"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"QuatToRot", "[", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], " ", "]"}], " ",
     ".", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "-", " ", 
   RowBox[{"Rest", "@", 
    RowBox[{"qprod", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
      RowBox[{"qprod", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "x", ",", "y", ",", "z"}], "}"}], " ", ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", 
          RowBox[{"-", "q1"}], ",", 
          RowBox[{"-", "q2"}], ",", 
          RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}], "]"}]}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.726367601029504*^9, 
  3.726367676356493*^9}},ExpressionUUID->"f368d518-32c2-422f-8bdb-\
0fd58cc4f8cb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.72636767789783*^9},ExpressionUUID->"b640dbee-4276-4238-b853-2c017f6b0884"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Remark", ":", " ", "w"}], "=", 
    RowBox[{
     RowBox[{"0", " ", "is", " ", "NOT", " ", "important"}], " ", "-", " ", 
     RowBox[{
     "conjugation", " ", "just", " ", "leaves", " ", "w", " ", 
      "INVARIANT"}]}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"qprod", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
       RowBox[{"qprod", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"q0", ",", 
           RowBox[{"-", "q1"}], ",", 
           RowBox[{"-", "q2"}], ",", 
           RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}], "]"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], "&"}]}],
     ")"}], "/.", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}]}]}]], "Input",
 CellChangeTimes->{{3.726367721696599*^9, 3.726367830122426*^9}, {
  3.726367870330628*^9, 
  3.7263678721049957`*^9}},ExpressionUUID->"2e6608f9-a2eb-4b20-9542-\
f85f23d5fed1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "-", 
       SuperscriptBox["q2", "2"], "-", 
       SuperscriptBox["q3", "2"]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
       RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
       RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
       RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "-", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "-", 
       SuperscriptBox["q3", "2"]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
       RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
       RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
       RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "-", 
       SuperscriptBox["q1", "2"], "-", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], " ", "z"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.726367722482831*^9, 3.7263677277811403`*^9}, {
  3.726367776175425*^9, 
  3.726367831242303*^9}},ExpressionUUID->"805ade3b-e004-44e4-9244-\
3788d5e8b675"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeRotation", "[", 
   RowBox[{
    RowBox[{"angle_:", "0"}], ",", 
    RowBox[{"n_List:", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", " ", "=", " ", 
       RowBox[{
        RowBox[{"Cos", "[", "angle", "]"}], "//", "N"}]}], ",", " ", 
      RowBox[{"s", " ", "=", " ", 
       RowBox[{
        RowBox[{"Sin", "[", "angle", "]"}], "//", "N"}]}], ",", " ", "cm"}], 
     "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"cm", " ", "=", " ", 
      RowBox[{"1", " ", "-", " ", "c"}]}], ";", "\n", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"c", " ", "+", " ", 
           RowBox[{"cm", "*", 
            RowBox[{
             RowBox[{"n", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}]}], ",", " ", 
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], " ", "-", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}]}], ",", " ", 
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}]}], "}"}], ",", "\n", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "+", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}]}], ",", " ", 
          RowBox[{"c", " ", "+", " ", 
           RowBox[{"cm", "*", 
            RowBox[{
             RowBox[{"n", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}]}], ",", "  ", 
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}]}], "}"}], ",", "\n", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], " ", "-", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], ",", " ", "\n", 
          "              ", 
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], " ", "+", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], ",", " ", 
          RowBox[{"c", " ", "+", " ", 
           RowBox[{"cm", "*", 
            RowBox[{
             RowBox[{"n", "[", 
              RowBox[{"[", "3", "]"}], "]"}], "^", "2"}]}]}]}], "}"}]}], 
       "}"}], "//", "N"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.584375852951816*^9, 3.58437587259674*^9}, {
  3.584375910037079*^9, 
  3.584375911589164*^9}},ExpressionUUID->"edc70156-a6c4-4084-a4f2-\
68e36b5725b8"],

Cell[TextData[StyleBox["Adjusted to produce random signs of q0, as needed for \
any statistical study.\nNOTE  that you should REPLACE this by a careful, \
bulletproof, implementation\n    of the Bar-Itzhack method...",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.729798246054468*^9, 3.729798266464499*^9}, {
  3.740673032255999*^9, 
  3.740673062439919*^9}},ExpressionUUID->"d070abeb-7b5a-43c2-b3e8-\
191ea649fe90"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RotToQuat", "[", "mat_List", "]"}], " ", ":=", "\n", "   ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "qinit", ",", "q0", ",", "q1", ",", "q2", ",", "q3", ",", "trace", ",", 
      "s", ",", "t1", ",", "t2", ",", "t3"}], "}"}], ",", "\n", "         ", 
    RowBox[{
     RowBox[{"trace", " ", "=", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"mat", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";", "\n", 
     "         ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"trace", " ", ">", " ", "0"}], ",", "\n", "             ", 
       RowBox[{
        RowBox[{"s", " ", "=", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"trace", " ", "+", " ", "1.0"}], "]"}]}], ";", "\n", 
        "               ", 
        RowBox[{"q0", " ", "=", " ", 
         RowBox[{"s", "/", "2"}]}], ";", "\n", "               ", 
        RowBox[{"s", " ", "=", " ", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", "s"}], ")"}]}]}], ";", "\n", "               ", 
        RowBox[{"q1", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "2"}], "]"}], "]"}], " ", "-", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}], "*", "s"}]}], 
        ";", "\n", "               ", 
        RowBox[{"q2", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "-", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ")"}], "*", "s"}]}], 
        ";", "\n", "               ", 
        RowBox[{"q3", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}], " ", "-", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}], "*", "s"}]}]}], 
       ",", "\n", "            ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", ">=", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}], " ", "&&", "\n",
           "                ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", ">=", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], ",", " ", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"i", "=", "0"}], ",", "  ", 
           RowBox[{"j", " ", "=", " ", "1"}], ",", " ", 
           RowBox[{"k", " ", "=", " ", "2"}]}], " ", "*)"}], "\n", 
         "                  ", 
         RowBox[{
          RowBox[{"s", " ", "=", " ", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "-", " ", 
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "-", " ", 
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"3", ",", "3"}], "]"}], "]"}], " ", "+", " ", "1.0"}], 
            "]"}]}], ";", "\n", "                  ", 
          RowBox[{"q1", " ", "=", " ", 
           RowBox[{"s", "/", "2"}]}], ";", " ", 
          RowBox[{"s", " ", "=", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", " ", "s"}], ")"}]}]}], ";", "\n", 
          "                  ", 
          RowBox[{"q0", " ", "=", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"3", ",", "2"}], "]"}], "]"}], " ", "-", " ", 
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}], "*", "s"}]}], 
          ";", "\n", "                  ", 
          RowBox[{"q2", "=", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "1"}], "]"}], "]"}], " ", "+", " ", 
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}], "*", "s"}]}], 
          ";", "\n", "                  ", 
          RowBox[{"q3", " ", "=", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "+", " ", 
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ")"}], "*", 
            "s"}]}]}], ",", "\n", "               ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "<", " ", 
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}], " ", "&&", 
            "\n", "                ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", ">=", " ", 
              RowBox[{"mat", "[", 
               RowBox[{"[", 
                RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], ",", " ", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{"i", "=", "1"}], ",", "  ", 
             RowBox[{"j", " ", "=", " ", "2"}], ",", " ", 
             RowBox[{"k", " ", "=", " ", "0"}]}], " ", "*)"}], "\n", 
           "                  ", 
           RowBox[{
            RowBox[{"s", " ", "=", " ", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{"mat", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "-", " ", 
               RowBox[{"mat", "[", 
                RowBox[{"[", 
                 RowBox[{"3", ",", "3"}], "]"}], "]"}], " ", "-", " ", 
               RowBox[{"mat", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "+", " ", 
               "1.0"}], "]"}]}], ";", "\n", "                  ", 
            RowBox[{"q2", " ", "=", " ", 
             RowBox[{"s", "/", "2"}]}], ";", " ", 
            RowBox[{"s", " ", "=", " ", 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"2", " ", "s"}], ")"}]}]}], ";", "\n", 
            "                  ", 
            RowBox[{"q0", " ", "=", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "-", " ", 
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ")"}], "*", 
              "s"}]}], ";", "\n", "                  ", 
            RowBox[{"q3", "=", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "2"}], "]"}], "]"}], " ", "+", " ", 
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}], "*", 
              "s"}]}], ";", "\n", "                  ", 
            RowBox[{"q1", " ", "=", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "1"}], "]"}], "]"}], " ", "+", " ", 
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}], "*", 
              "s"}]}]}], ",", "\n", "             ", 
           RowBox[{"(*", " ", 
            RowBox[{"Else", ":", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "<", " ", 
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}], " ", "&&", 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "<", " ", 
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "  ", 
            "*)"}], "\n", "             ", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{"i", "=", "2"}], ",", "  ", 
             RowBox[{"j", " ", "=", " ", "0"}], ",", " ", 
             RowBox[{"k", " ", "=", " ", "1"}]}], " ", "*)"}], "\n", 
           "            ", 
           RowBox[{
            RowBox[{"s", " ", "=", " ", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{"mat", "[", 
                RowBox[{"[", 
                 RowBox[{"3", ",", "3"}], "]"}], "]"}], " ", "-", " ", 
               RowBox[{"mat", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "-", " ", 
               RowBox[{"mat", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "+", " ", 
               "1.0"}], "]"}]}], ";", "\n", "                  ", 
            RowBox[{"q3", " ", "=", " ", 
             RowBox[{"s", "/", "2"}]}], ";", " ", 
            RowBox[{"s", " ", "=", " ", 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"2", " ", "s"}], ")"}]}]}], ";", "\n", 
            "                  ", 
            RowBox[{"q0", " ", "=", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "1"}], "]"}], "]"}], " ", "-", " ", 
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}], "*", 
              "s"}]}], ";", "\n", "                  ", 
            RowBox[{"q1", "=", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "+", " ", 
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ")"}], "*", 
              "s"}]}], ";", "\n", "                  ", 
            RowBox[{"q2", " ", "=", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "2"}], "]"}], "]"}], " ", "+", " ", 
                RowBox[{"mat", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}], "*", 
              "s"}]}]}]}], "]"}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "      ", 
     RowBox[{"qinit", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "      ", 
     RowBox[{"qinit", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Abs", "[", "q0", "]"}], "<", 
         SuperscriptBox["10", 
          RowBox[{"-", "10"}]]}], ",", " ", "qinit", ",", 
        RowBox[{
         RowBox[{"Sign", "[", "q0", "]"}], "*", "qinit"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "      ", 
     RowBox[{"qinit", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{"2", " ", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], "]"}]}]}], ")"}], "*", 
       "qinit"}]}], ";", "\n", "                  ", 
     RowBox[{"normalize", "[", "qinit", "]"}]}]}], "]"}]}], "\n", 
 RowBox[{"             "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.584375802986526*^9, 3.584375819508978*^9}, {
  3.7297980232810993`*^9, 3.729798214790941*^9}, {3.7297983952620287`*^9, 
  3.729798399856168*^9}, {3.7297985288620872`*^9, 
  3.729798530043605*^9}},ExpressionUUID->"1379b963-3089-4bd1-abfd-\
543249af94e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"test", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"RotToQuat", "[", 
        RowBox[{"QuatToRot", "[", 
         RowBox[{"Normalize", "[", 
          RowBox[{"RandomReal", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}], "]"}],
          "]"}], "]"}], ",", "1000"}], "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Tally", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Sign", "[", 
       RowBox[{"First", "[", "#", "]"}], "]"}], "&"}], "/@", "test"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7297984084796553`*^9, 
  3.7297985197966413`*^9}},ExpressionUUID->"cbd5ea1a-4234-40b8-90d9-\
6987f59aad80"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "495"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "505"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.72979852103187*^9, 3.729798534971718*^9}, {
  3.729798570803499*^9, 
  3.729798573210685*^9}},ExpressionUUID->"5a3f7a1f-0e43-4c00-b0e8-\
d8e8cbda0da9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "Rot4ToQuat2", "]"}]], "Input",
 CellChangeTimes->{{3.7442198357830553`*^9, 3.744219841617313*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"2dee8d68-a221-486c-bb72-96c52f18c72c"],

Cell[CellGroupData[{

Cell[BoxData["1*^-10"], "Input",
 CellChangeTimes->{{3.7442211389946117`*^9, 3.744221145141604*^9}},
 CellLabel->
  "In[246]:=",ExpressionUUID->"1aa5afb5-03b0-43c7-a90d-12ff8b98887b"],

Cell[BoxData[
 FractionBox["1", "10000000000"]], "Output",
 CellChangeTimes->{3.744221145887623*^9},
 CellLabel->
  "Out[246]=",ExpressionUUID->"fb7c0628-c49b-4d27-9529-80450d9630fd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Use", " ", "BarItzhack", " ", "method", " ", "to", " ", "get", " ", 
      "extract", " ", "quat", " ", "from", " ", "4", "D", " ", "orthogonal", 
      " ", "matrix"}], ";", "\[IndentingNewLine]", "   ", 
     RowBox[{"This", " ", "does", " ", "NOT", " ", "randomize", " ", "p0"}]}],
     ",", "q0"}], "  ", "*)"}], 
  RowBox[{
   RowBox[{"Rot4ToQuat2", "[", "rot4_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eigL", ",", "eigR", ",", "outL", ",", "outR", ",", 
       RowBox[{"profilemat4", " ", "=", " ", 
        RowBox[{"makeMwwmat", "[", "rot4", "]"}]}], ",", "PQTest"}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Remember", " ", "these", " ", "are", " ", "SWITCHED"}], " ", 
        "-", " ", 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], 
         RowBox[{
          RowBox[{
           RowBox[{"p", "'"}], "[", "j", "]"}], ".", "p"}]}]}], " ", "=", " ", 
       RowBox[{"lam", " ", 
        RowBox[{"p", ":", " ", 
         RowBox[{"is", " ", "\"\<right eigenvectoris LEFT arg\>\""}]}]}]}], 
      " ", "*)"}], " ", 
     RowBox[{
      RowBox[{"eigL", " ", "=", " ", 
       RowBox[{
        RowBox[{"Eigenvectors", "[", "profilemat4", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
      RowBox[{"eigR", " ", "=", " ", 
       RowBox[{
        RowBox[{"Eigenvectors", "[", 
         RowBox[{"Transpose", "[", "profilemat4", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"outL", "=", 
       RowBox[{
        RowBox[{"Normalize", "[", 
         RowBox[{"qinverse", "[", "eigL", "]"}], "]"}], "//", "Chop"}]}], ";", 
      RowBox[{"outR", "=", 
       RowBox[{
        RowBox[{"Normalize", "[", 
         RowBox[{"qinverse", "[", "eigR", "]"}], "]"}], " ", "//", "Chop"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"PQTest", " ", "=", " ", 
       RowBox[{"PQbTo4DRot", "[", 
        RowBox[{"outL", ",", "outR"}], " ", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"MUST", " ", "check", " ", "sign", " ", "of", " ", 
        RowBox[{"PQbar", "[", "]"}]}], "  ", "*)"}], " ", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"If", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rot4", ".", 
            RowBox[{"Transpose", "[", "PQTest", "]"}]}], ")"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "<", "0"}], ",", 
        RowBox[{"outR", "=", 
         RowBox[{"-", "outR"}]}]}], "]"}], ";", "  ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"If", "[", " ", 
         RowBox[{
          RowBox[{"blahblah", " ", "<", " ", "0"}], ",", 
          RowBox[{"eigL", "=", 
           RowBox[{"-", "eigL"}]}]}], "]"}], ";"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"outL", ",", "outR"}], "}"}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.744157915896215*^9, 3.7441581072265167`*^9}, {
   3.744158151477985*^9, 3.74415815276934*^9}, {3.744217928917739*^9, 
   3.744218019238022*^9}, {3.744218298279006*^9, 3.7442183202939672`*^9}, {
   3.744218612960739*^9, 3.744218696829723*^9}, {3.7442187561255703`*^9, 
   3.74421881176433*^9}, {3.744219027180722*^9, 3.744219044394623*^9}, {
   3.744219705499724*^9, 3.7442197330176888`*^9}, {3.744219895710404*^9, 
   3.744219923675067*^9}, {3.744219973066634*^9, 3.7442200368498707`*^9}, {
   3.744220086409683*^9, 3.744220115937765*^9}, {3.744220461339218*^9, 
   3.744220468390562*^9}, {3.74422057412074*^9, 3.74422057506956*^9}, {
   3.744220611725037*^9, 3.74422066986874*^9}, {3.744220937634801*^9, 
   3.7442209707548018`*^9}, {3.744221022670994*^9, 3.7442211068332376`*^9}, 
   3.744221153281541*^9, {3.7442212006378527`*^9, 3.7442212032289248`*^9}, {
   3.744221376909375*^9, 3.744221422630286*^9}, {3.744221683320503*^9, 
   3.7442216982910213`*^9}, {3.744290923940414*^9, 3.744291134860311*^9}, {
   3.744291164914941*^9, 3.744291208649197*^9}, {3.744291809291551*^9, 
   3.7442918471789*^9}},
 CellLabel->
  "In[294]:=",ExpressionUUID->"1b231e7a-d134-4b2a-8271-d14836ca222f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"arg1", "-", 
    RowBox[{"PQbTo4DRot", "@@", 
     RowBox[{"Rot4ToQuat2", "[", "arg1", "]"}]}]}], "}"}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.744291864888165*^9, 3.7442918848474417`*^9}},
 CellLabel->
  "In[296]:=",ExpressionUUID->"7f20c1b9-727a-4b60-9fc7-b1ba641317b5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744291880274819*^9, 3.744291885585267*^9}},
 CellLabel->
  "Out[296]=",ExpressionUUID->"6fbc493f-dfd0-4cbe-8fa9-1c04ca9cfbd7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"sign", " ", "checks"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Rot4ToQuat2", "[", "arg1", "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7442908051312037`*^9, 3.7442908195938063`*^9}, 
   3.7442917958659077`*^9},
 CellLabel->
  "In[287]:=",ExpressionUUID->"44afc2b1-5740-41ad-8c7e-d0457a1e5ab9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.32720686949264133`", ",", 
     RowBox[{"-", "0.695809036060321`"}], ",", "0.4313201208085498`", ",", 
     RowBox[{"-", "0.47196229010306584`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7679079130658697`", ",", "0.5441116986503074`", ",", 
     RowBox[{"-", "0.08827024515186513`"}], ",", 
     RowBox[{"-", "0.3262947444620088`"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.744290820414703*^9, 3.744291221089117*^9, 
  3.7442917958668013`*^9},
 CellLabel->
  "Out[287]=",ExpressionUUID->"82cadfc8-755a-48a1-b226-cb4f869bb6d3"],

Cell[BoxData[
 RowBox[{"MatrixForm", "/@", 
  RowBox[{"{", 
   RowBox[{"arg1", ",", 
    RowBox[{"PQbTo4DRot", "@@", 
     RowBox[{"Rot4ToQuat2", "[", "arg1", "]"}]}]}], "}"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7442908302887173`*^9, 3.744290870097395*^9}, 
   3.744291795867728*^9},
 CellLabel->
  "In[288]:=",ExpressionUUID->"748629fc-0168-494d-ac50-bfbb4d8a8960"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.011407010211915314`"}], "0.8947520659935295`", 
        "0.12374227056362155`", "0.4289247847747848`"},
       {
        RowBox[{"-", "0.529956634692768`"}], 
        RowBox[{"-", "0.24325917429627691`"}], "0.7652950168932724`", 
        "0.2725701314967133`"},
       {"0.843935799401427`", 
        RowBox[{"-", "0.17308390131902926`"}], "0.43779103319234175`", 
        "0.25720291765304837`"},
       {
        RowBox[{"-", "0.08239060596825012`"}], 
        RowBox[{"-", "0.33209287499913154`"}], 
        RowBox[{"-", "0.4553574407544776`"}], "0.8219341284875135`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.0114070102119221`"}], "0.894752065993528`", 
        "0.1237422705636253`", "0.4289247847747869`"},
       {
        RowBox[{"-", "0.5299566346927642`"}], 
        RowBox[{"-", "0.24325917429628524`"}], "0.7652950168932725`", 
        "0.2725701314967133`"},
       {"0.8439357994014295`", 
        RowBox[{"-", "0.17308390131902576`"}], "0.43779103319233764`", 
        "0.25720291765304976`"},
       {
        RowBox[{"-", "0.08239060596825024`"}], 
        RowBox[{"-", "0.33209287499913176`"}], 
        RowBox[{"-", "0.4553574407544802`"}], "0.8219341284875119`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.744290870629807*^9, 3.7442912257909718`*^9, 
  3.744291795868608*^9},
 CellLabel->
  "Out[288]=",ExpressionUUID->"20160821-10fb-4873-9806-979315d4c84b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Checks", " ", "*)"}], 
  RowBox[{"testonePQ", " ", "=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"qL", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}], 
         "]"}]}], ",", 
       RowBox[{"qR", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}], 
         "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"qL", ",", "qR"}], "}"}], ",", 
       RowBox[{"PQbTo4DRot", "[", 
        RowBox[{"qL", ",", "qR"}], "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.744218355069776*^9, 3.744218437701182*^9}, {
   3.744219126309352*^9, 3.744219130550647*^9}, 
   3.744291795869618*^9},ExpressionUUID->"bcacd23a-fe2b-454e-a10c-\
b4a7822197cf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.56039826294471`", ",", 
       RowBox[{"-", "0.39712576248429926`"}], ",", 
       RowBox[{"-", "0.3505207631924207`"}], ",", "0.6366946758304316`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.5758749859398`", ",", "0.43679572104220776`", ",", 
       "0.41653700591688825`", ",", 
       RowBox[{"-", "0.5514294346059585`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.3478405462964653`"}], ",", "0.5453937839094997`", ",", 
       "0.37616407880414704`", ",", 
       RowBox[{"-", "0.663365028202785`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.4015549285319274`"}], ",", "0.6463535623468797`", ",", 
       
       RowBox[{"-", "0.3761599857786024`"}], ",", "0.5286628196802367`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.49440142948196864`"}], ",", 
       RowBox[{"-", "0.26088710537453697`"}], ",", "0.7012694914606646`", ",",
        "0.4424095897717202`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.687988241360331`", ",", "0.4655218696942941`", ",", 
       "0.4745791306652345`", ",", "0.29109485966481385`"}], "}"}]}], "}"}]}],
   "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7442184234262543`*^9, 3.7442184422869797`*^9}, 
   3.7442917958701982`*^9},
 CellLabel->
  "Out[192]=",ExpressionUUID->"b13632ed-6870-40e3-8c3e-370722aa2c35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"ckll", ",", "ckrr"}], "}"}], "=", 
  RowBox[{"Rot4ToQuat2", "[", 
   RowBox[{"testonePQ", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.744218465693709*^9, 3.7442184684530888`*^9}, {
   3.744218872612246*^9, 3.7442188779376793`*^9}, 3.744291795870529*^9},
 CellLabel->
  "In[233]:=",ExpressionUUID->"4fab7ee6-1348-4d8d-bab6-96a4cdf653b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.5603982629447098`", ",", 
     RowBox[{"-", "0.3971257624842994`"}], ",", 
     RowBox[{"-", "0.3505207631924208`"}], ",", "0.6366946758304318`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5758749859398002`", ",", "0.43679572104220776`", ",", 
     "0.4165370059168881`", ",", 
     RowBox[{"-", "0.5514294346059584`"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7442184692420197`*^9, 3.7442188320982723`*^9, 
  3.7442188792233677`*^9, 3.744219050385998*^9, 3.7442198510241756`*^9, 
  3.744220138550022*^9, 3.744220484037416*^9, 3.744220677135021*^9, 
  3.74429179587084*^9},
 CellLabel->
  "Out[233]=",ExpressionUUID->"88f7cf61-979a-4da2-9b08-dce0cc5c9a58"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"MATCH", "!"}], " ", "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"PQbTo4DRot", "[", 
       RowBox[{"ckll", ",", "ckrr"}], "]"}], "-", 
      RowBox[{"testonePQ", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "//", "Chop"}], "//", "Flatten"}], "//",
    "Tally"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.744219072231591*^9, 3.7442190936955423`*^9}, {
   3.744219134650991*^9, 3.744219138552006*^9}, 3.744291795871195*^9},
 CellLabel->
  "In[234]:=",ExpressionUUID->"791d5b50-b6dd-489e-a02c-d299bb6cd691"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0", ",", "16"}], "}"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.744218952902439*^9, {3.744219056028802*^9, 3.744219094357664*^9}, 
   3.744220147818245*^9, 3.74422048733634*^9, 3.744220681667658*^9, 
   3.7442917958715067`*^9},
 CellLabel->
  "Out[234]=",ExpressionUUID->"a3987152-0800-42da-b7bf-c9951184814d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Bunch", " ", "of", " ", "test", " ", 
    RowBox[{"cases", " ", ":", " ", 
     RowBox[{"Still", " ", 
      RowBox[{"don", "'"}], "t", " ", "have", " ", "the", " ", "sign"}]}]}], 
   "*)"}], "  ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"testsome4Drot2quat", " ", "=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qL", ",", "qR"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"qL", "=", 
          RowBox[{"Normalize", "[", 
           RowBox[{"RandomReal", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}], 
           "]"}]}], ";", 
         RowBox[{"qR", "=", 
          RowBox[{"Normalize", "[", 
           RowBox[{"RandomReal", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"qL", ",", "qR"}], "}"}], ",", 
           RowBox[{"PQbTo4DRot", "[", 
            RowBox[{"qL", ",", "qR"}], "]"}]}], "}"}]}], ",", "100"}], 
       "]"}]}], "]"}]}], ";"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.74421806412111*^9, 3.744218266815647*^9}, 
   3.7442193817735033`*^9, {3.7442201569212313`*^9, 3.744220166384055*^9}, {
   3.744220886850316*^9, 3.7442208919924927`*^9}, 3.7442917958718977`*^9},
 CellLabel->
  "In[289]:=",ExpressionUUID->"746e750e-cc03-458f-af87-06757ad3b22a"],

Cell[BoxData[
 RowBox[{"arg1", "=", 
  RowBox[{
   RowBox[{"testsome4Drot2quat", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7442218724322977`*^9, {3.744221908124284*^9, 3.744221909959775*^9}, 
   3.744291795872213*^9},
 CellLabel->
  "In[268]:=",ExpressionUUID->"9f448b6a-347f-4813-960a-bb130ff229ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.011407010211915314`"}], ",", "0.8947520659935295`", ",", 
     "0.12374227056362155`", ",", "0.4289247847747848`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.529956634692768`"}], ",", 
     RowBox[{"-", "0.24325917429627691`"}], ",", "0.7652950168932724`", ",", 
     "0.2725701314967133`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.843935799401427`", ",", 
     RowBox[{"-", "0.17308390131902926`"}], ",", "0.43779103319234175`", ",", 
     "0.25720291765304837`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.08239060596825012`"}], ",", 
     RowBox[{"-", "0.33209287499913154`"}], ",", 
     RowBox[{"-", "0.4553574407544776`"}], ",", "0.8219341284875135`"}], 
    "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7442218729936113`*^9, 3.744221911095169*^9, 
  3.744291795872521*^9},
 CellLabel->
  "Out[268]=",ExpressionUUID->"4c39c365-4bb3-4a14-8097-40a572ec88dd"],

Cell[BoxData[
 RowBox[{"Rot4ToQuat2", "[", 
  RowBox[{
   RowBox[{"testsome4Drot2quat", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.744221835296406*^9, 3.744221848506258*^9}, 
   3.744291795872847*^9},
 CellLabel->
  "In[265]:=",ExpressionUUID->"8e784fd2-ed48-43f0-92ae-aa8d826fcb6c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.32720686949264133`", ",", 
     RowBox[{"-", "0.695809036060321`"}], ",", "0.4313201208085498`", ",", 
     RowBox[{"-", "0.47196229010306584`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7679079130658697`"}], ",", 
     RowBox[{"-", "0.5441116986503074`"}], ",", "0.08827024515186513`", ",", 
     "0.3262947444620088`"}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.74422185150384*^9, 3.744221853482903*^9}, 
   3.744291795873171*^9},
 CellLabel->
  "Out[265]=",ExpressionUUID->"795b6b6d-3a74-4823-ad36-af4ccdbc9a0c"],

Cell[BoxData[
 RowBox[{"res1", "=", 
  RowBox[{"PQbTo4DRot", "@@", 
   RowBox[{"Rot4ToQuat2", "[", 
    RowBox[{
     RowBox[{"testsome4Drot2quat", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.744221885607314*^9, 3.7442219160956087`*^9}, 
   3.7442917958735*^9},
 CellLabel->
  "In[269]:=",ExpressionUUID->"db364916-a81a-46e9-b3e3-5df12d2bbc9f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.0114070102119221`", ",", 
     RowBox[{"-", "0.894752065993528`"}], ",", 
     RowBox[{"-", "0.1237422705636253`"}], ",", 
     RowBox[{"-", "0.4289247847747869`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5299566346927642`", ",", "0.24325917429628524`", ",", 
     RowBox[{"-", "0.7652950168932725`"}], ",", 
     RowBox[{"-", "0.2725701314967133`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.8439357994014295`"}], ",", "0.17308390131902576`", ",", 
     RowBox[{"-", "0.43779103319233764`"}], ",", 
     RowBox[{"-", "0.25720291765304976`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.08239060596825024`", ",", "0.33209287499913176`", ",", 
     "0.4553574407544802`", ",", 
     RowBox[{"-", "0.8219341284875119`"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7442218941002293`*^9, 3.744221916550477*^9}, 
   3.744291795873811*^9},
 CellLabel->
  "Out[269]=",ExpressionUUID->"7383b543-0c33-4f93-a7c5-61dd3c8cd71d"],

Cell[BoxData[
 RowBox[{"res2", " ", "=", " ", 
  RowBox[{"PQbTo4DRot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Rot4ToQuat2", "[", 
      RowBox[{
       RowBox[{"testsome4Drot2quat", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"Rot4ToQuat2", "[", 
       RowBox[{
        RowBox[{"testsome4Drot2quat", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.744221976444027*^9, 3.744222027955271*^9}, 
   3.7442917958741703`*^9},
 CellLabel->
  "In[273]:=",ExpressionUUID->"14dc3aab-5a23-4601-bf95-d0019de0dece"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0114070102119221`"}], ",", "0.894752065993528`", ",", 
     "0.1237422705636253`", ",", "0.4289247847747869`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5299566346927642`"}], ",", 
     RowBox[{"-", "0.24325917429628524`"}], ",", "0.7652950168932725`", ",", 
     "0.2725701314967133`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8439357994014295`", ",", 
     RowBox[{"-", "0.17308390131902576`"}], ",", "0.43779103319233764`", ",", 
     "0.25720291765304976`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.08239060596825024`"}], ",", 
     RowBox[{"-", "0.33209287499913176`"}], ",", 
     RowBox[{"-", "0.4553574407544802`"}], ",", "0.8219341284875119`"}], 
    "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7442220224820843`*^9, 3.744222028691774*^9}, 
   3.744291795874482*^9},
 CellLabel->
  "Out[273]=",ExpressionUUID->"611f2af6-277a-4556-9049-97ee46c934d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"res1", ".", 
   RowBox[{"Transpose", "[", "arg1", "]"}]}], "//", "Chop"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.74422206361966*^9, 3.744222064766539*^9}, 
   3.744291795874807*^9},
 CellLabel->
  "In[275]:=",ExpressionUUID->"e5228c88-e70c-4a62-8456-585cac464f33"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0000000000000002`"}], ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1.0000000000000002`"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", "1.`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{"-", "1.0000000000000002`"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.744221958825482*^9, 3.744222065241835*^9, 
  3.7442917958751307`*^9},
 CellLabel->
  "Out[275]=",ExpressionUUID->"5e1c3e9b-1007-48b8-b811-00e988c4ceba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"res2", ".", 
   RowBox[{"Transpose", "[", "arg1", "]"}]}], "//", "Chop"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.744222074222715*^9, 3.7442917958754883`*^9},
 CellLabel->
  "In[276]:=",ExpressionUUID->"ae55ac47-d22e-46d1-ae57-36aa29732b3b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.0000000000000002`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.0000000000000002`", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1.0000000000000002`"}], "}"}]}], 
  "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.744222075087534*^9, 3.744291795875926*^9},
 CellLabel->
  "Out[276]=",ExpressionUUID->"7d746430-8508-42a4-8b86-3a3a565fabf9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"res1", ".", 
     RowBox[{"Transpose", "[", "arg1", "]"}]}], ")"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}], "<", " ", "0"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.744221921120666*^9, 3.7442219513837137`*^9}, {
   3.744222048006301*^9, 3.7442220491988487`*^9}, 3.744291795876255*^9},
 CellLabel->
  "In[274]:=",ExpressionUUID->"bb757c42-1621-4175-8c11-3545ef5031f0"],

Cell[BoxData["True"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.744221927191388*^9, 3.744222049843478*^9, 
  3.744291795876566*^9},
 CellLabel->
  "Out[274]=",ExpressionUUID->"db1f1b51-f397-4ea2-a7e7-92aee8f5f1af"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Tally", "@", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qL", ",", "qR"}], "}"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"qL", ",", "qR"}], "}"}], "=", 
          RowBox[{"Rot4ToQuat2", "[", 
           RowBox[{
            RowBox[{"testsome4Drot2quat", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"PQbTo4DRot", "[", 
              RowBox[{"qL", ",", "qR"}], "]"}], ".", 
             RowBox[{"Transpose", "[", 
              RowBox[{
               RowBox[{"testsome4Drot2quat", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}], "//", 
           RowBox[{
            RowBox[{"Chop", "[", " ", 
             RowBox[{"#", ",", 
              RowBox[{"10", "^", 
               RowBox[{"(", 
                RowBox[{"-", "n"}], ")"}]}]}], "]"}], "&"}]}], "//", 
          RowBox[{
           RowBox[{"Chop", "[", 
            RowBox[{
             RowBox[{"1", "-", "#"}], ",", 
             RowBox[{"10", "^", 
              RowBox[{"(", 
               RowBox[{"-", "n"}], ")"}]}]}], "]"}], "&"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "100"}], "}"}]}], "]"}]}], "]"}]}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "16"}], "}"}], ",", "4", ",", "24", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.744219167029862*^9, 3.744219250215053*^9}, {
   3.744219327550138*^9, 3.744219377942214*^9}, {3.744219431860565*^9, 
   3.7442195101804132`*^9}, {3.74422019083339*^9, 3.7442202577622433`*^9}, {
   3.744220755382169*^9, 3.744220835365872*^9}, {3.744221248548802*^9, 
   3.7442212810616007`*^9}, {3.7442213143582582`*^9, 
   3.7442213233481083`*^9}, {3.744221453110718*^9, 3.7442214619142303`*^9}, 
   3.744221497320581*^9, {3.744221777009416*^9, 3.744221796572605*^9}, {
   3.744291289378634*^9, 3.744291388557703*^9}, {3.744291443343163*^9, 
   3.744291456253849*^9}, {3.7442916104892883`*^9, 3.744291653475635*^9}, 
   3.744291795876994*^9},
 CellLabel->
  "In[293]:=",ExpressionUUID->"e60b2c30-7147-433c-b4e4-45cd1f1e939d"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`n$$ = 13, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 16}, 4, 24, 1}}, Typeset`size$$ = {
    472., {4., 10.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`n$115145$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`n$$ = 16}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$115145$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Tally[
        Module[{$CellContext`qL$, $CellContext`qR$}, 
         Table[{$CellContext`qL$, $CellContext`qR$} = $CellContext`Rot4ToQuat2[
             Part[
              Part[$CellContext`testsome4Drot2quat, $CellContext`i], 2]]; (
           Chop[1 - #, 10^(-$CellContext`n$$)]& )[
            (Chop[#, 10^(-$CellContext`n$$)]& )[
             Dot[
              $CellContext`PQbTo4DRot[$CellContext`qL$, $CellContext`qR$], 
              Transpose[
               Part[
                Part[$CellContext`testsome4Drot2quat, $CellContext`i], 
                2]]]]], {$CellContext`i, 1, 100}]]], 
      "Specifications" :> {{{$CellContext`n$$, 16}, 4, 24, 1, Appearance -> 
         "Labeled"}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{519., {50., 57.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.744291457617527*^9, 3.7442916560660267`*^9, 
  3.744291795877309*^9},
 CellLabel->
  "Out[293]=",ExpressionUUID->"af748b6c-fec9-41b0-89bb-0bb2866f2d57"]
}, Closed]],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testsome4Drot2quat\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"1\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,11,1,27348920716416593841,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.744848971607709*^9},
 CellLabel->"",ExpressionUUID->"59644dce-2b59-45a3-8587-9be5306d6aaa"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"1\\\", \\\"\[LeftDoubleBracket]\
\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \
\\\"\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,11,2,
   27348920716416593841,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.744848971636207*^9},
 CellLabel->"",ExpressionUUID->"07e1d662-05b7-4625-9e71-4e77445efb68"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"1\\\", \\\"\[LeftDoubleBracket]\
\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"2\\\"}], \
\\\"\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,11,3,
   27348920716416593841,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.744848971683464*^9},
 CellLabel->"",ExpressionUUID->"04f93c91-3dea-418b-8e44-3328679b712e"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,11,4,27348920716416593841,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7448489717026167`*^9},
 CellLabel->"",ExpressionUUID->"c15a3b5b-c11b-43db-ae99-573c3260bcb5"],

Cell[TextData[StyleBox["The above fails for SYMBOLIC arguments because, if it \
completes the symbolic Eigenvectors[ ]\n   call (which it might not),  the \
principal eigenvalue is LAST rather than first because it can\
\[CloseCurlyQuote]t\n   tell which end is which symbolically: it also seems \
to be NEGATIVE.  So this is a hack to check\n   this if you have a simple \
enough symbolic expression for an SO(4) matrix:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.744828885278516*^9, 
  3.744828978893897*^9}},ExpressionUUID->"cd687a2e-5201-4c32-93f6-\
33c091757497"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rot4ToQuat2Sym", "[", "rot4_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "eigL", ",", "eigR", ",", "outL", ",", "outR", ",", "scaleL", ",", 
      "scaleR", ",", 
      RowBox[{"profilemat4", "=", 
       RowBox[{"makeMwwmat", "[", "rot4", "]"}]}], ",", "PQTest"}], "}"}], 
    ",", 
    RowBox[{
     RowBox[{"eigL", "=", 
      RowBox[{
       RowBox[{"Eigenvectors", "[", "profilemat4", "]"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}], ";", 
     RowBox[{"eigR", "=", 
      RowBox[{
       RowBox[{"Eigenvectors", "[", 
        RowBox[{"Transpose", "[", "profilemat4", "]"}], "]"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}], ";", 
     RowBox[{"outL", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{"Normalize", "[", 
        RowBox[{"qinverse", "[", "eigL", "]"}], "]"}], "]"}]}], ";", 
     RowBox[{"outR", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{"Normalize", "[", 
        RowBox[{"qinverse", "[", "eigR", "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"scaleL", " ", "=", " ", 
      RowBox[{"Denominator", "[", 
       RowBox[{"outL", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", 
     RowBox[{"scaleR", " ", "=", " ", 
      RowBox[{"Denominator", "[", 
       RowBox[{"outR", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "scaleL"}], "*", "outL"}], ",", 
       RowBox[{
        RowBox[{"-", "scaleR"}], "*", "outR"}]}], "}"}]}]}], "]"}]}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.7448230358816557`*^9, 3.7448230684733133`*^9}, {
  3.744823142380072*^9, 3.7448232012418337`*^9}},
 CellLabel->
  "In[158]:=",ExpressionUUID->"dc20f87c-24d4-485c-b77d-a83a82735735"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"fails", " ", "with", " ", "numeric"}], "-", 
    RowBox[{"adapted", " ", "version"}]}], "*)"}], "\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q0", " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          FractionBox["q3", "q0"], "]"}], "2"]}]]}], ",", 
     RowBox[{"p0", " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          FractionBox["p3", "p0"], "]"}], "2"]}]]}]}], "}"}], "*", 
   RowBox[{"Rot4ToQuat2", "[", 
    RowBox[{"PQbTo4DRot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7448289986818247`*^9, 3.74482901215464*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"af55f316-e8ba-451f-8d1d-c9959e023d9d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q3", ",", "0", ",", "0", ",", 
     RowBox[{"-", "q0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p3", ",", "0", ",", "0", ",", 
     RowBox[{"-", "p0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744829016711625*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"791e646a-0602-4703-a8ed-f4aaeaffea0a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Symbolic", " ", 
    RowBox[{"modification", " ", "--"}], " ", "succeeds", " ", "for", " ", 
    "the", " ", "canonical", " ", "case"}], " ", "*)"}], 
  RowBox[{"Rot4ToQuat2Sym", "[", 
   RowBox[{"PQbTo4DRot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.74482903257834*^9, 
  3.744829050892499*^9}},ExpressionUUID->"a64b76e0-53a3-4b8e-9a84-\
1c6dc7188219"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.744829028812497*^9},
 CellLabel->
  "Out[163]=",ExpressionUUID->"359c70cd-363d-480f-9afe-7ff4be4ab349"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.7442202983413773`*^9},ExpressionUUID->"32a75acb-acf5-4f16-877b-\
bd80906bab18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "is", " ", "for", " ", "a", " ", "SEQUENCE", " ", "of", " ", 
    "frames", " ", "for", " ", "which", " ", "you", " ", "want", " ", "to", 
    " ", "draw", " ", "a", " ", "connecting", " ", "line", " ", "between", "  ", 
    RowBox[{"i", " ", ":", "  ", 
     RowBox[{"i", "+", 
      RowBox[{"1", "  ", "neighbors"}]}]}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"ForceCloseQFrames", "[", "qfrms_List", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"lastfrm", "=", 
        RowBox[{
        "qfrms", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
       ",", "thisfrm"}], "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"thisfrm", "=", 
         RowBox[{
         "qfrms", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
        ";", 
        RowBox[{"lastfrm", "=", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"thisfrm", ".", "lastfrm"}], "\[GreaterEqual]", "0"}], 
           ",", "thisfrm", ",", 
           RowBox[{"-", "thisfrm"}]}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "qfrms", "]"}]}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740597591425902*^9, 3.7405976338554583`*^9}},
 ImageRegion->{{0, 1}, {0, 
  1}},ExpressionUUID->"1948996e-8c99-4955-b232-db505c837334"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "this", " ", "is", " ", "needed", " ", "for", " ", "PAIRS", " ", "of", 
      " ", "quaternion", " ", "or", " ", "unit", " ", "z"}], "=", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{"I", " ", 
        RowBox[{"th", "/", "2"}]}], "]"}], " ", "lists"}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
    "if", " ", "they", " ", "are", " ", "REAL", " ", "data", " ", "from", " ", 
     RowBox[{"RotToQuat", ".", "  ", "Our"}], " ", "tests", " ", "were", " ", 
     "misleading", " ", "because", "\[IndentingNewLine]", " ", 
     RowBox[{"our", " ", "'"}], 
     RowBox[{"tgt", "'"}], " ", "frames", " ", "were", " ", "already", " ", 
     "close", " ", 
     RowBox[{"to", " ", "'"}], 
     RowBox[{"frm", "'"}], " ", "signs", " ", "by", " ", "construction"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "INDEPENDENT", " ", "of", " ", "dimension", " ", "of", " ", "the", " ", 
    "UNIT", " ", "vectors", " ", "to", " ", "be", " ", "matched"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"forceCloseFramePairs", "[", 
    RowBox[{"tgtList_", ",", " ", "refList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tgtout", "=", "tgtList"}], ",", 
       RowBox[{"num", " ", "=", " ", 
        RowBox[{"Length", "[", "refList", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"refList", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ".", 
            RowBox[{"tgtList", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "<", "0"}], ",", 
          RowBox[{
           RowBox[{"tgtout", "[", 
            RowBox[{"[", "i", "]"}], "]"}], " ", "=", " ", 
           RowBox[{"-", " ", 
            RowBox[{"tgtout", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "num"}], "}"}]}], "]"}], ";", 
      "tgtout"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739555393529522*^9, 3.739555636660008*^9}, {
  3.739556153489932*^9, 3.739556174447131*^9}, {3.739556266447158*^9, 
  3.7395562767389174`*^9}, {3.739556336835423*^9, 3.7395563484069147`*^9}, {
  3.7405977534420958`*^9, 3.7405978875413847`*^9}},
 CellLabel->
  "In[579]:=",ExpressionUUID->"f83f57bd-4ea2-4740-92c0-6a3f1d68a370"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Test   forceCloseQ -- looks OK",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739556193118044*^9, 
  3.739556221821718*^9}},ExpressionUUID->"d6fcc2fc-1fb8-4ee9-ac64-\
ef125cb1c702"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"forceCloseQframes", "[", 
    RowBox[{
     RowBox[{"data2Dquats", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"data2DquatsTgt", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "-", " ", 
   RowBox[{"data2DquatsTgt", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "//", "Union"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7395560166065617`*^9, 3.739556055967823*^9}, 
   3.73955620852738*^9},
 CellLabel->
  "In[578]:=",ExpressionUUID->"5b6453b7-1ddd-4982-9050-6758d28a2598"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0.`", ",", "0.`"}], "}"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739556035362344*^9, 3.739556057066691*^9}, 
   3.7395562085281076`*^9},
 CellLabel->
  "Out[578]=",ExpressionUUID->"b43ddad9-f9e9-49ef-ab8c-7b6daf054d1b"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", " ", 
     RowBox[{"2", 
      RowBox[{"RandomInteger", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], "]"}]}]}], ")"}], ",", "20"}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739555695386839*^9, 3.739555788138692*^9}, 
   3.7395562085288687`*^9},
 CellLabel->
  "In[570]:=",ExpressionUUID->"e443908f-9e32-4610-9ec0-cdec7fe37083"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739555707878005*^9, 3.739555719350238*^9}, 
   3.739555789563631*^9, 3.73955620852955*^9},
 CellLabel->
  "Out[570]=",ExpressionUUID->"10cb87b1-5783-498d-8c3b-66f4c66d5bf0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "test", " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"testSpatialTgt", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", " ", 
          RowBox[{"2", 
           RowBox[{"RandomInteger", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1"}], "}"}], "]"}]}]}], ")"}], "*", 
        RowBox[{"data2DquatsTgt", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "i"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"data2DquatsTgt", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"GraphicsRow", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"Point", "[", "#1", "]"}], ",", "Blue", ",", 
            RowBox[{"Point", "[", "#2", "]"}], ",", "Black", ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{"#1", ",", "#2"}], "}"}], "]"}]}], "}"}], "&"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"data2Dquats", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"1.2", "testSpatialTgt"}]}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"Point", "[", "#1", "]"}], ",", "Blue", ",", 
            RowBox[{"Point", "[", "#2", "]"}], ",", "Black", ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{"#1", ",", "#2"}], "}"}], "]"}]}], "}"}], "&"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"data2Dquats", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"1.2", 
            RowBox[{"forceCloseQframes", "[", 
             RowBox[{"testSpatialTgt", ",", 
              RowBox[{"data2Dquats", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "}"}]}], "]"}], 
       "]"}]}], "}"}], "]"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739555642406983*^9, 3.739555681970932*^9}, {
   3.7395558014962482`*^9, 3.73955595827374*^9}, {3.739556071061037*^9, 
   3.739556118808682*^9}, 3.739556208530531*^9, {3.7395563642200203`*^9, 
   3.7395563691582003`*^9}},
 CellLabel->
  "In[586]:=",ExpressionUUID->"6a8ecf06-315a-4aa3-bad0-53a6d49964b5"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9924847524262723, 0.12236836274691579`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1949880213743729`, -0.10956107325031478`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9924847524262723, 
          0.12236836274691579`}, {-1.1949880213743729`, \
-0.10956107325031478`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8589289111457403, 0.5120948404328958}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.119896335727256, 0.43108258747560796`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8589289111457403, 
          0.5120948404328958}, {-1.119896335727256, 
          0.43108258747560796`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.4766317270754905, -0.8791030637786648}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8508878269901463, 0.8461618674225321}]}, 
        {GrayLevel[0], 
         LineBox[{{
          0.4766317270754905, -0.8791030637786648}, {-0.8508878269901463, 
          0.8461618674225321}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.12452052822776452`, -0.9922170317273729}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.05743942093428762, -1.1986245087277057`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.12452052822776452`, -0.9922170317273729}, \
{-0.05743942093428762, -1.1986245087277057`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.2538142018163433, 0.9672529922188572}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.02838078739773768, 1.1996643409331982`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.2538142018163433, 0.9672529922188572}, {
          0.02838078739773768, 1.1996643409331982`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.5459242814692948, 0.8378345176120605}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.5197643567251835, -1.0815937377213574`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.5459242814692948, 
          0.8378345176120605}, {-0.5197643567251835, \
-1.0815937377213574`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.3867245283917826, 0.9221952825406089}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.3067970772245405, 1.1601187669400401`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.3867245283917826, 0.9221952825406089}, {
          0.3067970772245405, 1.1601187669400401`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.32840954404338063`, -0.9445354262182116}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.7771733180761996, 0.9143312494224564}]}, 
        {GrayLevel[0], 
         LineBox[{{
          0.32840954404338063`, -0.9445354262182116}, {-0.7771733180761996, 
          0.9143312494224564}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.020099150202423546`, 0.9997979916768888}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.16606636381728995`, -1.1884536014537979`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.020099150202423546`, 0.9997979916768888}, {
          0.16606636381728995`, -1.1884536014537979`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.84853139280539, 0.5291450419532859}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.085210085213387, 0.5121709391903772}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.84853139280539, 
          0.5291450419532859}, {-1.085210085213387, 
          0.5121709391903772}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8779416533471308, 0.478767640216114}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.118113402203727, -0.43568614829072433`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8779416533471308, 0.478767640216114}, {
          1.118113402203727, -0.43568614829072433`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9990884219842714, -0.04268869940602934}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1393404180411542`, -0.3767006926165753}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9990884219842714, -0.04268869940602934}, \
{-1.1393404180411542`, -0.3767006926165753}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9804482439953981, 0.19677713496831917`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1449167611900557`, 0.35939617408379904`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9804482439953981, 0.19677713496831917`}, {
          1.1449167611900557`, 0.35939617408379904`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.8189914607037194, 0.5738057051776217}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8278385326237324, 0.8687251371425747}]}, 
        {GrayLevel[0], 
         LineBox[{{0.8189914607037194, 0.5738057051776217}, {
          0.8278385326237324, 0.8687251371425747}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.02214966923892654, -0.9997546659819128}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.30724516270084073`, 1.1600001767228025`}]}, 
        {GrayLevel[0], 
         LineBox[{{
          0.02214966923892654, -0.9997546659819128}, {-0.30724516270084073`, 
          1.1600001767228025`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9784811626053739, 0.20633616848830807`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.163261689246672, 0.29465614253053973`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9784811626053739, 0.20633616848830807`}, {
          1.163261689246672, 0.29465614253053973`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.7211615533358603, -0.6927669261665206}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.6080112544392252, 1.0345638281301157`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.7211615533358603, -0.6927669261665206}, {
          0.6080112544392252, 1.0345638281301157`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7320430609398993, -0.6812583628328852}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.112937941074949, -0.4487417289665116}]}, 
        {GrayLevel[0], 
         LineBox[{{0.7320430609398993, -0.6812583628328852}, {
          1.112937941074949, -0.4487417289665116}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.788516427991662, -0.6150136931705426}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.7255409465680931, -0.9558191956918817}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.788516427991662, -0.6150136931705426}, \
{-0.7255409465680931, -0.9558191956918817}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9874511043137629, 0.15792503471435532`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1126777950081368`, 0.4493863866383038}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9874511043137629, 0.15792503471435532`}, {
          1.1126777950081368`, 0.4493863866383038}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.06347725901218441, 0.9979832852249079}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.29867645944511395`, 1.1622359367070572`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.06347725901218441, 
          0.9979832852249079}, {-0.29867645944511395`, 
          1.1622359367070572`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9614595223364147, -0.27494651645116946`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.0603001590718948`, 0.5619284408820351}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9614595223364147, -0.27494651645116946`}, {
          1.0603001590718948`, 0.5619284408820351}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9608753557297541, 0.2769811378979053}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1694970523221584`, -0.2688431598716669}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9608753557297541, 0.2769811378979053}, {
          1.1694970523221584`, -0.2688431598716669}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7996430379806834, -0.6004756546347431}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.9667044512501901, 0.7109729277075661}]}, 
        {GrayLevel[0], 
         LineBox[{{
          0.7996430379806834, -0.6004756546347431}, {-0.9667044512501901, 
          0.7109729277075661}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8740572642210918, 0.48582290895175023`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1750504172565805`, 0.24342661503035312`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8740572642210918, 
          0.48582290895175023`}, {-1.1750504172565805`, 
          0.24342661503035312`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.728362290006388, -0.6851922171891989}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8686035755348407, 0.8279660793583817}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.728362290006388, -0.6851922171891989}, {
          0.8686035755348407, 0.8279660793583817}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.3858500500287061, 0.9225615095444015}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.4186440410480294, 1.1246053382831576`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.3858500500287061, 0.9225615095444015}, {
          0.4186440410480294, 1.1246053382831576`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.203404431525689, 0.9790948050294779}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.06223410971289969, -1.1983851282406015`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.203404431525689, 
          0.9790948050294779}, {-0.06223410971289969, \
-1.1983851282406015`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9755537527203365, -0.2197609509291148}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1536917272045417`, 0.33014451166088127`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9755537527203365, -0.2197609509291148}, {
          1.1536917272045417`, 0.33014451166088127`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9827978368482321, -0.18468462818122153`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1631648687757723`, -0.29503811286991455`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9827978368482321, -0.18468462818122153`}, \
{-1.1631648687757723`, -0.29503811286991455`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.19267080675351772`, -0.9812634509778443}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.1443330500598949, -1.1912883658713396`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.19267080675351772`, -0.9812634509778443}, \
{-0.1443330500598949, -1.1912883658713396`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9071181447618851, 0.42087607611238176`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.190351021405548, -0.15186983189155323`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9071181447618851, 0.42087607611238176`}, {
          1.190351021405548, -0.15186983189155323`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8668162499474384, 0.4986277056352364}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1716874210029906`, -0.2591304448793317}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8668162499474384, 0.4986277056352364}, {
          1.1716874210029906`, -0.2591304448793317}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.5672662626849703, 0.8235344481073189}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.7962790395568574, -0.8977414389245985}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.5672662626849703, 0.8235344481073189}, {
          0.7962790395568574, -0.8977414389245985}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.033688985430666986`, -0.9994323650255941}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.41923928508374037`, 1.1243835741607373`}]}, 
        {GrayLevel[0], 
         LineBox[{{
          0.033688985430666986`, -0.9994323650255941}, {-0.41923928508374037`,
           1.1243835741607373`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.8103608598446232, -0.5859311195284672}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.0289048382716073`, -0.6175393378411433}]}, 
        {GrayLevel[0], 
         LineBox[{{0.8103608598446232, -0.5859311195284672}, {
          1.0289048382716073`, -0.6175393378411433}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8408702953183844, -0.541236682470038}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.9054057264147702, 0.7875534715657989}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8408702953183844, -0.541236682470038}, {
          0.9054057264147702, 0.7875534715657989}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7262083653534982, 0.6874746614171319}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8518446036650119, 0.8451986578354219}]}, 
        {GrayLevel[0], 
         LineBox[{{0.7262083653534982, 0.6874746614171319}, {
          0.8518446036650119, 0.8451986578354219}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9583373191772874, -0.28563890258872343`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1952338742439401`, 0.10684561694249048`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9583373191772874, -0.28563890258872343`}, {
          1.1952338742439401`, 0.10684561694249048`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9181127667521751, -0.39631924950305664`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0308163354611353`, -0.6143432937262976}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9181127667521751, -0.39631924950305664`}, \
{-1.0308163354611353`, -0.6143432937262976}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.22965804674813803`, 0.9732713812518223}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.4304959405620498, 1.120121977804023}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.22965804674813803`, 
          0.9732713812518223}, {-0.4304959405620498, 
          1.120121977804023}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.6062699514916889, 0.7952589175345757}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.84525902728946, -0.8517847009577452}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.6062699514916889, 0.7952589175345757}, {
          0.84525902728946, -0.8517847009577452}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.6461954713949797, -0.7631719417985833}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.40046435713152795`, 1.1312065676379501`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.6461954713949797, -0.7631719417985833}, {
          0.40046435713152795`, 1.1312065676379501`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.6830027306827883, -0.7304158198450075}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.6924304570780956, -0.9800714576553177}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.6830027306827883, -0.7304158198450075}, \
{-0.6924304570780956, -0.9800714576553177}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.44789241940942115`, 0.8940874569277745}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8393166060820155, 0.8576407375789505}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.44789241940942115`, 
          0.8940874569277745}, {-0.8393166060820155, 0.8576407375789505}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.2429419596651051, -0.9700408260656241}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.25094948808302486`, 1.173466810110481}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.2429419596651051, -0.9700408260656241}, {
          0.25094948808302486`, 1.173466810110481}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.18771855569058843`, -0.9822228585455746}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.34068578990648624`, -1.1506229584689305`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.18771855569058843`, -0.9822228585455746}, {
          0.34068578990648624`, -1.1506229584689305`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.609257452521684, -0.7929724815822982}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.7350628879414293, -0.9485159728603446}]}, 
        {GrayLevel[0], 
         LineBox[{{0.609257452521684, -0.7929724815822982}, {
          0.7350628879414293, -0.9485159728603446}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9172355634760032, -0.398345228532813}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8509838424549655, -0.846065304737514}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9172355634760032, -0.398345228532813}, \
{-0.8509838424549655, -0.846065304737514}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.8862883406442859, 0.4631338653542821}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8791208454805118, -0.8167903886809821}]}, 
        {GrayLevel[0], 
         LineBox[{{0.8862883406442859, 
          0.4631338653542821}, {-0.8791208454805118, \
-0.8167903886809821}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9805375438838032, -0.19633167099151083`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0205928473947636`, -0.6311816219176921}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9805375438838032, -0.19633167099151083`}, \
{-1.0205928473947636`, -0.6311816219176921}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9595695193999594, -0.2814717347062242}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1908374461978217`, -0.1480073536451824}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9595695193999594, -0.2814717347062242}, {
          1.1908374461978217`, -0.1480073536451824}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.18831038273697193`, -0.9821095660635096}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.4530505900970634, -1.111190875958178}]}, 
        {GrayLevel[0], 
         LineBox[{{0.18831038273697193`, -0.9821095660635096}, {
          0.4530505900970634, -1.111190875958178}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.055997800609267075`, 0.998430892113683}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.3679444304855233, -1.1421982735386549`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.055997800609267075`, 0.998430892113683}, {
          0.3679444304855233, -1.1421982735386549`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.5481632514864504, -0.836371358739527}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.4547038537091924, -1.1105153782915431`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.5481632514864504, -0.836371358739527}, \
{-0.4547038537091924, -1.1105153782915431`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.7761768417311095, -0.630515273693128}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8295627442818161, 0.8670788045498643}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.7761768417311095, -0.630515273693128}, {
          0.8295627442818161, 0.8670788045498643}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9627242446746919, -0.27048480311386064`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1455585677400728`, 0.3573451662990735}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9627242446746919, -0.27048480311386064`}, {
          1.1455585677400728`, 0.3573451662990735}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.13926455639893873`, -0.9902552112112346}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.019006206855978574`, -1.199849475601397}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.13926455639893873`, -0.9902552112112346}, \
{-0.019006206855978574`, -1.199849475601397}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.7778717328249074, 0.6284230798371236}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0264959239394296`, 0.6215352911426161}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.7778717328249074, 
          0.6284230798371236}, {-1.0264959239394296`, 
          0.6215352911426161}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.25325730565927923`, 0.9673989544806229}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.13833908286306776`, 1.1919992861376236`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.25325730565927923`, 
          0.9673989544806229}, {-0.13833908286306776`, 
          1.1919992861376236`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8866440802108865, -0.46245245704503596`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8609699524542038, 0.8359011550243282}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8866440802108865, -0.46245245704503596`}, {
          0.8609699524542038, 0.8359011550243282}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9539719775272757, -0.29989575871075397`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.9278407373834993, 0.7609938015855607}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9539719775272757, -0.29989575871075397`}, {
          0.9278407373834993, 0.7609938015855607}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9827981863519378, 0.18468276829022737`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1933629608980294`, -0.12603508859316961`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9827981863519378, 
          0.18468276829022737`}, {-1.1933629608980294`, \
-0.12603508859316961`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.2114253440474967, 0.9773941497136135}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.05003099660800434, -1.1989565877788944`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.2114253440474967, 0.9773941497136135}, {
          0.05003099660800434, -1.1989565877788944`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.8519073829832324, -0.5236924773363278}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.054114015155097, -0.5734489018679866}]}, 
        {GrayLevel[0], 
         LineBox[{{0.8519073829832324, -0.5236924773363278}, {
          1.054114015155097, -0.5734489018679866}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.20830631520862608`, 0.9780636375227352}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.44234103460421514`, 1.1154973819356422`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.20830631520862608`, 
          0.9780636375227352}, {-0.44234103460421514`, 
          1.1154973819356422`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.6569254536092441, -0.7539555347633498}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.9103706848907629, -0.7818089383548408}]}, 
        {GrayLevel[0], 
         LineBox[{{0.6569254536092441, -0.7539555347633498}, {
          0.9103706848907629, -0.7818089383548408}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.24694531527304828`, -0.9690294171307158}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.14856722631525346`, 1.1907677268321442`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.24694531527304828`, -0.9690294171307158}, {
          0.14856722631525346`, 1.1907677268321442`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.18969381836654234`, 0.9818432946624025}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.4385212351858951, 1.117004532797892}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.18969381836654234`, 
          0.9818432946624025}, {-0.4385212351858951, 
          1.117004532797892}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.16366703991942527`, 0.9865156359855699}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.0639354353423508, 1.1982955645864606`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.16366703991942527`, 0.9865156359855699}, {
          0.0639354353423508, 1.1982955645864606`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.17427173974344662`, -0.9846975986193894}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.006019230704095424, 1.1999849035974288`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.17427173974344662`, -0.9846975986193894}, \
{-0.006019230704095424, 1.1999849035974288`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.4345626451702227, 0.9006416087560353}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.43404013520497975`, 1.1187533959864628`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.4345626451702227, 0.9006416087560353}, {
          0.43404013520497975`, 1.1187533959864628`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.999289800775696, -0.03768148173400268}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1846808515038934`, -0.19113157792476354`}]}, 
        {GrayLevel[0], 
         LineBox[{{
          0.999289800775696, -0.03768148173400268}, {-1.1846808515038934`, \
-0.19113157792476354`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.6421383366275288, 0.7665887793551573}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.3597031596484121, -1.144820351382237}]}, 
        {GrayLevel[0], 
         LineBox[{{0.6421383366275288, 
          0.7665887793551573}, {-0.3597031596484121, -1.144820351382237}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8282015513234, -0.5604303617627384}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8930596319096659, 0.8015263525632655}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8282015513234, -0.5604303617627384}, {
          0.8930596319096659, 0.8015263525632655}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9954792466798302, -0.09497931053528291}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1499193199040423`, 0.34305328698530874`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9954792466798302, -0.09497931053528291}, {
          1.1499193199040423`, 0.34305328698530874`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9612517409261029, -0.27567207070455363`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.9748903010217818, -0.6997062962226794}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9612517409261029, -0.27567207070455363`}, \
{-0.9748903010217818, -0.6997062962226794}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9827667226622501, 0.18485012531156134`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1538804346319589`, 0.3294843586174633}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9827667226622501, 0.18485012531156134`}, {
          1.1538804346319589`, 0.3294843586174633}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.5880693317799994, 0.8088105223226422}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.29592268159119706`, 1.1629401388377112`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.5880693317799994, 0.8088105223226422}, {
          0.29592268159119706`, 1.1629401388377112`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7466728004935, 0.6651914979937685}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.6177223351792972, -1.0287949827932852`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.7466728004935, 
          0.6651914979937685}, {-0.6177223351792972, \
-1.0287949827932852`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9015499823259668, 0.43267496965741964`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1880403366028542`, -0.16899751064609317`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9015499823259668, 0.43267496965741964`}, {
          1.1880403366028542`, -0.16899751064609317`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.27087891890264, 0.9626134277549514}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.6847572979544764, -0.985447838750527}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.27087891890264, 0.9626134277549514}, {
          0.6847572979544764, -0.985447838750527}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9630432941945226, 0.26934664190771374`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1930908687195279`, 0.12858529845236003`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9630432941945226, 0.26934664190771374`}, {
          1.1930908687195279`, 0.12858529845236003`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.6404934685934145, 0.7679636167743735}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.9985140049276655, -0.6655597508588647}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.6404934685934145, 0.7679636167743735}, {
          0.9985140049276655, -0.6655597508588647}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9154034972740934, 0.40253749785375115`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1525872437013622`, 0.333980007870077}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9154034972740934, 
          0.40253749785375115`}, {-1.1525872437013622`, 
          0.333980007870077}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.5244039214944852, 0.8514696278324939}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.27579232350459887`, 1.167877816509901}]}, 
        {GrayLevel[0], 
         LineBox[{{0.5244039214944852, 0.8514696278324939}, {
          0.27579232350459887`, 1.167877816509901}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.5980110201146679, -0.8014878787738554}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.6179849979419416, -1.0286372258083498`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.5980110201146679, -0.8014878787738554}, \
{-0.6179849979419416, -1.0286372258083498`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7882464032353602, -0.615359738516031}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0405883152746565`, 0.5976419982848034}]}, 
        {GrayLevel[0], 
         LineBox[{{
          0.7882464032353602, -0.615359738516031}, {-1.0405883152746565`, 
          0.5976419982848034}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9939970714373731, -0.10940668157807264`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1866599238538555`, -0.1784326907244351}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9939970714373731, -0.10940668157807264`}, \
{-1.1866599238538555`, -0.1784326907244351}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.2085702776354608, -0.9780073820207428}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.6617860434145877, -1.0010190970913921`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.2085702776354608, -0.9780073820207428}, {
          0.6617860434145877, -1.0010190970913921`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9397308207919725, 0.3419151714294726}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1215826023457471`, -0.4266760669586958}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9397308207919725, 
          0.3419151714294726}, {-1.1215826023457471`, \
-0.4266760669586958}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.5011614983121483, 0.8653537730948669}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.2496312636066847, -1.1737479423752484`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.5011614983121483, 
          0.8653537730948669}, {-0.2496312636066847, \
-1.1737479423752484`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9016375888602993, -0.43249237953308023`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.9945931005195972, -0.6714049183606078}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9016375888602993, -0.43249237953308023`}, \
{-0.9945931005195972, -0.6714049183606078}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.488728801507221, 0.8724357618629095}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.4341607719176248, 1.1187065853600273`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.488728801507221, 0.8724357618629095}, {
          0.4341607719176248, 1.1187065853600273`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.17281261748206103`, 0.9849547193851089}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.28062738613883353`, -1.1667254476306264`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.17281261748206103`, 0.9849547193851089}, {
          0.28062738613883353`, -1.1667254476306264`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9652126237079234, 0.2614662330681854}]}, 
        {RGBColor[0, 0, 1], PointBox[{1.054709158948689, 0.572353553347709}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9652126237079234, 0.2614662330681854}, {
          1.054709158948689, 0.572353553347709}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.37526765638493276`, 0.9269164935803872}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.12552902281535316`, -1.1934162997173376`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.37526765638493276`, 
          0.9269164935803872}, {-0.12552902281535316`, \
-1.1934162997173376`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.3454385276360904, 0.9384413799618013}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.005710886115688462, 1.1999864106646265`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.3454385276360904, 
          0.9384413799618013}, {-0.005710886115688462, 
          1.1999864106646265`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9751777045287374, -0.22142367667000357`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.0892841333009713`, 0.5034481869455396}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9751777045287374, -0.22142367667000357`}, {
          1.0892841333009713`, 0.5034481869455396}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.008200944436585556, -0.9999663716897425}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.12427562949866537`, -1.1935474719979557`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.008200944436585556, -0.9999663716897425}, {
          0.12427562949866537`, -1.1935474719979557`}}]}}}], {192., -189.7655532657435},
      ImageScaled[{0.5, 0.5}], {360., 361.45819669665434}], InsetBox[
     GraphicsBox[{{
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9924847524262723, 0.12236836274691579`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1949880213743729`, -0.10956107325031478`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9924847524262723, 
          0.12236836274691579`}, {-1.1949880213743729`, \
-0.10956107325031478`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8589289111457403, 0.5120948404328958}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.119896335727256, 0.43108258747560796`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8589289111457403, 
          0.5120948404328958}, {-1.119896335727256, 
          0.43108258747560796`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.4766317270754905, -0.8791030637786648}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8508878269901463, -0.8461618674225321}]}, 
        {GrayLevel[0], 
         LineBox[{{0.4766317270754905, -0.8791030637786648}, {
          0.8508878269901463, -0.8461618674225321}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.12452052822776452`, -0.9922170317273729}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.05743942093428762, -1.1986245087277057`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.12452052822776452`, -0.9922170317273729}, \
{-0.05743942093428762, -1.1986245087277057`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.2538142018163433, 0.9672529922188572}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.02838078739773768, 1.1996643409331982`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.2538142018163433, 0.9672529922188572}, {
          0.02838078739773768, 1.1996643409331982`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.5459242814692948, 0.8378345176120605}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.5197643567251835, 1.0815937377213574`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.5459242814692948, 0.8378345176120605}, {
          0.5197643567251835, 1.0815937377213574`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.3867245283917826, 0.9221952825406089}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.3067970772245405, 1.1601187669400401`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.3867245283917826, 0.9221952825406089}, {
          0.3067970772245405, 1.1601187669400401`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.32840954404338063`, -0.9445354262182116}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.7771733180761996, -0.9143312494224564}]}, 
        {GrayLevel[0], 
         LineBox[{{0.32840954404338063`, -0.9445354262182116}, {
          0.7771733180761996, -0.9143312494224564}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.020099150202423546`, 0.9997979916768888}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.16606636381728995`, 1.1884536014537979`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.020099150202423546`, 
          0.9997979916768888}, {-0.16606636381728995`, 
          1.1884536014537979`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.84853139280539, 0.5291450419532859}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.085210085213387, 0.5121709391903772}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.84853139280539, 
          0.5291450419532859}, {-1.085210085213387, 
          0.5121709391903772}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8779416533471308, 0.478767640216114}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.118113402203727, 0.43568614829072433`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8779416533471308, 
          0.478767640216114}, {-1.118113402203727, 0.43568614829072433`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9990884219842714, -0.04268869940602934}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1393404180411542`, -0.3767006926165753}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9990884219842714, -0.04268869940602934}, \
{-1.1393404180411542`, -0.3767006926165753}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9804482439953981, 0.19677713496831917`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1449167611900557`, 0.35939617408379904`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9804482439953981, 0.19677713496831917`}, {
          1.1449167611900557`, 0.35939617408379904`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.8189914607037194, 0.5738057051776217}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8278385326237324, 0.8687251371425747}]}, 
        {GrayLevel[0], 
         LineBox[{{0.8189914607037194, 0.5738057051776217}, {
          0.8278385326237324, 0.8687251371425747}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.02214966923892654, -0.9997546659819128}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.30724516270084073`, -1.1600001767228025`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.02214966923892654, -0.9997546659819128}, {
          0.30724516270084073`, -1.1600001767228025`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9784811626053739, 0.20633616848830807`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.163261689246672, 0.29465614253053973`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9784811626053739, 0.20633616848830807`}, {
          1.163261689246672, 0.29465614253053973`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.7211615533358603, -0.6927669261665206}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.6080112544392252, -1.0345638281301157`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.7211615533358603, -0.6927669261665206}, \
{-0.6080112544392252, -1.0345638281301157`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7320430609398993, -0.6812583628328852}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.112937941074949, -0.4487417289665116}]}, 
        {GrayLevel[0], 
         LineBox[{{0.7320430609398993, -0.6812583628328852}, {
          1.112937941074949, -0.4487417289665116}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.788516427991662, -0.6150136931705426}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.7255409465680931, -0.9558191956918817}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.788516427991662, -0.6150136931705426}, \
{-0.7255409465680931, -0.9558191956918817}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9874511043137629, 0.15792503471435532`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1126777950081368`, 0.4493863866383038}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9874511043137629, 0.15792503471435532`}, {
          1.1126777950081368`, 0.4493863866383038}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.06347725901218441, 0.9979832852249079}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.29867645944511395`, 1.1622359367070572`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.06347725901218441, 
          0.9979832852249079}, {-0.29867645944511395`, 
          1.1622359367070572`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9614595223364147, -0.27494651645116946`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0603001590718948`, -0.5619284408820351}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9614595223364147, -0.27494651645116946`}, \
{-1.0603001590718948`, -0.5619284408820351}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9608753557297541, 0.2769811378979053}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1694970523221584`, 0.2688431598716669}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9608753557297541, 
          0.2769811378979053}, {-1.1694970523221584`, 
          0.2688431598716669}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7996430379806834, -0.6004756546347431}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.9667044512501901, -0.7109729277075661}]}, 
        {GrayLevel[0], 
         LineBox[{{0.7996430379806834, -0.6004756546347431}, {
          0.9667044512501901, -0.7109729277075661}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8740572642210918, 0.48582290895175023`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1750504172565805`, 0.24342661503035312`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8740572642210918, 
          0.48582290895175023`}, {-1.1750504172565805`, 
          0.24342661503035312`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.728362290006388, -0.6851922171891989}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8686035755348407, -0.8279660793583817}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.728362290006388, -0.6851922171891989}, \
{-0.8686035755348407, -0.8279660793583817}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.3858500500287061, 0.9225615095444015}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.4186440410480294, 1.1246053382831576`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.3858500500287061, 0.9225615095444015}, {
          0.4186440410480294, 1.1246053382831576`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.203404431525689, 0.9790948050294779}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.06223410971289969, 1.1983851282406015`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.203404431525689, 0.9790948050294779}, {
          0.06223410971289969, 1.1983851282406015`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9755537527203365, -0.2197609509291148}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1536917272045417`, -0.33014451166088127`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9755537527203365, -0.2197609509291148}, \
{-1.1536917272045417`, -0.33014451166088127`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9827978368482321, -0.18468462818122153`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1631648687757723`, -0.29503811286991455`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9827978368482321, -0.18468462818122153`}, \
{-1.1631648687757723`, -0.29503811286991455`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.19267080675351772`, -0.9812634509778443}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.1443330500598949, -1.1912883658713396`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.19267080675351772`, -0.9812634509778443}, \
{-0.1443330500598949, -1.1912883658713396`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9071181447618851, 0.42087607611238176`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.190351021405548, 0.15186983189155323`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9071181447618851, 
          0.42087607611238176`}, {-1.190351021405548, 
          0.15186983189155323`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8668162499474384, 0.4986277056352364}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1716874210029906`, 0.2591304448793317}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8668162499474384, 
          0.4986277056352364}, {-1.1716874210029906`, 
          0.2591304448793317}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.5672662626849703, 0.8235344481073189}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.7962790395568574, 0.8977414389245985}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.5672662626849703, 
          0.8235344481073189}, {-0.7962790395568574, 0.8977414389245985}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.033688985430666986`, -0.9994323650255941}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.41923928508374037`, -1.1243835741607373`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.033688985430666986`, -0.9994323650255941}, {
          0.41923928508374037`, -1.1243835741607373`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.8103608598446232, -0.5859311195284672}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.0289048382716073`, -0.6175393378411433}]}, 
        {GrayLevel[0], 
         LineBox[{{0.8103608598446232, -0.5859311195284672}, {
          1.0289048382716073`, -0.6175393378411433}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8408702953183844, -0.541236682470038}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.9054057264147702, -0.7875534715657989}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8408702953183844, -0.541236682470038}, \
{-0.9054057264147702, -0.7875534715657989}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7262083653534982, 0.6874746614171319}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8518446036650119, 0.8451986578354219}]}, 
        {GrayLevel[0], 
         LineBox[{{0.7262083653534982, 0.6874746614171319}, {
          0.8518446036650119, 0.8451986578354219}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9583373191772874, -0.28563890258872343`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1952338742439401`, 0.10684561694249048`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9583373191772874, -0.28563890258872343`}, {
          1.1952338742439401`, 0.10684561694249048`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9181127667521751, -0.39631924950305664`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0308163354611353`, -0.6143432937262976}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9181127667521751, -0.39631924950305664`}, \
{-1.0308163354611353`, -0.6143432937262976}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.22965804674813803`, 0.9732713812518223}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.4304959405620498, 1.120121977804023}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.22965804674813803`, 
          0.9732713812518223}, {-0.4304959405620498, 
          1.120121977804023}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.6062699514916889, 0.7952589175345757}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.84525902728946, 0.8517847009577452}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.6062699514916889, 
          0.7952589175345757}, {-0.84525902728946, 0.8517847009577452}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.6461954713949797, -0.7631719417985833}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.40046435713152795`, -1.1312065676379501`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.6461954713949797, -0.7631719417985833}, \
{-0.40046435713152795`, -1.1312065676379501`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.6830027306827883, -0.7304158198450075}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.6924304570780956, -0.9800714576553177}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.6830027306827883, -0.7304158198450075}, \
{-0.6924304570780956, -0.9800714576553177}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.44789241940942115`, 0.8940874569277745}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8393166060820155, 0.8576407375789505}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.44789241940942115`, 
          0.8940874569277745}, {-0.8393166060820155, 0.8576407375789505}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.2429419596651051, -0.9700408260656241}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.25094948808302486`, -1.173466810110481}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.2429419596651051, -0.9700408260656241}, \
{-0.25094948808302486`, -1.173466810110481}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.18771855569058843`, -0.9822228585455746}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.34068578990648624`, -1.1506229584689305`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.18771855569058843`, -0.9822228585455746}, {
          0.34068578990648624`, -1.1506229584689305`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.609257452521684, -0.7929724815822982}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.7350628879414293, -0.9485159728603446}]}, 
        {GrayLevel[0], 
         LineBox[{{0.609257452521684, -0.7929724815822982}, {
          0.7350628879414293, -0.9485159728603446}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9172355634760032, -0.398345228532813}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8509838424549655, -0.846065304737514}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9172355634760032, -0.398345228532813}, \
{-0.8509838424549655, -0.846065304737514}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.8862883406442859, 0.4631338653542821}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.8791208454805118, 0.8167903886809821}]}, 
        {GrayLevel[0], 
         LineBox[{{0.8862883406442859, 0.4631338653542821}, {
          0.8791208454805118, 0.8167903886809821}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9805375438838032, -0.19633167099151083`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0205928473947636`, -0.6311816219176921}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9805375438838032, -0.19633167099151083`}, \
{-1.0205928473947636`, -0.6311816219176921}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9595695193999594, -0.2814717347062242}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1908374461978217`, -0.1480073536451824}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9595695193999594, -0.2814717347062242}, {
          1.1908374461978217`, -0.1480073536451824}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.18831038273697193`, -0.9821095660635096}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.4530505900970634, -1.111190875958178}]}, 
        {GrayLevel[0], 
         LineBox[{{0.18831038273697193`, -0.9821095660635096}, {
          0.4530505900970634, -1.111190875958178}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.055997800609267075`, 0.998430892113683}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.3679444304855233, 1.1421982735386549`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.055997800609267075`, 
          0.998430892113683}, {-0.3679444304855233, 1.1421982735386549`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.5481632514864504, -0.836371358739527}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.4547038537091924, -1.1105153782915431`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.5481632514864504, -0.836371358739527}, \
{-0.4547038537091924, -1.1105153782915431`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.7761768417311095, -0.630515273693128}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8295627442818161, -0.8670788045498643}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.7761768417311095, -0.630515273693128}, \
{-0.8295627442818161, -0.8670788045498643}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9627242446746919, -0.27048480311386064`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1455585677400728`, -0.3573451662990735}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9627242446746919, -0.27048480311386064`}, \
{-1.1455585677400728`, -0.3573451662990735}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.13926455639893873`, -0.9902552112112346}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.019006206855978574`, -1.199849475601397}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.13926455639893873`, -0.9902552112112346}, \
{-0.019006206855978574`, -1.199849475601397}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.7778717328249074, 0.6284230798371236}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0264959239394296`, 0.6215352911426161}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.7778717328249074, 
          0.6284230798371236}, {-1.0264959239394296`, 
          0.6215352911426161}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.25325730565927923`, 0.9673989544806229}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.13833908286306776`, 1.1919992861376236`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.25325730565927923`, 
          0.9673989544806229}, {-0.13833908286306776`, 
          1.1919992861376236`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8866440802108865, -0.46245245704503596`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8609699524542038, -0.8359011550243282}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8866440802108865, -0.46245245704503596`}, \
{-0.8609699524542038, -0.8359011550243282}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9539719775272757, -0.29989575871075397`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.9278407373834993, -0.7609938015855607}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9539719775272757, -0.29989575871075397`}, \
{-0.9278407373834993, -0.7609938015855607}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9827981863519378, 0.18468276829022737`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1933629608980294`, -0.12603508859316961`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9827981863519378, 
          0.18468276829022737`}, {-1.1933629608980294`, \
-0.12603508859316961`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.2114253440474967, 0.9773941497136135}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.05003099660800434, 1.1989565877788944`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.2114253440474967, 
          0.9773941497136135}, {-0.05003099660800434, 
          1.1989565877788944`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.8519073829832324, -0.5236924773363278}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.054114015155097, -0.5734489018679866}]}, 
        {GrayLevel[0], 
         LineBox[{{0.8519073829832324, -0.5236924773363278}, {
          1.054114015155097, -0.5734489018679866}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.20830631520862608`, 0.9780636375227352}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.44234103460421514`, 1.1154973819356422`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.20830631520862608`, 
          0.9780636375227352}, {-0.44234103460421514`, 
          1.1154973819356422`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.6569254536092441, -0.7539555347633498}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.9103706848907629, -0.7818089383548408}]}, 
        {GrayLevel[0], 
         LineBox[{{0.6569254536092441, -0.7539555347633498}, {
          0.9103706848907629, -0.7818089383548408}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.24694531527304828`, -0.9690294171307158}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.14856722631525346`, -1.1907677268321442`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.24694531527304828`, -0.9690294171307158}, \
{-0.14856722631525346`, -1.1907677268321442`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.18969381836654234`, 0.9818432946624025}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.4385212351858951, 1.117004532797892}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.18969381836654234`, 
          0.9818432946624025}, {-0.4385212351858951, 
          1.117004532797892}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.16366703991942527`, 0.9865156359855699}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.0639354353423508, 1.1982955645864606`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.16366703991942527`, 0.9865156359855699}, {
          0.0639354353423508, 1.1982955645864606`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.17427173974344662`, -0.9846975986193894}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.006019230704095424, -1.1999849035974288`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.17427173974344662`, -0.9846975986193894}, {
          0.006019230704095424, -1.1999849035974288`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.4345626451702227, 0.9006416087560353}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.43404013520497975`, 1.1187533959864628`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.4345626451702227, 0.9006416087560353}, {
          0.43404013520497975`, 1.1187533959864628`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.999289800775696, -0.03768148173400268}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1846808515038934`, 0.19113157792476354`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.999289800775696, -0.03768148173400268}, {
          1.1846808515038934`, 0.19113157792476354`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.6421383366275288, 0.7665887793551573}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.3597031596484121, 1.144820351382237}]}, 
        {GrayLevel[0], 
         LineBox[{{0.6421383366275288, 0.7665887793551573}, {
          0.3597031596484121, 1.144820351382237}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.8282015513234, -0.5604303617627384}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.8930596319096659, -0.8015263525632655}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.8282015513234, -0.5604303617627384}, \
{-0.8930596319096659, -0.8015263525632655}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9954792466798302, -0.09497931053528291}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1499193199040423`, -0.34305328698530874`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9954792466798302, -0.09497931053528291}, \
{-1.1499193199040423`, -0.34305328698530874`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9612517409261029, -0.27567207070455363`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.9748903010217818, -0.6997062962226794}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9612517409261029, -0.27567207070455363`}, \
{-0.9748903010217818, -0.6997062962226794}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9827667226622501, 0.18485012531156134`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1538804346319589`, 0.3294843586174633}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9827667226622501, 0.18485012531156134`}, {
          1.1538804346319589`, 0.3294843586174633}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.5880693317799994, 0.8088105223226422}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.29592268159119706`, 1.1629401388377112`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.5880693317799994, 0.8088105223226422}, {
          0.29592268159119706`, 1.1629401388377112`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7466728004935, 0.6651914979937685}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.6177223351792972, 1.0287949827932852`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.7466728004935, 0.6651914979937685}, {0.6177223351792972, 
          1.0287949827932852`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9015499823259668, 0.43267496965741964`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1880403366028542`, 0.16899751064609317`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9015499823259668, 
          0.43267496965741964`}, {-1.1880403366028542`, 
          0.16899751064609317`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.27087891890264, 0.9626134277549514}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.6847572979544764, 0.985447838750527}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.27087891890264, 
          0.9626134277549514}, {-0.6847572979544764, 
          0.985447838750527}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9630432941945226, 0.26934664190771374`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1930908687195279`, -0.12858529845236003`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9630432941945226, 
          0.26934664190771374`}, {-1.1930908687195279`, \
-0.12858529845236003`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.6404934685934145, 0.7679636167743735}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.9985140049276655, 0.6655597508588647}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.6404934685934145, 
          0.7679636167743735}, {-0.9985140049276655, 0.6655597508588647}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9154034972740934, 0.40253749785375115`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1525872437013622`, 0.333980007870077}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9154034972740934, 
          0.40253749785375115`}, {-1.1525872437013622`, 
          0.333980007870077}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.5244039214944852, 0.8514696278324939}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.27579232350459887`, 1.167877816509901}]}, 
        {GrayLevel[0], 
         LineBox[{{0.5244039214944852, 0.8514696278324939}, {
          0.27579232350459887`, 1.167877816509901}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.5980110201146679, -0.8014878787738554}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.6179849979419416, -1.0286372258083498`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.5980110201146679, -0.8014878787738554}, \
{-0.6179849979419416, -1.0286372258083498`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.7882464032353602, -0.615359738516031}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.0405883152746565`, -0.5976419982848034}]}, 
        {GrayLevel[0], 
         LineBox[{{0.7882464032353602, -0.615359738516031}, {
          1.0405883152746565`, -0.5976419982848034}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9939970714373731, -0.10940668157807264`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.1866599238538555`, -0.1784326907244351}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9939970714373731, -0.10940668157807264`}, \
{-1.1866599238538555`, -0.1784326907244351}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.2085702776354608, -0.9780073820207428}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.6617860434145877, -1.0010190970913921`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.2085702776354608, -0.9780073820207428}, {
          0.6617860434145877, -1.0010190970913921`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9397308207919725, 0.3419151714294726}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{1.1215826023457471`, 0.4266760669586958}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9397308207919725, 0.3419151714294726}, {
          1.1215826023457471`, 0.4266760669586958}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.5011614983121483, 0.8653537730948669}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.2496312636066847, 1.1737479423752484`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.5011614983121483, 0.8653537730948669}, {
          0.2496312636066847, 1.1737479423752484`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9016375888602993, -0.43249237953308023`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.9945931005195972, -0.6714049183606078}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9016375888602993, -0.43249237953308023`}, \
{-0.9945931005195972, -0.6714049183606078}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.488728801507221, 0.8724357618629095}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.4341607719176248, 1.1187065853600273`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.488728801507221, 0.8724357618629095}, {
          0.4341607719176248, 1.1187065853600273`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.17281261748206103`, 0.9849547193851089}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.28062738613883353`, 1.1667254476306264`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.17281261748206103`, 
          0.9849547193851089}, {-0.28062738613883353`, 
          1.1667254476306264`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.9652126237079234, 0.2614662330681854}]}, 
        {RGBColor[0, 0, 1], PointBox[{1.054709158948689, 0.572353553347709}]}, 
        {GrayLevel[0], 
         LineBox[{{0.9652126237079234, 0.2614662330681854}, {
          1.054709158948689, 0.572353553347709}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.37526765638493276`, 0.9269164935803872}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.12552902281535316`, 1.1934162997173376`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.37526765638493276`, 0.9269164935803872}, {
          0.12552902281535316`, 1.1934162997173376`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{0.3454385276360904, 0.9384413799618013}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-0.005710886115688462, 1.1999864106646265`}]}, 
        {GrayLevel[0], 
         LineBox[{{0.3454385276360904, 
          0.9384413799618013}, {-0.005710886115688462, 
          1.1999864106646265`}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.9751777045287374, -0.22142367667000357`}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{-1.0892841333009713`, -0.5034481869455396}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.9751777045287374, -0.22142367667000357`}, \
{-1.0892841333009713`, -0.5034481869455396}}]}}, {
        {RGBColor[1, 0, 0], 
         PointBox[{-0.008200944436585556, -0.9999663716897425}]}, 
        {RGBColor[0, 0, 1], 
         PointBox[{0.12427562949866537`, -1.1935474719979557`}]}, 
        {GrayLevel[0], 
         LineBox[{{-0.008200944436585556, -0.9999663716897425}, {
          0.12427562949866537`, -1.1935474719979557`}}]}}}], {576., -189.7655532657435},
      ImageScaled[{0.5, 0.5}], {360., 361.45819669665434}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7395558875539827`*^9, 3.739555959054525*^9, {3.739556082142404*^9, 
   3.739556119367227*^9}, 3.739556208531363*^9, 3.739556371040265*^9},
 CellLabel->
  "Out[587]=",ExpressionUUID->"c4f8d7d2-2ab8-40ea-bae0-1f57442d6907"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Checks of 3D--  ",
  FontWeight->"Bold"],
 "q= {cot/2, sint/2 (nhat)}  ",
 StyleBox[" --- fine...",
  FontWeight->"Bold"]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.726367955799733*^9, 3.726368022887343*^9}, 
   3.740597702871584*^9, {3.740598341680839*^9, 
   3.740598348032867*^9}},ExpressionUUID->"5ac11885-fe92-436d-9440-\
03e8245ac652"],

Cell[BoxData[
 RowBox[{"checkQ", " ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"vectorFromForm", "[", 
      RowBox[{"#", ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], "&"}], 
    ",", " ", 
    RowBox[{"qprod", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
      RowBox[{"qprod", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], " ", ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", 
          RowBox[{"-", "q1"}], ",", 
          RowBox[{"-", "q2"}], ",", 
          RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}], "]"}]}], "]"}]}]], "Input",\

 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.7263488993759203`*^9, 3.726348922505287*^9}, 
   3.726367973792848*^9, 
   3.740597702872335*^9},ExpressionUUID->"1b49c889-3181-486b-ae88-\
2e48bf8d6b30"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{3.7263489229203367`*^9, 3.726367973793332*^9, 
  3.740597702873107*^9},ExpressionUUID->"2c3645d3-6b0c-48c1-a297-\
d472dde93c20"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"checkQ", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"2", ";;", "4"}], ",", 
            RowBox[{"2", ";;", "4"}]}], "]"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"q0", "\[Rule]", 
            RowBox[{"Cos", "[", 
             RowBox[{"t", "/", "2"}], "]"}]}], ",", 
           RowBox[{"q1", "\[Rule]", " ", 
            RowBox[{"nx", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"t", "/", "2"}], "]"}]}]}], ",", 
           RowBox[{"q2", "\[Rule]", " ", 
            RowBox[{"ny", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"t", "/", "2"}], "]"}]}]}], ",", 
           RowBox[{"q3", "\[Rule]", " ", 
            RowBox[{"nz", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"t", "/", "2"}], "]"}]}]}]}], "}"}]}], "//", 
        "TrigReduce"}], "//", "Simplify"}], "//", "MatrixForm"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["nx", "2"], "+", 
         SuperscriptBox["ny", "2"], "+", 
         SuperscriptBox["nz", "2"]}], ")"}], "\[Rule]", " ", 
       RowBox[{"2", " ", "-", 
        RowBox[{"2", 
         SuperscriptBox["nx", "2"]}]}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["nx", "2"], "-", 
         SuperscriptBox["ny", "2"], "+", 
         SuperscriptBox["nz", "2"]}], ")"}], "\[Rule]", " ", 
       RowBox[{"2", " ", "-", 
        RowBox[{"2", 
         SuperscriptBox["ny", "2"]}]}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["nx", "2"], "+", 
         SuperscriptBox["ny", "2"], "-", 
         SuperscriptBox["nz", "2"]}], ")"}], "\[Rule]", " ", 
       RowBox[{"2", " ", "-", 
        RowBox[{"2", 
         SuperscriptBox["nz", "2"]}]}]}]}], "}"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "+", 
       SuperscriptBox["nx", "2"], "-", 
       SuperscriptBox["ny", "2"], "-", 
       SuperscriptBox["nz", "2"]}], "\[Rule]", "  ", 
      RowBox[{"2", " ", 
       SuperscriptBox["nx", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"1", "-", 
       SuperscriptBox["nx", "2"], "+", 
       SuperscriptBox["ny", "2"], "-", 
       SuperscriptBox["nz", "2"]}], "\[Rule]", "   ", 
      RowBox[{"2", " ", 
       SuperscriptBox["ny", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"1", "-", 
       SuperscriptBox["nx", "2"], "-", 
       SuperscriptBox["ny", "2"], "+", 
       SuperscriptBox["nz", "2"]}], "\[Rule]", "   ", 
      RowBox[{"2", " ", 
       SuperscriptBox["nz", "2"]}]}]}], "}"}]}], "//", "Simplify"}]], "Input",\

 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.726349050656274*^9, 3.7263491111410427`*^9}, {
   3.7263491631181498`*^9, 3.7263491843642397`*^9}, {3.726349308380659*^9, 
   3.726349338538558*^9}, {3.726349393859468*^9, 3.7263494996492033`*^9}, {
   3.726349549358073*^9, 3.726349570449789*^9}, {3.726349602620985*^9, 
   3.7263496539050627`*^9}, {3.726349734466134*^9, 3.726349750247257*^9}, 
   3.726367973793912*^9, 
   3.7405977028738613`*^9},ExpressionUUID->"660b1eda-1291-4918-97a7-\
fd311852a14f"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["nx", "2"], "+", 
       RowBox[{"Cos", "[", "t", "]"}], "-", 
       RowBox[{
        SuperscriptBox["nx", "2"], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}]}], 
      RowBox[{
       RowBox[{"nx", " ", "ny"}], "-", 
       RowBox[{"nx", " ", "ny", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "-", 
       RowBox[{"nz", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], 
      RowBox[{
       RowBox[{"nx", " ", "nz"}], "-", 
       RowBox[{"nx", " ", "nz", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "+", 
       RowBox[{"ny", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}]},
     {
      RowBox[{
       RowBox[{"nx", " ", "ny"}], "-", 
       RowBox[{"nx", " ", "ny", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "+", 
       RowBox[{"nz", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], 
      RowBox[{
       SuperscriptBox["ny", "2"], "+", 
       RowBox[{"Cos", "[", "t", "]"}], "-", 
       RowBox[{
        SuperscriptBox["ny", "2"], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}]}], 
      RowBox[{
       RowBox[{"ny", " ", "nz"}], "-", 
       RowBox[{"ny", " ", "nz", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "-", 
       RowBox[{"nx", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}]},
     {
      RowBox[{
       RowBox[{"nx", " ", "nz"}], "-", 
       RowBox[{"nx", " ", "nz", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "-", 
       RowBox[{"ny", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], 
      RowBox[{
       RowBox[{"ny", " ", "nz"}], "-", 
       RowBox[{"ny", " ", "nz", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "+", 
       RowBox[{"nx", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], 
      RowBox[{
       SuperscriptBox["nz", "2"], "+", 
       RowBox[{"Cos", "[", "t", "]"}], "-", 
       RowBox[{
        SuperscriptBox["nz", "2"], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{
  3.726349112148559*^9, {3.7263491743932543`*^9, 3.726349184742257*^9}, {
   3.726349310749937*^9, 3.7263493390557833`*^9}, 3.72634945179849*^9, 
   3.7263495000207157`*^9, 3.726349571732724*^9, 3.726349655115286*^9, 
   3.726349751854589*^9, 3.726367973794388*^9, 
   3.740597702874585*^9},ExpressionUUID->"bc1465c4-ae1c-4f1e-8d28-\
275182d825ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeRotation", "[", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"nx", ",", "ny", ",", "nz"}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{"1.0", "  ", "\[Rule]", "1"}], " ", "}"}]}], " ", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1.`", " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], " ", "\[Rule]", 
    RowBox[{"Cos", "[", "t", "]"}]}], " ", "}"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.726349204093691*^9, 3.72634927590757*^9}, {
   3.726349790664712*^9, 3.726349830882172*^9}, 3.726367973794877*^9, 
   3.7405977028753357`*^9},ExpressionUUID->"29974b0d-3dc3-46fc-85fa-\
ad78c6f03160"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["nx", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"Cos", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"nx", " ", "ny", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"1.`", " ", "nz", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"nx", " ", "nz", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"ny", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"nx", " ", "ny", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"nz", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["ny", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"Cos", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"ny", " ", "nz", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"1.`", " ", "nx", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"nx", " ", "nz", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"1.`", " ", "ny", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"ny", " ", "nz", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"nx", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["nz", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1.`", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.},
 CellChangeTimes->{{3.726349217285158*^9, 3.726349276935594*^9}, {
   3.726349798306847*^9, 3.72634983340457*^9}, 3.726367973795343*^9, 
   3.7405977028760977`*^9},ExpressionUUID->"e58b40c7-f3da-4e6b-88a5-\
a97c9370e97b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic path to the 3D  solution:", "Section",
 CellChangeTimes->{{3.706144720115918*^9, 3.706144727715445*^9}, {
  3.7061447874115543`*^9, 3.706144789875288*^9}, {3.706146616724567*^9, 
  3.706146624747994*^9}, {3.707662418145602*^9, 3.7076624192177267`*^9}, {
  3.727633939670992*^9, 3.7276339462960978`*^9}, {3.7276339844706917`*^9, 
  3.727633986287195*^9}},ExpressionUUID->"ea156c93-390a-40b0-b9e4-\
13e491dd53e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"convert", " ", "to", " ", "p3sq"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqnsxxyyzz", "=", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["xx", "2"], "-", 
        RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
        SuperscriptBox["yy", "2"], "-", 
        RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
        RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
        SuperscriptBox["zz", "2"]}], "\[Equal]", "p4"}], ",", 
      RowBox[{
       RowBox[{"64", " ", "xx", " ", "yy", " ", "zz"}], "\[Equal]", 
       SuperscriptBox["p3", "2"]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], "\[Equal]", "p2"}]}], 
     "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.718239887083992*^9, 3.7182399901036453`*^9}, {
   3.718240791303701*^9, 3.718240799621731*^9}, {3.7182408955467787`*^9, 
   3.718240914318993*^9}, 3.718240984413211*^9, {3.71830239090114*^9, 
   3.718302396188451*^9}, {3.718965969710548*^9, 
   3.71896597823615*^9}},ExpressionUUID->"a6863ca0-67a1-454b-b8d1-\
08567101ccbe"],

Cell[TextData[StyleBox["  the set of equations in {xx,yy,zz}  runs for 1 \
minute and gets an answer:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.718268135077319*^9, 3.7182682029245033`*^9}, {
  3.718566109874337*^9, 3.718566135309482*^9}, {3.718566499759536*^9, 
  3.7185665194930973`*^9}},ExpressionUUID->"0c6c834c-1733-4164-831d-\
fd99406549cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"solnxxyyzz", " ", "=", " ", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"eqnsxxyyzz", ",", 
       RowBox[{"{", 
        RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}]}], "]"}], "//", 
     "Simplify"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7182409772892*^9, 3.718240991567073*^9}, {
   3.718242410990157*^9, 3.718242413268931*^9}, 
   3.718242612270728*^9},ExpressionUUID->"43bc3b1f-d892-4736-9c4f-\
cc1c91deb70d"],

Cell[BoxData["75.621503`"], "Output",
 CellChangeTimes->{3.718242699464625*^9, 3.7182796602963037`*^9, 
  3.71856660705029*^9, 3.718995670959694*^9, 
  3.719170972747797*^9},ExpressionUUID->"9f9cad83-7e18-4b4f-855f-\
5ed9a4347ea4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"ByteCount", ",", "solnxxyyzz", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.718566621440036*^9, 
  3.718566631973278*^9}},ExpressionUUID->"f5e2e995-391f-4c1a-9498-\
3380df0cf807"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4584", ",", "19544", ",", "21552"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4584", ",", "19448", ",", "21552"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22232", ",", "28640"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22400", ",", "28736"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22256", ",", "28632"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22392", ",", "28728"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.718566632372364*^9, 3.718995741308429*^9, 
  3.719171018166819*^9},ExpressionUUID->"b6a5f092-9151-412f-ac94-\
0df8062a7d35"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Example", " ", "solution"}], " ", "*)"}], "  ", 
  RowBox[{"solnxxyyzz", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.718566729644546*^9, 3.718566732652195*^9}, {
  3.7185667698797073`*^9, 3.7185667977156057`*^9}, {3.718566883276229*^9, 
  3.718566890506445*^9}},ExpressionUUID->"4b8665f4-376d-44b1-a890-\
42d0c1ab6f29"],

Cell[BoxData[
 RowBox[{"xx", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["p2", "6"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p2", "2"], "+", 
      RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"12", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", 
               SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
              RowBox[{"432", " ", "p2", " ", 
               SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", 
           SuperscriptBox["p3", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"81", " ", 
             SuperscriptBox["p3", "4"]}], "-", 
            RowBox[{"48", " ", 
             SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
            RowBox[{"432", " ", "p2", " ", 
             SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["p2", "2"], " ", 
             SuperscriptBox["p4", "2"]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]}]}]], "Output",
 CellChangeTimes->{
  3.719170982846155*^9},ExpressionUUID->"1a0f180c-f092-43c0-a06f-\
0d254e9eaf6e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bottom line: 3D  - these functions are rock solid for p1 = 0", \
"Subchapter",
 CellChangeTimes->{{3.729097251686034*^9, 3.7290972633097973`*^9}, {
  3.729103266894742*^9, 
  3.729103269878552*^9}},ExpressionUUID->"e523ad89-3903-43e3-84bf-\
6534ef2522fc"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  "\"\</home/hanson/Dropbox/Articles/Horn-soln-dir/00paper/figs/\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.7293512769570103`*^9, 
  3.7293512846296663`*^9}},ExpressionUUID->"e808e76c-f034-4ce1-b530-\
326ab82a58ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Recover", " ", "same", " ", "1000", " ", "samples", " ", "for", " ", 
    "repeatability"}], "*)"}], "  ", 
  RowBox[{
   RowBox[{"Get", "[", "\"\<3Dmats+rules.m\>\"", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.729103934003336*^9, 3.729103959105101*^9}, 
   3.729104021591982*^9, {3.729351816247738*^9, 
   3.729351829224512*^9}},ExpressionUUID->"59eb3e4b-73ca-4735-8611-\
4e816140d8b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Recover", " ", "same", " ", "1000", " ", "samples"}], " ", "*)"}],
   "  ", 
  RowBox[{
   RowBox[{"Get", "[", "\"\<4Dmats+rules.m\>\"", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.729104028184649*^9, 3.729104030736085*^9}, {
  3.729351833488845*^9, 
  3.729351840256299*^9}},ExpressionUUID->"1000df5c-8457-47a6-bfa5-\
0e780767f7ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "large3Dmats", ",", "large3DPnrules", ",", "large4Dmats", ",", 
    "large4DPnrules"}], "}"}], ";"}]], "Input",
 CellChangeTimes->{{3.7290973515661297`*^9, 3.729097376061071*^9}, {
  3.7293513017173777`*^9, 
  3.729351311941111*^9}},ExpressionUUID->"8cc3e9d3-aa9a-4988-9e13-\
7fe238bac849"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"large3Dmats", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"makeMxxmat", "[", 
        RowBox[{"makeExxmat", "@@", 
         RowBox[{
          RowBox[{"buildXRMSDdataset", "[", "100", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], ",", "1000"}], 
      "]"}]}], ",", 
    RowBox[{"large3DPnrules", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"makePnNumRule", "[", 
        RowBox[{"makeXYZnumRule", "[", 
         RowBox[{"large3Dmats", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "large3Dmats", "]"}]}], "}"}]}], "]"}]}]}], 
   "}"}], ";"}]], "Input",
 CellChangeTimes->{{3.728827714768053*^9, 3.7288278204261103`*^9}, {
  3.7290135775148687`*^9, 3.729013581978819*^9}, {3.729013614971999*^9, 
  3.729013708269033*^9}},ExpressionUUID->"1c4c4d7d-8f79-408c-bc05-\
ee2b1dfe34ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"large4Dmats", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"makeMwwmat", "[", 
        RowBox[{"makeEwwmat", "@@", 
         RowBox[{
          RowBox[{"buildX4DRMSDdataset", "[", "100", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], ",", "1000"}], 
      "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"large4DPnrules", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"makePn4NumRule", "[", 
        RowBox[{"makeWXYZnumRule", "[", 
         RowBox[{"large4Dmats", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "large4Dmats", "]"}]}], "}"}]}], "]"}]}]}], 
   "}"}], ";"}]], "Input",
 CellChangeTimes->{{3.728827714768053*^9, 3.728827748133671*^9}, {
  3.728827792313651*^9, 3.7288278254090567`*^9}, {3.728828235973421*^9, 
  3.728828304896839*^9}, {3.7288283507320213`*^9, 3.7288284023085527`*^9}, {
  3.729013548698675*^9, 
  3.729013556170617*^9}},ExpressionUUID->"aa5d76b6-9b8a-43d9-92e1-\
b853ec6fc8f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"buildQRMSDdataset", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.729967659416113*^9, 
  3.729967671258872*^9}},ExpressionUUID->"0aff2cfd-8866-47ba-b1ac-\
dc5972c71f50"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.2880433202066317`"}], ",", "0.11021499228505621`", ",",
        "0.9449474398245093`", ",", "0.10935281033906152`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2317382837023868`", ",", 
       RowBox[{"-", "0.8598722667866934`"}], ",", "0.33738064406185597`", ",", 
       RowBox[{"-", "0.30510875715094377`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.42765239871041955`"}], ",", "0.30537472674730287`", 
       ",", "0.8267907600702653`", ",", 
       RowBox[{"-", "0.20069066047942452`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0130249763958735`", ",", 
       RowBox[{"-", "0.9007893656070014`"}], ",", "0.2333453529264015`", ",", 
       
       RowBox[{"-", "0.36600384569957234`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9238795325112867`", ",", "0.2709105613242519`", ",", 
       RowBox[{"-", "0.2509656809057525`"}], ",", "0.10035090521373975`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.85389184566059`", ",", 
         RowBox[{"-", "0.32140280176650965`"}], ",", 
         RowBox[{"-", "0.4093518717814647`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.049445787817307685`", ",", "0.8330743271715235`", ",", 
         RowBox[{"-", "0.5509467120101899`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.5180963520248688`", ",", "0.4502081789842906`", ",", 
         "0.7272473895409814`"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4624346467397234`"}], ",", "0.3021294865824282`", 
         ",", "0.8192932679542029`", ",", 
         RowBox[{"-", "0.15372219071125984`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13413912428055222`"}], ",", 
         RowBox[{"-", "0.8999141103319357`"}], ",", "0.37348920355105225`", 
         ",", 
         RowBox[{"-", "0.1807404332005663`"}]}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.729967694702628*^9},ExpressionUUID->"0f97a779-8d18-4d6b-b069-\
781c79f67c76"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Dimensions", "/@", 
   RowBox[{"{", 
    RowBox[{
    "large3Dmats", ",", "large3DPnrules", ",", "large4Dmats", ",", 
     "large4DPnrules"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.729103974147737*^9, 
  3.729103999704648*^9}},ExpressionUUID->"aa874b8b-f178-40b7-ae48-\
9abd09b4597c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1000", ",", "4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729103988436645*^9, 
  3.7291040007481823`*^9}},ExpressionUUID->"2bcbf03d-1da1-4413-9d81-\
54b85ac04235"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox[" ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["See abSubRule in HornXYZ-2.nb -- this is basic derivation of \
Solution\n\
----------------------------------------------------------------------------",
  
  FontSize->24,
  FontWeight->"Bold"]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7293513969241343`*^9, 3.7293514113715363`*^9}, {
  3.729351685657381*^9, 3.729351711933303*^9}, {3.729967628827374*^9, 
  3.729967631475285*^9}},ExpressionUUID->"c0005cd0-c90e-4b09-8d45-\
45044a7d3b1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pNtoABRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"9", " ", "p2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "p3"}], "+", 
          RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
       RowBox[{"27", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p3", "2"], "+", 
          RowBox[{
           SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], "\[Rule]", 
      RowBox[{"2", " ", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{"9", " ", "p2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "p3"}], "+", 
          RowBox[{"8", " ", "p4"}]}], ")"}]}], "-", 
       RowBox[{"27", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p3", "2"], "+", 
          RowBox[{
           SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], "a"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", "p2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p1", " ", "p3"}], "+", 
             RowBox[{"8", " ", "p4"}]}], ")"}]}], "-", 
          RowBox[{"27", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p3", "2"], "+", 
             RowBox[{
              SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}]}], 
      "\[Rule]", 
      RowBox[{"-", " ", "a"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "-", 
           RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
           RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "3"]}], "-", 
          RowBox[{"9", " ", "p2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p1", " ", "p3"}], "+", 
             RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
          RowBox[{"27", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p3", "2"], "+", 
             RowBox[{
              SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
        "2"]}], "\[Rule]", " ", 
      RowBox[{"4", 
       SuperscriptBox["b", "2"]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "-", 
        RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
        RowBox[{"12", " ", "p4"}]}], ")"}], "\[Rule]", " ", 
      SuperscriptBox[
       RowBox[{"(", "asqPMbsq", ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}]]}]}], "}"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.72882443237049*^9, 3.728824437058282*^9}, {
   3.728848014842094*^9, 3.728848051019175*^9}, {3.728848095054039*^9, 
   3.7288480986824093`*^9}, 3.728848166801447*^9, {3.728848400383953*^9, 
   3.728848400917441*^9}, {3.728848432191791*^9, 3.728848515708892*^9}, 
   3.729351699738743*^9},ExpressionUUID->"9b946ebc-ea11-4f0c-bb3c-\
b3357e20bf27"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "+", " ", "b"}], ")"}], 
     RowBox[{"1", "/", "3"}]], "\[Rule]", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "+", " ", "b"}], ")"}], 
     RowBox[{"1", "/", "3"}]]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", " ", "b"}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], 
      RowBox[{"1", "/", "6"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], 
      RowBox[{"1", "/", "6"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}], "]"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], 
      RowBox[{"1", "/", "6"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"-", "a"}], ",", "b"}], "]"}]}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"-", "a"}], ",", "b"}], "]"}]}], "]"}]}]}], ")"}]}]}], 
   ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], 
      RowBox[{"1", "/", "6"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "6"], "+", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"ArcTan", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}]}], "]"}]}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "6"], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}]}], "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], 
      RowBox[{"1", "/", "6"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"-", "a"}], ",", 
           RowBox[{"-", "b"}]}], "]"}]}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"-", "a"}], ",", 
            RowBox[{"-", "b"}]}], "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], 
      RowBox[{"1", "/", "6"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "6"], "+", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"ArcTan", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}]}], "]"}]}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "6"], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}]}], "]"}]}], ")"}]}]}]}], 
  "}"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7291229358658524`*^9, {3.729122990513308*^9, 3.729123024288988*^9}, 
   3.729351699739262*^9},ExpressionUUID->"d4e84bf1-d993-4fe3-be2c-\
31bf5644a831"],

Cell[TextData[StyleBox["   These are out of order, etc., but the \
simplification process is here:\n     the earlier versions had  x,y,z mixed \
up because of (-a - i b)",
 FontSize->24,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.729351594361958*^9, 3.729351632698769*^9}, 
   3.729351699739579*^9},ExpressionUUID->"0ccd9650-2787-437e-a240-\
0d94e09331bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"This", " ", "is", " ", "X"}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "-", 
        RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
        RowBox[{"12", " ", "p4"}]}], "  ", ")"}], 
      RowBox[{
       RowBox[{"root3", "[", "\"\<x\>\"", "]"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"theQfun", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}]]}]], " ", "+", "  ", 
     RowBox[{
      RowBox[{"root3", "[", "\"\<x\>\"", "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"theQfun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}]]}]}], "/.", "pNtoABRule"}], " ", "/.", 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "-", 
         RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"9", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "p3"}], "+", 
           RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
        RowBox[{"27", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p3", "2"], "+", 
           RowBox[{
            SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
      "2"]}], "\[Rule]", " ", 
    RowBox[{"4", 
     SuperscriptBox["b", "2"]}]}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.728849276277337*^9, 3.7288492843965197`*^9}, {
   3.7288507099337997`*^9, 3.728850717326754*^9}, 
   3.729351699740098*^9},ExpressionUUID->"94bb3881-9c31-421c-85a8-\
8d176094f942"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["asqPMbsq", 
     RowBox[{"1", "/", "3"}]]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox[
         SuperscriptBox["b", "2"]]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox[
        SuperscriptBox["b", "2"]]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.728850720522736*^9, 
  3.7293516997406816`*^9},ExpressionUUID->"20b95de8-4fe7-4259-a35d-\
f19a29b06ce4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"This", " ", "is", " ", "Y"}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "-", 
        RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
        RowBox[{"12", " ", "p4"}]}], "  ", ")"}], 
      RowBox[{
       RowBox[{"root3", "[", "\"\<y\>\"", "]"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"theQfun", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}]]}]], " ", "+", "  ", 
     RowBox[{
      RowBox[{"root3", "[", "\"\<y\>\"", "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"theQfun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}]]}]}], "/.", "pNtoABRule"}], " ", "/.", 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "-", 
         RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"9", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "p3"}], "+", 
           RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
        RowBox[{"27", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p3", "2"], "+", 
           RowBox[{
            SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
      "2"]}], "\[Rule]", " ", 
    RowBox[{"4", 
     SuperscriptBox["b", "2"]}]}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7288478904503117`*^9, 3.728847910410499*^9}, {
   3.728848318333612*^9, 3.728848320904709*^9}, {3.728848355112073*^9, 
   3.7288483786483393`*^9}, {3.7288485901327868`*^9, 3.728848609628083*^9}, {
   3.728848697964203*^9, 3.7288487238504133`*^9}, 
   3.729351699741234*^9},ExpressionUUID->"5cfc5699-8557-48da-9c94-\
aa718473153b"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["asqPMbsq", 
     RowBox[{"1", "/", "3"}]]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox[
         SuperscriptBox["b", "2"]]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox[
        SuperscriptBox["b", "2"]]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.728848321867837*^9, {3.728848366009818*^9, 3.728848380667923*^9}, 
   3.728848530090094*^9, {3.728848593403945*^9, 3.728848611033444*^9}, 
   3.72884872566028*^9, 
   3.729351699741846*^9},ExpressionUUID->"3ca72701-7bc3-421a-8551-\
5f90982d94e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"This", " ", "is", " ", "Z"}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "-", 
        RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
        RowBox[{"12", " ", "p4"}]}], "  ", ")"}], 
      RowBox[{
       RowBox[{"root3", "[", "\"\<z\>\"", "]"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"theQfun", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}]]}]], " ", "+", "  ", 
     RowBox[{
      RowBox[{"root3", "[", "\"\<z\>\"", "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"theQfun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}]]}]}], "/.", "pNtoABRule"}], " ", "/.", 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "-", 
         RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"9", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "p3"}], "+", 
           RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
        RowBox[{"27", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p3", "2"], "+", 
           RowBox[{
            SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
      "2"]}], "\[Rule]", " ", 
    RowBox[{"4", 
     SuperscriptBox["b", "2"]}]}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.728849276277337*^9, 3.7288492843965197`*^9}, 
   3.729351699742391*^9},ExpressionUUID->"df2b95c4-64e5-43bd-a87f-\
a278bd8977dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    SuperscriptBox["asqPMbsq", 
     RowBox[{"1", "/", "3"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox[
         SuperscriptBox["b", "2"]]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]]}], "-", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "a"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}]}], ")"}], 
   RowBox[{"1", "/", "3"}]]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.728849289664567*^9, 
  3.7293516997430277`*^9},ExpressionUUID->"3943c3c2-49eb-46ca-9ff7-\
dfd4d086a0f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"phi0", ",", "phip", ",", "phim"}], "}"}], " ", "\[Rule]", 
  RowBox[{"First", "[", " ", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"Switch", "[", 
      RowBox[{"tag", ",", "\"\<x\>\"", ",", 
       RowBox[{"-", "1"}], ",", "\"\<y\>\"", ",", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], "2"], " ", ",", "\"\<z\>\"", ",", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], "2"]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tag", "\[Rule]", "\"\<x\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"tag", "\[Rule]", "\"\<y\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"tag", "\[Rule]", "\"\<z\>\""}], "}"}]}], "}"}]}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.729352209077531*^9, 
  3.729352446763831*^9}},ExpressionUUID->"bad0fdd9-f69b-4c3a-ac4e-\
e5470b2e222c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"phi0", ",", "phip", ",", "phim"}], "}"}], "\[Rule]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}]}], ",", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}]}]}], "}"}]}]], "Output",
 CellChangeTimes->{
  3.729352359283875*^9, {3.7293523912842913`*^9, 
   3.7293524476180153`*^9}},ExpressionUUID->"afc03b1b-aec9-44be-86e4-\
e6d20b87d2a9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"aFun", "[", " ", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   SuperscriptBox["p2", "3"], "+", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "9"}], " ", "p2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "p3"}], "+", 
         RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
      RowBox[{"27", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p3", "2"], "+", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.72874044187215*^9, 3.7287404569567757`*^9}, {
  3.728747493423954*^9, 
  3.728747506947139*^9}},ExpressionUUID->"bb3c6292-0046-4196-9507-\
56297fd07ae4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsqFun", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", " ", 
  RowBox[{"(", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "-", 
       RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}], "3"], "-", 
    SuperscriptBox[
     RowBox[{"(", " ", 
      RowBox[{
       SuperscriptBox["p2", "3"], "-", 
       RowBox[{
        FractionBox["9", "2"], " ", "p2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "p3"}], "+", 
          RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"27", " "}], "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p3", "2"], "+", 
          RowBox[{
           SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], "2"]}],
    ")"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.7287404672947407`*^9, 3.728740482828661*^9}, {
   3.728747413656727*^9, 3.728747449355983*^9}, {3.729105062207823*^9, 
   3.729105096599821*^9}, 
   3.729105296941227*^9},ExpressionUUID->"12d56fec-c68f-42a1-b5ba-\
cebe2fb3d629"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p2", "2"], "-", 
      RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
      RowBox[{"12", " ", "p4"}]}], ")"}], "3"], "-", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p2", "3"], "-", 
      RowBox[{
       FractionBox["9", "2"], " ", "p2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "p3"}], "+", 
         RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p3", "2"], "+", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
    "2"]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.729105134486219*^9, 3.729105134492717*^9}, 
   3.729105296941743*^9},ExpressionUUID->"3fa53f0f-53ca-4e4c-a89a-\
291de517a150"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "-", 
         RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"9", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "p3"}], "+", 
           RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
        RowBox[{"27", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p3", "2"], "+", 
           RowBox[{
            SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
      "2"]}], ")"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.729105122877694*^9, 3.729105122883686*^9}, 
   3.729105296942235*^9},ExpressionUUID->"7e1bc77d-151f-4375-b4e0-\
e7beea27e1a4"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "-", 
       RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}], "3"], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "3"], "-", 
       RowBox[{
        FractionBox["9", "2"], " ", "p2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "p3"}], "+", 
          RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["27", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p3", "2"], "+", 
          RowBox[{
           SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], "2"], 
    "-", 
    RowBox[{"(", " ", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "-", 
            RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "3"]}], "-", 
           RowBox[{"9", " ", "p2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"p1", " ", "p3"}], "+", 
              RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
           RowBox[{"27", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p3", "2"], "+", 
              RowBox[{
               SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
         "2"]}], ")"}]}], ")"}]}], "//", "Expand"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7291051466696253`*^9, 3.7291051581178617`*^9}, {
   3.7291052021286507`*^9, 3.729105230709244*^9}, 
   3.729105296942897*^9},ExpressionUUID->"ef3e1d89-8477-4dac-b0f3-\
36932074b698"],

Cell[BoxData["0"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.729105231139797*^9, 
  3.729105296943396*^9},ExpressionUUID->"007a4982-442b-4e6e-98cf-\
aeef3b1b10a2"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Problem", " ", "-", " ", 
     RowBox[{
     "the", " ", "Sign", " ", "of", " ", "nFun", " ", "may", " ", 
      "change"}]}], ",", " ", 
    RowBox[{
    "which", " ", "makes", " ", "the", " ", "cube", " ", "root", " ", "of", 
     " ", "THIS", " ", "ambiguous", " ", "by", " ", "a", " ", "phase"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"bsqFun", "[", 
     RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "+", 
    SuperscriptBox[
     RowBox[{"aFun", "[", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "2"]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.728954312664928*^9, 3.728954355303568*^9}, {
  3.729352144302202*^9, 
  3.7293521769730377`*^9}},ExpressionUUID->"117bc67e-bb2d-45f6-882f-\
f30e93e98d25"],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["p2", "2"], "-", 
    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]], "Output",
 CellChangeTimes->{{3.728954343117567*^9, 3.728954355943754*^9}, 
   3.729105278203979*^9},ExpressionUUID->"e4328809-cc98-451f-b414-\
5eefe0ec72c6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"th", " ", "-", " ", 
        RowBox[{"2", "   ", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}], "//", "TrigExpand"}], ",", 
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"th", " ", "-", " ", 
        RowBox[{"Pi", "/", "3"}]}], "]"}]}]}], "}"}], "//", "FullSimplify"}], 
  "//", "TrigExpand"}]], "Input",
 CellChangeTimes->{{3.729377441490171*^9, 3.729377503921504*^9}, {
  3.729377540507286*^9, 3.7293775448405*^9}, {3.7293777682486*^9, 
  3.729377769261812*^9}},ExpressionUUID->"a4bcc574-54bf-48a1-bdd3-\
615c414a1ac9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Cos", "[", "th", "]"}], "2"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox["3"], " ", 
     RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Cos", "[", "th", "]"}], "2"]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox["3"], " ", 
     RowBox[{"Sin", "[", "th", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7293775048485537`*^9, 
  3.7293775452839537`*^9},ExpressionUUID->"3dcbf1f6-81bc-4966-9328-\
12677d7ff669"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"th", " ", "+", " ", 
       RowBox[{"2", " ", 
        RowBox[{"Pi", "/", "3"}]}]}], "]"}], "//", "TrigExpand"}], ")"}], "-", 
   RowBox[{"(", 
    RowBox[{"-", 
     RowBox[{"Cos", "[", 
      RowBox[{"th", " ", "-", " ", 
       RowBox[{"Pi", "/", "3"}]}], "]"}]}], ")"}]}], "//", 
  "TrigExpand"}]], "Input",
 CellChangeTimes->{{3.729377757733549*^9, 
  3.729377799370989*^9}},ExpressionUUID->"92f9325e-6eaa-4d2f-a88a-\
073796ab53b9"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.729377781124043*^9, 
  3.7293778005632067`*^9}},ExpressionUUID->"a220556b-586f-4f15-98c4-\
551989ae61e4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"th", " ", "+", "   ", 
      RowBox[{"Pi", "/", "3"}]}], "]"}], "//", "TrigExpand"}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"th", " ", "-", " ", 
      RowBox[{"Pi", "/", "3"}]}], "]"}], "//", "TrigExpand"}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"th", " ", "+", " ", 
      RowBox[{"2", " ", 
       RowBox[{"Pi", "/", "3"}]}]}], "]"}], "//", "TrigExpand"}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"th", " ", "-", " ", 
      RowBox[{"2", " ", 
       RowBox[{"Pi", "/", "3"}]}]}], "]"}], "//", "TrigExpand"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.729377335838739*^9, 
  3.7293774081467733`*^9}},ExpressionUUID->"fe52a415-7aa5-44dc-a945-\
5eccdb0c3d2d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"Cos", "[", "th", "]"}], "2"], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox["3"], " ", 
     RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"Cos", "[", "th", "]"}], "2"], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox["3"], " ", 
     RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Cos", "[", "th", "]"}], "2"]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox["3"], " ", 
     RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Cos", "[", "th", "]"}], "2"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox["3"], " ", 
     RowBox[{"Sin", "[", "th", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.729377359033044*^9, 
  3.72937741029841*^9},ExpressionUUID->"310c86ad-9813-43c2-aca5-a08db582c4be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cos", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"Pi", "/", "3"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.729378187764492*^9, 
  3.729378188650159*^9}},ExpressionUUID->"065101e7-4570-48ad-994d-\
6b89b06a6fbc"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"Sin", "[", 
   RowBox[{
    FractionBox["\[Pi]", "6"], "+", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"a", ",", "b"}], "]"}]}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.729378175408176*^9, 
  3.72937819063765*^9}},ExpressionUUID->"f58d336b-d131-4091-8947-\
6878f28aa370"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ExpToTrig", "[", 
    RowBox[{"Exp", "[", " ", 
     RowBox[{
      RowBox[{"-", "I"}], " ", "2", " ", 
      RowBox[{"Pi", "/", "3"}]}], "]"}], "]"}], ",", 
   RowBox[{"ExpToTrig", "[", 
    RowBox[{"Exp", "[", " ", 
     RowBox[{
      RowBox[{"+", "I"}], " ", "2", " ", 
      RowBox[{"Pi", "/", "3"}]}], "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.72937820133471*^9, 3.729378265465626*^9}, {
  3.7293783371382427`*^9, 
  3.729378386640539*^9}},ExpressionUUID->"20197db0-5360-41ee-a1e1-\
9b519f7b1df6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], "+", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7293782314244957`*^9, 3.7293782665683002`*^9}, 
   3.729378349749922*^9, 
   3.729378387367877*^9},ExpressionUUID->"aa0331aa-1202-4414-95c8-\
29d6c220c2af"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"Arg", "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}], "2"]}], "]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"Arg", "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}], "2"]}], "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.7293784365962553`*^9, 
  3.729378463543262*^9}},ExpressionUUID->"5ca6a947-4f91-4c56-91c4-\
9d9a0247cecf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729378464550687*^9},ExpressionUUID->"9c6eb6c1-db96-49af-a66d-\
9bdcca0da2c2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"nFun", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   SuperscriptBox["p2", "2"], "-", 
   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
   RowBox[{"12", " ", "p4"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.728954401344324*^9, 3.7289544290863247`*^9}},
 CellLabel->
  "In[293]:=",ExpressionUUID->"3652efd4-4b05-4efa-95e2-ddc676fc2588"],

Cell[BoxData[
 RowBox[{"Clear", "[", "xyzEps0", "]"}]], "Input",
 CellChangeTimes->{{3.741026329469825*^9, 3.741026341103405*^9}},
 CellLabel->
  "In[450]:=",ExpressionUUID->"0f68d42c-19ca-4b34-a16d-2f6a031740a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xyzSolns", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"aFun", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"bsqFun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "]"}]}], ",",
       "r", ",", "cosx3", ",", "cosy3", ",", "cosz3", ",", "xx", ",", "yy", 
      ",", "zz"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r", "=", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], 
       RowBox[{"1", "/", "6"}]]}], ";", 
     RowBox[{"cosx3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "]"}]}], ";", 
     RowBox[{"cosy3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ";", 
     RowBox[{"cosz3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "+", 
        RowBox[{"2", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xx", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosx3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"yy", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosy3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"zz", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosz3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", "  ", 
      RowBox[{"xx", " ", ",", " ", "yy", ",", " ", "zz"}], "}"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.728669446125628*^9, 3.7286697239218187`*^9}, {
   3.7287497678043756`*^9, 3.7287498065768948`*^9}, {3.728754912828916*^9, 
   3.7287549815386477`*^9}, {3.7287581870960207`*^9, 3.728758190655588*^9}, {
   3.7287599069186363`*^9, 3.728759916652416*^9}, 3.7287606242827044`*^9, {
   3.72882659763416*^9, 3.7288265983850393`*^9}, 3.728826797517808*^9, {
   3.728827629027663*^9, 3.7288276581739798`*^9}, {3.729351892172475*^9, 
   3.72935195432892*^9}, {3.7293778345773897`*^9, 3.7293778407682447`*^9}, 
   3.7294410766534767`*^9, {3.7410263608496017`*^9, 
   3.741026372994372*^9}},ExpressionUUID->"bfafe1db-94f6-4a65-902a-\
f06dc6d43598"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cosEpsxyz", "[", 
   RowBox[{"rootNum_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], 
   "]"}], ":=", " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"aFun", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"bsqFun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "]"}]}], ",",
       "r", ",", "cosx3", ",", "cosy3", ",", "cosz3", ",", "xx", ",", "yy", 
      ",", "zz"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r", "=", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], 
       RowBox[{"1", "/", "6"}]]}], ";", 
     RowBox[{"cosx3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "]"}]}], ";", 
     RowBox[{"cosy3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ";", 
     RowBox[{"cosz3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "+", 
        RowBox[{"2", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xx", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosx3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"yy", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosy3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"zz", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosz3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{"rootNum", ",", "\[IndentingNewLine]", "1", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "+", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", "2", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "+", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "-", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "-", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", "\[IndentingNewLine]", 
       "3", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "-", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "-", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", " ", "4", ",", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "-", "  ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "-", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}]}], "  ", "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.728669446125628*^9, 3.7286697239218187`*^9}, {
   3.7287497678043756`*^9, 3.7287498065768948`*^9}, {3.728754912828916*^9, 
   3.7287549815386477`*^9}, {3.7287581870960207`*^9, 3.728758190655588*^9}, {
   3.7287599069186363`*^9, 3.728759916652416*^9}, 3.7287606242827044`*^9, {
   3.72882659763416*^9, 3.7288265983850393`*^9}, 3.728826797517808*^9, {
   3.728827629027663*^9, 3.7288276581739798`*^9}, {3.729014730350665*^9, 
   3.72901494313868*^9}, {3.729015053588427*^9, 3.729015081172817*^9}, {
   3.7293778475590267`*^9, 
   3.7293778533776407`*^9}},ExpressionUUID->"1bf50598-7ea3-4609-af1f-\
eb014ea51110"],

Cell[TextData[StyleBox["Better notation, separate Eps0 for \
\[OpenCurlyDoubleQuote]optimal eigenvalue\[CloseCurlyDoubleQuote] from this \
EpsN for \[OpenCurlyDoubleQuote]any one\[CloseCurlyDoubleQuote].",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.740744536373927*^9, 
  3.740744565050766*^9}},ExpressionUUID->"cbe54daf-051f-47e5-a764-\
732073ed6914"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xyzEpsN", "[", 
   RowBox[{"rootNum_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], 
   "]"}], ":=", " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"aFun", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"bsqFun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "]"}]}], ",",
       "r", ",", "cosx3", ",", "cosy3", ",", "cosz3", ",", "xx", ",", "yy", 
      ",", "zz"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r", "=", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], 
       RowBox[{"1", "/", "6"}]]}], ";", 
     RowBox[{"cosx3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "]"}]}], ";", 
     RowBox[{"cosy3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ";", 
     RowBox[{"cosz3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "+", 
        RowBox[{"2", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xx", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosx3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"yy", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosy3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"zz", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosz3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{"rootNum", ",", "\[IndentingNewLine]", "1", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "+", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", "2", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "+", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "-", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "-", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", "\[IndentingNewLine]", 
       "3", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "-", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "-", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", " ", "4", ",", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "-", "  ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "-", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}]}], "  ", "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.728669446125628*^9, 3.7286697239218187`*^9}, {
   3.7287497678043756`*^9, 3.7287498065768948`*^9}, {3.728754912828916*^9, 
   3.7287549815386477`*^9}, {3.7287581870960207`*^9, 3.728758190655588*^9}, {
   3.7287599069186363`*^9, 3.728759916652416*^9}, 3.7287606242827044`*^9, {
   3.72882659763416*^9, 3.7288265983850393`*^9}, 3.728826797517808*^9, {
   3.728827629027663*^9, 3.7288276581739798`*^9}, {3.729014730350665*^9, 
   3.72901494313868*^9}, {3.729015053588427*^9, 3.729015081172817*^9}, {
   3.7293778475590267`*^9, 3.7293778533776407`*^9}, {3.7407412264292994`*^9, 
   3.740741232130877*^9}},
 CellLabel->
  "In[295]:=",ExpressionUUID->"fe37daee-5463-407e-9a06-baa0c45f9d36"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xyzEps0", "[", " ", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"aFun", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"bsqFun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "]"}]}], ",",
       "r", ",", "cosx3", ",", "cosy3", ",", "cosz3", ",", "xx", ",", "yy", 
      ",", "zz"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r", "=", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], 
       RowBox[{"1", "/", "6"}]]}], ";", 
     RowBox[{"cosx3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "]"}]}], ";", 
     RowBox[{"cosy3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ";", 
     RowBox[{"cosz3", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "/", "3"}], "+", 
        RowBox[{"2", 
         RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xx", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosx3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"yy", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosy3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"zz", "=", " ", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", "cosz3"}], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     " ", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "p1"}], "4"], "+", " ", 
      RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
      RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
      RowBox[{"Sqrt", "[", "zz", "]"}]}]}]}], " ", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.728669446125628*^9, 3.7286697239218187`*^9}, {
   3.7287497678043756`*^9, 3.7287498065768948`*^9}, {3.728754912828916*^9, 
   3.7287549815386477`*^9}, {3.7287581870960207`*^9, 3.728758190655588*^9}, {
   3.7287599069186363`*^9, 3.728759916652416*^9}, 3.7287606242827044`*^9, {
   3.72882659763416*^9, 3.7288265983850393`*^9}, 3.728826797517808*^9, {
   3.728827629027663*^9, 3.7288276581739798`*^9}, {3.729014730350665*^9, 
   3.72901494313868*^9}, {3.729015053588427*^9, 3.729015081172817*^9}, {
   3.7293778475590267`*^9, 3.7293778533776407`*^9}, {3.7407412264292994`*^9, 
   3.740741232130877*^9}, {3.741026393900311*^9, 3.741026436033772*^9}},
 CellLabel->
  "In[294]:=",ExpressionUUID->"b97da43f-f9a3-4ee4-a5c9-46057fb3202e"],

Cell[TextData[StyleBox["Now insert the arguments without global symbols:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.742993876889153*^9, 
  3.742993896400877*^9}},ExpressionUUID->"e4168531-de11-4e3c-ae49-\
839b8ca9fa27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Returns", " ", "p1"}], ",", "p2", ",", "p3", ",", 
    RowBox[{"p4", "  ", "given", " ", "4", "x4", " ", "profile", " ", 
     RowBox[{"(", 
      RowBox[{
      "as", " ", "fcn", " ", "of", " ", "E33", " ", "or", " ", "E44"}], 
      " "}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Pn4Dfun", "[", "mat4_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Tr", "[", "mat4", "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"Tr", "[", "mat4", "]"}], ")"}], "2"]}], " ", "-", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"Tr", "[", " ", 
          RowBox[{"mat4", ".", "mat4"}], "]"}]}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"-", "1"}], "6"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"Tr", "[", "mat4", "]"}], " ", ")"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}], 
          RowBox[{"Tr", "[", 
           RowBox[{"mat4", ".", "mat4"}], "]"}], 
          RowBox[{"Tr", "[", "mat4", "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "3"}], ")"}], 
          RowBox[{"Tr", "[", 
           RowBox[{"mat4", ".", "mat4", ".", "mat4"}], "]"}]}]}], ")"}], ",", 
       " ", 
       RowBox[{"Det", "[", "mat4", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742950973674449*^9, 3.742951054291946*^9}, {
  3.7429510850920067`*^9, 3.7429510874036217`*^9}, {3.7429511190752172`*^9, 
  3.7429511628842793`*^9}, {3.74295161916133*^9, 3.74295163747264*^9}, {
  3.7429939377314663`*^9, 
  3.742993976713747*^9}},ExpressionUUID->"7350e831-66d0-449e-987f-\
d874647ba0d7"],

Cell[TextData[StyleBox["   3D data Checks:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.742994069944269*^9, 3.74299407167118*^9}, {
  3.742994397156918*^9, 
  3.742994402164472*^9}},ExpressionUUID->"3c91d99f-2f99-4650-8f5a-\
89929bc5fe7a"],

Cell[CellGroupData[{

Cell[BoxData["hornE3mat"], "Input",
 CellChangeTimes->{{3.742994100222562*^9, 3.742994104158744*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"02bdf75f-fcbf-4445-a8e3-d1ee09940806"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7429941082539797`*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"98d70663-edf5-4283-b311-aae2e584c7b4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"hornM3mat", ",", 
    RowBox[{"Tr", "[", "hornM3mat", "]"}], ",", 
    RowBox[{"hornM3mat", "-", 
     RowBox[{"Transpose", "[", "hornM3mat", "]"}]}]}], "}"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.742994252082942*^9, 3.742994302916788*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"4bcaecce-cd51-4188-8d1a-5652b3a66663"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ",", 
       RowBox[{"Eyz", "-", "Ezy"}], ",", 
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], ",", 
       RowBox[{"Exy", "-", "Eyx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eyz", "-", "Ezy"}], ",", 
       RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ",", 
       RowBox[{"Exy", "+", "Eyx"}], ",", 
       RowBox[{"Exz", "+", "Ezx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], ",", 
       RowBox[{"Exy", "+", "Eyx"}], ",", 
       RowBox[{
        RowBox[{"-", "Exx"}], "+", "Eyy", "-", "Ezz"}], ",", 
       RowBox[{"Eyz", "+", "Ezy"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exy", "-", "Eyx"}], ",", 
       RowBox[{"Exz", "+", "Ezx"}], ",", 
       RowBox[{"Eyz", "+", "Ezy"}], ",", 
       RowBox[{
        RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}]}], "}"}]}], "}"}], ",",
    "0", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742994258299026*^9, 3.74299430379277*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"0e2cd394-fbd6-4ffa-9e0f-ce1c1075548e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeMxxmat", "[", "hornE3mat", "]"}]], "Input",
 CellChangeTimes->{3.74299434535388*^9},
 CellLabel->"In[55]:=",ExpressionUUID->"513000f1-764b-432f-b225-3a4ae60a0ce9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{"Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Exz"}], "+", "Ezx"}], ",", 
     RowBox[{"Exy", "-", "Eyx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{"Exy", "+", "Eyx"}], ",", 
     RowBox[{"Exz", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Exz"}], "+", "Ezx"}], ",", 
     RowBox[{"Exy", "+", "Eyx"}], ",", 
     RowBox[{
      RowBox[{"-", "Exx"}], "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{"Eyz", "+", "Ezy"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Exy", "-", "Eyx"}], ",", 
     RowBox[{"Exz", "+", "Ezx"}], ",", 
     RowBox[{"Eyz", "+", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.742994327930884*^9, 3.742994350365279*^9}},
 CellLabel->"Out[55]=",ExpressionUUID->"17200187-e53b-4dd0-8333-60427836d797"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makeMxxmat", "[", "hornE3mat", "]"}], "-", " ", 
  "hornM3mat"}]], "Input",
 CellChangeTimes->{{3.742994122999853*^9, 3.742994159806983*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"c205b439-da2f-4e44-9fa4-2afc98c0c7d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.742994160509591*^9, 3.742994359689333*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"5f30ad6e-ff43-432a-aebf-21a170c712d0"]
}, Open  ]],

Cell[TextData[StyleBox["    all looks OK for the 3D data case   ",
 FontSize->16,
 FontSlant->"Italic",
 FontVariations->{"Underline"->True}]], "Text",
 CellChangeTimes->{{3.742994371195632*^9, 
  3.742994383764624*^9}},ExpressionUUID->"21a0ba0c-d60a-4341-8535-\
7dda02e45759"],

Cell[TextData[StyleBox["  4D data checks:   Something appears to be wrong \
with makeMwwmat ??",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.742994390348193*^9, 3.742994393892489*^9}, {
  3.742995353180118*^9, 
  3.7429953794919453`*^9}},ExpressionUUID->"014f9ba4-1838-477b-954a-\
d5b69d0f8ce1"],

Cell[CellGroupData[{

Cell[BoxData["hornE4mat"], "Input",
 CellChangeTimes->{{3.742994110542965*^9, 3.742994113998994*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"40748e7b-b4f3-44a4-9233-194c6b3f9919"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Exw", ",", "Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Eyw", ",", "Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742994115080686*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"27b0fa65-ae9d-4a6d-a83b-4d673dae12ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "makeMwwmat"}]], "Input",
 CellChangeTimes->{{3.742995388442725*^9, 3.742995398064973*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"0c8a03dd-9ad2-4bf9-a3ba-97cbaf0f60df"],

Cell[CellGroupData[{

Cell["Global`makeMwwmat", "Print", "PrintUsage",
 CellChangeTimes->{3.742995400673573*^9},
 CellTags->
  "Info683742981000-7551584",ExpressionUUID->"c1e7ae49-ab68-47e5-8339-\
c6373c984492"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"makeMwwmat", "[", "Ewwmat_", "]"}], ":=", 
         RowBox[{"Module", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Eww", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Ewx", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Ewy", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Ewz", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Exw", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Exx", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Exy", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Exz", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Eyw", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Eyx", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Eyy", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Eyz", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"3", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Ezw", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"4", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Ezx", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"4", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Ezy", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"4", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Ezz", "=", 
              RowBox[{"Ewwmat", "\[LeftDoubleBracket]", 
               RowBox[{"4", ",", "4"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
               RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
               RowBox[{"Ewy", "-", "Eyw", "+", "Ezx", "-", "Exz"}], ",", 
               RowBox[{"Ewz", "-", "Ezw", "+", "Exy", "-", "Eyx"}]}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], 
               ",", 
               RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
               RowBox[{"Ewz", "+", "Ezw", "+", "Exy", "+", "Eyx"}], ",", 
               RowBox[{
                RowBox[{"-", "Ewy"}], "-", "Eyw", "+", "Ezx", "+", "Exz"}]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "Ewy"}], "+", "Eyw", "+", "Ezx", "-", "Exz"}], 
               ",", 
               RowBox[{
                RowBox[{"-", "Ewz"}], "-", "Ezw", "+", "Exy", "+", "Eyx"}], 
               ",", 
               RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
               RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "Ewz"}], "+", "Ezw", "+", "Exy", "-", "Eyx"}], 
               ",", 
               RowBox[{"Ewy", "+", "Eyw", "+", "Ezx", "+", "Exz"}], ",", 
               RowBox[{
                RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}], 
               ",", 
               RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}],
             "}"}]}], "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`makeMwwmat],
  Editable->False]], "Print",
 CellChangeTimes->{3.742995400768972*^9},
 CellTags->
  "Info683742981000-7551584",ExpressionUUID->"a5822828-3359-4efa-b872-\
9078f4e3dac0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixFromLRCoeff", "[", 
  RowBox[{
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"PQbTo4DRot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".", 
     "hornE4mat"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}]], "Input",\

 CellLabel->"In[63]:=",ExpressionUUID->"f6ee43f8-df5d-4b82-bf03-daa77c0a4dc4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7429950925212193`*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"f6b24bf9-addf-4da6-8ea4-a293c617cdc2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeMwwmat", "[", "hornE4mat", "]"}]], "Input",
 CellLabel->"In[67]:=",ExpressionUUID->"51dbfc67-c1ba-41d1-94ca-8267723789a5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7429953222319813`*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"a808b9cc-7681-4d9c-85f3-993d796b17c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"hornM4mat", ",", 
    RowBox[{"Tr", "[", "hornM4mat", "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"hornM4mat", "-", 
       RowBox[{"Transpose", "[", "hornM4mat", "]"}]}], "//", "Factor"}], "//",
      "MatrixForm"}]}], "}"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.742994730913681*^9, 3.7429947512582197`*^9}, {
  3.7429952170109253`*^9, 3.742995262557324*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"aeae8c53-2cf4-4a2a-88f7-b94fb90b4fab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
       RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
       RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
       RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
       RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
       RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
       RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"4", " ", "Eww"}], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Ewx"}], "+", 
         RowBox[{"2", " ", "Exw"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Ewy"}], "+", 
         RowBox[{"2", " ", "Eyw"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Ewz"}], "+", 
         RowBox[{"2", " ", "Ezw"}]}]},
       {
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"Ewx", "-", "Exw"}], ")"}]}], "0", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"Ewz", "+", "Ezw"}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"Ewy", "+", "Eyw"}], ")"}]}]},
       {
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"Ewy", "-", "Eyw"}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"Ewz", "+", "Ezw"}], ")"}]}], "0", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"Ewx", "+", "Exw"}], ")"}]}]},
       {
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"Ewz", "-", "Ezw"}], ")"}]}], 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"Ewy", "+", "Eyw"}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"Ewx", "+", "Exw"}], ")"}]}], "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.742994753008171*^9, {3.742995227626268*^9, 3.74299526304917*^9}},
 CellLabel->"Out[66]=",ExpressionUUID->"4f9521fa-d3ab-412b-bc9c-d161cb275f0a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makeMxxmat", "[", "hornE3mat", "]"}], "-", " ", 
  "hornM3mat"}]], "Input",
 CellChangeTimes->{{3.742994122999853*^9, 3.742994159806983*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"6487a81a-6b26-431a-b9e4-b0e3d4efef94"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.742994160509591*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"c3001de2-d754-4e19-b4f0-3af29c75ce50"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{
    StyleBox[
     RowBox[{"(", "*"}]], " ", 
    RowBox[{"THIS", " ", "FAILS"}], " ", 
    StyleBox[
     RowBox[{"*", ")"}]]}],
   FontSize->24], 
  RowBox[{
   RowBox[{"makeMwwmat", "[", "hornE4mat", "]"}], "-", " ", 
   "hornM4mat"}]}]], "Input",
 CellChangeTimes->{{3.742994176286724*^9, 3.74299418499008*^9}, {
  3.742995506950921*^9, 3.742995512956728*^9}},
 FontSize->16,ExpressionUUID->"63dcfda5-add2-476d-b16f-6f10b0d8c0e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"2", " ", "Ewx"}], "-", 
      RowBox[{"2", " ", "Exw"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "Ewy"}], "-", 
      RowBox[{"2", " ", "Eyw"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "Ewz"}], "-", 
      RowBox[{"2", " ", "Ezw"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "Ewx"}], "+", 
      RowBox[{"2", " ", "Exw"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "Ewz"}], "+", 
      RowBox[{"2", " ", "Ezw"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "Ewy"}], "-", 
      RowBox[{"2", " ", "Eyw"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "Ewy"}], "+", 
      RowBox[{"2", " ", "Eyw"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "Ewz"}], "-", 
      RowBox[{"2", " ", "Ezw"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "Ewx"}], "+", 
      RowBox[{"2", " ", "Exw"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "Ewz"}], "+", 
      RowBox[{"2", " ", "Ezw"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "Ewy"}], "+", 
      RowBox[{"2", " ", "Eyw"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "Ewx"}], "-", 
      RowBox[{"2", " ", "Exw"}]}], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.742994185792932*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"4faab36c-7e94-4e06-8f00-a7694636abbe"]
}, Open  ]],

Cell[TextData[StyleBox["  ** Now confirm that Pn4Dfun[MprofileExxOREww] = e^k \
coefficients of Det[M -e]",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.742994536939026*^9, 
  3.742994596739057*^9}},ExpressionUUID->"5536ad9f-48a3-439f-9edc-\
31013be67ea1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"referencePnOfE3", " ", "=", " ", 
  RowBox[{
   RowBox[{"Reverse", "[", 
    RowBox[{"CoefficientList", "[", 
     RowBox[{
      RowBox[{"Det", "[", 
       RowBox[{"hornM3mat", " ", "-", " ", 
        RowBox[{"e", " ", 
         RowBox[{"IdentityMatrix", "[", "4", "]"}]}]}], "]"}], ",", "e"}], 
     "]"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.742951214003335*^9, 3.7429512791859713`*^9}, {
  3.742951346040468*^9, 3.7429514192321653`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"eaec67b9-e2db-4c8e-a4a4-a9939cdc200b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Exx", "2"], "+", 
      SuperscriptBox["Exy", "2"], "+", 
      SuperscriptBox["Exz", "2"], "+", 
      SuperscriptBox["Eyx", "2"], "+", 
      SuperscriptBox["Eyy", "2"], "+", 
      SuperscriptBox["Eyz", "2"], "+", 
      SuperscriptBox["Ezx", "2"], "+", 
      SuperscriptBox["Ezy", "2"], "+", 
      SuperscriptBox["Ezz", "2"]}], ")"}]}], ",", 
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "-", 
      RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "-", 
      RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "+", 
      RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "+", 
      RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "-", 
      RowBox[{"Exx", " ", "Eyy", " ", "Ezz"}]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["Exx", "4"], "+", 
    SuperscriptBox["Exy", "4"], "+", 
    SuperscriptBox["Exz", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Eyx", "2"]}], "+", 
    SuperscriptBox["Eyx", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "+", 
    SuperscriptBox["Eyy", "4"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    SuperscriptBox["Eyz", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyz", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "+", 
    SuperscriptBox["Ezx", "4"], "+", 
    RowBox[{"8", " ", "Eyx", " ", "Eyy", " ", "Ezx", " ", "Ezy"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyz", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezx", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "+", 
    SuperscriptBox["Ezy", "4"], "+", 
    RowBox[{"8", " ", "Eyx", " ", "Eyz", " ", "Ezx", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Eyy", " ", "Eyz", " ", "Ezy", " ", "Ezz"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyz", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezx", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezy", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    SuperscriptBox["Ezz", "4"], "+", 
    RowBox[{"8", " ", "Exx", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Exy", " ", "Eyx", " ", "Eyy"}], "+", 
       RowBox[{"Exz", " ", "Eyx", " ", "Eyz"}], "+", 
       RowBox[{"Exy", " ", "Ezx", " ", "Ezy"}], "+", 
       RowBox[{"Exz", " ", "Ezx", " ", "Ezz"}]}], ")"}]}], "+", 
    RowBox[{"8", " ", "Exy", " ", "Exz", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eyy", " ", "Eyz"}], "+", 
       RowBox[{"Ezy", " ", "Ezz"}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["Exy", "2"], "+", 
       SuperscriptBox["Exz", "2"], "+", 
       SuperscriptBox["Eyx", "2"], "-", 
       SuperscriptBox["Eyy", "2"], "-", 
       SuperscriptBox["Eyz", "2"], "+", 
       SuperscriptBox["Ezx", "2"], "-", 
       SuperscriptBox["Ezy", "2"], "-", 
       SuperscriptBox["Ezz", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["Exz", "2"], "-", 
       SuperscriptBox["Eyx", "2"], "+", 
       SuperscriptBox["Eyy", "2"], "-", 
       SuperscriptBox["Eyz", "2"], "-", 
       SuperscriptBox["Ezx", "2"], "+", 
       SuperscriptBox["Ezy", "2"], "-", 
       SuperscriptBox["Ezz", "2"]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.742994659102392*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"13d5bf72-d8f3-4ee7-9f61-eb82bd8df40b"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"referencePnOfE4", " ", "=", " ", 
  RowBox[{
   RowBox[{"Reverse", "[", 
    RowBox[{"CoefficientList", "[", 
     RowBox[{
      RowBox[{"Det", "[", 
       RowBox[{"hornM4mat", " ", "-", " ", 
        RowBox[{"e", " ", 
         RowBox[{"IdentityMatrix", "[", "4", "]"}]}]}], "]"}], ",", "e"}], 
     "]"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.742951192168742*^9, 3.7429512036423073`*^9}, {
  3.742951467612422*^9, 3.74295149525642*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"23c60a05-549e-43e2-bbdb-0a61bb84d1a2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "Eww"}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["Eww", "2"]}], "+", 
      SuperscriptBox["Ewx", "2"], "+", 
      SuperscriptBox["Ewy", "2"], "+", 
      SuperscriptBox["Ewz", "2"], "+", 
      SuperscriptBox["Exw", "2"], "-", 
      SuperscriptBox["Exx", "2"], "-", 
      SuperscriptBox["Exy", "2"], "-", 
      SuperscriptBox["Exz", "2"], "+", 
      SuperscriptBox["Eyw", "2"], "-", 
      SuperscriptBox["Eyx", "2"], "-", 
      SuperscriptBox["Eyy", "2"], "-", 
      SuperscriptBox["Eyz", "2"], "+", 
      SuperscriptBox["Ezw", "2"], "-", 
      SuperscriptBox["Ezx", "2"], "-", 
      SuperscriptBox["Ezy", "2"], "-", 
      SuperscriptBox["Ezz", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Eww", "3"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Ewy", " ", "Exw", " ", "Exy"}], "+", 
         RowBox[{"Ewz", " ", "Exw", " ", "Exz"}], "+", 
         RowBox[{"Ewy", " ", "Eyw", " ", "Eyy"}], "+", 
         RowBox[{"Ewz", " ", "Eyw", " ", "Eyz"}], "-", 
         RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "+", 
         RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "+", 
         RowBox[{"Ewx", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Exw", " ", "Exx"}], "+", 
            RowBox[{"Eyw", " ", "Eyx"}], "+", 
            RowBox[{"Ezw", " ", "Ezx"}]}], ")"}]}], "+", 
         RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "-", 
         RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "+", 
         RowBox[{"Ewy", " ", "Ezw", " ", "Ezy"}], "-", 
         RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "+", 
         RowBox[{"Exx", " ", "Eyy", " ", "Ezz"}], "+", 
         RowBox[{"Ewz", " ", "Ezw", " ", "Ezz"}]}], ")"}]}], "+", 
      RowBox[{"Eww", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], "+", 
         SuperscriptBox["Ewy", "2"], "+", 
         SuperscriptBox["Ewz", "2"], "+", 
         SuperscriptBox["Exw", "2"], "-", 
         SuperscriptBox["Exx", "2"], "-", 
         SuperscriptBox["Exy", "2"], "-", 
         SuperscriptBox["Exz", "2"], "+", 
         SuperscriptBox["Eyw", "2"], "-", 
         SuperscriptBox["Eyx", "2"], "-", 
         SuperscriptBox["Eyy", "2"], "-", 
         SuperscriptBox["Eyz", "2"], "+", 
         SuperscriptBox["Ezw", "2"], "-", 
         SuperscriptBox["Ezx", "2"], "-", 
         SuperscriptBox["Ezy", "2"], "-", 
         SuperscriptBox["Ezz", "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["Eww", "4"], "+", 
    SuperscriptBox["Ewx", "4"], "+", 
    SuperscriptBox["Ewy", "4"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Ewz", "2"]}], "+", 
    SuperscriptBox["Ewz", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Exw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Exw", "2"]}], "+", 
    SuperscriptBox["Exw", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Exx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Exx", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Exx", "2"]}], "+", 
    SuperscriptBox["Exx", "4"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Exy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Exy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Exy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Exy", "2"]}], "+", 
    SuperscriptBox["Exy", "4"], "+", 
    RowBox[{"8", " ", "Ewy", " ", "Ewz", " ", "Exy", " ", "Exz"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Exz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Exz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Exz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Exz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Exz", "2"]}], "+", 
    SuperscriptBox["Exz", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Eyw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Eyw", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Eyw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Eyw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Eyw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Eyw", "2"]}], "+", 
    SuperscriptBox["Eyw", "4"], "+", 
    RowBox[{"8", " ", "Exw", " ", "Exx", " ", "Eyw", " ", "Eyx"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Eyx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Eyx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Eyx", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Eyx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Eyx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Eyx", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyw", "2"], " ", 
     SuperscriptBox["Eyx", "2"]}], "+", 
    SuperscriptBox["Eyx", "4"], "+", 
    RowBox[{"8", " ", "Exw", " ", "Exy", " ", "Eyw", " ", "Eyy"}], "+", 
    RowBox[{"8", " ", "Exx", " ", "Exy", " ", "Eyx", " ", "Eyy"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyw", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Eyy", "2"]}], "+", 
    SuperscriptBox["Eyy", "4"], "+", 
    RowBox[{"8", " ", "Exw", " ", "Exz", " ", "Eyw", " ", "Eyz"}], "+", 
    RowBox[{"8", " ", "Exx", " ", "Exz", " ", "Eyx", " ", "Eyz"}], "+", 
    RowBox[{"8", " ", "Ewy", " ", "Ewz", " ", "Eyy", " ", "Eyz"}], "+", 
    RowBox[{"8", " ", "Exy", " ", "Exz", " ", "Eyy", " ", "Eyz"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyw", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Eyz", "2"]}], "+", 
    SuperscriptBox["Eyz", "4"], "+", 
    RowBox[{"8", " ", "Ewz", " ", "Exy", " ", "Eyx", " ", "Ezw"}], "-", 
    RowBox[{"8", " ", "Ewy", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "-", 
    RowBox[{"8", " ", "Ewz", " ", "Exx", " ", "Eyy", " ", "Ezw"}], "+", 
    RowBox[{"8", " ", "Ewy", " ", "Exx", " ", "Eyz", " ", "Ezw"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyw", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyz", "2"], " ", 
     SuperscriptBox["Ezw", "2"]}], "+", 
    SuperscriptBox["Ezw", "4"], "-", 
    RowBox[{"8", " ", "Ewz", " ", "Exy", " ", "Eyw", " ", "Ezx"}], "+", 
    RowBox[{"8", " ", "Ewy", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "+", 
    RowBox[{"8", " ", "Ewz", " ", "Exw", " ", "Eyy", " ", "Ezx"}], "-", 
    RowBox[{"8", " ", "Ewy", " ", "Exw", " ", "Eyz", " ", "Ezx"}], "+", 
    RowBox[{"8", " ", "Exw", " ", "Exx", " ", "Ezw", " ", "Ezx"}], "+", 
    RowBox[{"8", " ", "Eyw", " ", "Eyx", " ", "Ezw", " ", "Ezx"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyw", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyz", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezw", "2"], " ", 
     SuperscriptBox["Ezx", "2"]}], "+", 
    SuperscriptBox["Ezx", "4"], "+", 
    RowBox[{"8", " ", "Ewz", " ", "Exx", " ", "Eyw", " ", "Ezy"}], "-", 
    RowBox[{"8", " ", "Ewz", " ", "Exw", " ", "Eyx", " ", "Ezy"}], "+", 
    RowBox[{"8", " ", "Exw", " ", "Exy", " ", "Ezw", " ", "Ezy"}], "+", 
    RowBox[{"8", " ", "Eyw", " ", "Eyy", " ", "Ezw", " ", "Ezy"}], "+", 
    RowBox[{"8", " ", "Exx", " ", "Exy", " ", "Ezx", " ", "Ezy"}], "+", 
    RowBox[{"8", " ", "Eyx", " ", "Eyy", " ", "Ezx", " ", "Ezy"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyw", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyz", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezw", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezx", "2"], " ", 
     SuperscriptBox["Ezy", "2"]}], "+", 
    SuperscriptBox["Ezy", "4"], "-", 
    RowBox[{"8", " ", "Ewy", " ", "Exx", " ", "Eyw", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Ewy", " ", "Exw", " ", "Eyx", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Exw", " ", "Exz", " ", "Ezw", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Eyw", " ", "Eyz", " ", "Ezw", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Exx", " ", "Exz", " ", "Ezx", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Eyx", " ", "Eyz", " ", "Ezx", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Ewy", " ", "Ewz", " ", "Ezy", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Exy", " ", "Exz", " ", "Ezy", " ", "Ezz"}], "+", 
    RowBox[{"8", " ", "Eyy", " ", "Eyz", " ", "Ezy", " ", "Ezz"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewy", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewz", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exw", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exx", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exy", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Exz", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyw", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyx", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyy", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eyz", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezw", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezx", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ezy", "2"], " ", 
     SuperscriptBox["Ezz", "2"]}], "+", 
    SuperscriptBox["Ezz", "4"], "+", 
    RowBox[{"8", " ", "Eww", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Ewy", " ", "Exw", " ", "Exy"}], "+", 
       RowBox[{"Ewz", " ", "Exw", " ", "Exz"}], "+", 
       RowBox[{"Ewy", " ", "Eyw", " ", "Eyy"}], "+", 
       RowBox[{"Ewz", " ", "Eyw", " ", "Eyz"}], "-", 
       RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "+", 
       RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "+", 
       RowBox[{"Ewx", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exw", " ", "Exx"}], "+", 
          RowBox[{"Eyw", " ", "Eyx"}], "+", 
          RowBox[{"Ezw", " ", "Ezx"}]}], ")"}]}], "+", 
       RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "-", 
       RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "+", 
       RowBox[{"Ewy", " ", "Ezw", " ", "Ezy"}], "-", 
       RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "+", 
       RowBox[{"Exx", " ", "Eyy", " ", "Ezz"}], "+", 
       RowBox[{"Ewz", " ", "Ezw", " ", "Ezz"}]}], ")"}]}], "+", 
    RowBox[{"8", " ", "Ewx", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Ewy", " ", "Exx", " ", "Exy"}], "+", 
       RowBox[{"Ewz", " ", "Exx", " ", "Exz"}], "+", 
       RowBox[{"Ewy", " ", "Eyx", " ", "Eyy"}], "+", 
       RowBox[{"Ewz", " ", "Eyx", " ", "Eyz"}], "+", 
       RowBox[{"Exz", " ", "Eyy", " ", "Ezw"}], "-", 
       RowBox[{"Exy", " ", "Eyz", " ", "Ezw"}], "-", 
       RowBox[{"Exz", " ", "Eyw", " ", "Ezy"}], "+", 
       RowBox[{"Exw", " ", "Eyz", " ", "Ezy"}], "+", 
       RowBox[{"Ewy", " ", "Ezx", " ", "Ezy"}], "+", 
       RowBox[{"Exy", " ", "Eyw", " ", "Ezz"}], "-", 
       RowBox[{"Exw", " ", "Eyy", " ", "Ezz"}], "+", 
       RowBox[{"Ewz", " ", "Ezx", " ", "Ezz"}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Eww", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["Ewx", "2"], "+", 
       SuperscriptBox["Ewy", "2"], "+", 
       SuperscriptBox["Ewz", "2"], "+", 
       SuperscriptBox["Exw", "2"], "-", 
       SuperscriptBox["Exx", "2"], "-", 
       SuperscriptBox["Exy", "2"], "-", 
       SuperscriptBox["Exz", "2"], "+", 
       SuperscriptBox["Eyw", "2"], "-", 
       SuperscriptBox["Eyx", "2"], "-", 
       SuperscriptBox["Eyy", "2"], "-", 
       SuperscriptBox["Eyz", "2"], "+", 
       SuperscriptBox["Ezw", "2"], "-", 
       SuperscriptBox["Ezx", "2"], "-", 
       SuperscriptBox["Ezy", "2"], "-", 
       SuperscriptBox["Ezz", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["Ewx", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["Ewy", "2"], "+", 
       SuperscriptBox["Ewz", "2"], "-", 
       SuperscriptBox["Exw", "2"], "+", 
       SuperscriptBox["Exx", "2"], "-", 
       SuperscriptBox["Exy", "2"], "-", 
       SuperscriptBox["Exz", "2"], "-", 
       SuperscriptBox["Eyw", "2"], "+", 
       SuperscriptBox["Eyx", "2"], "-", 
       SuperscriptBox["Eyy", "2"], "-", 
       SuperscriptBox["Eyz", "2"], "-", 
       SuperscriptBox["Ezw", "2"], "+", 
       SuperscriptBox["Ezx", "2"], "-", 
       SuperscriptBox["Ezy", "2"], "-", 
       SuperscriptBox["Ezz", "2"]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.742994644312604*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"5037799b-955d-4053-b324-601b1a15f789"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Rest", "[", "referencePnOfE3", "]"}], "-", 
   RowBox[{"Pn4Dfun", "[", "hornM3mat", "]"}]}], "//", "Simplify"}]], "Input",\

 CellLabel->"In[57]:=",ExpressionUUID->"0f6fb15f-19f2-4373-a4a5-7a33034c3fbd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.742994497550994*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"8b396f20-aef1-4574-8b79-dab37f727aaa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Rest", "[", "referencePnOfE4", "]"}], "-", 
   RowBox[{"Pn4Dfun", "[", "hornM4mat", "]"}]}], "//", "Simplify"}]], "Input",\

 CellChangeTimes->{{3.74299449337217*^9, 3.74299451413913*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"e95600d9-c1c0-44bd-b353-66bec5088a4a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.742994504979534*^9, 3.7429945149268208`*^9}},
 CellLabel->"Out[59]=",ExpressionUUID->"4ea5f875-7247-4fd7-a5e3-04a1df593531"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.742994483201804*^9},ExpressionUUID->"b8094579-cdc7-4fa1-8862-\
a7610507be96"],

Cell[BoxData[
 RowBox[{" ", "xxxxxxxxxxxxxxxxxxxxxxxxxx"}]], "Input",
 CellChangeTimes->{{3.742994471824534*^9, 
  3.742994481894912*^9}},ExpressionUUID->"ae39a321-2ce4-43ec-88c7-\
22ebf1e0ab9d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Arg", "[", 
   RowBox[{"a", " ", "+", " ", 
    RowBox[{"I", " ", "b"}]}], "]"}], "//", "TrigExpand"}]], "Input",
 CellChangeTimes->{{3.729378001249013*^9, 3.729378044323516*^9}, {
  3.729378084308777*^9, 
  3.729378094307054*^9}},ExpressionUUID->"beb93e13-23c7-4a48-a36a-\
2b74c5593586"],

Cell[BoxData[
 RowBox[{"Arg", "[", 
  RowBox[{"a", "+", 
   RowBox[{"\[ImaginaryI]", " ", "b"}]}], "]"}]], "Output",
 CellChangeTimes->{
  3.729378012920994*^9, 3.729378045277009*^9, {3.729378087990453*^9, 
   3.729378095062703*^9}},ExpressionUUID->"b84aedb3-e987-4604-a484-\
be263683374e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ArcTan", "[", 
   RowBox[{"Arg", "[", 
    RowBox[{"a", " ", "+", " ", 
     RowBox[{"I", " ", "b"}]}], "]"}], "]"}], "//", "TrigExpand"}]], "Input",
 CellChangeTimes->{{3.742996339810474*^9, 3.7429963730033216`*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"4bdc57da-cb8d-466a-88f3-8cf13cbb84d3"],

Cell[BoxData[
 RowBox[{"ArcTan", "[", 
  RowBox[{"Arg", "[", 
   RowBox[{"a", "+", 
    RowBox[{"\[ImaginaryI]", " ", "b"}]}], "]"}], "]"}]], "Output",
 CellChangeTimes->{{3.742996349287929*^9, 3.742996374595585*^9}},
 CellLabel->"Out[77]=",ExpressionUUID->"fe06540e-91ba-4917-895c-6dba7c8c5574"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"ArcTan", "[", 
       RowBox[{"a", ",", "b"}], "]"}], "3"], "+", 
     FractionBox[
      RowBox[{"2", " ", "Pi"}], "3"]}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"ArcTan", "[", 
       RowBox[{"a", ",", "b"}], "]"}], "3"], "-", 
     FractionBox[
      RowBox[{"2", " ", "Pi"}], "3"]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.742996387241737*^9, 3.7429965028512993`*^9}, {
  3.742996624441324*^9, 3.742996689450531*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"77a5fa93-71c9-4859-a7cf-5f63c7a40faa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["a", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}]]], ",", 
   FractionBox["b", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}]]], ",", 
   RowBox[{"-", 
    RowBox[{"Sin", "[", 
     RowBox[{
      FractionBox["\[Pi]", "6"], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"a", ",", "b"}], "]"}]}]}], "]"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"Sin", "[", 
     RowBox[{
      FractionBox["\[Pi]", "6"], "-", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"a", ",", "b"}], "]"}]}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.742996396689743*^9, 3.7429964665556307`*^9, 3.742996504576695*^9, {
   3.742996642408032*^9, 3.742996690489072*^9}},
 CellLabel->"Out[83]=",ExpressionUUID->"9100869b-3985-4ad9-a76a-e0e6cbec247a"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7290972700317907`*^9, 
  3.729097282301463*^9}},ExpressionUUID->"32041c54-28d5-4c74-8de3-\
1d2a434bcb7f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "[", 
  RowBox[{"Sign", "/@", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"bsqFun", "[", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
     "large3DPnrules"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.729097383006173*^9, 
  3.729097427564109*^9}},ExpressionUUID->"7cef1013-ae98-49b4-8d0d-\
7019ca61d986"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1000"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.729097843074154*^9},ExpressionUUID->"acb2d488-650c-4765-b45e-\
e6d143dd50b5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericEigVal4list", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{"#", ",", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"#1", ">", "#2"}], "&"}], ")"}]}], "]"}], "&"}], "/@", " ", 
    RowBox[{"Map", "[", 
     RowBox[{"Eigenvalues", " ", ",", "large3Dmats"}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7290974676372137`*^9, 3.72909753042732*^9}, {
   3.729097565483745*^9, 3.729097642865425*^9}, 
   3.72909785584921*^9},ExpressionUUID->"ba874959-5793-4edd-bb51-\
8d4f63970788"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numericEigVal4list", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "4"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729097872392851*^9, 
  3.72909787422361*^9}},ExpressionUUID->"835e2ad5-48cf-45a0-b172-\
19c3acfb06d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"94.87360988846933`", ",", 
     RowBox[{"-", "19.702037382553847`"}], ",", 
     RowBox[{"-", "30.110441599936365`"}], ",", 
     RowBox[{"-", "45.061130905979134`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"92.80689114374151`", ",", 
     RowBox[{"-", "14.106708303346734`"}], ",", 
     RowBox[{"-", "36.336410185043135`"}], ",", 
     RowBox[{"-", "42.36377265535164`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"95.5140836431852`", ",", 
     RowBox[{"-", "19.92970059873093`"}], ",", 
     RowBox[{"-", "33.98129374161569`"}], ",", 
     RowBox[{"-", "41.60308930283859`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"88.72042393040371`", ",", 
     RowBox[{"-", "13.937043991359271`"}], ",", 
     RowBox[{"-", "33.519402382426485`"}], ",", 
     RowBox[{"-", "41.263977556617995`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729097874782102*^9},ExpressionUUID->"64f07190-1007-402f-81b7-\
39b5af34aee0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"formulacosEpsEigVal4list", " ", "=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"cosEpsxyz", "[", 
       RowBox[{"k", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
    "large3DPnrules"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7290974676372137`*^9, 3.729097578042824*^9}, {
  3.729097895016704*^9, 
  3.729097981162187*^9}},ExpressionUUID->"da0925b4-57aa-45b0-96b4-\
7dec533fd2ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"formulacosEpsEigVal4list", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "4"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.72909796332825*^9},ExpressionUUID->"51699fbd-be56-49b9-b68d-d411241e2cee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"94.87360988846933`", ",", 
     RowBox[{"-", "19.702037382553826`"}], ",", 
     RowBox[{"-", "30.11044159993645`"}], ",", 
     RowBox[{"-", "45.06113090597905`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"92.80689114374154`", ",", 
     RowBox[{"-", "14.106708303346739`"}], ",", 
     RowBox[{"-", "36.33641018504315`"}], ",", 
     RowBox[{"-", "42.36377265535164`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"95.51408364318524`", ",", 
     RowBox[{"-", "19.92970059873094`"}], ",", 
     RowBox[{"-", "33.981293741615694`"}], ",", 
     RowBox[{"-", "41.60308930283861`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"88.72042393040377`", ",", 
     RowBox[{"-", "13.937043991359278`"}], ",", 
     RowBox[{"-", "33.51940238242646`"}], ",", 
     RowBox[{"-", "41.26397755661804`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729097964691434*^9, 
  3.7290979874600697`*^9}},ExpressionUUID->"702549d1-7032-4630-892b-\
4c9c4451bae0"]
}, Open  ]],

Cell[TextData[{
 StyleBox["   ",
  FontSize->18,
  FontSlant->"Italic"],
 StyleBox["ROCK SOLID MATCH  for   p1=0 ",
  FontSize->18,
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}]
}], "Text",
 CellChangeTimes->{{3.7293517633762817`*^9, 
  3.7293517758257093`*^9}},ExpressionUUID->"cee6ae20-760e-4e3b-8795-\
eb0c4b5abb5a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Tally", "[", 
   RowBox[{
    RowBox[{"numericEigVal4list", "-", " ", "formulacosEpsEigVal4list"}], "//",
     "Chop"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.729098004102734*^9, 
  3.729098074302437*^9}},ExpressionUUID->"c3349716-ffda-4d2c-8c72-\
6a97cd50bc10"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "1000"}], "}"}],
   "}"}]], "Output",
 CellChangeTimes->{{3.729098023393241*^9, 
  3.729098075072671*^9}},ExpressionUUID->"4dfdb64f-84b9-4f60-9cf0-\
dcf27c21fdef"]
}, Open  ]],

Cell[TextData[StyleBox["Double check with new trig:",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.729377898108079*^9, 
  3.729377902332821*^9}},ExpressionUUID->"43734a4a-3879-477f-8f1f-\
e40f2492d28b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checknewArgs", "=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"cosEpsxyz", "[", 
       RowBox[{"k", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
    "large3DPnrules"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729377893480109*^9, 
  3.7293779180757504`*^9}},ExpressionUUID->"e1887f12-dc1e-495e-a25e-\
b95933bb9aac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Tally", "[", 
   RowBox[{
    RowBox[{"numericEigVal4list", "-", " ", "checknewArgs"}], "//", "Chop"}], 
   "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.7293779437828817`*^9},ExpressionUUID->"d9c7f057-47c9-4974-94d0-\
f520327e2b76"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "1000"}], "}"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.729377945435112*^9},ExpressionUUID->"1f605ce0-af5a-4fec-84f7-\
c63ae57d3ffa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Bottom line: 4D - these solutions are rock solid for any  matrix,
   but one has to use the Mathematica phases and do no hand
   division by ( a + b)^(1/3)  simplifications.\
\>", "Subchapter",
 CellChangeTimes->{{3.729352579008947*^9, 
  3.729352642441702*^9}},ExpressionUUID->"86feb067-2bf4-4d77-b515-\
378a39a1609b"],

Cell[CellGroupData[{

Cell[BoxData["formOfxxyyzz4DF"], "Input",
 CellChangeTimes->{{3.729352720492626*^9, 
  3.72935274079974*^9}},ExpressionUUID->"b38bad19-4f52-498f-a62a-\
a58d45d87a30"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"xx", "\[Rule]", 
    RowBox[{
     FractionBox[
      SuperscriptBox["p1", "2"], "16"], "-", 
     FractionBox["p2", "6"], "-", 
     RowBox[{
      FractionBox["1", "12"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         SqrtBox[
          RowBox[{"-", "bsq"}]]}], ")"}], 
       RowBox[{"1", "/", "3"}]], " ", "phi0"}], "-", 
     FractionBox[
      RowBox[{"n", " ", "phi0"}], 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"-", "bsq"}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]]}]}], ",", 
   RowBox[{"yy", "\[Rule]", 
    RowBox[{
     FractionBox[
      SuperscriptBox["p1", "2"], "16"], "-", 
     FractionBox["p2", "6"], "-", 
     FractionBox[
      RowBox[{"n", " ", "phim"}], 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"-", "bsq"}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]], "-", 
     RowBox[{
      FractionBox["1", "12"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         SqrtBox[
          RowBox[{"-", "bsq"}]]}], ")"}], 
       RowBox[{"1", "/", "3"}]], " ", "phip"}]}]}], ",", 
   RowBox[{"zz", "\[Rule]", 
    RowBox[{
     FractionBox[
      SuperscriptBox["p1", "2"], "16"], "-", 
     FractionBox["p2", "6"], "-", 
     RowBox[{
      FractionBox["1", "12"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         SqrtBox[
          RowBox[{"-", "bsq"}]]}], ")"}], 
       RowBox[{"1", "/", "3"}]], " ", "phim"}], "-", 
     FractionBox[
      RowBox[{"n", " ", "phip"}], 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"-", "bsq"}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729352742505602*^9},ExpressionUUID->"541b92db-2091-4946-9703-\
6052f3b83f9e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rootRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"phi0", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"phip", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}]}]}], ",", 
     RowBox[{"phim", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}]}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.72935283912386*^9, 
  3.7293528674954357`*^9}},ExpressionUUID->"a753b40a-5a36-4bb4-90b2-\
b9a3f3c6f573"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abnRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", 
      RowBox[{
       SuperscriptBox["p2", "3"], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", "p2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p1", " ", "p3"}], "+", 
             RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
          RowBox[{"27", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p3", "2"], "+", 
             RowBox[{
              SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
         ")"}]}]}]}], ",", 
     RowBox[{"bsq", "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "-", 
          RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "3"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "-", 
          RowBox[{
           FractionBox["9", "2"], " ", "p2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p1", " ", "p3"}], "+", 
             RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["27", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p3", "2"], "+", 
             RowBox[{
              SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
        "2"]}]}], ",", 
     RowBox[{"n", "\[Rule]", 
      RowBox[{
       SuperscriptBox["p2", "2"], "-", 
       RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
       RowBox[{"12", " ", "p4"}]}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729352873115038*^9, 
  3.729352887136166*^9}},ExpressionUUID->"92b6f116-3ec4-48ce-a89a-\
fa29e292c524"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["p2", "3"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "9"}], " ", "p2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "p3"}], "+", 
         RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
      RowBox[{"27", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p3", "2"], "+", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}]}], "//",
   "TeXForm"}]], "Input",
 CellChangeTimes->{{3.7293528584319897`*^9, 3.7293528584407787`*^9}, {
  3.729361173268012*^9, 
  3.729361182675993*^9}},ExpressionUUID->"5cfba0b2-8075-40e4-8eef-\
107277e0cd41"],

Cell["\<\
\\frac{1}{2} \\left(27 \\left(\\text{p1}^2 \\text{p4}+\\text{p3}^2\\right)-9 \
\\text{p2} (\\text{p1} \\text{p3}+8
   \\text{p4})\\right)+\\text{p2}^3\
\>", "Output",
 CellChangeTimes->{
  3.729361184174065*^9},ExpressionUUID->"d5ae8931-0ba5-4bf8-ab1f-\
140b3db3dbd4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"formOfxxyyzz4DF", "/.", "rootRule"}], "/.", 
   "abnRule"}]}]], "Input",ExpressionUUID->"571deb14-e7f6-455e-a6b8-\
8f34c62b36be"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"This", " ", "is", " ", "the", " ", "complete", " ", "form"}], 
    ",", " ", 
    RowBox[{"should", " ", "match", " ", "xxyyzzRoot4D"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "formOfxxyyzz4DFS"}]], "Input",
 CellChangeTimes->{
  3.7293527511351757`*^9, {3.729352915847968*^9, 
   3.729352932566436*^9}},ExpressionUUID->"acb7e5d8-c8c9-46ec-b311-\
19e1634199c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"xx", "\[Rule]", 
    RowBox[{
     FractionBox[
      SuperscriptBox["p1", "2"], "16"], "-", 
     FractionBox["p2", "6"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["p2", "2"], "-", 
       RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
       RowBox[{"12", " ", "p4"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"p1", " ", "p3"}], "+", 
                RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
             RowBox[{"27", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p3", "2"], "+", 
                RowBox[{
                 SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}],
           "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "3"], "-", 
               RowBox[{
                FractionBox["9", "2"], " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"p1", " ", "p3"}], "+", 
                  RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
               RowBox[{
                FractionBox["27", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p3", "2"], "+", 
                  RowBox[{
                   SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}],
              "2"]}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]], "+", 
     RowBox[{
      FractionBox["1", "12"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "3"], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", "p2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"p1", " ", "p3"}], "+", 
               RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
            RowBox[{"27", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p3", "2"], "+", 
               RowBox[{
                SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}], 
         "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "3"], "-", 
              RowBox[{
               FractionBox["9", "2"], " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"p1", " ", "p3"}], "+", 
                 RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
              RowBox[{
               FractionBox["27", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p3", "2"], "+", 
                 RowBox[{
                  SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
            "2"]}]]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}]}], ",", 
   RowBox[{"yy", "\[Rule]", 
    RowBox[{
     FractionBox[
      SuperscriptBox["p1", "2"], "16"], "-", 
     FractionBox["p2", "6"], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "-", 
         RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"p1", " ", "p3"}], "+", 
                RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
             RowBox[{"27", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p3", "2"], "+", 
                RowBox[{
                 SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}],
           "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "3"], "-", 
               RowBox[{
                FractionBox["9", "2"], " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"p1", " ", "p3"}], "+", 
                  RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
               RowBox[{
                FractionBox["27", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p3", "2"], "+", 
                  RowBox[{
                   SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}],
              "2"]}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]], "-", 
     RowBox[{
      FractionBox["1", "24"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "3"], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", "p2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"p1", " ", "p3"}], "+", 
               RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
            RowBox[{"27", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p3", "2"], "+", 
               RowBox[{
                SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}], 
         "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "3"], "-", 
              RowBox[{
               FractionBox["9", "2"], " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"p1", " ", "p3"}], "+", 
                 RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
              RowBox[{
               FractionBox["27", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p3", "2"], "+", 
                 RowBox[{
                  SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
            "2"]}]]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}]}], ",", 
   RowBox[{"zz", "\[Rule]", 
    RowBox[{
     FractionBox[
      SuperscriptBox["p1", "2"], "16"], "-", 
     FractionBox["p2", "6"], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "-", 
         RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"p1", " ", "p3"}], "+", 
                RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
             RowBox[{"27", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p3", "2"], "+", 
                RowBox[{
                 SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}],
           "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "3"], "-", 
               RowBox[{
                FractionBox["9", "2"], " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"p1", " ", "p3"}], "+", 
                  RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
               RowBox[{
                FractionBox["27", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p3", "2"], "+", 
                  RowBox[{
                   SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}],
              "2"]}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]], "-", 
     RowBox[{
      FractionBox["1", "24"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "3"], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", "p2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"p1", " ", "p3"}], "+", 
               RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
            RowBox[{"27", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p3", "2"], "+", 
               RowBox[{
                SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}], 
         "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "3"], "-", 
              RowBox[{
               FractionBox["9", "2"], " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"p1", " ", "p3"}], "+", 
                 RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
              RowBox[{
               FractionBox["27", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p3", "2"], "+", 
                 RowBox[{
                  SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
            "2"]}]]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729352752673284*^9},ExpressionUUID->"ea11446f-bd98-4d53-86ed-\
7383d19d17e5"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Call", " ", "with", " ", "root"}], " ", "=", " ", 
     RowBox[{"string", " ", "\"\<x\>\""}]}], ",", " ", "\"\<y\>\"", ",", " ", 
    
    RowBox[{"or", " ", "\"\<z\>\"", "\[IndentingNewLine]", "  ", 
     RowBox[{"NOTE", "!"}], " ", "The", " ", "ORDER", " ", "of", " ", "X", 
     " ", "Y", " ", "Z", " ", "had", " ", "to", " ", "be", " ", "switched", 
     " ", "to", " ", "agree", " ", "with", " ", "eigval", " ", "rank", " ", 
     "ordering"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"xxyyzzRoot4D", "[", 
    RowBox[{"root_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], 
   " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"base", ",", 
       RowBox[{"phi0", "=", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"phip", "=", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}], "2"]}], ",", 
       RowBox[{"phim", "=", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}], "2"]}], " ", ",", "\[IndentingNewLine]", 
       
       RowBox[{"a", " ", "=", " ", 
        RowBox[{"aFun", " ", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
       RowBox[{"bsq", "=", 
        RowBox[{"bsqFun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
       RowBox[{"n", "=", 
        RowBox[{"nFun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"base", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{"root", ",", "\"\<x\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{
          FractionBox[
           SuperscriptBox["p1", "2"], "16"], "-", 
          FractionBox["p2", "6"], "-", 
          RowBox[{
           FractionBox["1", "12"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", 
              SqrtBox[
               RowBox[{"-", "bsq"}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]], " ", "phi0"}], "-", 
          FractionBox[
           RowBox[{"n", " ", "phi0"}], 
           RowBox[{"12", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", 
               SqrtBox[
                RowBox[{"-", "bsq"}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]]}], ",", "\"\<y\>\"", ",", 
         RowBox[{
          FractionBox[
           SuperscriptBox["p1", "2"], "16"], "-", 
          FractionBox["p2", "6"], "-", 
          RowBox[{
           FractionBox["1", "12"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", 
              SqrtBox[
               RowBox[{"-", "bsq"}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]], " ", "phip"}], "-", 
          FractionBox[
           RowBox[{"n", " ", "phim"}], 
           RowBox[{"12", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", 
               SqrtBox[
                RowBox[{"-", "bsq"}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]]}], ",", "\"\<z\>\"", ",", 
         RowBox[{
          FractionBox[
           SuperscriptBox["p1", "2"], "16"], "-", 
          FractionBox["p2", "6"], "-", 
          RowBox[{
           FractionBox["1", "12"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", 
              SqrtBox[
               RowBox[{"-", "bsq"}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]], " ", "phim"}], "-", 
          FractionBox[
           RowBox[{"n", " ", "phip"}], 
           RowBox[{"12", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", 
               SqrtBox[
                RowBox[{"-", "bsq"}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "base"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719597193946005*^9, 3.719597305370088*^9}, {
   3.7195973505286922`*^9, 3.719597382137249*^9}, {3.7195974123298903`*^9, 
   3.719597510213501*^9}, {3.719597604532134*^9, 3.719597613925857*^9}, {
   3.7195976910520077`*^9, 3.7195976921617413`*^9}, 3.7195984437457933`*^9, {
   3.719598546775992*^9, 3.719598570169475*^9}, {3.719801985921894*^9, 
   3.71980199062432*^9}, {3.719802071752438*^9, 3.719802072574925*^9}, 
   3.719802200937204*^9, {3.719802702899005*^9, 3.719802744546809*^9}, {
   3.719802897544032*^9, 3.719802919926641*^9}, {3.729303809984123*^9, 
   3.729303870668518*^9}, {3.729303951500503*^9, 3.729304096335128*^9}, {
   3.7293041307818108`*^9, 3.7293041411728287`*^9}, {3.729304183923993*^9, 
   3.7293042173806047`*^9}, 3.7293042510681868`*^9, {3.729353288008215*^9, 
   3.729353288638289*^9}},ExpressionUUID->"82c826e3-9847-4885-a44d-\
282d8b205196"],

Cell[BoxData[
 RowBox[{
  RowBox[{"the4DeigVals", "[", 
   RowBox[{"rootNum_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], 
   "]"}], ":=", " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"base", ",", "xx", ",", "yy", ",", "zz", ",", 
      RowBox[{"phi0", "=", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"phip", "=", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], "2"]}], ",", 
      RowBox[{"phim", "=", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], "2"]}], " ", ",", "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"aFun", " ", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      RowBox[{"bsq", "=", 
       RowBox[{"bsqFun", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      RowBox[{"n", "=", 
       RowBox[{"nFun", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "=", 
      RowBox[{
       FractionBox[
        SuperscriptBox["p1", "2"], "16"], "-", 
       FractionBox["p2", "6"], "-", 
       RowBox[{
        FractionBox["1", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", 
           SqrtBox[
            RowBox[{"-", "bsq"}]]}], ")"}], 
         RowBox[{"1", "/", "3"}]], " ", "phi0"}], "-", 
       FractionBox[
        RowBox[{"n", " ", "phi0"}], 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", 
            SqrtBox[
             RowBox[{"-", "bsq"}]]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"yy", "=", 
      RowBox[{
       FractionBox[
        SuperscriptBox["p1", "2"], "16"], "-", 
       FractionBox["p2", "6"], "-", 
       RowBox[{
        FractionBox["1", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", 
           SqrtBox[
            RowBox[{"-", "bsq"}]]}], ")"}], 
         RowBox[{"1", "/", "3"}]], " ", "phip"}], "-", 
       FractionBox[
        RowBox[{"n", " ", "phim"}], 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", 
            SqrtBox[
             RowBox[{"-", "bsq"}]]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"zz", " ", "=", 
      RowBox[{
       FractionBox[
        SuperscriptBox["p1", "2"], "16"], "-", 
       FractionBox["p2", "6"], "-", 
       RowBox[{
        FractionBox["1", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", 
           SqrtBox[
            RowBox[{"-", "bsq"}]]}], ")"}], 
         RowBox[{"1", "/", "3"}]], " ", "phim"}], "-", 
       FractionBox[
        RowBox[{"n", " ", "phip"}], 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", 
            SqrtBox[
             RowBox[{"-", "bsq"}]]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]]}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", " ", 
      RowBox[{"rootNum", ",", "\[IndentingNewLine]", "1", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "+", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", "2", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "+", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "-", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "-", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", "\[IndentingNewLine]", 
       "3", ",", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "-", " ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "-", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}], " ", ",", " ", "4", ",", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "p1"}], "4"], "-", "  ", 
        RowBox[{"Sqrt", "[", "xx", "]"}], "-", 
        RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
        RowBox[{"Sqrt", "[", "zz", "]"}]}]}], "  ", "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7293533020143538`*^9, 3.729353312683384*^9}, {
  3.729353352508162*^9, 3.729353352796471*^9}, {3.729353405145801*^9, 
  3.7293536034895372`*^9}},ExpressionUUID->"7d7195f9-ea9c-41aa-acf4-\
10e866568465"],

Cell[TextData[StyleBox["Need the eigenvector as well: xxxx",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7424013463339376`*^9, 
  3.7424013696542387`*^9}},ExpressionUUID->"ea430988-606e-49de-9047-\
25b1f4cca0a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"vv", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/.", "formOfxxyyzz4DFS"}], ")"}], 
     " ", "-", " ", 
     RowBox[{"xxyyzzRoot4D", "[", 
      RowBox[{
       RowBox[{"vv", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", "p1", ",", "p2", ",", "p3", ",", 
       "p4"}], "]"}]}], "//", "Simplify"}], ",", 
   RowBox[{"{", 
    RowBox[{"vv", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xx", ",", "\"\<x\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yy", ",", "\"\<y\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"zz", ",", "\"\<z\>\""}], "}"}]}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.729352961597845*^9, 3.729352977477476*^9}, {
  3.729353018213828*^9, 
  3.729353105245153*^9}},ExpressionUUID->"db8b037c-df67-48a5-bbb4-\
f87df7c1c0f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7293530398112183`*^9, {3.72935309333482*^9, 
   3.729353106047556*^9}},ExpressionUUID->"2f1b732d-32d2-4ce9-9d58-\
72f5b7db4d02"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"numericEigvals", "=", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Sort", "[", 
       RowBox[{"#", ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Re", "[", "#1", "]"}], ">", 
           RowBox[{"Re", "[", "#2", "]"}]}], "&"}], ")"}]}], "]"}], "&"}], 
     ",", " ", 
     RowBox[{"Eigenvalues", "/@", 
      RowBox[{"large4Dmats", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "16"}], "]"}], "]"}]}]}], " ", "]"}], "//", 
   "Chop"}]}]], "Input",ExpressionUUID->"9f9a6468-56c2-424b-9b97-\
4e04f6aad47b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fromEqnEigvals4DFS", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], "/", "4"}], " ", "+", " ", 
          RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
          RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
          RowBox[{"Sqrt", "[", "zz", "]"}]}], ")"}], " ", ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], "/", "4"}], " ", "+", " ", 
          RowBox[{"Sqrt", "[", "xx", "]"}], "-", 
          RowBox[{"Sqrt", "[", "yy", "]"}], "-", 
          RowBox[{"Sqrt", "[", "zz", "]"}]}], ")"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], "/", "4"}], " ", "-", " ", 
          RowBox[{"Sqrt", "[", "xx", "]"}], "+", 
          RowBox[{"Sqrt", "[", "yy", "]"}], "-", 
          RowBox[{"Sqrt", "[", "zz", "]"}]}], ")"}], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], "/", "4"}], " ", "-", " ", 
          RowBox[{"Sqrt", "[", "xx", "]"}], "-", 
          RowBox[{"Sqrt", "[", "yy", "]"}], "+", 
          RowBox[{"Sqrt", "[", "zz", "]"}]}], ")"}]}], "}"}], "/.", 
      "formOfxxyyzz4DFS"}], "/.", 
     RowBox[{"large4DPnrules", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "16"}], "]"}], "]"}]}], "//", "Chop"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.729353124757292*^9, 
  3.729353132724824*^9}},ExpressionUUID->"5f745f49-0d92-4170-bd40-\
544e71efa961"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fromEqnEigvalsRoot4D", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"the4DeigVals", "[", 
        RowBox[{"k", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
     RowBox[{"large4DPnrules", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "16"}], "]"}], "]"}]}], "//", "Chop"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.729353147891741*^9, 3.729353210560544*^9}, {
   3.729353637586252*^9, 3.7293536857586727`*^9}, 
   3.729353720466529*^9},ExpressionUUID->"bd1f20c1-8af6-4c7f-b422-\
59c2abafd9a0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fromEqnEigvals4DFS", "-", "fromEqnEigvalsRoot4D"}]], "Input",
 CellChangeTimes->{{3.729353717334598*^9, 
  3.729353726745515*^9}},ExpressionUUID->"919f7a6b-526c-46e7-bd09-\
90d4b04d37c3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729353728019734*^9},ExpressionUUID->"b4d0d35f-d80e-48b9-8b10-\
7caa69d669b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Match", " ", "is", " ", "pretty", " ", "good", " ", "except", " ", "for", 
    " ", "ordering"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Tally", "[", 
   RowBox[{
    RowBox[{"numericEigvals", "-", " ", "fromEqnEigvalsRoot4D"}], "//", 
    "Chop"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.7293538053843718`*^9, 
  3.7293538640375338`*^9}},ExpressionUUID->"24739dc8-b6ed-425f-8b63-\
3346f4bc54ac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "13"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"13.745316801050219`", "\[VeryThinSpace]", "-", 
        RowBox[{"11.731539399564944`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"23.463078799129878`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "13.745316801050244`"}], "-", 
        RowBox[{"11.731539399564934`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"10.77979668084092`", "\[VeryThinSpace]", "-", 
        RowBox[{"6.307111853312692`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"12.614223706625289`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "10.779796680840985`"}], "-", 
        RowBox[{"6.307111853312597`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"3.352669762343174`", "\[VeryThinSpace]", "-", 
        RowBox[{"11.109186313475059`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"22.218372626950124`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "3.352669762343174`"}], "-", 
        RowBox[{"11.109186313475066`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729353829276897*^9},ExpressionUUID->"81c28879-d4c7-485a-9dde-\
e623f4364fe8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "/@", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"#", ",", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Re", "[", "#1", "]"}], ">", 
              RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], 
         "&"}], "/@", "numericEigvals"}], ")"}], "-", "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"#", ",", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Re", "[", "#1", "]"}], ">", 
              RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], 
         "&"}], "/@", "fromEqnEigvalsRoot4D"}], " ", ")"}]}], "}"}], "//", 
    "Chop"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.729354993594741*^9, 3.729355017842854*^9}, {
  3.72935528320383*^9, 
  3.729355284104459*^9}},ExpressionUUID->"0d8742d5-9812-4d66-856a-\
4cf95ffd5919"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "16"}], "}"}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.729354996453217*^9, 3.7293550188262463`*^9}, 
   3.729355284593027*^9},ExpressionUUID->"ce54e555-0026-4b87-a7ff-\
0290fdff527b"]
}, Open  ]],

Cell[TextData[StyleBox[" Now try them all and see what happens:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.729355167616592*^9, 
  3.729355174625244*^9}},ExpressionUUID->"2e1f86e8-e009-491d-ae5e-\
5e477bfdab7a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"moreNumericEigvals", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{"#", ",", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Re", "[", "#1", "]"}], ">", 
          RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], "&"}],
     "/@", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{"Eigenvalues", "/@", "large4Dmats"}], " ", ")"}], "//", 
      "Chop"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729355032658176*^9, 3.729355057570591*^9}, {
  3.72935509171684*^9, 
  3.729355118289906*^9}},ExpressionUUID->"db77bf6e-8d7d-42c5-bdce-\
aa2f35086741"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"moreNumericEigvals", "//", "Dimensions"}], ",", 
   RowBox[{"moreNumericEigvals", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.729355128689502*^9, 
  3.7293551478578157`*^9}},ExpressionUUID->"a2eda75f-063a-4d3e-8dd9-\
dae327645767"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1000", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "108.50116767362051`", ",", "15.232341740838239`", ",", 
       "0.5842032878872925`", ",", 
       RowBox[{"-", "12.221774458260368`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"113.52857652133953`", ",", 
       RowBox[{
        RowBox[{"-", "0.8370003185160015`"}], "-", 
        RowBox[{"11.731539399564944`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.8370003185160015`"}], "+", 
        RowBox[{"11.731539399564944`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "14.582317119566241`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7293551330000134`*^9, 
  3.729355148530422*^9}},ExpressionUUID->"c3485109-74fc-4134-beb7-\
df9e7c9ad5f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numericEigvals", " ", "-", " ", 
  RowBox[{"moreNumericEigvals", "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "16"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729355577568955*^9, 
  3.729355600501289*^9}},ExpressionUUID->"210130fe-59b5-4f56-9b11-\
bad49abada55"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7293556011099157`*^9},ExpressionUUID->"8ae62fa5-2227-4eca-a129-\
de60b98921d4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"moreExactEigvals", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{"#", ",", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Re", "[", "#1", "]"}], ">", 
          RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], "&"}],
     "/@", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"(", "  ", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"the4DeigVals", "[", 
           RowBox[{"k", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
        "large4DPnrules"}], ")"}], "//", "Chop"}], ")"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.729355032658176*^9, 3.729355057570591*^9}, {
   3.72935509171684*^9, 3.729355118289906*^9}, {3.729355183681939*^9, 
   3.729355221215329*^9}, 
   3.72935525613798*^9},ExpressionUUID->"4690e876-dfa8-4815-b6e6-\
1f51b045b871"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"moreExactEigvals", "//", "Dimensions"}], ",", 
   RowBox[{"moreExactEigvals", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.729355128689502*^9, 3.7293551478578157`*^9}, {
  3.729355189797402*^9, 3.729355191237434*^9}, {3.729355243195724*^9, 
  3.729355245108275*^9}},ExpressionUUID->"b01a1c10-8523-4457-8bf1-\
21351f60f21a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1000", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "108.50116767362044`", ",", "15.232341740838237`", ",", 
       "0.5842032878872914`", ",", 
       RowBox[{"-", "12.22177445826037`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"113.52857652133952`", ",", 
       RowBox[{
        RowBox[{"-", "0.8370003185159973`"}], "+", 
        RowBox[{"11.731539399564934`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.8370003185159973`"}], "-", 
        RowBox[{"11.731539399564934`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "14.58231711956622`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7293552478248568`*^9, 
  3.7293552612480307`*^9}},ExpressionUUID->"e96a7e5b-7d02-4228-bb9a-\
9e2cd714c163"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Sort", "[", 
       RowBox[{"#", ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Re", "[", "#1", "]"}], ">", 
           RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], 
      "&"}], "/@", "fromEqnEigvalsRoot4D"}], ")"}], "-", 
   RowBox[{"moreExactEigvals", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "16"}], "]"}], "]"}]}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.729355974034025*^9, 3.729355981634015*^9}, {
  3.729356022152845*^9, 
  3.729356024826048*^9}},ExpressionUUID->"980de284-b1ca-40c9-b507-\
579e4d830352"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7293559826920223`*^9, 
  3.7293560272474213`*^9},ExpressionUUID->"d59ff1ce-27e8-460c-a55f-\
83135a561c39"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Sort", "[", 
        RowBox[{"#", ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Re", "[", "#1", "]"}], ">", 
            RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], 
       "&"}], "/@", 
      RowBox[{"moreNumericEigvals", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "16"}], "]"}], "]"}]}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sort", "[", 
         RowBox[{"#", ",", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", "#1", "]"}], ">", 
             RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], 
        "&"}], "/@", 
       RowBox[{"fromEqnEigvalsRoot4D", "[", 
        RowBox[{"[", 
         RowBox[{"1", ";;", "16"}], "]"}], "]"}]}], ")"}]}], ")"}], "//", 
   "Chop"}], ")"}]], "Input",
 CellChangeTimes->{{3.7293553039602203`*^9, 3.729355356239871*^9}, {
   3.729355411385065*^9, 3.7293554227751207`*^9}, 3.729355513376774*^9, {
   3.729356085093975*^9, 3.729356097465308*^9}, 
   3.7293562106793013`*^9},ExpressionUUID->"df51ab2e-7098-4cd4-baa3-\
50d8a82cdb30"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729355341816229*^9, 3.7293553569245872`*^9}, 
   3.729355423592894*^9, 3.7293555142116213`*^9, 3.729356098582326*^9, 
   3.729356212359132*^9},ExpressionUUID->"9ad25639-4bab-4fe3-b7b5-\
ef1c5092f5fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Sort", "[", 
        RowBox[{"#", ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Re", "[", "#1", "]"}], ">", 
            RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], 
       "&"}], "/@", 
      RowBox[{"moreNumericEigvals", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "16"}], "]"}], "]"}]}], ")"}], "-", 
    RowBox[{"moreExactEigvals", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "16"}], "]"}], "]"}]}], ")"}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.729355974034025*^9, 3.729355981634015*^9}, {
  3.729356022152845*^9, 3.729356024826048*^9}, {3.729356298211546*^9, 
  3.729356306974729*^9}},ExpressionUUID->"4049bde2-a4e7-4623-bcd5-\
6c9aef8a8e41"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729356307952993*^9},ExpressionUUID->"a8b52994-4319-4fb4-b68d-\
18d47699d1c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
So it is VERY CLOSE to getting all 1000 in order: not sure why it misses 7, \
and has 10^-8 --10^-10 instead of
   10^-12 rounding errors\
\>", "Subsubsection",
 CellChangeTimes->{{3.729356728314724*^9, 3.7293567535951223`*^9}, {
  3.72935684714679*^9, 
  3.729356884801791*^9}},ExpressionUUID->"69705374-ec6a-43a1-a48c-\
52de1b63aad3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "@", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"#", ",", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Re", "[", "#1", "]"}], ">", 
              RowBox[{"Re", "[", "#2", "]"}]}], " ", "&"}], ")"}]}], "]"}], 
         "&"}], "/@", "moreNumericEigvals"}], ")"}], "-", " ", 
      RowBox[{"(", "moreExactEigvals", ")"}]}], ")"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", 
       RowBox[{"10", "^", 
        RowBox[{"(", 
         RowBox[{"-", "8"}], ")"}]}]}], " ", "]"}], "&"}]}], ")"}]}]], "Input",\

 CellChangeTimes->{{3.729355642217038*^9, 3.729355703412603*^9}, {
  3.729356407319694*^9, 3.729356495829339*^9}, {3.729356543866332*^9, 
  3.729356650380682*^9}, {3.729356761378509*^9, 
  3.729356815101739*^9}},ExpressionUUID->"1ca2f849-32d7-42e1-b8ba-\
fcfb20aa4f5b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "993"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"6.5017094846452785`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"6.5017094846452785`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.524830395283061`*^-8"}], ",", 
       RowBox[{"5.361468247144785`*^-8", "+", 
        RowBox[{"4.4521016206999775`*^-8", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"5.361468247144785`*^-8", "-", 
        RowBox[{"4.4521016206999775`*^-8", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "9.198103612106934`*^-8"}]}], "}"}], ",", "1"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.3875794551840597`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.387579455184059`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"13.122058637154705`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"13.122058637154705`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"9.992720021144263`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"9.992720021144263`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"5.874083108572945`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"5.874083108572945`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"10.002880874843317`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"10.002880874843317`", " ", "\[ImaginaryI]"}]}], ",", "0"}], 
      "}"}], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729356651686224*^9, {3.729356796050207*^9, 
   3.7293568161085176`*^9}},ExpressionUUID->"11acd642-bc1b-4ebd-98c8-\
a65ea40dc40d"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Earlier  Solutions for the 4D (and 3D) Horn problem:", "Subchapter",
 CellChangeTimes->{{3.727633344884883*^9, 3.727633356563237*^9}, {
  3.729353751853767*^9, 
  3.729353755173678*^9}},ExpressionUUID->"80371059-b02f-4410-a2d2-\
5b004fbef82b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"optEigValss", "[", 
   RowBox[{
    RowBox[{"s1_", "/;", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s1", "\[Equal]", 
        RowBox[{"+", "1"}]}], "||", 
       RowBox[{"s1", "\[Equal]", 
        RowBox[{"-", "1"}]}]}], ")"}]}], ",", 
    RowBox[{"s2_", "/;", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s2", "\[Equal]", 
        RowBox[{"+", "1"}]}], "||", 
       RowBox[{"s2", "\[Equal]", 
        RowBox[{"-", "1"}]}]}], ")"}]}], ",", "p1_", ",", "p2_", ",", "p3_", 
    ",", "p4_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "3"]}], "-", 
          RowBox[{"9", " ", "p2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p1", " ", "p3"}], "+", 
             RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
          RowBox[{"27", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p3", "2"], "+", 
             RowBox[{
              SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}]}]}], 
      ",", " ", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{
        FractionBox["1", "2"], 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"p1", " ", "p3"}], "+", 
                RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
             RowBox[{"27", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p3", "2"], "+", 
                RowBox[{
                 SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
           "2"]}]]}]}], ",", "norm3"}], "}"}], ",", 
    RowBox[{"(*", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "-", 
        RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
        RowBox[{"12", " ", "p4"}]}], ")"}], "3"], " ", "*)"}], " ", 
    RowBox[{
     RowBox[{"norm3", "=", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"]}], "//", "Simplify"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", "norm3"}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"9", " ", "p2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"p1", " ", "p3"}], "+", 
               RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
            RowBox[{"27", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p3", "2"], "+", 
               RowBox[{
                SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
          "2"]}]], "  ", "=", " ", 
       RowBox[{"2", " ", "b"}]}], "  ", "*)"}], "\n", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["p1", "4"]}], "+", 
      RowBox[{
       FractionBox["s1", 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]], 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], 
          RowBox[{"1", "/", "3"}]], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], 
          RowBox[{"1", "/", "3"}]], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "4"], "-", 
         RowBox[{"2", " ", "p2"}]}]]}], "+", 
      RowBox[{
       FractionBox["s2", 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]], 
       RowBox[{"(", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", "  ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "b"}], ")"}], 
            RowBox[{"1", "/", "3"}]], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"4", " ", "p2"}], "-", 
           RowBox[{"s1", 
            FractionBox[
             RowBox[{"3", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], 
             RowBox[{"4", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"a", "-", "b"}], ")"}], 
                 RowBox[{"1", "/", "3"}]], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"a", "+", "b"}], ")"}], 
                 RowBox[{"1", "/", "3"}]], "+", 
                FractionBox[
                 RowBox[{"3", " ", 
                  SuperscriptBox["p1", "2"]}], "4"], "-", 
                RowBox[{"2", " ", "p2"}]}]]}]]}]}], ")"}]}], ")"}]}]}]}]}], 
   " ", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.727439548827971*^9, 3.727439599645434*^9}, {
   3.727439654821084*^9, 3.727439740398273*^9}, {3.7274420630122623`*^9, 
   3.727442086408935*^9}, {3.727442138919271*^9, 3.727442197488311*^9}, 
   3.727442245617111*^9, {3.7274422941383142`*^9, 3.727442307595796*^9}, {
   3.727442338676384*^9, 3.727442427972777*^9}, {3.727442463349135*^9, 
   3.727442536498591*^9}, {3.727442608567336*^9, 3.7274426086490107`*^9}, {
   3.7274428061683292`*^9, 3.727442808385659*^9}, 3.727442842499538*^9, 
   3.727442943878537*^9, {3.727443615457793*^9, 3.727443618385996*^9}, 
   3.727443706619173*^9, {3.727443757936503*^9, 3.727443758779396*^9}, 
   3.727444108653429*^9, {3.727444212580936*^9, 3.727444258778254*^9}, {
   3.727444300433734*^9, 3.7274443657384768`*^9}, 3.727444509048319*^9, {
   3.72744536566998*^9, 3.72744536610993*^9}, 3.727451703056172*^9, {
   3.727452339466495*^9, 3.727452406261889*^9}, 3.7274525607460213`*^9, {
   3.7274526578511353`*^9, 3.727452707458478*^9}, {3.7274527417470217`*^9, 
   3.72745274237838*^9}, {3.72745282379176*^9, 
   3.727452845158614*^9}},ExpressionUUID->"c1abb585-1122-4ffc-b284-\
5f86155fcd83"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" Obsolete 4D versions, defined below, before I worked \
out  work out the norm3 division:",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.7276336301380672`*^9, 3.727633649003069*^9}, 
   3.727633738009069*^9, {3.7276340000868187`*^9, 3.72763401229591*^9}, {
   3.7276340739816513`*^9, 
   3.7276340747829857`*^9}},ExpressionUUID->"807788fa-39ef-413a-86d6-\
1d6b9f9600f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optEigvalFull", "[", 
  RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellChangeTimes->{{3.727634033204525*^9, 
  3.7276340451758204`*^9}},ExpressionUUID->"06727341-1095-465b-85e8-\
1a15157d2b47"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "12"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", "p1"}], "+", 
    RowBox[{
     SqrtBox["3"], " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["p1", "2"]}], "-", 
        RowBox[{"8", " ", "p2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", " ", 
           SuperscriptBox["2", 
            RowBox[{"1", "/", "3"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p2", "2"], "-", 
             RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
             RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "-", 
                  RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "-", 
                 RowBox[{"9", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                 RowBox[{"27", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                ")"}], "2"]}]]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["2", 
          RowBox[{"2", "/", "3"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "-", 
                  RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "-", 
                 RowBox[{"9", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                 RowBox[{"27", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                ")"}], "2"]}]]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
    RowBox[{
     SqrtBox["6"], " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["p1", "2"]}], "-", 
        RowBox[{"8", " ", "p2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"1", "/", "3"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p2", "2"], "-", 
             RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
             RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "-", 
                  RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "-", 
                 RowBox[{"9", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                 RowBox[{"27", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                ")"}], "2"]}]]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], "-", 
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{"2", "/", "3"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "-", 
                  RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "-", 
                 RowBox[{"9", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                 RowBox[{"27", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                ")"}], "2"]}]]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", " ", 
           SqrtBox["3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p1", "3"], "-", 
             RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
             RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["p1", "2"]}], "-", 
             RowBox[{"8", " ", "p2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", " ", 
                SuperscriptBox["2", 
                 RowBox[{"1", "/", "3"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "-", 
                  RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "-", 
                 RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}]]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"2", "/", "3"}]], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "-", 
                 RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}]]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.727634046726736*^9},ExpressionUUID->"50e61bac-cd22-4336-93c2-\
b09200a2a2fa"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"optEigVal", " ", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "p1"}], "+", " ", 
     RowBox[{
      FractionBox[
       SqrtBox["3"], "12"], 
      SqrtBox[
       RowBox[{" ", 
        RowBox[{
         RowBox[{
          RowBox[{"+", "3"}], " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"theFfun", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
          " "}]}]}]]}], "+", 
     RowBox[{
      FractionBox[
       SqrtBox["6"], "12"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"+", "3"}], " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "-", 
         RowBox[{"theFfun", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "-", 
         FractionBox[
          RowBox[{"3", " ", 
           SqrtBox["3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p1", "3"], "-", 
             RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
             RowBox[{"8", " ", "p3"}]}], ")"}]}], 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"+", "3"}], " ", 
             SuperscriptBox["p1", "2"]}], "-", 
            RowBox[{"8", " ", "p2"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"theFfun", "[", 
              RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}]]]}], 
        ")"}]}]}]}], ")"}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.726079764558526*^9, 3.726079794637978*^9}, {
  3.726079864276005*^9, 3.726079892095599*^9}, {3.726080673657496*^9, 
  3.72608067485046*^9}},ExpressionUUID->"de0583c2-8b93-4f8d-890d-\
99964d3e869f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theEigValN", " ", "[", 
   RowBox[{"n_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ",
   ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"S1", " ", "=", " ", 
       RowBox[{"Switch", "[", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"+", "1"}], ",", " ", "2", ",", " ", 
         RowBox[{"+", "1"}], ",", " ", "3", ",", 
         RowBox[{"-", "1"}], ",", "4", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"S2", " ", "=", " ", 
       RowBox[{"Switch", "[", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"+", "1"}], ",", " ", "2", ",", " ", 
         RowBox[{"-", "1"}], ",", " ", "3", ",", 
         RowBox[{"+", "1"}], ",", "4", ",", 
         RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "p1"}], "+", 
      RowBox[{"S1", " ", 
       FractionBox[
        SqrtBox["3"], "12"], 
       SqrtBox[
        RowBox[{" ", 
         RowBox[{
          RowBox[{
           RowBox[{"+", "3"}], " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"theFfun", "[", 
            RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
           " "}]}]}]]}], "+", 
      RowBox[{"S2", 
       FractionBox[
        SqrtBox["6"], "12"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"+", "3"}], " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{"theFfun", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "-", 
          RowBox[{"S1", 
           FractionBox[
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"+", "3"}], " ", 
               SuperscriptBox["p1", "2"]}], "-", 
              RowBox[{"8", " ", "p2"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"theFfun", "[", 
                RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], 
                "]"}]}]}]]]}]}], ")"}]}]}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.726079764558526*^9, 3.726079794637978*^9}, {
   3.726079864276005*^9, 3.726079892095599*^9}, {3.72608010291181*^9, 
   3.72608030843752*^9}, {3.726080339133754*^9, 3.726080347827962*^9}, 
   3.726080398715815*^9},ExpressionUUID->"b22de601-2df6-4513-9d04-\
dd026dae8a82"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theGfun", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["p2", "3"]}], "-", 
    RowBox[{"9", " ", "p2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"p1", " ", "p3"}], "+", 
       RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
    RowBox[{"27", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p3", "2"], "+", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"9", " ", "p2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", " ", "p3"}], "+", 
            RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
         RowBox[{"27", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p3", "2"], "+", 
            RowBox[{
             SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], "2"],
       "-", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "-", 
          RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}]}]]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.7260775312314167`*^9, 3.726077546784399*^9}, {
  3.7260783128118563`*^9, 3.72607832589255*^9}, {3.7260783855416527`*^9, 
  3.7260783964845552`*^9}, {3.7260785439554358`*^9, 
  3.726078587163566*^9}},ExpressionUUID->"6f5ab490-cf3d-40d5-9321-\
d4a4b568673a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theGfun", "[", 
   RowBox[{"0", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["p2", "3"]}], "+", 
    RowBox[{"27", " ", 
     SuperscriptBox["p3", "2"]}], "-", 
    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
    RowBox[{"3", 
     SqrtBox[
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["p2", "3"], " ", 
        SuperscriptBox["p3", "2"]}], "+", 
       RowBox[{"81", " ", 
        SuperscriptBox["p3", "4"]}], "-", 
       RowBox[{"48", " ", 
        SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
       RowBox[{"432", " ", "p2", " ", 
        SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
       RowBox[{"384", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p4", "2"]}], "-", 
       RowBox[{"768", " ", 
        SuperscriptBox["p4", "3"]}]}]]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.7260775312314167`*^9, 3.726077546784399*^9}, {
   3.7260783128118563`*^9, 3.72607832589255*^9}, {3.7260783855416527`*^9, 
   3.7260783964845552`*^9}, {3.7260785439554358`*^9, 3.726078587163566*^9}, 
   3.7261692664995813`*^9, {3.726169449074918*^9, 3.7261694629375563`*^9}, 
   3.7261694932312937`*^9},ExpressionUUID->"152ccef4-2cc3-452c-bcf9-\
c010f6a7c9dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theFfun", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox[
     RowBox[{"theGfun", "[", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
     RowBox[{"1", "/", "3"}]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["2", 
      RowBox[{"1", "/", "3"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "-", 
       RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"theGfun", "[", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
     RowBox[{"1", "/", "3"}]]]}]}]], "Input",
 CellChangeTimes->{{3.726079275700633*^9, 3.7260793219973373`*^9}, {
  3.7260793595079813`*^9, 3.726079382051634*^9}, {3.726079920507094*^9, 
  3.7260799330310707`*^9}},ExpressionUUID->"25a8fd56-44e7-4ec4-8cf9-\
5c460b302731"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions for the 3D Horn problem", "Subchapter",
 CellChangeTimes->{{3.718565733869712*^9, 
  3.718565741253331*^9}},ExpressionUUID->"67314e02-9e3b-4a80-88b4-\
110a6d60a5b6"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1a.  (333)  Horn Matrix  expressions for 3D data",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.716571747674493*^9, 3.7165717634583597`*^9}, {
  3.716572358885088*^9, 3.7165723698533583`*^9}, {3.726344904015291*^9, 
  3.726344909687067*^9}, {3.726344942526772*^9, 
  3.726344946094708*^9}},ExpressionUUID->"6bce817c-12d6-4bd3-b896-\
2982bbd001ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornSmat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sxx", "+", "syy", "+", "szz"}], ",", 
       RowBox[{"syz", "-", "szy"}], ",", 
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
       RowBox[{"sxy", "-", "syx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"syz", "-", "szy"}], ",", 
       RowBox[{"sxx", "-", "syy", "-", "szz"}], ",", 
       RowBox[{"sxy", "+", "syx"}], ",", 
       RowBox[{"sxz", "+", "szx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
       RowBox[{"sxy", "+", "syx"}], ",", 
       RowBox[{
        RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ",", 
       RowBox[{"syz", "+", "szy"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sxy", "-", "syx"}], ",", 
       RowBox[{"sxz", "+", "szx"}], ",", 
       RowBox[{"syz", "+", "szy"}], ",", 
       RowBox[{
        RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.715445743865513*^9, 3.715445749105234*^9}, {
  3.7185497408228188`*^9, 
  3.718549741214612*^9}},ExpressionUUID->"67ca6994-2b9d-4f97-9415-\
e1642dd232fb"],

Cell[CellGroupData[{

Cell["Transformations among coordinate systems:", "Subsubsection",
 CellChangeTimes->{{3.7165724462135143`*^9, 
  3.716572456613344*^9}},ExpressionUUID->"95118b21-6173-4094-9e80-\
5fe18e3d1b73"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornS2ARule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxx", "\[Rule]", " ", "x"}], " ", ",", 
     RowBox[{"syy", " ", "\[Rule]", "y"}], ",", 
     RowBox[{"szz", "\[Rule]", "z"}], ",", 
     RowBox[{
      RowBox[{"syz", "-", "szy"}], "\[Rule]", "a"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "sxz"}], "+", "szx"}], "\[Rule]", "b"}], ",", 
     RowBox[{
      RowBox[{"sxy", "-", "syx"}], "\[Rule]", "c"}], ",", 
     RowBox[{
      RowBox[{"sxy", "+", "syx"}], "\[Rule]", "cc"}], ",", 
     RowBox[{
      RowBox[{"sxz", "+", "szx"}], "\[Rule]", "bb"}], ",", 
     RowBox[{
      RowBox[{"syz", "+", "szy"}], "\[Rule]", "aa"}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.716139313568243*^9, 3.716139361073591*^9}, 
   3.7161396811751623`*^9},ExpressionUUID->"1f9a2d66-72a3-4dd6-80b6-\
4c2ac2584f4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornA2SRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "sxx"}], " ", ",", 
     RowBox[{"y", "\[Rule]", "syy"}], ",", 
     RowBox[{"z", "\[Rule]", "szz"}], ",", 
     RowBox[{"a", "\[Rule]", 
      RowBox[{"syz", "-", "szy"}]}], ",", 
     RowBox[{"b", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "sxz"}], "+", "szx"}]}], ",", 
     RowBox[{"c", "\[Rule]", 
      RowBox[{"sxy", "-", "syx"}]}], ",", 
     RowBox[{"cc", "\[Rule]", 
      RowBox[{"sxy", "+", "syx"}]}], ",", 
     RowBox[{"bb", "\[Rule]", 
      RowBox[{"sxz", "+", "szx"}]}], ",", 
     RowBox[{"aa", "\[Rule]", 
      RowBox[{"syz", "+", "szy"}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7161394193628387`*^9, 3.7161394893981333`*^9}, 
   3.71613968448726*^9},ExpressionUUID->"d92aaa99-ed5e-4952-ba3b-\
72b1199f9105"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornSmat", "/.", "hornS2ARule"}]], "Input",
 CellChangeTimes->{{3.718550177708343*^9, 
  3.718550186180805*^9}},ExpressionUUID->"313df013-2625-448d-960f-\
5596de7f1cde"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "+", "y", "+", "z"}], ",", "a", ",", "b", ",", "c"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"x", "-", "y", "-", "z"}], ",", "cc", ",", "bb"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "cc", ",", 
     RowBox[{
      RowBox[{"-", "x"}], "+", "y", "-", "z"}], ",", "aa"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "bb", ",", "aa", ",", 
     RowBox[{
      RowBox[{"-", "x"}], "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.718549768418871*^9, 3.718549802067041*^9, 
  3.71855018687293*^9},ExpressionUUID->"2be6d02c-038d-4a2b-b91d-04dce16d998c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Array", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sym", "[", 
     RowBox[{"\"\<E\>\"", ",", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "[", 
       RowBox[{"[", "#1", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "[", 
       RowBox[{"[", "#2", "]"}], "]"}]}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.742950598266391*^9, 3.7429506553432417`*^9}, {
  3.742997367568921*^9, 3.7429973749222097`*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"01e0da64-7b11-4882-aea0-25c73cedf7d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.742997376684577*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"428a925b-9d09-4c8b-91e1-d1a846f3fa8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Array", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sym", "[", 
     RowBox[{"\"\<E\>\"", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "[", 
       RowBox[{"[", "#1", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "[", 
       RowBox[{"[", "#2", "]"}], "]"}]}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.742950598266391*^9, 3.7429506553432417`*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"7a4c8d8c-a033-4fba-bb6b-cf12556d070e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Exw", ",", "Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Eyw", ",", "Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.74299737963787*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"4e6f8402-a300-4769-b05a-0634668a3985"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"PQbTo4DRot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".", 
     
     RowBox[{"{", 
      RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "-", 
    RowBox[{"qprod", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"qprod", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", 
          RowBox[{"-", "q1"}], ",", 
          RowBox[{"-", "q2"}], ",", 
          RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}], "]"}]}], ")"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.74208211784585*^9, 3.742082121234069*^9}, {
  3.7421445731318617`*^9, 3.74214467680346*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"3997e4c7-7d43-4f4b-804e-b45e63d0dac9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.742144677237322*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"17a350b4-7f33-4add-8057-aaa783eb2d8c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CHECKhornM4mat", " ", "=", " ", 
  RowBox[{"matrixFromLRCoeff", "[", 
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{
      RowBox[{"PQbTo4DRot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".",
       "hornE4mat"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.742081605600173*^9, 3.742081657610359*^9}, {
   3.742081884654695*^9, 3.742081927119203*^9}, {3.742082014798903*^9, 
   3.742082095826495*^9}, 3.742168519458087*^9, {3.742997980105249*^9, 
   3.7429979808534117`*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"647f8a96-6772-46fa-8e8a-959628badeac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742082097293445*^9, 3.7429502976521807`*^9, 
  3.7429979850033007`*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"8ffdeefc-8566-4aa2-892c-948467fce6b3"]
}, Open  ]],

Cell["Register the standards here, omitted in early file::", "Text",
 CellChangeTimes->{{3.742997822278495*^9, 
  3.742997834926298*^9}},ExpressionUUID->"7a2e08ab-2397-47b9-a5e2-\
27bc8700b875"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornE3mat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742000646059269*^9, 3.742000652963683*^9}, {
  3.7429505556903267`*^9, 3.742950577695804*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"f7f9e68b-8336-4c6e-a824-645d04dad8bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornM3mat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ",", 
       RowBox[{"Eyz", "-", "Ezy"}], ",", 
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], ",", 
       RowBox[{"Exy", "-", "Eyx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eyz", "-", "Ezy"}], ",", 
       RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ",", 
       RowBox[{"Exy", "+", "Eyx"}], ",", 
       RowBox[{"Exz", "+", "Ezx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], ",", 
       RowBox[{"Exy", "+", "Eyx"}], ",", 
       RowBox[{
        RowBox[{"-", "Exx"}], "+", "Eyy", "-", "Ezz"}], ",", 
       RowBox[{"Eyz", "+", "Ezy"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exy", "-", "Eyx"}], ",", 
       RowBox[{"Exz", "+", "Ezx"}], ",", 
       RowBox[{"Eyz", "+", "Ezy"}], ",", 
       RowBox[{
        RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742950740406219*^9, 3.742950748383486*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"b1dfe5c2-bf33-4554-8476-d4c7ad6b46ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornE4mat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Exw", ",", "Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Eyw", ",", "Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742950678129162*^9, 3.7429507058948174`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"1236bef2-3aac-4742-9d6b-f05e71a945d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornM4mat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
       RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
       RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
       RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
       RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
       RowBox[{
        RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
       RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
       RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7429507586639433`*^9, 3.742950789075365*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"36303099-486c-4316-b59e-9d30638bf11b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornAmat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "+", "y", "+", "z"}], ",", "a", ",", "b", ",", "c"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"x", "-", "y", "-", "z"}], ",", "cc", ",", "bb"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"b", ",", "cc", ",", 
       RowBox[{
        RowBox[{"-", "x"}], "+", "y", "-", "z"}], ",", "aa"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "bb", ",", "aa", ",", 
       RowBox[{
        RowBox[{"-", "x"}], "-", "y", "+", "z"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.716572509809708*^9, 
  3.716572519878406*^9}},ExpressionUUID->"da722435-9605-43f0-ab03-\
8cc4702702ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"detH", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["cc", "2"]}], "+", 
    RowBox[{"2", " ", "aa", " ", "bb", " ", "cc", " ", "x"}], "-", 
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["cc", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    SuperscriptBox["x", "4"], "+", 
    RowBox[{"2", " ", "aa", " ", "bb", " ", "cc", " ", "y"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["c", "2"], " ", "x", " ", "y"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["cc", "2"], " ", "x", " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["cc", "2"], " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["y", "4"], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", "y"}]}], ")"}], " ", "z"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox["bb", "2"], "-", 
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["cc", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    SuperscriptBox["z", "4"], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "z"}], "+", 
       SuperscriptBox["z", "2"]}], ")"}]}], "-", 
    RowBox[{"2", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", "bb"}], "+", 
          RowBox[{"c", " ", "cc"}]}], ")"}]}], "+", 
       RowBox[{"b", " ", "cc", " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
       RowBox[{"bb", " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["aa", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "b", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bb", " ", "cc"}], "+", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7185535681783867`*^9, 
  3.7185535752199907`*^9}},ExpressionUUID->"3485fb63-976d-407b-b2ac-\
9fe87540aeb8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Times", "@@", 
    RowBox[{"formTr0", "[", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]}], ",", " ", 
   RowBox[{
    RowBox[{"Times", "@@", 
     RowBox[{"formTr0", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]}], "//", "Expand"}], 
   ",", 
   RowBox[{"formQuad", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "^", "2"}], ",", 
      RowBox[{"y", "^", "2"}], ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.7189941951782827`*^9, 3.71899419975069*^9}, {
  3.718994241614829*^9, 
  3.718994332973003*^9}},ExpressionUUID->"1ca7a4ac-5221-49f8-bdf6-\
858ababd455d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["y", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    SuperscriptBox["z", "4"]}], ",", 
   RowBox[{
    SuperscriptBox["x", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["y", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    SuperscriptBox["z", "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.718994249359593*^9, 3.718994273837194*^9}, {
  3.718994311208641*^9, 
  3.718994333281087*^9}},ExpressionUUID->"f1ee88e5-37c7-47a9-b1b1-\
07a20e6d228e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "This", " ", "is", " ", "p4", " ", "in", " ", "a", " ", "symmetrical", 
     " ", 
     RowBox[{"grouping", ":", " ", "const"}]}], ",", " ", 
    RowBox[{"linear", " ", "in", " ", "xyz"}], ",", " ", "quadratic", ",", 
    " ", 
    RowBox[{"NO", " ", "cubic"}], ",", " ", 
    RowBox[{"Times", "@@", 
     RowBox[{"formTr0", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]}]}], "  ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7173669515262527`*^9, 3.7173670050712223`*^9}, {
  3.7189946846459627`*^9, 
  3.71899473918661*^9}},ExpressionUUID->"feb65915-6a73-4dba-9c29-\
d25cac6b2906"],

Cell[BoxData[
 RowBox[{
  RowBox[{"detHnice", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["aa", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["bb", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["cc", "2"]}], "-", 
    RowBox[{"2", " ", "a", " ", "aa", " ", "b", " ", "bb"}], "-", 
    RowBox[{"2", " ", "a", " ", "aa", " ", "c", " ", "cc"}], "-", 
    RowBox[{"2", " ", "b", " ", "bb", " ", "c", " ", "cc"}], "+", 
    "\[IndentingNewLine]", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", "b", " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], "+", 
       RowBox[{"a", " ", "bb", " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}], "+", 
       RowBox[{"a", " ", "b", " ", "cc", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{"aa", " ", "bb", " ", "cc", " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
    "\[IndentingNewLine]", " ", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", "\[IndentingNewLine]", 
    
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["cc", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718994596499716*^9, 3.718994655245895*^9}, {
  3.718994755704384*^9, 3.718994766144092*^9}, {3.718994805873913*^9, 
  3.7189948648220253`*^9}, {3.7189949084631233`*^9, 
  3.7189949552206917`*^9}},ExpressionUUID->"51e37d1a-6c46-48fb-954c-\
75ebfbef568f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"detH", "-", 
     RowBox[{"Det", "[", "hornAmat", "]"}]}], "//", "Simplify"}], ",", " ", 
   RowBox[{
    RowBox[{"detH", "-", "detHnice"}], "//", "Expand"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.718993840140772*^9, 3.7189938472644672`*^9}, {
  3.718993892212062*^9, 3.7189939454354897`*^9}, {3.718994960529676*^9, 
  3.718994972879858*^9}, {3.718995008977872*^9, 
  3.718995013168087*^9}},ExpressionUUID->"b7b3f3c1-0f28-4f53-8ea2-\
0d7ecaa61167"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.718994965425308*^9, 3.7189949733458223`*^9}, 
   3.718995013471932*^9},ExpressionUUID->"93380237-28c0-4853-984c-\
2ce8422917b1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"thePRule", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p4", "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["aa", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["bb", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox["cc", "2"]}], "-", 
       RowBox[{"2", " ", "a", " ", "aa", " ", "b", " ", "bb"}], "-", 
       RowBox[{"2", " ", "a", " ", "aa", " ", "c", " ", "cc"}], "-", 
       RowBox[{"2", " ", "b", " ", "bb", " ", "c", " ", "cc"}], "+", 
       "\[IndentingNewLine]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "b", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], "+", 
          RowBox[{"a", " ", "bb", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}], "+", 
          RowBox[{"a", " ", "b", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "+", 
          RowBox[{"aa", " ", "bb", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
       "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["cc", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}]}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "b", " ", "c"}], "+", 
          RowBox[{"a", " ", "bb", " ", "c"}], "+", 
          RowBox[{"a", " ", "b", " ", "cc"}], "+", 
          RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["aa", "2"]}], " ", ")"}], "x"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "-", 
             SuperscriptBox["bb", "2"]}], " ", ")"}], "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["c", "2"], "-", 
             SuperscriptBox["cc", "2"]}], " ", ")"}], "z"}]}], ")"}]}], "-", 
       RowBox[{"8", " ", "x", " ", "y", " ", "z"}]}]}], ",", 
     RowBox[{"p2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "-", 
       SuperscriptBox["aa", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["bb", "2"], "-", 
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["cc", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}]}]}]}]}], "}"}]}], ";"}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.718033761879839*^9, 3.7180337680212927`*^9}, 
   3.718033975361393*^9, 3.718993823626432*^9, {3.718995054736902*^9, 
   3.71899512717223*^9}, 
   3.7189951838049183`*^9},ExpressionUUID->"e73eb0b4-031f-49d4-aec3-\
268449cd63ab"],

Cell[BoxData[
 RowBox[{"Clear", "[", "b", "]"}]], "Input",
 CellChangeTimes->{{3.729018519674533*^9, 
  3.7290185246010027`*^9}},ExpressionUUID->"e087b651-5c13-4eae-a0e2-\
93b17fbc24bf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"thexyz2ERule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "Exx"}], ",", 
    RowBox[{"y", "\[Rule]", "Eyy"}], ",", 
    RowBox[{"z", "\[Rule]", "Ezz"}], ",", 
    RowBox[{"a", "\[Rule]", 
     RowBox[{"Eyz", "-", "Ezy"}]}], ",", 
    RowBox[{"b", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "Exz"}], "+", "Ezx"}]}], ",", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Exy", "-", "Eyx"}]}], ",", 
    RowBox[{"cc", "\[Rule]", 
     RowBox[{"Exy", "+", "Eyx"}]}], ",", 
    RowBox[{"bb", "\[Rule]", 
     RowBox[{"Exz", "+", "Ezx"}]}], ",", 
    RowBox[{"aa", "\[Rule]", 
     RowBox[{"Eyz", "+", "Ezy"}]}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729018474200198*^9, 
  3.729018482072617*^9}},ExpressionUUID->"3c14f83a-7265-499f-b435-\
4dde199c6850"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "Exx"}], ",", 
   RowBox[{"y", "\[Rule]", "Eyy"}], ",", 
   RowBox[{"z", "\[Rule]", "Ezz"}], ",", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"Eyz", "-", "Ezy"}]}], ",", 
   RowBox[{"b", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "Exz"}], "+", "Ezx"}]}], ",", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"Exy", "-", "Eyx"}]}], ",", 
   RowBox[{"cc", "\[Rule]", 
    RowBox[{"Exy", "+", "Eyx"}]}], ",", 
   RowBox[{"bb", "\[Rule]", 
    RowBox[{"Exz", "+", "Ezx"}]}], ",", 
   RowBox[{"aa", "\[Rule]", 
    RowBox[{"Eyz", "+", "Ezy"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.729018489107636*^9, 
  3.7290185288951387`*^9},ExpressionUUID->"e229cf45-4b17-480c-a95e-\
1782a5f711f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theP2ERule", " ", "=", 
  RowBox[{"thePRule", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "Exx"}], ",", 
     RowBox[{"y", "\[Rule]", "Eyy"}], ",", 
     RowBox[{"z", "\[Rule]", "Ezz"}], ",", 
     RowBox[{"a", "\[Rule]", 
      RowBox[{"Eyz", "-", "Ezy"}]}], ",", 
     RowBox[{"b", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Exz"}], "+", "Ezx"}]}], ",", 
     RowBox[{"c", "\[Rule]", 
      RowBox[{"Exy", "-", "Eyx"}]}], ",", 
     RowBox[{"cc", "\[Rule]", 
      RowBox[{"Exy", "+", "Eyx"}]}], ",", 
     RowBox[{"bb", "\[Rule]", 
      RowBox[{"Exz", "+", "Ezx"}]}], ",", 
     RowBox[{"aa", "\[Rule]", 
      RowBox[{"Eyz", "+", "Ezy"}]}]}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725573433925993*^9, 
  3.725573513333879*^9}},ExpressionUUID->"e30ab8be-593d-4d7c-bffb-\
a927e4c80315"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Exy", "-", "Eyx"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Exy", "+", "Eyx"}], ")"}], "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"Exy", "-", "Eyx"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exy", "+", "Eyx"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exz", "+", "Ezx"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Exz", "+", "Ezx"}], ")"}], "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"Exy", "-", "Eyx"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exy", "+", "Eyx"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Eyz", "-", "Ezy"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Eyz", "+", "Ezy"}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exz", "+", "Ezx"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Eyz", "-", "Ezy"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Eyz", "+", "Ezy"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Eyz", "-", "Ezy"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Eyz", "+", "Ezy"}], ")"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "+", "Eyy", "-", "Ezz"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Exy", "-", "Eyx"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "-", "Eyy", "+", "Ezz"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Eyz", "-", "Ezy"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "-", "Eyy", "+", "Ezz"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Exy", "+", "Eyx"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "+", "Eyy", "-", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Exz", "+", "Ezx"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "-", "Eyy", "+", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "+", "Eyy", "-", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "-", "Eyy", "+", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Eyz", "+", "Ezy"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Exx"}], "+", "Eyy", "+", "Ezz"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Exy", "-", "Eyx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Eyz", "+", "Ezy"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Exy", "-", "Eyx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Exz", "+", "Ezx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Eyz", "-", "Ezy"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "Exx"}], "+", "Eyy", "-", "Ezz"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Exy", "+", "Eyx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Eyz", "-", "Ezy"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Exy", "+", "Eyx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Exz", "+", "Ezx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Eyz", "+", "Ezy"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}]}], ")"}]}]}]}], 
   ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", "Exx", " ", "Eyy", " ", "Ezz"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Eyy", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"Exz", "+", "Ezx"}], ")"}], "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Exy", "+", "Eyx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Eyz", "-", "Ezy"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Exy", "-", "Eyx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Exz", "+", "Ezx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Eyz", "-", "Ezy"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Exy", "-", "Eyx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Eyz", "+", "Ezy"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Exy", "+", "Eyx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Exz", "+", "Ezx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Eyz", "+", "Ezy"}], ")"}]}], "+", 
        RowBox[{"Exx", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"Eyz", "-", "Ezy"}], ")"}], "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"Eyz", "+", "Ezy"}], ")"}], "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"Exy", "-", "Eyx"}], ")"}], "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"Exy", "+", "Eyx"}], ")"}], "2"]}], ")"}], " ", 
         "Ezz"}]}], ")"}]}]}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Exy", "-", "Eyx"}], ")"}], "2"]}], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"Exy", "+", "Eyx"}], ")"}], "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], ")"}], "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"Exz", "+", "Ezx"}], ")"}], "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"Eyz", "-", "Ezy"}], ")"}], "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"Eyz", "+", "Ezy"}], ")"}], "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["Exx", "2"], "+", 
        SuperscriptBox["Eyy", "2"], "+", 
        SuperscriptBox["Ezz", "2"]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.72625676239878*^9, 
  3.729008625995914*^9},ExpressionUUID->"7056c233-de63-4f8a-b8e7-\
01a8f0f94b87"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", " ", 
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{"Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
   RowBox[{"{", " ", 
    RowBox[{"Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
   RowBox[{"{", " ", 
    RowBox[{"Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.725573862843258*^9, 
  3.72557387431625*^9}},ExpressionUUID->"515bf23a-844e-4adc-9069-\
79caad5d48d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Exw", ",", "Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Eyw", ",", "Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{
  3.725573878676207*^9},ExpressionUUID->"7eca3e70-c0d5-4b94-9754-\
0e79ec62432b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeP2E3DValsRule", "[", "EijArray3D_", "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"{", " ", 
          RowBox[{"Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
         RowBox[{"{", " ", 
          RowBox[{"Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
         RowBox[{"{", " ", 
          RowBox[{"Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], "}"}], "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "\[Rule]", " ", 
      RowBox[{"EijArray3D", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725573757069449*^9, 3.7255738071452427`*^9}, {
  3.725573896088089*^9, 
  3.7255739558445997`*^9}},ExpressionUUID->"8c9ac3af-634a-4558-8286-\
47aba84782ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeP2E4DValsRule", "[", "EijArray4D_", "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"Exw", ",", "Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Eyw", ",", "Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], "}"}],
        "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "\[Rule]", " ", 
      RowBox[{"EijArray4D", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725573757069449*^9, 3.7255738071452427`*^9}, {
  3.725573896088089*^9, 3.72557399100323*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"2594ee35-007b-4417-becb-388b3c923eba"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Note", ":", "   ", 
    RowBox[{"really", " ", "from", " ", "eqQuadratic"}]}], ",", "  ", 
   "eqGenEig", ",", " ", 
   RowBox[{"defined", " ", "later"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7192599205437*^9, 3.719259941791847*^9}, {
  3.7197785388920527`*^9, 
  3.719778548295576*^9}},ExpressionUUID->"fe60e243-0b77-47f3-8182-\
f5533cb3ec78"],

Cell[CellGroupData[{

Cell[BoxData["eqQuadratic"], "Input",
 CellChangeTimes->{{3.719778558425715*^9, 
  3.719778562147169*^9}},ExpressionUUID->"35d8acf5-9ae4-47d4-b9d7-\
047255f85f88"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["xx", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
    SuperscriptBox["yy", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
    RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
    SuperscriptBox["zz", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SqrtBox["xx"], " ", 
    SqrtBox["yy"], " ", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.719778562732963*^9},ExpressionUUID->"a4a31dcc-83f7-4df0-8e18-\
9f833d5f7287"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pToxxRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "8"}], " ", 
       SqrtBox["xx"], " ", 
       SqrtBox["yy"], " ", 
       SqrtBox["zz"]}]}], ",", 
     RowBox[{"p4", "\[Rule]", 
      RowBox[{
       SuperscriptBox["xx", "2"], "-", 
       RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
       SuperscriptBox["yy", "2"], "-", 
       RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
       RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
       SuperscriptBox["zz", "2"]}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719679142850054*^9, 3.719679154465569*^9}, {
  3.729167052147661*^9, 
  3.729167067700612*^9}},ExpressionUUID->"37fcc4d0-310f-4407-ac7a-\
b266e8c18f21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pToeeRule", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ee1", "\[Rule]", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "p1"}], "4"], "+", " ", 
       SqrtBox["xx"], " ", "+", 
       SqrtBox["yy"], " ", "+", 
       SqrtBox["zz"]}]}], ",", 
     RowBox[{"ee2", "\[Rule]", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "p1"}], "4"], "+", " ", 
       SqrtBox["xx"], " ", "-", 
       SqrtBox["yy"], " ", "-", 
       SqrtBox["zz"]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ee3", "\[Rule]", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "p1"}], "4"], "-", " ", 
       SqrtBox["xx"], " ", "+", 
       SqrtBox["yy"], " ", "-", 
       SqrtBox["zz"]}]}], ",", 
     RowBox[{"ee4", "\[Rule]", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "p1"}], "4"], "-", " ", 
       SqrtBox["xx"], " ", "-", 
       SqrtBox["yy"], " ", "+", 
       SqrtBox["zz"]}]}]}], "}"}]}], "//", "FullSimplify"}]], "Input",Expressi\
onUUID->"61e46162-00dd-4600-ab67-e09a212abf9b"],

Cell[BoxData[
 RowBox[{"p4DToeRule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p2", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "8"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}]}], ",", 
    RowBox[{"p3", "\[Rule]", 
     RowBox[{
      FractionBox[
       SuperscriptBox["p1", "3"], "16"], "-", 
      RowBox[{"8", " ", 
       SqrtBox["xx"], " ", 
       SqrtBox["yy"], " ", 
       SqrtBox["zz"]}], "-", 
      RowBox[{"p1", " ", 
       RowBox[{"(", 
        RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}]}], ",", 
    RowBox[{"p4", "\[Rule]", 
     RowBox[{
      FractionBox[
       SuperscriptBox["p1", "4"], "256"], "+", 
      SuperscriptBox["xx", "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"yy", "-", "zz"}], ")"}], "2"], "-", 
      RowBox[{"2", " ", "p1", " ", 
       SqrtBox["xx"], " ", 
       SqrtBox["yy"], " ", 
       SqrtBox["zz"]}], "-", 
      RowBox[{"2", " ", "xx", " ", 
       RowBox[{"(", 
        RowBox[{"yy", "+", "zz"}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SuperscriptBox["p1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}]}]}], "}"}]}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.7291669953653584`*^9, 
  3.729166996293209*^9}},ExpressionUUID->"83e1c73a-eb0e-45ed-a6d6-\
0f0cc972c154"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"eqPform", "[", 
     RowBox[{"[", "i", "]"}], "]"}], "->", 
    RowBox[{"eqGenEig", "[", 
     RowBox[{"[", "i", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.719680240275879*^9, 3.719680299347753*^9}, {
  3.719778110500671*^9, 
  3.719778113307396*^9}},ExpressionUUID->"58a464e5-b839-4172-8243-\
14947c88da34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"ee1", " ", "ee2"}], "+", 
     RowBox[{"ee1", " ", "ee3"}], "+", 
     RowBox[{"ee2", " ", "ee3"}], "+", 
     RowBox[{"ee1", " ", "ee4"}], "+", 
     RowBox[{"ee2", " ", "ee4"}], "+", 
     RowBox[{"ee3", " ", "ee4"}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "ee1"}], " ", "ee2", " ", "ee3"}], "-", 
     RowBox[{"ee1", " ", "ee2", " ", "ee4"}], "-", 
     RowBox[{"ee1", " ", "ee3", " ", "ee4"}], "-", 
     RowBox[{"ee2", " ", "ee3", " ", "ee4"}]}]}], ",", 
   RowBox[{"p4", "\[Rule]", 
    RowBox[{"ee1", " ", "ee2", " ", "ee3", " ", "ee4"}]}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.71977811542006*^9},ExpressionUUID->"e1f2e347-1685-40f0-8597-b0b5d04a9e3c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pToeeRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p2", "\[Rule]", 
      RowBox[{
       RowBox[{"ee1", " ", "ee2"}], "+", 
       RowBox[{"ee1", " ", "ee3"}], "+", 
       RowBox[{"ee2", " ", "ee3"}], "+", 
       RowBox[{"ee1", " ", "ee4"}], "+", 
       RowBox[{"ee2", " ", "ee4"}], "+", 
       RowBox[{"ee3", " ", "ee4"}]}]}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee1"}], " ", "ee2", " ", "ee3"}], "-", 
       RowBox[{"ee1", " ", "ee2", " ", "ee4"}], "-", 
       RowBox[{"ee1", " ", "ee3", " ", "ee4"}], "-", 
       RowBox[{"ee2", " ", "ee3", " ", "ee4"}]}]}], ",", 
     RowBox[{"p4", "\[Rule]", 
      RowBox[{"ee1", " ", "ee2", " ", "ee3", " ", "ee4"}]}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719778103900003*^9, 
  3.719778121171136*^9}},ExpressionUUID->"f604762a-2154-47df-82fd-\
1d860733af2a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Origin", " ", "of", " ", "the", " ", "radial", " ", 
     RowBox[{"variables", ":", " ", 
      RowBox[{"order", " ", "2"}]}]}], ",", " ", 
    RowBox[{"order", " ", "3"}], ",", " ", 
    RowBox[{"order", " ", "4"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rr", "\[Rule]", " ", 
       FractionBox[
        RowBox[{"-", "p2"}], "2"]}], ",", 
      RowBox[{"RR", "\[Rule]", " ", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"(", 
         RowBox[{"p4", " ", "+", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox["p2", "2"], ")"}], "2"]}], ")"}]}]}], ",", 
      RowBox[{"ss", "\[Rule]", 
       RowBox[{"-", " ", 
        FractionBox["p3", "8"]}]}]}], "}"}], "/.", "pToxxRule"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.719778176939809*^9, 3.7197781994744368`*^9}, {
  3.719778234564746*^9, 
  3.719778251234638*^9}},ExpressionUUID->"30915239-75e1-45d4-9fea-\
b50de9ac5af9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"rr", "\[Rule]", 
    RowBox[{"xx", "+", "yy", "+", "zz"}]}], ",", 
   RowBox[{"RR", "\[Rule]", 
    RowBox[{
     SuperscriptBox["xx", "2"], "+", 
     SuperscriptBox["yy", "2"], "+", 
     SuperscriptBox["zz", "2"]}]}], ",", 
   RowBox[{"ss", "\[Rule]", 
    RowBox[{
     SqrtBox["xx"], " ", 
     SqrtBox["yy"], " ", 
     SqrtBox["zz"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719778194824836*^9, 
  3.719778199909663*^9}},ExpressionUUID->"1aa3cc3c-3a86-47df-ae2c-\
9ac96d96a8a5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pToRadiiRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", "rr", ")"}]}]}], ",", "  ", 
     RowBox[{"p4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["rr", "2"]}], "+", 
       RowBox[{"2", " ", "RR"}]}]}], ",", " ", 
     RowBox[{"p3", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"-", "8"}], " ", "ss"}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719678366085175*^9, 3.719678405764901*^9}, {
   3.719678497960087*^9, 3.71967853848738*^9}, 
   3.719678714522097*^9},ExpressionUUID->"f7916ba6-5aa9-4d97-8029-\
1a684a93d364"],

Cell[BoxData[
 RowBox[{
  RowBox[{"backRadiiRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"rr", "\[Rule]", " ", 
      FractionBox[
       RowBox[{"-", "p2"}], "2"]}], ",", 
     RowBox[{"RR", "\[Rule]", " ", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{"p4", " ", "+", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["p2", "2"], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{"ss", "\[Rule]", 
      RowBox[{"-", " ", 
       FractionBox["p3", "8"]}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719678637848649*^9, 
  3.719678717178423*^9}},ExpressionUUID->"52361237-8431-4d96-b52c-\
5bad57c5d8ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Check a few special combinations  w[p2,p4], r [p2,p4] \
that occur frequently: don\[CloseCurlyQuote]t initialize them",
 FontSize->16,
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.719019783410776*^9, 3.719019793634522*^9}, {
  3.719259970784293*^9, 
  3.7192600051048737`*^9}},ExpressionUUID->"eca59d51-953e-4610-bc06-\
77b959a2d58e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p4", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p2", "/", "2"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{"p4", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p2", "/", "2"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{
       SuperscriptBox["p2", "2"], "+", 
       RowBox[{"12", " ", "p4"}]}]}], "}"}], "/.", "thePXRule"}], "//", 
   "Expand"}], "//", "Factor"}]], "Input",
 CellChangeTimes->{{3.71901908273912*^9, 3.719019119866407*^9}, {
  3.7190198094923687`*^9, 
  3.719019812754957*^9}},ExpressionUUID->"57c119f5-2184-426f-91ec-\
aed51baac19d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["xx", "2"], "+", 
      SuperscriptBox["yy", "2"], "+", 
      SuperscriptBox["zz", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"xx", " ", "yy"}], "+", 
      RowBox[{"xx", " ", "zz"}], "+", 
      RowBox[{"yy", " ", "zz"}]}], ")"}]}], ",", 
   RowBox[{"16", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["xx", "2"], "-", 
      RowBox[{"xx", " ", "yy"}], "+", 
      SuperscriptBox["yy", "2"], "-", 
      RowBox[{"xx", " ", "zz"}], "-", 
      RowBox[{"yy", " ", "zz"}], "+", 
      SuperscriptBox["zz", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7190191150144978`*^9, 3.719019120228805*^9}, 
   3.71901981323055*^9},ExpressionUUID->"17304259-fde2-40d8-bfc1-\
23e412b84fab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"thePWRule", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"w", "\[Rule]", " ", 
     RowBox[{"Power", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"p4", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"p2", "/", "2"}], ")"}], "^", "2"}]}], ")"}], "/.", 
         "thePRule"}], "//", "FullSimplify"}], ",", 
       RowBox[{"1", "/", "4"}]}], "]"}]}], ",", " ", 
    RowBox[{"r", "\[Rule]", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "p2"}], "/", "2"}], "/.", "thePRule"}], "]"}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7183892170946836`*^9, 3.718389227226017*^9}, {
  3.718391890447711*^9, 
  3.718392007777384*^9}},ExpressionUUID->"89ed5645-3ac7-42c6-8301-\
6e672e5edb9a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", "\[Rule]", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["aa", "2"]}], "-", 
       RowBox[{"2", " ", "a", " ", "aa", " ", "b", " ", "bb"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["bb", "2"]}], "-", 
       RowBox[{"2", " ", "a", " ", "aa", " ", "c", " ", "cc"}], "-", 
       RowBox[{"2", " ", "b", " ", "bb", " ", "c", " ", "cc"}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox["cc", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["cc", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "-", 
       RowBox[{"2", " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
          RowBox[{"bb", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{"x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", "aa", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], "+", 
          RowBox[{"bb", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["aa", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["bb", "2"], "+", 
           SuperscriptBox["c", "2"], "+", 
           SuperscriptBox["cc", "2"], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"], "+", 
              SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}], "2"]}]}], ")"}], 
     RowBox[{"1", "/", "4"}]]}], ",", 
   RowBox[{"r", "\[Rule]", 
    FractionBox[
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["cc", "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}]}]}]], 
     SqrtBox["2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7185520451446943`*^9, 3.718646210442401*^9, 
  3.718673051873685*^9, 3.718813024644573*^9, 3.7189921368722878`*^9, 
  3.719106105601214*^9, 
  3.719249942111164*^9},ExpressionUUID->"397e27c4-f566-4ee9-b477-\
a0ac09899821"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["xAplaneRule"], "Input",
 CellChangeTimes->{{3.7192600479710627`*^9, 
  3.719260049907103*^9}},ExpressionUUID->"e0a00ccd-fb3e-41e0-9b1e-\
89f54e01eb42"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "0"}], ",", 
   RowBox[{"b", "\[Rule]", "0"}], ",", 
   RowBox[{"bb", "\[Rule]", "0"}], ",", 
   RowBox[{"c", "\[Rule]", "0"}], ",", 
   RowBox[{"cc", "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719260050429017*^9},ExpressionUUID->"6aebd41b-90fc-4fe1-a77e-\
81d5b4de5932"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"thePWXplaneRule", " ", "=", " ", 
  RowBox[{
   RowBox[{"thePWRule", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", "0"}], ",", 
      RowBox[{"b", "\[Rule]", "0"}], ",", 
      RowBox[{"bb", "\[Rule]", "0"}], ",", 
      RowBox[{"c", "\[Rule]", "0"}], ",", 
      RowBox[{"cc", "\[Rule]", "0"}]}], "}"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7183925687412453`*^9, 3.7183926107764807`*^9}, 
   3.719260061932796*^9},ExpressionUUID->"e21a2b87-a0ee-41bf-8563-\
fce62d0e9542"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", "\[Rule]", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["aa", "4"], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["aa", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["y", "2"], "+", 
           RowBox[{"y", " ", "z"}], "+", 
           SuperscriptBox["z", "2"]}], ")"}]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["y", "4"], "+", 
           SuperscriptBox["z", "4"]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            SuperscriptBox["aa", "2"]}], "+", 
           RowBox[{"8", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["y", "2"], "-", 
              RowBox[{"y", " ", "z"}], "+", 
              SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "4"}]], 
     SqrtBox["2"]]}], ",", 
   RowBox[{"r", "\[Rule]", 
    FractionBox[
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["aa", "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}]}]}]], 
     SqrtBox["2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.718392586735537*^9, 3.718392611461348*^9}, 
   3.718646210679996*^9, 3.718673052674547*^9, 3.7188130250272923`*^9, 
   3.718992137317333*^9, 3.718993666615212*^9, 3.7191061061937923`*^9, 
   3.7192499422977*^9, 
   3.71926006870676*^9},ExpressionUUID->"3f0fe256-62cc-411d-878b-\
227866862565"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1b.    (4444)      Horn Matrix  expressions for 4D \
data:\n     choose order  R4.X = p*{X}*qbar",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.716571747674493*^9, 3.7165717634583597`*^9}, {
  3.716572358885088*^9, 3.7165723698533583`*^9}, {3.7263440584876137`*^9, 
  3.7263440635756207`*^9}, {3.726344125375289*^9, 3.7263441265432034`*^9}, {
  3.726344926868965*^9, 3.726344962694837*^9}, {3.726346611166493*^9, 
  3.726346638174314*^9}},ExpressionUUID->"618496fe-949b-4587-9e0f-\
e7161a652bef"],

Cell[TextData[StyleBox["Check 3D:",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.726347738403257*^9, 
  3.7263477411626472`*^9}},ExpressionUUID->"4acf8f6a-bd58-4edc-a305-\
38a0e65df23d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"QuatToRot", "[", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], ".", 
       RowBox[{"{", " ", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], " ", "-", 
      RowBox[{"Rest", "@", 
       RowBox[{"qprod", "[", " ", 
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", " ", "q1", ",", " ", "q2", ",", " ", "q3"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
         
         RowBox[{"{", 
          RowBox[{"q0", ",", 
           RowBox[{"-", "q1"}], ",", 
           RowBox[{"-", "q2"}], ",", 
           RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}]}], "}"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "&"}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.726347764854389*^9, 3.726347854218782*^9}, {
  3.726347908786689*^9, 3.7263479346018553`*^9}, {3.726347998596457*^9, 
  3.726348011538761*^9}},ExpressionUUID->"e91253f4-7aaf-4ee8-9eb7-\
155f9ce86755"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.726347936028655*^9, {3.726348003841238*^9, 
   3.72634801211043*^9}},ExpressionUUID->"71d05b55-0cb0-42ec-861c-\
497dac5a3315"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Exercise", " ", "for", " ", "Berthold"}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"qprod", "[", " ", 
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", " ", "q1", ",", " ", "q2", ",", " ", "q3"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
         
         RowBox[{"{", 
          RowBox[{"q0", ",", 
           RowBox[{"-", "q1"}], ",", 
           RowBox[{"-", "q2"}], ",", 
           RowBox[{"-", "q3"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"qprod", "[", " ", 
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", " ", "q1", ",", " ", "q2", ",", " ", "q3"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "q0"}], ",", "q1", ",", 
           RowBox[{"-", "q2"}], ",", 
           RowBox[{"-", "q3"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"qprod", "[", " ", 
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", " ", "q1", ",", " ", "q2", ",", " ", "q3"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "q0"}], ",", 
           RowBox[{"-", "q1"}], ",", "q2", ",", 
           RowBox[{"-", "q3"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"qprod", "[", " ", 
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", " ", "q1", ",", " ", "q2", ",", " ", "q3"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "q0"}], ",", 
           RowBox[{"-", "q1"}], ",", 
           RowBox[{"-", "q2"}], ",", " ", "q3"}], "}"}]}], "]"}]}], "}"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], "&"}]}],
     ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["q0", "2"], "+", 
        SuperscriptBox["q1", "2"], "+", 
        SuperscriptBox["q2", "2"], "+", 
        SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.726414519856639*^9, 3.726414663211884*^9}, {
  3.726414703262689*^9, 
  3.726414726499465*^9}},ExpressionUUID->"1899d0e4-7aa7-4879-883f-\
db080e080ffd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"w", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q0", "2"], "+", 
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"], "-", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "y"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "z"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q0", "2"], "-", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "-", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "y"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "z"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "y"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q0", "2"], "-", 
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "z"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "-", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "y"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q1", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "z"}]}], ",", 
     RowBox[{"-", "x"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "-", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "y"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "z"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q1", " ", "q2"}], "-", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "y"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "+", 
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "z"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "+", 
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q0", " ", "q1"}], "-", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "z"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "-", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "-", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "z"}]}], ",", 
     RowBox[{"-", "y"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "-", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "z"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "-", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q0", " ", "q2"}], "-", 
         RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "y"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
         RowBox[{"2", " ", "q2", " ", "q3"}]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "+", 
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "y"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "-", 
         RowBox[{"2", " ", "q1", " ", "q3"}]}], ")"}], " ", "w"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
         RowBox[{"2", " ", "q0", " ", "q3"}]}], ")"}], " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q0", "2"]}], "-", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], ")"}], " ", "y"}]}], ",", 
     RowBox[{"-", "z"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.726414664846088*^9, 
  3.726414727641657*^9},ExpressionUUID->"fbf1e7bf-ef8e-4a4a-a4ed-\
d9907172224c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PQbTo4DRot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], " ", "-", 
   RowBox[{"qprod", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
     RowBox[{"qprod", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", 
         RowBox[{"-", "q1"}], ",", 
         RowBox[{"-", "q2"}], ",", 
         RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7264144673411913`*^9, 
  3.726414491932467*^9}},ExpressionUUID->"462d73d8-35e0-4b4b-a8de-\
cb834b2583b8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.726414492517511*^9},ExpressionUUID->"3e1f38e8-c67f-4cf5-89e3-\
18b765d764f9"]
}, Open  ]],

Cell[TextData[{
 StyleBox["  ",
  FontSize->16],
 StyleBox["Continue 4D - using NEW, proper order corresponding to   p* X * \
qbar",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.7263477218511744`*^9, 3.726347728139073*^9}, {
  3.72636946437477*^9, 
  3.726369507934043*^9}},ExpressionUUID->"9310eac2-1293-4ad9-9a0c-\
87b77be79323"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PQbTo4DRot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}]], "Input",\
ExpressionUUID->"6ff7e967-3906-45b1-b76f-9ee4bfc9fd22"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "+", 
      RowBox[{"p1", " ", "q1"}], "+", 
      RowBox[{"p2", " ", "q2"}], "+", 
      RowBox[{"p3", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p1"}], " ", "q0"}], "+", 
      RowBox[{"p0", " ", "q1"}], "+", 
      RowBox[{"p3", " ", "q2"}], "-", 
      RowBox[{"p2", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p2"}], " ", "q0"}], "-", 
      RowBox[{"p3", " ", "q1"}], "+", 
      RowBox[{"p0", " ", "q2"}], "+", 
      RowBox[{"p1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p3"}], " ", "q0"}], "+", 
      RowBox[{"p2", " ", "q1"}], "-", 
      RowBox[{"p1", " ", "q2"}], "+", 
      RowBox[{"p0", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p1", " ", "q0"}], "-", 
      RowBox[{"p0", " ", "q1"}], "+", 
      RowBox[{"p3", " ", "q2"}], "-", 
      RowBox[{"p2", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "+", 
      RowBox[{"p1", " ", "q1"}], "-", 
      RowBox[{"p2", " ", "q2"}], "-", 
      RowBox[{"p3", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p3"}], " ", "q0"}], "+", 
      RowBox[{"p2", " ", "q1"}], "+", 
      RowBox[{"p1", " ", "q2"}], "-", 
      RowBox[{"p0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p2", " ", "q0"}], "+", 
      RowBox[{"p3", " ", "q1"}], "+", 
      RowBox[{"p0", " ", "q2"}], "+", 
      RowBox[{"p1", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p2", " ", "q0"}], "-", 
      RowBox[{"p3", " ", "q1"}], "-", 
      RowBox[{"p0", " ", "q2"}], "+", 
      RowBox[{"p1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p3", " ", "q0"}], "+", 
      RowBox[{"p2", " ", "q1"}], "+", 
      RowBox[{"p1", " ", "q2"}], "+", 
      RowBox[{"p0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "-", 
      RowBox[{"p1", " ", "q1"}], "+", 
      RowBox[{"p2", " ", "q2"}], "-", 
      RowBox[{"p3", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p1"}], " ", "q0"}], "-", 
      RowBox[{"p0", " ", "q1"}], "+", 
      RowBox[{"p3", " ", "q2"}], "+", 
      RowBox[{"p2", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p3", " ", "q0"}], "+", 
      RowBox[{"p2", " ", "q1"}], "-", 
      RowBox[{"p1", " ", "q2"}], "-", 
      RowBox[{"p0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p2"}], " ", "q0"}], "+", 
      RowBox[{"p3", " ", "q1"}], "-", 
      RowBox[{"p0", " ", "q2"}], "+", 
      RowBox[{"p1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p1", " ", "q0"}], "+", 
      RowBox[{"p0", " ", "q1"}], "+", 
      RowBox[{"p3", " ", "q2"}], "+", 
      RowBox[{"p2", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "-", 
      RowBox[{"p1", " ", "q1"}], "-", 
      RowBox[{"p2", " ", "q2"}], "+", 
      RowBox[{"p3", " ", "q3"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726369457979495*^9},ExpressionUUID->"8f2ccf5c-4e91-42d8-a31f-\
929bb2d4bd80"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "verify", " ", "*)"}], 
  RowBox[{"checkPQb", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"vectorFromForm", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], "&"}], 
     ",", " ", 
     RowBox[{"qprod", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"qprod", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"q0", ",", 
           RowBox[{"-", "q1"}], ",", 
           RowBox[{"-", "q2"}], ",", 
           RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.726369592858172*^9, 
  3.726369619180656*^9}},ExpressionUUID->"bacac8d0-38db-4339-a9dc-\
0ea9c41b84d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "+", 
      RowBox[{"p1", " ", "q1"}], "+", 
      RowBox[{"p2", " ", "q2"}], "+", 
      RowBox[{"p3", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p1"}], " ", "q0"}], "+", 
      RowBox[{"p0", " ", "q1"}], "+", 
      RowBox[{"p3", " ", "q2"}], "-", 
      RowBox[{"p2", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p2"}], " ", "q0"}], "-", 
      RowBox[{"p3", " ", "q1"}], "+", 
      RowBox[{"p0", " ", "q2"}], "+", 
      RowBox[{"p1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p3"}], " ", "q0"}], "+", 
      RowBox[{"p2", " ", "q1"}], "-", 
      RowBox[{"p1", " ", "q2"}], "+", 
      RowBox[{"p0", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p1", " ", "q0"}], "-", 
      RowBox[{"p0", " ", "q1"}], "+", 
      RowBox[{"p3", " ", "q2"}], "-", 
      RowBox[{"p2", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "+", 
      RowBox[{"p1", " ", "q1"}], "-", 
      RowBox[{"p2", " ", "q2"}], "-", 
      RowBox[{"p3", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p3"}], " ", "q0"}], "+", 
      RowBox[{"p2", " ", "q1"}], "+", 
      RowBox[{"p1", " ", "q2"}], "-", 
      RowBox[{"p0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p2", " ", "q0"}], "+", 
      RowBox[{"p3", " ", "q1"}], "+", 
      RowBox[{"p0", " ", "q2"}], "+", 
      RowBox[{"p1", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p2", " ", "q0"}], "-", 
      RowBox[{"p3", " ", "q1"}], "-", 
      RowBox[{"p0", " ", "q2"}], "+", 
      RowBox[{"p1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p3", " ", "q0"}], "+", 
      RowBox[{"p2", " ", "q1"}], "+", 
      RowBox[{"p1", " ", "q2"}], "+", 
      RowBox[{"p0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "-", 
      RowBox[{"p1", " ", "q1"}], "+", 
      RowBox[{"p2", " ", "q2"}], "-", 
      RowBox[{"p3", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p1"}], " ", "q0"}], "-", 
      RowBox[{"p0", " ", "q1"}], "+", 
      RowBox[{"p3", " ", "q2"}], "+", 
      RowBox[{"p2", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p3", " ", "q0"}], "+", 
      RowBox[{"p2", " ", "q1"}], "-", 
      RowBox[{"p1", " ", "q2"}], "-", 
      RowBox[{"p0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "p2"}], " ", "q0"}], "+", 
      RowBox[{"p3", " ", "q1"}], "-", 
      RowBox[{"p0", " ", "q2"}], "+", 
      RowBox[{"p1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p1", " ", "q0"}], "+", 
      RowBox[{"p0", " ", "q1"}], "+", 
      RowBox[{"p3", " ", "q2"}], "+", 
      RowBox[{"p2", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"p0", " ", "q0"}], "-", 
      RowBox[{"p1", " ", "q1"}], "-", 
      RowBox[{"p2", " ", "q2"}], "+", 
      RowBox[{"p3", " ", "q3"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.726369517921639*^9, 
  3.726369598242217*^9},ExpressionUUID->"6695b583-5660-4784-88b9-\
a81913957089"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornMwwmatForm", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"matrixFromLRCoeff", "[", 
      RowBox[{"horn4DRMSform", ",", 
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//",
      "Expand"}], ")"}], "/.", "coeffToExx4DRule"}]}]], "Input",
 CellChangeTimes->{{3.726419294542561*^9, 
  3.726419295570943*^9}},ExpressionUUID->"dc810fe9-e5fe-40ad-9977-\
f58c6c3a6ce8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.726419278515913*^9, 
  3.7264192981442633`*^9}},ExpressionUUID->"38eb0bd8-eaa1-4e37-8834-\
0629d6b03c7b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"THIS", " ", "IS", " ", "THE", " ", "GOLD", " ", "STANDARD"}], 
      " ", "-", " ", 
      RowBox[{"SIGNS", " ", "OF", " ", "aw"}]}], " ", "=", " ", 
     RowBox[{"Ewx", "-", "Exw"}]}], ",", " ", ",", " ", 
    RowBox[{"aaw", " ", "=", " ", 
     RowBox[{"Ewx", "+", 
      RowBox[{"Exw", " ", "ARE", " ", "POSITIVE"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"makehornM4mat", "=", " ", 
   RowBox[{"matrixFromLRCoeff", "[", 
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{
       RowBox[{"PQbTo4DRot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], 
       ".", "hornE4mat"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.742081605600173*^9, 3.742081657610359*^9}, {
  3.742081884654695*^9, 3.742081927119203*^9}, {3.742082014798903*^9, 
  3.742082095826495*^9}, {3.7421522564839983`*^9, 
  3.742152384264098*^9}},ExpressionUUID->"e24160d2-6004-4483-91f8-\
65bc490629ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742082097293445*^9, 3.742152276194436*^9, 
  3.7421523077227907`*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"2a1512a2-724f-4b26-a1ba-0358601f5ef9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["hornM4mat"], "Input",
 CellChangeTimes->{{3.742996813662002*^9, 3.742996817671425*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"ae045007-0c2a-4dde-8581-97aef3004af7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742996818432117*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"5f4147db-c1d6-425e-85e8-d78891aad6d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeMwwmat", "[", "hornE4mat", "]"}]], "Input",
 CellChangeTimes->{{3.742996830083314*^9, 3.742996855151477*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"1b5fb84e-84b2-4638-9568-5dfc4b238bae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742996855987585*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"9433fc66-aa68-4884-9fa5-f342ae99ef7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornMwwmatForm", "-", "checkMwwformat"}]], "Input",
 CellChangeTimes->{{3.72634642011237*^9, 
  3.72634642387654*^9}},ExpressionUUID->"b1198c9f-be64-49df-8f05-\
7173f615644b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.726346424584805*^9, 3.7264192152727127`*^9, 
  3.726419304376605*^9},ExpressionUUID->"80ca97e4-d22b-4a2b-8812-\
4e52a2248a6c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornA4mat", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", 
      RowBox[{"a", "-", "aw"}], ",", 
      RowBox[{"b", "-", "bw"}], ",", 
      RowBox[{"c", "-", "cw"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "+", "aw"}], ",", 
      RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", 
      RowBox[{"cc", "-", "ccw"}], ",", 
      RowBox[{"bb", "+", "bbw"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"b", "+", "bw"}], ",", 
      RowBox[{"cc", "+", "ccw"}], ",", 
      RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", 
      RowBox[{"aa", "-", "aaw"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", "+", "cw"}], ",", 
      RowBox[{"bb", "-", "bbw"}], ",", 
      RowBox[{"aa", "+", "aaw"}], ",", 
      RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], 
   "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.72634421412903*^9, 3.72634421563212*^9}, {
  3.7421519981397657`*^9, 3.742152035401194*^9}, {3.742152147393999*^9, 
  3.742152183546547*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"b5698570-6286-4bc0-b694-5a1055bf9ede"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", 
     RowBox[{"a", "-", "aw"}], ",", 
     RowBox[{"b", "-", "bw"}], ",", 
     RowBox[{"c", "-", "cw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "aw"}], ",", 
     RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", 
     RowBox[{"cc", "-", "ccw"}], ",", 
     RowBox[{"bb", "+", "bbw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", "+", "bw"}], ",", 
     RowBox[{"cc", "+", "ccw"}], ",", 
     RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", 
     RowBox[{"aa", "-", "aaw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "+", "cw"}], ",", 
     RowBox[{"bb", "-", "bbw"}], ",", 
     RowBox[{"aa", "+", "aaw"}], ",", 
     RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.726345367293318*^9, 3.7287443182017393`*^9, 3.7290086260756197`*^9, {
   3.742152187835808*^9, 3.7421522085142117`*^9}},
 CellLabel->
  "Out[123]=",ExpressionUUID->"d1b9d1c0-a4af-4a64-a58e-8f2b59ba8546"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornAw2EwwRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "\[Rule]", "Eww"}], ",", 
     RowBox[{"x", "\[Rule]", "Exx"}], ",", 
     RowBox[{"y", "\[Rule]", "Eyy"}], ",", 
     RowBox[{"z", "\[Rule]", "Ezz"}], ",", 
     RowBox[{"a", "\[Rule]", 
      RowBox[{"Eyz", "-", "Ezy"}]}], ",", 
     RowBox[{"b", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Exz"}], "+", "Ezx"}]}], ",", 
     RowBox[{"c", "\[Rule]", 
      RowBox[{"Exy", "-", "Eyx"}]}], ",", 
     RowBox[{"cc", "\[Rule]", 
      RowBox[{"Exy", "+", "Eyx"}]}], ",", 
     RowBox[{"bb", "\[Rule]", 
      RowBox[{"Exz", "+", "Ezx"}]}], ",", 
     RowBox[{"aa", "\[Rule]", 
      RowBox[{"Eyz", "+", "Ezy"}]}], ",", 
     RowBox[{"aw", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Ewx", "-", "Exw"}], ")"}]}], ",", 
     RowBox[{"bw", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Ewy", "-", "Eyw"}], ")"}]}], ",", 
     RowBox[{"cw", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Ewz", "-", "Ezw"}], ")"}]}], ",", 
     RowBox[{"aaw", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Ewx", "+", "Exw"}], ")"}]}], ",", 
     RowBox[{"bbw", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Ewy", "+", "Eyw"}], ")"}]}], ",", 
     RowBox[{"ccw", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Ewz", "+", "Ezw"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aw"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Ewx"}], "+", "Exw"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bw"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Ewy"}], "+", "Eyw"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cw"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Ewz"}], "+", "Ezw"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aaw"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Ewx"}], "-", "Exw"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bbw"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Ewy"}], "-", "Eyw"}]}], ",", 
     RowBox[{
      RowBox[{"-", "ccw"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Ewz"}], "-", "Ezw"}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7263454459984407`*^9, 3.7263454625878363`*^9}, {
  3.726419507011174*^9, 3.7264196344248953`*^9}, {3.74215185808512*^9, 
  3.742151930507331*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"759d0fb9-9fd0-469b-9980-65eab75583a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"hornA4mat", "/.", "hornAw2EwwRule"}], ")"}], "-", 
  "makehornM4mat"}]], "Input",
 CellChangeTimes->{{3.742152226160627*^9, 3.742152240752544*^9}, {
   3.742152283840077*^9, 3.742152283993971*^9}, 3.742152315420207*^9},
 CellLabel->
  "In[127]:=",ExpressionUUID->"e60ab638-7b39-47f4-a1ee-0cdccda6d822"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.742152284640307*^9, 3.742152316086725*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"3f110cf0-9864-4b49-a12e-0775544b9fee"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornEwwAwRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", " ", "\[Rule]", " ", "w"}], ",", 
     RowBox[{"Exx", "\[Rule]", " ", "x"}], " ", ",", 
     RowBox[{"Eyy", " ", "\[Rule]", "y"}], ",", 
     RowBox[{"Ezz", "\[Rule]", "z"}], ",", 
     RowBox[{
      RowBox[{"Eyz", "-", "Ezy"}], "\[Rule]", "a"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Exz"}], "+", "Ezx"}], "\[Rule]", "b"}], ",", 
     RowBox[{
      RowBox[{"Exy", "-", "Eyx"}], "\[Rule]", "c"}], ",", 
     RowBox[{
      RowBox[{"Exy", "+", "Eyx"}], "\[Rule]", "cc"}], ",", 
     RowBox[{
      RowBox[{"Exz", "+", "Ezx"}], "\[Rule]", "bb"}], ",", 
     RowBox[{
      RowBox[{"Eyz", "+", "Ezy"}], "\[Rule]", "aa"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Ewx", "-", "Exw"}], "\[Rule]", "aw"}], ",", 
     RowBox[{
      RowBox[{"Ewy", "-", "Eyw"}], "\[Rule]", "bw"}], " ", ",", 
     RowBox[{
      RowBox[{"Ewz", "-", "Ezw"}], "\[Rule]", "cw"}], " ", ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Ewx", "+", "Exw"}], "\[Rule]", " ", "aaw"}], " ", ",", 
     RowBox[{
      RowBox[{"Ewy", "+", " ", "Eyw"}], "\[Rule]", " ", "bbw"}], ",", 
     RowBox[{
      RowBox[{"Ewz", "+", "Ezw"}], "\[Rule]", " ", "ccw"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewx"}], "+", "Exw"}], "\[Rule]", 
      RowBox[{"-", "aw"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewy"}], "+", "Eyw"}], "\[Rule]", 
      RowBox[{"-", "bw"}]}], " ", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewz"}], "+", "Ezw"}], "\[Rule]", 
      RowBox[{"-", "cw"}]}], " ", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewx"}], "-", "Exw"}], "\[Rule]", 
      RowBox[{"-", " ", "aaw"}]}], " ", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewy"}], "-", " ", "Eyw"}], "\[Rule]", 
      RowBox[{"-", "bbw"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewz"}], "-", "Ezw"}], "\[Rule]", 
      RowBox[{"-", " ", "ccw"}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.716139313568243*^9, 3.716139361073591*^9}, 
   3.7161396811751623`*^9, {3.72109036162605*^9, 3.7210903957615623`*^9}, {
   3.721608385441609*^9, 3.721608385454297*^9}, {3.721747038259066*^9, 
   3.721747210928911*^9}, {3.7217472508194933`*^9, 3.721747275353578*^9}, {
   3.7217473230727158`*^9, 3.7217473237319727`*^9}, {3.7217473667930183`*^9, 
   3.7217474123115*^9}, {3.721747444791284*^9, 3.721747462783*^9}, {
   3.7263454680277777`*^9, 3.726345511524469*^9}, {3.726369708517921*^9, 
   3.726369709133399*^9}, {3.726419442778277*^9, 3.726419468658502*^9}, {
   3.7421517973608932`*^9, 3.742151844348278*^9}},
 CellLabel->
  "In[122]:=",ExpressionUUID->"15bc2aa9-20bc-48dc-bfdb-e1dc151c8c35"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makehornM4mat", "/.", "hornEwwAwRule"}], "/.", "hornEwwAwRule"}], 
  "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.742152427318388*^9, 3.742152448869957*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"0389ef8b-ea72-4095-b9dc-fc83ec58da77"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"w", "+", "x", "+", "y", "+", "z"}], 
      RowBox[{"a", "-", "aw"}], 
      RowBox[{"b", "-", "bw"}], 
      RowBox[{"c", "-", "cw"}]},
     {
      RowBox[{"a", "+", "aw"}], 
      RowBox[{"w", "+", "x", "-", "y", "-", "z"}], 
      RowBox[{"cc", "-", "ccw"}], 
      RowBox[{"bb", "+", "bbw"}]},
     {
      RowBox[{"b", "+", "bw"}], 
      RowBox[{"cc", "+", "ccw"}], 
      RowBox[{"w", "-", "x", "+", "y", "-", "z"}], 
      RowBox[{"aa", "-", "aaw"}]},
     {
      RowBox[{"c", "+", "cw"}], 
      RowBox[{"bb", "-", "bbw"}], 
      RowBox[{"aa", "+", "aaw"}], 
      RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.742152433914835*^9, 3.742152449701666*^9}},
 CellLabel->
  "Out[130]//MatrixForm=",ExpressionUUID->"b1efd0dd-6f52-4f6f-9f2f-\
a6dd24876a39"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "-", "hornA4mat"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.742152483630075*^9, 3.7421524883471403`*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"dd54f50e-e9e7-4a4e-bd72-6a9eb8330b95"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.742152488995963*^9},
 CellLabel->
  "Out[131]//MatrixForm=",ExpressionUUID->"be2244d1-a066-4a16-b6b0-\
8857875c633e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pn4NumRule", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "4"}], " ", "w"}]}], ",", 
     RowBox[{"p2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "-", 
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox["aaw", "2"], "+", 
       SuperscriptBox["aw", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox["bbw", "2"], "+", 
       SuperscriptBox["bw", "2"], "-", 
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox["ccw", "2"], "+", 
       SuperscriptBox["cw", "2"], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["w", "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}]}]}]}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"aw", " ", "bbw", " ", "c"}], "-", 
         RowBox[{"aaw", " ", "bw", " ", "c"}], "-", 
         RowBox[{"aaw", " ", "bbw", " ", "cc"}], "+", 
         RowBox[{"aw", " ", "bw", " ", "cc"}], "-", 
         RowBox[{"aw", " ", "b", " ", "ccw"}], "-", 
         RowBox[{"aaw", " ", "bb", " ", "ccw"}], "+", 
         RowBox[{"aaw", " ", "b", " ", "cw"}], "+", 
         RowBox[{"aw", " ", "bb", " ", "cw"}], "-", 
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"bb", " ", "c"}], "+", 
            RowBox[{"b", " ", "cc"}], "-", 
            RowBox[{"bw", " ", "ccw"}], "+", 
            RowBox[{"bbw", " ", "cw"}]}], ")"}]}], "-", 
         RowBox[{"aa", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", " ", "c"}], "+", 
            RowBox[{"bb", " ", "cc"}], "+", 
            RowBox[{"bbw", " ", "ccw"}], "-", 
            RowBox[{"bw", " ", "cw"}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["aaw", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["aw", "2"], " ", "w"}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "w"}], "+", 
         RowBox[{
          SuperscriptBox["bb", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["bbw", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["bw", "2"], " ", "w"}], "+", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", "w"}], "+", 
         RowBox[{
          SuperscriptBox["cc", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["ccw", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["cw", "2"], " ", "w"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["w", "3"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"w", "-", "x"}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["aaw", "2"], " ", "x"}], "+", 
         RowBox[{
          SuperscriptBox["aw", "2"], " ", "x"}], "+", 
         RowBox[{"2", " ", "w", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["aa", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"w", "+", "x"}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "y"}], "+", 
         RowBox[{
          SuperscriptBox["bb", "2"], " ", "y"}], "-", 
         RowBox[{
          SuperscriptBox["bbw", "2"], " ", "y"}], "+", 
         RowBox[{
          SuperscriptBox["bw", "2"], " ", "y"}], "+", 
         RowBox[{"2", " ", "w", " ", 
          SuperscriptBox["y", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["cc", "2"], "-", 
            SuperscriptBox["ccw", "2"], "+", 
            SuperscriptBox["cw", "2"], "-", 
            RowBox[{"4", " ", "x", " ", "y"}]}], ")"}], " ", "z"}], "+", 
         RowBox[{"2", " ", "w", " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}]}], ",", 
     RowBox[{"p4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"c", "-", "cw"}], ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"cc", "-", "ccw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"bb", "-", "bbw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"b", "+", "bw"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"cc", "+", "ccw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"c", "+", "cw"}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"aa", "+", "aaw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"a", "+", "aw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"cc", "+", "ccw"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"b", "+", "bw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ")"}]}]}], 
            ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"a", "+", "aw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"bb", "-", "bbw"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"c", "+", "cw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
       "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"aa", "-", "aaw"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "bw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"a", "+", "aw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"bb", "-", "bbw"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"c", "+", "cw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ")"}]}]}], 
            ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"aa", "+", "aaw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["aw", "2"], "+", 
             SuperscriptBox["w", "2"], "+", 
             RowBox[{"2", " ", "w", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "-", 
             SuperscriptBox["y", "2"], "-", 
             RowBox[{"2", " ", "y", " ", "z"}], "-", 
             SuperscriptBox["z", "2"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"cc", "-", "ccw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", 
              RowBox[{"(", 
               RowBox[{"c", "+", "cw"}], ")"}]}], "+", 
             RowBox[{"aw", " ", 
              RowBox[{"(", 
               RowBox[{"c", "+", "cw"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"bb", "-", "bbw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"bb", "+", "bbw"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "bw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"bb", "-", "bbw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"b", "+", "bw"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"cc", "+", "ccw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"c", "+", "cw"}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", 
              RowBox[{"(", 
               RowBox[{"c", "+", "cw"}], ")"}]}], "+", 
             RowBox[{"aw", " ", 
              RowBox[{"(", 
               RowBox[{"c", "+", "cw"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"bb", "-", "bbw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ")"}]}]}], 
            ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"aa", "+", "aaw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", 
              RowBox[{"(", 
               RowBox[{"b", "+", "bw"}], ")"}]}], "+", 
             RowBox[{"aw", " ", 
              RowBox[{"(", 
               RowBox[{"b", "+", "bw"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"cc", "+", "ccw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"w", "-", "x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "bw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"a", "+", "aw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"cc", "+", "ccw"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"b", "+", "bw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ")"}]}]}], 
            ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["aw", "2"], "+", 
             SuperscriptBox["w", "2"], "+", 
             RowBox[{"2", " ", "w", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "-", 
             SuperscriptBox["y", "2"], "-", 
             RowBox[{"2", " ", "y", " ", "z"}], "-", 
             SuperscriptBox["z", "2"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"cc", "-", "ccw"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", 
              RowBox[{"(", 
               RowBox[{"b", "+", "bw"}], ")"}]}], "+", 
             RowBox[{"aw", " ", 
              RowBox[{"(", 
               RowBox[{"b", "+", "bw"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"cc", "+", "ccw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7289481420997877`*^9, 3.7289481461004543`*^9}, 
   3.7289482395706873`*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"df46155b-30ca-493e-83e2-0a96511e48d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"wxyz2EwwRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "\[Rule]", "Eww"}], ",", 
     RowBox[{"x", "\[Rule]", "Exx"}], ",", 
     RowBox[{"y", "\[Rule]", "Eyy"}], ",", 
     RowBox[{"z", "\[Rule]", "Ezz"}], ",", 
     RowBox[{"a", "\[Rule]", 
      RowBox[{"Eyz", "-", "Ezy"}]}], ",", 
     RowBox[{"aw", "\[Rule]", 
      RowBox[{"Ewx", "-", "Exw"}]}], ",", 
     RowBox[{"b", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "Exz"}], "+", "Ezx"}]}], ",", 
     RowBox[{"bw", "\[Rule]", 
      RowBox[{"Ewy", "-", "Eyw"}]}], ",", 
     RowBox[{"c", "\[Rule]", 
      RowBox[{"Exy", "-", "Eyx"}]}], ",", 
     RowBox[{"cw", "\[Rule]", 
      RowBox[{"Ewz", "-", "Ezw"}]}], ",", 
     RowBox[{"aa", "\[Rule]", 
      RowBox[{"Eyz", "+", "Ezy"}]}], ",", 
     RowBox[{"aaw", "\[Rule]", 
      RowBox[{"Ewx", "+", "Exw"}]}], ",", 
     RowBox[{"bb", "\[Rule]", 
      RowBox[{"Exz", "+", "Ezx"}]}], ",", 
     RowBox[{"bbw", "\[Rule]", 
      RowBox[{"Ewy", "+", "Eyw"}]}], ",", 
     RowBox[{"cc", "\[Rule]", 
      RowBox[{"Exy", "+", "Eyx"}]}], ",", 
     RowBox[{"ccw", "\[Rule]", 
      RowBox[{"Ewz", "+", "Ezw"}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.728948204251606*^9, 3.728948206203074*^9}, 
   3.728948243938678*^9},ExpressionUUID->"79650e84-bc82-439f-90f7-\
df98f9ba0e9a"],

Cell[BoxData[
 RowBox[{"pn4toEwwRule", " ", "=", 
  RowBox[{
   RowBox[{"pn4NumRule", "/.", "wxyz2EwwRule"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7289479271607943`*^9, 
  3.728947973292632*^9}},ExpressionUUID->"6f442079-cc87-4eb3-8b1f-\
9dc43a927429"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pn4toEwwRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "4"}], " ", "Eww"}]}], ",", 
     RowBox[{"p2", "\[Rule]", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["Eww", "2"]}], "+", 
         SuperscriptBox["Ewx", "2"], "+", 
         SuperscriptBox["Ewy", "2"], "+", 
         SuperscriptBox["Ewz", "2"], "+", 
         SuperscriptBox["Exw", "2"], "-", 
         SuperscriptBox["Exx", "2"], "-", 
         SuperscriptBox["Exy", "2"], "-", 
         SuperscriptBox["Exz", "2"], "+", 
         SuperscriptBox["Eyw", "2"], "-", 
         SuperscriptBox["Eyx", "2"], "-", 
         SuperscriptBox["Eyy", "2"], "-", 
         SuperscriptBox["Eyz", "2"], "+", 
         SuperscriptBox["Ezw", "2"], "-", 
         SuperscriptBox["Ezx", "2"], "-", 
         SuperscriptBox["Ezy", "2"], "-", 
         SuperscriptBox["Ezz", "2"]}], ")"}]}]}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Eww", "3"], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Ewy", " ", "Exw", " ", "Exy"}], "+", 
            RowBox[{"Ewz", " ", "Exw", " ", "Exz"}], "+", 
            RowBox[{"Ewy", " ", "Eyw", " ", "Eyy"}], "+", 
            RowBox[{"Ewz", " ", "Eyw", " ", "Eyz"}], "-", 
            RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "+", 
            RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "+", 
            RowBox[{"Ewx", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Exw", " ", "Exx"}], "+", 
               RowBox[{"Eyw", " ", "Eyx"}], "+", 
               RowBox[{"Ezw", " ", "Ezx"}]}], ")"}]}], "+", 
            RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "-", 
            RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "+", 
            RowBox[{"Ewy", " ", "Ezw", " ", "Ezy"}], "-", 
            RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "+", 
            RowBox[{"Exx", " ", "Eyy", " ", "Ezz"}], "+", 
            RowBox[{"Ewz", " ", "Ezw", " ", "Ezz"}]}], ")"}]}], "+", 
         RowBox[{"Eww", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["Ewx", "2"], "+", 
            SuperscriptBox["Ewy", "2"], "+", 
            SuperscriptBox["Ewz", "2"], "+", 
            SuperscriptBox["Exw", "2"], "-", 
            SuperscriptBox["Exx", "2"], "-", 
            SuperscriptBox["Exy", "2"], "-", 
            SuperscriptBox["Exz", "2"], "+", 
            SuperscriptBox["Eyw", "2"], "-", 
            SuperscriptBox["Eyx", "2"], "-", 
            SuperscriptBox["Eyy", "2"], "-", 
            SuperscriptBox["Eyz", "2"], "+", 
            SuperscriptBox["Ezw", "2"], "-", 
            SuperscriptBox["Ezx", "2"], "-", 
            SuperscriptBox["Ezy", "2"], "-", 
            SuperscriptBox["Ezz", "2"]}], ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{"p4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}], 
          ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ")"}]}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ")"}]}], 
             "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ")"}]}]}],
             ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ")"}]}]}],
             ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ")"}]}]}],
             ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["Eww", "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw"}], ")"}], "2"], "+", 
             RowBox[{"2", " ", "Eww", " ", "Exx"}], "+", 
             SuperscriptBox["Exx", "2"], "-", 
             SuperscriptBox["Eyy", "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"Eyz", "-", "Ezy"}], ")"}], "2"], "-", 
             RowBox[{"2", " ", "Eyy", " ", "Ezz"}], "-", 
             SuperscriptBox["Ezz", "2"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eyz", "-", "Ezy"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}]}],
             ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ")"}]}]}],
             ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["Eww", "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw"}], ")"}], "2"], "+", 
             RowBox[{"2", " ", "Eww", " ", "Exx"}], "+", 
             SuperscriptBox["Exx", "2"], "-", 
             SuperscriptBox["Eyy", "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"Eyz", "-", "Ezy"}], ")"}], "2"], "-", 
             RowBox[{"2", " ", "Eyy", " ", "Ezz"}], "-", 
             SuperscriptBox["Ezz", "2"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eyz", "-", "Ezy"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}]}],
             ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ")"}]}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ")"}]}], 
             "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eyz", "-", "Ezy"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}]}],
             ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewx", "-", "Exw"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ")"}]}], 
             "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"Eyz", "-", "Ezy"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}]}],
             ")"}]}]}], ")"}]}]}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.728948084342079*^9, 3.728948097298633*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"4181d2bc-0b45-466a-acfc-e795789b7146"],

Cell[CellGroupData[{

Cell["Someplace below, we need to define the datasets for Eww...", \
"Subsubsection",
 CellChangeTimes->{{3.72636985509809*^9, 
  3.7263698808733377`*^9}},ExpressionUUID->"9ccd6b29-dcb5-42dd-936d-\
0d981ddd549e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"horn4DRMSform", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"PQbTo4DRot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], 
       ".", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "x1", ",", "x2", ",", "x3"}], "}"}]}], ")"}], ".", 
     
     RowBox[{"{", 
      RowBox[{"y0", ",", "y1", ",", "y2", ",", "y3"}], "}"}]}], "//", 
    "Expand"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.720236563761919*^9, 3.72023659853258*^9}, {
   3.7202370319437113`*^9, 3.720237096865796*^9}, {3.720238458214272*^9, 
   3.720238474446063*^9}, {3.72023855101127*^9, 3.7202385682518873`*^9}, {
   3.720238957029044*^9, 3.720238959035647*^9}, {3.721608385511001*^9, 
   3.7216083855144053`*^9}, {3.721697895418688*^9, 3.721697900354113*^9}, {
   3.721697943934907*^9, 3.721697960542657*^9}, 3.726345676193026*^9, 
   3.726346763449356*^9, {3.726419014957756*^9, 
   3.726419015869196*^9}},ExpressionUUID->"edaef0f3-8907-434a-8248-\
96133c179dd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Order", " ", "of", " ", "Eab", " ", "is", " ", "xa"}], ",", 
    "yb"}], "*)"}], "\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{"coeffToExx4DRule", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"x0", " ", "y0"}], "\[Rule]", "Eww"}], ",", 
      RowBox[{
       RowBox[{"x1", " ", "y1"}], "\[Rule]", "Exx"}], ",", " ", 
      RowBox[{
       RowBox[{"x2", " ", "y2"}], "\[Rule]", "Eyy"}], ",", " ", 
      RowBox[{
       RowBox[{"x3", " ", "y3"}], "\[Rule]", "Ezz"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x3", " ", "y2"}], "\[Rule]", " ", "Ezy"}], ",", 
      RowBox[{
       RowBox[{"x2", " ", "y3"}], "->", " ", "Eyz"}], ",", " ", 
      RowBox[{
       RowBox[{"x3", " ", "y1"}], "\[Rule]", " ", "Ezx"}], ",", " ", 
      RowBox[{
       RowBox[{"x1", " ", "y3"}], "\[Rule]", " ", "Exz"}], ",", 
      RowBox[{
       RowBox[{"x2", " ", "y1"}], "\[Rule]", "Eyx"}], ",", 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"x1", " ", "y2"}], "\[Rule]", " ", "Exy"}], ",", 
      RowBox[{
       RowBox[{"x0", " ", "y1"}], "\[Rule]", "Ewx"}], ",", 
      RowBox[{
       RowBox[{"x1", " ", "y0"}], "\[Rule]", "Exw"}], ",", 
      RowBox[{
       RowBox[{"x0", " ", "y2"}], "\[Rule]", "Ewy"}], ",", 
      RowBox[{
       RowBox[{"x2", " ", "y0"}], "\[Rule]", "Eyw"}], ",", 
      RowBox[{
       RowBox[{"x0", " ", "y3"}], "\[Rule]", "Ewz"}], ",", 
      RowBox[{
       RowBox[{"x3", " ", "y0"}], "\[Rule]", "Ezw"}]}], "}"}]}], 
   ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.720237146580874*^9, 3.7202372365674963`*^9}, {
   3.7202372865539494`*^9, 3.720237372965621*^9}, {3.720237404007352*^9, 
   3.720237483249465*^9}, 3.720237559287985*^9, 3.720238585066986*^9, {
   3.7202389732463818`*^9, 3.720238994133312*^9}, {3.720239024408929*^9, 
   3.72023929546856*^9}, 3.720239500437771*^9, {3.7202395519425287`*^9, 
   3.720239552654134*^9}, {3.721608385618794*^9, 3.7216083856518707`*^9}, {
   3.726345574545291*^9, 3.726345589994073*^9}, 3.726345630361601*^9, {
   3.7263468136945353`*^9, 3.726346830197604*^9}, 
   3.726418152366153*^9},ExpressionUUID->"0aa810af-2ebc-4dca-883f-\
fc3590d2ca2a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"checkMwwformat", " ", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"matrixFromLRCoeff", "[", 
      RowBox[{"horn4DRMSform", ",", 
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//",
      "Expand"}], ")"}], "/.", "coeffToExx4DRule"}]}]], "Input",
 CellChangeTimes->{{3.720237106523018*^9, 3.720237123850226*^9}, 
   3.72023859989977*^9, 3.720238912768073*^9, {3.720239363271274*^9, 
   3.720239395615044*^9}, 3.720239435571534*^9, {3.7263456577525997`*^9, 
   3.726345670024876*^9}, {3.726345706610222*^9, 3.726345713968339*^9}, {
   3.726346877008391*^9, 
   3.726346886388445*^9}},ExpressionUUID->"ad2b0aa1-a5c3-4a4d-86e6-\
a4a968debe0f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.726418905616267*^9},ExpressionUUID->"022f3dae-c0c8-4aaa-b310-\
4d3d0d389ae6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Right", " ", "*)"}], "  ", 
  RowBox[{"hornA4mat", "/.", "hornAw2EwwRule"}]}]], "Input",
 CellChangeTimes->{{3.726419657383514*^9, 3.726419663152999*^9}, {
  3.726419710415011*^9, 
  3.7264197144227753`*^9}},ExpressionUUID->"edd84f1c-8f71-4c90-9654-\
551d4bf7fc15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7264196659602213`*^9},ExpressionUUID->"c243069e-bcd3-41ed-a908-\
51d5ce25222d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", " ", "-", " ", "checkMwwformat"}], "//", "Simplify"}]], "Input",\

 CellChangeTimes->{{3.7264196714993362`*^9, 
  3.7264196807984056`*^9}},ExpressionUUID->"f2763c62-833c-4eb5-9c3b-\
9c7d3a46ce04"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.72641968115377*^9},ExpressionUUID->"9672ec8d-4077-4840-9649-06e6659e9f29"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "Wrong", " ", "*)"}], "  ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
      RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
      RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
      RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
      RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
      RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
      RowBox[{
       RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
      RowBox[{
       RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
      RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
      RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}], ",", 
      RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
      RowBox[{
       RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
      RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.726418900885166*^9, 3.726418900890052*^9}, {
  3.726418938013529*^9, 
  3.726418945205229*^9}},ExpressionUUID->"849e37af-2f5f-4c35-8341-\
57f85ce4937e"],

Cell[CellGroupData[{

Cell[BoxData["hornA4mat"], "Input",ExpressionUUID->"4da2ee8a-753f-4f7b-8d33-d088824c55cd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", 
     RowBox[{"a", "+", "aw"}], ",", 
     RowBox[{"b", "+", "bw"}], ",", 
     RowBox[{"c", "+", "cw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", "aw"}], ",", 
     RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", 
     RowBox[{"cc", "+", "ccw"}], ",", 
     RowBox[{"bb", "-", "bbw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", "-", "bw"}], ",", 
     RowBox[{"cc", "-", "ccw"}], ",", 
     RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", 
     RowBox[{"aa", "+", "aaw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "-", "cw"}], ",", 
     RowBox[{"bb", "+", "bbw"}], ",", 
     RowBox[{"aa", "-", "aaw"}], ",", 
     RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.726419117495335*^9},ExpressionUUID->"1d01a2c7-b4ec-4a84-bf21-\
aad49d4314aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Is", " ", "substitution", " ", "right", " ", "or", " ", "wrong"}],
    " ", "*)"}], " ", 
  RowBox[{"hornA4mat", "/.", "hornAw2EwwRule"}]}]], "Input",
 CellChangeTimes->{{3.726419075656171*^9, 
  3.726419109854252*^9}},ExpressionUUID->"1e90a5b9-04f4-4568-9f19-\
55971eb8fd70"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.72641907979946*^9, 
  3.7264191120903063`*^9},ExpressionUUID->"75f5774d-0734-48fb-bb84-\
89dea81931bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"checkMwwformat", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "\[Rule]", "0"}], ",", 
     RowBox[{"Ewx", "\[Rule]", "0"}], ",", 
     RowBox[{"Exw", "\[Rule]", "0"}], ",", 
     RowBox[{"Ewy", "\[Rule]", " ", "0"}], ",", 
     RowBox[{"Eyw", "\[Rule]", "0"}], ",", 
     RowBox[{"Ewz", "\[Rule]", "0"}], ",", 
     RowBox[{"Ezw", "\[Rule]", "0"}]}], "}"}]}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.7263464966809483`*^9, 
  3.726346549622909*^9}},ExpressionUUID->"955979ab-1beb-434f-9978-\
48c09df80fe5"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], 
      RowBox[{"Eyz", "-", "Ezy"}], 
      RowBox[{
       RowBox[{"-", "Exz"}], "+", "Ezx"}], 
      RowBox[{"Exy", "-", "Eyx"}]},
     {
      RowBox[{"Eyz", "-", "Ezy"}], 
      RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], 
      RowBox[{"Exy", "+", "Eyx"}], 
      RowBox[{"Exz", "+", "Ezx"}]},
     {
      RowBox[{
       RowBox[{"-", "Exz"}], "+", "Ezx"}], 
      RowBox[{"Exy", "+", "Eyx"}], 
      RowBox[{
       RowBox[{"-", "Exx"}], "+", "Eyy", "-", "Ezz"}], 
      RowBox[{"Eyz", "+", "Ezy"}]},
     {
      RowBox[{"Exy", "-", "Eyx"}], 
      RowBox[{"Exz", "+", "Ezx"}], 
      RowBox[{"Eyz", "+", "Ezy"}], 
      RowBox[{
       RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.726347035050641*^9, 
  3.726418954968555*^9},ExpressionUUID->"f9915e73-0aca-49d1-9e4e-\
1dfa207cefae"]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], 
       RowBox[{"Eyz", "-", "Ezy"}], 
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], 
       RowBox[{"Exy", "-", "Eyx"}]},
      {
       RowBox[{"Eyz", "-", "Ezy"}], 
       RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], 
       RowBox[{"Exy", "+", "Eyx"}], 
       RowBox[{"Exz", "+", "Ezx"}]},
      {
       RowBox[{
        RowBox[{"-", "Exz"}], "+", "Ezx"}], 
       RowBox[{"Exy", "+", "Eyx"}], 
       RowBox[{
        RowBox[{"-", "Exx"}], "+", "Eyy", "-", "Ezz"}], 
       RowBox[{"Eyz", "+", "Ezy"}]},
      {
       RowBox[{"Exy", "-", "Eyx"}], 
       RowBox[{"Exz", "+", "Ezx"}], 
       RowBox[{"Eyz", "+", "Ezy"}], 
       RowBox[{
        RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Input",
 CellChangeTimes->{{3.726347031009836*^9, 
  3.7263470310183496`*^9}},ExpressionUUID->"e40922a1-f408-425f-b2f5-\
7fdcdc935835"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"TeXForm", " ", "utility", " ", "template"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"StringReplace", "[", 
   RowBox[{
    RowBox[{"ToString", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"p3", "/.", "the4DPRule"}], "//", "Expand"}], "//", 
      "TeXForm"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<\\\\text{aa}\>\"", "\[Rule]", " ", "\"\<A\>\""}], ",", 
      RowBox[{"\"\<\\\\text{bb}\>\"", "\[Rule]", " ", "\"\<B\>\""}], ",", 
      RowBox[{"\"\<\\\\text{cc}\>\"", "\[Rule]", " ", "\"\<C\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<\\\\text{aaw}\>\"", "\[Rule]", " ", "\"\<A_w\>\""}], ",", 
      RowBox[{"\"\<\\\\text{bbw}\>\"", "\[Rule]", " ", "\"\<B_w\>\""}], ",", 
      RowBox[{"\"\<\\\\text{ccw}\>\"", "\[Rule]", " ", "\"\<C_w\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<\\\\text{aw}\>\"", "\[Rule]", " ", "\"\<a_w\>\""}], ",", 
      RowBox[{"\"\<\\\\text{bw}\>\"", "\[Rule]", " ", "\"\<b_w\>\""}], ",", 
      RowBox[{"\"\<\\\\text{cw}\>\"", "\[Rule]", " ", "\"\<c_w\>\""}]}], 
     "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.722127758015676*^9, 3.722127793956093*^9}, {
  3.722127860339203*^9, 3.7221279707394943`*^9}, {3.7263442891197863`*^9, 
  3.726344309255432*^9}},ExpressionUUID->"27e01e39-f8fd-413c-bbd0-\
5afd3f4d7934"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Base expressions: coefficients of powers of \
lambda, in ee1...ee4 coords and in  xyz:abc:aabbcc coords.",
 FontWeight->"Bold"]], "Subsection",
 InitializationCell->True,
 CellChangeTimes->{{3.716571747674493*^9, 3.7165717634583597`*^9}, {
  3.716572544004992*^9, 
  3.716572589949443*^9}},ExpressionUUID->"88adb178-7a73-428f-9286-\
ca9685485261"],

Cell[BoxData[
 RowBox[{
  RowBox[{"formTr0", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", "+", "y", "+", "z"}], ")"}], ",", 
    RowBox[{"(", 
     RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], " ", 
   "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.716383682024107*^9, 3.716383720980792*^9}, {
  3.716383794059269*^9, 
  3.716383817828455*^9}},ExpressionUUID->"b582bad8-0497-4761-9ee7-\
5e19d819b721"],

Cell[BoxData[
 RowBox[{
  RowBox[{"formQuad", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], " ", ":=", " ", 
  RowBox[{
   SuperscriptBox["x", "2"], "+", 
   SuperscriptBox["y", "2"], "+", 
   SuperscriptBox["z", "2"], "-", 
   RowBox[{"2", " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", "x", " ", "z"}], "-", 
   RowBox[{"2", " ", "y", " ", "z"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.716383682024107*^9, 3.716383720980792*^9}, {
  3.716383794059269*^9, 3.716383817828455*^9}, {3.716383876219798*^9, 
  3.716383882202726*^9}, {3.716383925493492*^9, 
  3.716383946277323*^9}},ExpressionUUID->"7da6d278-41c5-4d0c-99ea-\
62913c932084"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Powers", " ", "of", " ", "eigenvalues", " ", "in", " ", "Lambda", " ", 
    "factorization"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqGenEig", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ee1", " ", "ee2", " ", "ee3", " ", "ee4"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee1"}], " ", "ee2", " ", "ee3"}], "-", 
       RowBox[{"ee1", " ", "ee2", " ", "ee4"}], "-", 
       RowBox[{"ee1", " ", "ee3", " ", "ee4"}], "-", 
       RowBox[{"ee2", " ", "ee3", " ", "ee4"}]}], ",", 
      RowBox[{
       RowBox[{"ee1", " ", "ee2"}], "+", 
       RowBox[{"ee1", " ", "ee3"}], "+", 
       RowBox[{"ee2", " ", "ee3"}], "+", 
       RowBox[{"ee1", " ", "ee4"}], "+", 
       RowBox[{"ee2", " ", "ee4"}], "+", 
       RowBox[{"ee3", " ", "ee4"}]}], ",", 
      RowBox[{
       RowBox[{"-", "ee1"}], "-", "ee2", "-", "ee3", "-", "ee4"}], ",", "1"}],
      "}"}]}], ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.716572118244183*^9, 3.716572181243928*^9}, 
   3.71676984570403*^9},ExpressionUUID->"8aa9c222-633b-4fd4-a948-\
428c5d700713"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeEigSub", "[", 
   RowBox[{"{", 
    RowBox[{"e1_", ",", "e2_", ",", "e3_", ",", "e4_"}], "}"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ee1", "\[Rule]", "e1"}], ",", 
    RowBox[{"ee2", "\[Rule]", "e2"}], ",", 
    RowBox[{"ee3", "\[Rule]", "e3"}], ",", 
    RowBox[{"ee4", "\[Rule]", "e4"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.716429236979011*^9, 
  3.7164293124880037`*^9}},ExpressionUUID->"126d0b7e-e015-4a29-b3c4-\
6cf34ae72c2c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Det", "[", 
      RowBox[{"hornAmat", " ", "-", " ", 
       RowBox[{"l", " ", 
        RowBox[{"IdentityMatrix", "[", "4", "]"}]}]}], "]"}], ",", "l"}], 
    "]"}], " ", "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.718814272896673*^9, 3.7188143591834173`*^9}, {
  3.718814419344904*^9, 
  3.718814436807276*^9}},ExpressionUUID->"39141cf5-9079-4f9f-b7b1-\
80a485d9bd70"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["cc", "2"]}], "+", 
    RowBox[{"2", " ", "aa", " ", "bb", " ", "cc", " ", "x"}], "-", 
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["cc", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    SuperscriptBox["x", "4"], "+", 
    RowBox[{"2", " ", "aa", " ", "bb", " ", "cc", " ", "y"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["c", "2"], " ", "x", " ", "y"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["cc", "2"], " ", "x", " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["cc", "2"], " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["y", "4"], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["aa", "2"], "-", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "z"}], ")"}], "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", "aa", " ", "bb", " ", "cc", " ", "z"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["bb", "2"], " ", "x", " ", "z"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["aa", "2"], " ", "y", " ", "z"}], "+", 
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["cc", "2"], " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    SuperscriptBox["z", "4"], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "z"}], "+", 
       SuperscriptBox["z", "2"]}], ")"}]}], "-", 
    RowBox[{"2", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", "bb"}], "+", 
          RowBox[{"c", " ", "cc"}]}], ")"}]}], "+", 
       RowBox[{"b", " ", "cc", " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
       RowBox[{"bb", " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "b", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bb", " ", "cc"}], "+", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"aa", " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", "bb", " ", "c"}], "+", 
      RowBox[{"a", " ", "b", " ", "cc"}], "+", 
      RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["aa", "2"], " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "y"}], "-", 
      RowBox[{
       SuperscriptBox["bb", "2"], " ", "y"}], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", "z"}], "-", 
      RowBox[{
       SuperscriptBox["cc", "2"], " ", "z"}], "+", 
      RowBox[{"4", " ", "x", " ", "y", " ", "z"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "-", 
    SuperscriptBox["aa", "2"], "-", 
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["bb", "2"], "-", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox["cc", "2"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["z", "2"]}]}], ",", "0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{{3.7188143366892347`*^9, 3.7188143597377567`*^9}, {
  3.718814425433641*^9, 
  3.718814439809113*^9}},ExpressionUUID->"c4406b77-dbc4-4efe-bd55-\
2267410d5f24"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqHorn", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["cc", "2"]}], "+", 
      RowBox[{"2", " ", "aa", " ", "bb", " ", "cc", " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["aa", "2"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["bb", "2"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["cc", "2"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      SuperscriptBox["x", "4"], "+", 
      RowBox[{"2", " ", "aa", " ", "bb", " ", "cc", " ", "y"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", "x", " ", "y"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["cc", "2"], " ", "x", " ", "y"}], "+", 
      RowBox[{
       SuperscriptBox["aa", "2"], " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["bb", "2"], " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["cc", "2"], " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "2"]}], "+", 
      SuperscriptBox["y", "4"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
         RowBox[{
          SuperscriptBox["bb", "2"], " ", "x"}], "+", 
         RowBox[{
          SuperscriptBox["aa", "2"], " ", "y"}]}], ")"}], " ", "z"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["aa", "2"], "+", 
         SuperscriptBox["bb", "2"], "-", 
         SuperscriptBox["c", "2"], "-", 
         SuperscriptBox["cc", "2"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox["z", "2"]}], "+", 
      SuperscriptBox["z", "4"], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["bb", "2"], "+", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"], "-", 
         RowBox[{"2", " ", "x", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"aa", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", " ", "bb"}], "+", 
            RowBox[{"c", " ", "cc"}]}], ")"}]}], "+", 
         RowBox[{"b", " ", "cc", " ", 
          RowBox[{"(", 
           RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
         RowBox[{"bb", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{"x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["aa", "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", "b", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"bb", " ", "cc"}], "+", 
         RowBox[{"aa", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", "bb", " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "cc"}], "+", 
        RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "x"}], "-", 
        RowBox[{
         SuperscriptBox["aa", "2"], " ", "x"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "y"}], "-", 
        RowBox[{
         SuperscriptBox["bb", "2"], " ", "y"}], "+", 
        RowBox[{
         SuperscriptBox["c", "2"], " ", "z"}], "-", 
        RowBox[{
         SuperscriptBox["cc", "2"], " ", "z"}], "+", 
        RowBox[{"4", " ", "x", " ", "y", " ", "z"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "-", 
      SuperscriptBox["aa", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["bb", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["cc", "2"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]}], ",", "0", ",", "1"}], "}"}]}],
   ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7165869097539473`*^9, 3.7165869112108107`*^9}, 
   3.716769841347653*^9, 
   3.718814510046896*^9},ExpressionUUID->"9cdeb71c-2f16-4091-98d4-\
994142cdad7c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subForee", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ee1", "\[Rule]", 
     RowBox[{"xE", "+", "yE", "+", "zE"}]}], ",", 
    RowBox[{"ee2", "\[Rule]", 
     RowBox[{"xE", "-", "yE", "-", "zE"}]}], ",", 
    RowBox[{"ee3", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}]}], ",", 
    RowBox[{"ee4", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718565670550342*^9, 3.718565696654541*^9}, 
   3.718813863955921*^9},ExpressionUUID->"61fa5ba0-dc17-4cff-9044-\
ee36881a5968"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ee1", "\[Rule]", 
    RowBox[{"xE", "+", "yE", "+", "zE"}]}], ",", 
   RowBox[{"ee2", "\[Rule]", 
    RowBox[{"xE", "-", "yE", "-", "zE"}]}], ",", 
   RowBox[{"ee3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}]}], ",", 
   RowBox[{"ee4", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}]}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.718813864726913*^9, 3.718814028232498*^9, 
  3.718992137439515*^9, 3.719106106342675*^9, 3.7192499423412323`*^9, 
  3.719280081155201*^9, 3.719332657222404*^9, 3.7193496000627327`*^9, 
  3.719423516222287*^9, 3.719673117033415*^9, 3.71970314289358*^9, 
  3.719872974677856*^9, 3.719944671698882*^9, 3.725127498395876*^9, 
  3.725482051301832*^9, 3.725483983402158*^9, 3.7262567626220217`*^9, 
  3.729008626190793*^9},ExpressionUUID->"fdcf34b4-d4c8-41f5-bd85-\
2d4749b7cad8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subForxx", " ", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ee1", "\[Rule]", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], ",", 
     RowBox[{"ee2", "->", " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], ",", 
     RowBox[{"ee3", "\[Rule]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}], ",", 
     RowBox[{"ee4", "\[Rule]", "  ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}]}], "   ", "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"Sqrt", "[", "xx", "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"Sqrt", "[", "yy", "]"}]}], ",", 
     RowBox[{"z", "\[Rule]", 
      RowBox[{"Sqrt", "[", "zz", "]"}]}]}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.717087890096558*^9, 3.717087943500222*^9}, {
  3.71708799552514*^9, 3.717088090355217*^9}, {3.717088625865206*^9, 
  3.717088632101878*^9}, {3.718813828860877*^9, 
  3.718813847611825*^9}},ExpressionUUID->"82e9c269-b94e-4f44-95e5-\
d7aafbed69f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ee1", "\[Rule]", 
    RowBox[{
     SqrtBox["xx"], "+", 
     SqrtBox["yy"], "+", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee2", "\[Rule]", 
    RowBox[{
     SqrtBox["xx"], "-", 
     SqrtBox["yy"], "-", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["xx"]}], "+", 
     SqrtBox["yy"], "-", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee4", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["xx"]}], "-", 
     SqrtBox["yy"], "+", 
     SqrtBox["zz"]}]}]}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.718553895458702*^9, 3.718646210759568*^9, 
  3.718673053168124*^9, 3.7188130251480837`*^9, 3.718813848478207*^9, 
  3.7188140282931843`*^9, 3.71899213748565*^9, 3.719106106396057*^9, 
  3.7192499423651037`*^9, 3.719280081208767*^9, 3.719332657244631*^9, 
  3.719349600122528*^9, 3.719423516254809*^9, 3.7196731170684147`*^9, 
  3.719703142947322*^9, 3.7198729747600107`*^9, 3.719944671710124*^9, 
  3.725127498455523*^9, 3.725482051354389*^9, 3.725483983437277*^9, 
  3.7262567626673326`*^9, 
  3.7290086262172194`*^9},ExpressionUUID->"c647b83e-51e1-44f8-96c5-\
de7d2232e45e"]
}, Open  ]],

Cell[TextData[StyleBox[" Properties: extend to  Traceless Linear and \
Traceless Quadratic forms",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.7188136452965918`*^9, 3.7188136482202873`*^9}, {
  3.718814558158739*^9, 
  3.718814582229876*^9}},ExpressionUUID->"465c7270-7ce7-48bf-8d75-\
196e8ed8e835"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Use", " ", "this", " ", "when", " ", "we", " ", "do", " ", "Trace"}], 
    " ", "\[NotEqual]", " ", "0"}], "  ", "*)"}], "\[IndentingNewLine]", " ", 
  
  RowBox[{"eqGenEig", "/.", 
   RowBox[{"makeEigSub", "[", 
    RowBox[{"{", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.718813181339734*^9, 3.718813249451211*^9}, {
  3.718813333193739*^9, 3.7188133575114717`*^9}, {3.718813392904952*^9, 
  3.718813407426525*^9}, {3.718813937556381*^9, 
  3.718813954579296*^9}},ExpressionUUID->"17edab1a-3d71-4020-9a2b-\
51fa6b856701"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", " ", "x", " ", "y", " ", "z"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "w"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"w", " ", "x", " ", "z"}], "-", 
    RowBox[{"w", " ", "y", " ", "z"}], "-", 
    RowBox[{"x", " ", "y", " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{"w", " ", "x"}], "+", 
    RowBox[{"w", " ", "y"}], "+", 
    RowBox[{"x", " ", "y"}], "+", 
    RowBox[{"w", " ", "z"}], "+", 
    RowBox[{"x", " ", "z"}], "+", 
    RowBox[{"y", " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{"-", "w"}], "-", "x", "-", "y", "-", "z"}], ",", "1"}], 
  "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{{3.718813229351932*^9, 3.71881325013735*^9}, 
   3.718813334052957*^9, {3.718813375470859*^9, 3.718813413300606*^9}, 
   3.71881402835151*^9},ExpressionUUID->"e5b03144-3738-4f62-9454-\
c715d852f0b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqGenEig", "/.", 
  RowBox[{"makeEigSub", "[", 
   RowBox[{"formTr0", "[", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7188134305918617`*^9, 
  3.718813440374983*^9}},ExpressionUUID->"376a3228-14e3-45db-b9c7-\
776b6cd2428e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ",", "0", ",", "1"}], 
  "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.7188134412067747`*^9, 
  3.7188140284137783`*^9},ExpressionUUID->"9addf5ed-e99a-494a-9b45-\
c0f939863c09"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "Expand", " "}]], "Input",
 CellChangeTimes->{{3.718813450689126*^9, 3.718813453833077*^9}, {
  3.718813491369464*^9, 
  3.71881349650985*^9}},ExpressionUUID->"43e6d814-b185-4389-a6f1-\
cbcf44812536"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["y", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["y", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    SuperscriptBox["z", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "x", " ", "y", " ", "z"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["z", "2"]}]}], ",", "0", ",", "1"}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.718813454453903*^9, 3.718813496913501*^9, 
  3.718814028472597*^9},ExpressionUUID->"17faaa74-b48d-4922-833e-\
9b6322f0a66b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Derive", " ", "the", " ", "bare", " ", "Traceless", " ", "Ansatz"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqGenEig", "/.", "subForee"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.718813542577238*^9, 
  3.718813630308963*^9}},ExpressionUUID->"be6d759c-3d9d-4fb1-8933-\
072b40ab7d0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["xE", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["xE", "2"], " ", 
     SuperscriptBox["yE", "2"]}], "+", 
    SuperscriptBox["yE", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["xE", "2"], " ", 
     SuperscriptBox["zE", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["yE", "2"], " ", 
     SuperscriptBox["zE", "2"]}], "+", 
    SuperscriptBox["zE", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["xE", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["yE", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["zE", "2"]}]}], ",", "0", ",", "1"}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{{3.7188135632299213`*^9, 3.7188135876769953`*^9}, 
   3.7188140285252237`*^9},ExpressionUUID->"e1b701cf-847f-46c5-8b8e-\
1b42adb3b340"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqLinear", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["xE", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["xE", "2"], " ", 
       SuperscriptBox["yE", "2"]}], "+", 
      SuperscriptBox["yE", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["xE", "2"], " ", 
       SuperscriptBox["zE", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["yE", "2"], " ", 
       SuperscriptBox["zE", "2"]}], "+", 
      SuperscriptBox["zE", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["xE", "2"], "+", 
        SuperscriptBox["yE", "2"], "+", 
        SuperscriptBox["zE", "2"]}], ")"}]}], ",", "0", ",", "1"}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718813602313676*^9, 3.718813603950697*^9}, 
   3.718814172495448*^9},ExpressionUUID->"1273c529-81cb-48ee-8981-\
98ced3a4f218"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eqGenEig", "/.", "subForxx"}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.716585529216775*^9, 3.716585561893716*^9}, {
  3.7165855949268703`*^9, 3.716585596759122*^9}, {3.71881389019184*^9, 
  3.718813904673995*^9}},ExpressionUUID->"748bfe50-4c45-4037-8ae9-\
6c8ad30a1427"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["xx", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
    SuperscriptBox["yy", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
    RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
    SuperscriptBox["zz", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SqrtBox["xx"], " ", 
    SqrtBox["yy"], " ", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "xx"}], "-", 
    RowBox[{"2", " ", "yy"}], "-", 
    RowBox[{"2", " ", "zz"}]}], ",", "0", ",", "1"}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{
  3.7165855629411488`*^9, 3.716585597428392*^9, {3.718813895588513*^9, 
   3.7188139051056757`*^9}, {3.7188140285994463`*^9, 
   3.718814044130413*^9}},ExpressionUUID->"fb0113ef-4f57-4384-a168-\
1922a0e25227"]
}, Open  ]],

Cell[TextData[StyleBox["  Remark:  Squaring the  p3  term makes the equation \
solution more efficient: (not really)",
 FontSize->16,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.718814056313943*^9, 3.718814097209692*^9}, {
  3.719778410104699*^9, 
  3.719778417312448*^9}},ExpressionUUID->"a4721fa4-2f74-4712-9148-\
45ea135fa7bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqQuadratic", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["xx", "2"], "-", 
      RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
      SuperscriptBox["yy", "2"], "-", 
      RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
      RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
      SuperscriptBox["zz", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SqrtBox["xx"], " ", 
      SqrtBox["yy"], " ", 
      SqrtBox["zz"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], ",", "0", ",", "1"}], 
    "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7188140010293827`*^9, 3.718814019187117*^9}, {
   3.7188141186197433`*^9, 3.7188141459069347`*^9}, 
   3.71881419506844*^9},ExpressionUUID->"7e0ec31f-d0c8-400f-8343-\
85b3064d54f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqPform", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"p4", ",", "p3", ",", "p2", ",", "p1", ",", "p0"}], "}"}]}], " ", 
  
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"coefficients", " ", "of", " ", 
     RowBox[{"lambda", "^", 
      RowBox[{"(", 
       RowBox[{"4", "-", "n"}], ")"}]}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "4"}], "}"}]}], "  ", "*)"}], ";"}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.718814743810812*^9, 3.718814758708902*^9}, {
   3.718815248176689*^9, 3.718815274760386*^9}, 
   3.7188153348490067`*^9},ExpressionUUID->"f9086c5d-25ef-4a9d-806b-\
901d0c85d7bf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Construction", " ", "of", " ", "basic", " ", "equation"}], ",", 
    " ", 
    RowBox[{"matching", " ", "pToxxRule"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"eqPform", "[", 
      RowBox[{"[", "i", "]"}], "]"}], " ", "\[Equal]", " ", 
     RowBox[{"eqQuadratic", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.719675126129963*^9, 3.719675210913663*^9}, 
   3.719679250403655*^9, {3.719679286468272*^9, 
   3.719679302371695*^9}},ExpressionUUID->"1f2b76cc-bf2d-49df-9512-\
98dd79f1133c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p2", "\[Equal]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}], ",", 
   RowBox[{"p3", "\[Equal]", 
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     SqrtBox["xx"], " ", 
     SqrtBox["yy"], " ", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"p4", "\[Equal]", 
    RowBox[{
     SuperscriptBox["xx", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
     SuperscriptBox["yy", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
     RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
     SuperscriptBox["zz", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.719675211502206*^9, 
  3.719679252495039*^9},ExpressionUUID->"fb04b4cd-2248-404f-a262-\
1180a71c9f87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornEigValEqn", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p2", "\[Equal]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}], ",", 
    RowBox[{"p3", "\[Equal]", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SqrtBox["xx"], " ", 
      SqrtBox["yy"], " ", 
      SqrtBox["zz"]}]}], ",", 
    RowBox[{"p4", "\[Equal]", 
     RowBox[{
      SuperscriptBox["xx", "2"], "-", 
      RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
      SuperscriptBox["yy", "2"], "-", 
      RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
      RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
      SuperscriptBox["zz", "2"]}]}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.7196792634934893`*^9},ExpressionUUID->"3822d4c6-5760-4381-b15e-\
620902cf3c1b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p2", "\[Equal]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}], ",", 
   RowBox[{"p3", "\[Equal]", 
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     SqrtBox["xx"], " ", 
     SqrtBox["yy"], " ", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"p4", "\[Equal]", 
    RowBox[{
     SuperscriptBox["xx", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
     SuperscriptBox["yy", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
     RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
     SuperscriptBox["zz", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7197031430793543`*^9, 3.719872975014271*^9, 
  3.719944671767866*^9, 3.725127498523118*^9, 3.7254820514379587`*^9, 
  3.725483983505479*^9, 3.7262567627521048`*^9, 
  3.7290086262678967`*^9},ExpressionUUID->"00bacca3-f944-4931-ba60-\
7dc940bbfed0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.  Subplane limits of Horn Matrix  expressions, \
eigenvalues, and eigenvectors",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.716571747674493*^9, 3.7165717634583597`*^9}, {
  3.716572358885088*^9, 3.7165723698533583`*^9}, {3.716572604427875*^9, 
  3.716572629212173*^9}},ExpressionUUID->"3ece1528-0a8f-4c73-aa3d-\
5954067d6db4"],

Cell[CellGroupData[{

Cell["The limiting cases", "Subsubsection",
 CellChangeTimes->{{3.7165726943156233`*^9, 
  3.71657270362778*^9}},ExpressionUUID->"5c4c37db-517a-42d9-9d9a-\
d021f63f0af3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xplaneRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxx", "\[Rule]", "0"}], ",", 
     RowBox[{"sxy", "\[Rule]", "0"}], ",", 
     RowBox[{"syx", "\[Rule]", "0"}], ",", 
     RowBox[{"sxz", "\[Rule]", "0"}], ",", 
     RowBox[{"szx", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yplaneRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"syy", "\[Rule]", "0"}], ",", 
     RowBox[{"sxy", "\[Rule]", "0"}], ",", 
     RowBox[{"syx", "\[Rule]", "0"}], ",", 
     RowBox[{"syz", "\[Rule]", "0"}], ",", 
     RowBox[{"szy", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zplaneRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"szz", "\[Rule]", "0"}], ",", 
     RowBox[{"sxz", "\[Rule]", "0"}], ",", 
     RowBox[{"szx", "\[Rule]", "0"}], ",", 
     RowBox[{"syz", "\[Rule]", "0"}], ",", 
     RowBox[{"szy", "\[Rule]", "0"}]}], "}"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.715265643867124*^9, 
  3.715265765993311*^9}},ExpressionUUID->"f02fba56-fd35-434d-b63a-\
6f378a0cf9e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xAplaneRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"b", "\[Rule]", " ", "0"}], ",", 
     RowBox[{"bb", "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", "0"}], ",", 
     RowBox[{"cc", "\[Rule]", "0"}]}], "}"}]}], ";", 
  RowBox[{"yAplaneRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y", "\[Rule]", "0"}], ",", 
     RowBox[{"a", "\[Rule]", " ", "0"}], ",", 
     RowBox[{"aa", "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", "0"}], ",", 
     RowBox[{"cc", "\[Rule]", "0"}]}], "}"}]}], ";", 
  RowBox[{"zAplaneRule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "\[Rule]", "0"}], ",", 
     RowBox[{"a", "\[Rule]", " ", "0"}], ",", 
     RowBox[{"aa", "\[Rule]", "0"}], ",", 
     RowBox[{"b", "\[Rule]", " ", "0"}], ",", 
     RowBox[{"bb", "\[Rule]", "0"}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.715596616377907*^9, 3.715596733899928*^9}, {
  3.715647304418516*^9, 3.715647333809617*^9}, {3.716572842971541*^9, 
  3.716572844979588*^9}},ExpressionUUID->"03c293f8-3e49-4612-9eca-\
317599480906"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"xxsubAmat", ",", "yysubAmat", ",", "zzsubAmat"}], "}"}], "=", 
  RowBox[{"hornAmat", "/.", 
   RowBox[{"{", 
    RowBox[{"xAplaneRule", ",", "yAplaneRule", ",", "zAplaneRule"}], 
    "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.715597147579812*^9, 3.7155971633608723`*^9}, {
  3.715597245815591*^9, 3.71559724750776*^9}, {3.715647399881069*^9, 
  3.7156474184570293`*^9}, {3.7156474695543957`*^9, 
  3.715647488800456*^9}},ExpressionUUID->"1d97d220-bfc4-4b6f-a8f6-\
9269121aee02"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "+", "z"}], ",", "a", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{
        RowBox[{"-", "y"}], "-", "z"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"y", "-", "z"}], ",", "aa"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "aa", ",", 
       RowBox[{
        RowBox[{"-", "y"}], "+", "z"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "+", "z"}], ",", "0", ",", "b", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"x", "-", "z"}], ",", "0", ",", "bb"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "x"}], "-", "z"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "bb", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "x"}], "+", "z"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "+", "y"}], ",", "0", ",", "0", ",", "c"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"x", "-", "y"}], ",", "cc", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "cc", ",", 
       RowBox[{
        RowBox[{"-", "x"}], "+", "y"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "x"}], "-", "y"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.716572889146864*^9, 3.716769824363199*^9, 
  3.716769907765493*^9, 3.716847262553526*^9, 3.7169347733787813`*^9, 
  3.716935138417197*^9, 3.7170723645698357`*^9, 3.71796201653541*^9, 
  3.7179685114326963`*^9, 3.718132701898839*^9, 3.718211397876523*^9, 
  3.718211510529985*^9, 3.718279013112617*^9, 3.71864621079571*^9, 
  3.718673053416111*^9, 3.718813025223475*^9, 3.718992137575013*^9, 
  3.7191061065291224`*^9, 3.719249942413085*^9, 3.719280081354953*^9, 
  3.719332657291312*^9, 3.7193496002562532`*^9, 3.719423516320537*^9, 
  3.719673117138625*^9, 3.719703143163741*^9, 3.7198729750931587`*^9, 
  3.719944671821184*^9, 3.725127498579537*^9, 3.72548205150732*^9, 
  3.725483983567754*^9, 3.72625676282185*^9, 
  3.7290086263050547`*^9},ExpressionUUID->"0b6b6b36-a942-4263-a4f4-\
9630bafa23a5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The limiting eigensystems", "Subsubsection",
 CellChangeTimes->{{3.7165727080435047`*^9, 
  3.716572713931451*^9}},ExpressionUUID->"2be63612-62d7-4d6d-b83c-\
9466d3e5dbd5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"eigValX0List", ",", "eigVecX0List"}], "}"}], " ", "=", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"aa", ",", "aa", ",", "a", ",", "a"}], "}"}]}], "}"}], "*", 
      " ", 
      RowBox[{"Eigensystem", "[", "xxsubAmat", "]"}]}], "//", 
     "FullSimplify"}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7165726370899687`*^9, 3.716572689292448*^9}, {
  3.716573247300528*^9, 3.7165733486948957`*^9}, {3.71657343888244*^9, 
  3.716573470951755*^9}},ExpressionUUID->"c5a5e403-1efa-4fb8-982f-\
a2540edc06fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "+", "z"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "z"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["aa", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "+", "z", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}], ",", "a", ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "+", "z", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}], ",", "a", ",", "0", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"y", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["aa", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y", "-", "z"}], ")"}], "2"]}]], "-", "z"}], ",", "aa"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"y", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["aa", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y", "-", "z"}], ")"}], "2"]}]], "-", "z"}], ",", "aa"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.71657325940947*^9, 3.716573349956579*^9, 
  3.716573491097411*^9, 3.716935139025693*^9, 3.717072365111658*^9, 
  3.717962017425735*^9, 3.71796851200229*^9, 3.7181327025018263`*^9, 
  3.718211398733912*^9, 3.718211510812999*^9, 3.718279013753221*^9, 
  3.718646211091777*^9, 3.7186730540049047`*^9, 3.7188130258037558`*^9, 
  3.718992138073595*^9, 3.719106107103959*^9, 3.719249942700691*^9, 
  3.719280082056995*^9, 3.719332657769684*^9, 3.719349600983886*^9, 
  3.719423516891864*^9, 3.719673117619529*^9, 3.719703143880817*^9, 
  3.719872976365364*^9, 3.7199446725644712`*^9, 3.72512749866995*^9, 
  3.725482052184553*^9, 3.725483983653145*^9, 3.726256762916891*^9, 
  3.729008626968519*^9},ExpressionUUID->"ca66adbd-5c96-4d02-b71a-\
8162f246e1a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"eigValY0List", ",", "eigVecY0List"}], "}"}], " ", "=", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"bb", ",", "bb", ",", "b", ",", "b"}], "}"}]}], "}"}], "*", 
      " ", 
      RowBox[{"Eigensystem", "[", "yysubAmat", "]"}]}], "//", 
     "FullSimplify"}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7165726370899687`*^9, 3.716572689292448*^9}, {
  3.716573247300528*^9, 3.7165733486948957`*^9}, {3.71657343888244*^9, 
  3.716573526758444*^9}},ExpressionUUID->"c6564fd0-b83d-4d58-990b-\
7ee7d1c3709d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "z"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "z"}], ")"}], "2"]}]]}], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "z"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["bb", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "z"}], ")"}], "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "+", "z", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "+", "z"}], ")"}], "2"]}]]}], ",", "0", ",", "b", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "+", "z", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "+", "z"}], ")"}], "2"]}]]}], ",", "0", ",", "b", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"x", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["bb", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "z"}], ")"}], "2"]}]], "-", "z"}], ",", "0", 
       ",", "bb"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"x", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["bb", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "z"}], ")"}], "2"]}]], "-", "z"}], ",", "0", 
       ",", "bb"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.716573529663547*^9, 3.716935139586054*^9, 
  3.717072365666205*^9, 3.7179620179880037`*^9, 3.7179685125211153`*^9, 
  3.7181327029757853`*^9, 3.718211399434959*^9, 3.718211511094294*^9, 
  3.718279014297409*^9, 3.718646211362646*^9, 3.718673054512241*^9, 
  3.7188130263660927`*^9, 3.7189921385933943`*^9, 3.71910610765306*^9, 
  3.7192499429711523`*^9, 3.7192800827894*^9, 3.719332658061819*^9, 
  3.719349601767005*^9, 3.71942351734449*^9, 3.7196731178859158`*^9, 
  3.719703144457631*^9, 3.719872977094089*^9, 3.7199446730839567`*^9, 
  3.725127498736932*^9, 3.725482052719708*^9, 3.725483983714398*^9, 
  3.726256762985642*^9, 
  3.7290086272711163`*^9},ExpressionUUID->"358736e7-86c5-4185-a84c-\
82c29f922a9f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"eigValZ0List", ",", "eigVecZ0List"}], "}"}], " ", "=", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"cc", ",", "cc", ",", "c", ",", "c"}], "}"}]}], "}"}], "*", 
      " ", 
      RowBox[{"Eigensystem", "[", "zzsubAmat", "]"}]}], "//", 
     "FullSimplify"}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7165726370899687`*^9, 3.716572689292448*^9}, {
  3.716573247300528*^9, 3.7165733486948957`*^9}, {3.71657343888244*^9, 
  3.716573564693461*^9}},ExpressionUUID->"d559d9db-c761-4bd6-a810-\
9f7477e85cac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "y"}], ")"}], "2"]}]]}], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["cc", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "y"}], ")"}], "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "+", "y", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "+", "y"}], ")"}], "2"]}]]}], ",", "0", ",", "0", 
       ",", "c"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "+", "y", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "+", "y"}], ")"}], "2"]}]]}], ",", "0", ",", "0", 
       ",", "c"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"x", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["cc", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "y"}], ")"}], "2"]}]], "-", "y"}], ",", "cc", 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"x", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["cc", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "y"}], ")"}], "2"]}]], "-", "y"}], ",", "cc", 
       ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.716573557450054*^9, 3.716573565537312*^9}, 
   3.716935140057219*^9, 3.717072366124797*^9, 3.71796201903446*^9, 
   3.7179685131190157`*^9, 3.718132703514076*^9, 3.718211400038604*^9, 
   3.718211511421262*^9, 3.7182790147948923`*^9, 3.718646211635476*^9, 
   3.718673054973448*^9, 3.718813026851811*^9, 3.718992139045313*^9, 
   3.719106108102233*^9, 3.7192499432421093`*^9, 3.719280083554377*^9, 
   3.719332658388454*^9, 3.719349602728283*^9, 3.719423517824987*^9, 
   3.719673118195202*^9, 3.7197031449149723`*^9, 3.7198729776709538`*^9, 
   3.719944673543126*^9, 3.7251274987967463`*^9, 3.725482053198291*^9, 
   3.7254839837703733`*^9, 3.726256763088871*^9, 
   3.729008627538822*^9},ExpressionUUID->"fcd1d77c-ba42-4fe0-a252-\
4d3b68f6ebbd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eqHorn", "/.", 
    RowBox[{"{", 
     RowBox[{"xAplaneRule", ",", "yAplaneRule", ",", "zAplaneRule"}], "}"}]}],
    "//", "FullSimplify"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.717075076026141*^9, 3.7170751017880993`*^9}, {
  3.7170751471222553`*^9, 
  3.71707520108524*^9}},ExpressionUUID->"da7eb22d-9717-4646-9c35-\
a0b38de7a8e2"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["aa", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}], "2"]}], ")"}]}], "0", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "-", 
      SuperscriptBox["aa", "2"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]}], "0", "1"},
    {
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["bb", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "z"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "z"}], ")"}], "2"]}], ")"}]}], "0", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["bb", "2"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]}], "0", "1"},
    {
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["cc", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "y"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "y"}], ")"}], "2"]}], ")"}]}], "0", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["cc", "2"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}]}], "0", "1"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.717075093769602*^9, 3.717075102285185*^9}, {
  3.7170751551074867`*^9, 
  3.717075201733832*^9}},ExpressionUUID->"f81425c6-1569-473e-93d4-\
3cc27bfbb0db"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.  Best guess for  extension of Subplane limits of \
Horn Matrix  expressions",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.716571747674493*^9, 3.7165717634583597`*^9}, {
  3.716572358885088*^9, 3.7165723698533583`*^9}, {3.716572604427875*^9, 
  3.716572629212173*^9}, {3.716573088481303*^9, 
  3.7165731231930656`*^9}},ExpressionUUID->"033abeaa-9ff8-4062-a43a-\
ecb37e3d1e7f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigValTryOK", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox["x", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "y"}], "+", 
       SuperscriptBox["y", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "z"}], "+", 
       RowBox[{"2", " ", "y", " ", "z"}], "+", 
       SuperscriptBox["z", "2"]}]], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["x", "2"], "+", 
       RowBox[{"2", " ", "x", " ", "y"}], "+", 
       SuperscriptBox["y", "2"], "+", 
       RowBox[{"2", " ", "x", " ", "z"}], "-", 
       RowBox[{"2", " ", "y", " ", "z"}], "+", 
       SuperscriptBox["z", "2"]}]], ",", "\[IndentingNewLine]", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["aa", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["x", "2"], "+", 
        RowBox[{"2", " ", "x", " ", "y"}], "+", 
        SuperscriptBox["y", "2"], "+", 
        RowBox[{"2", " ", "x", " ", "z"}], "-", 
        RowBox[{"2", " ", "y", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]]}], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["bb", "2"], "+", 
        SuperscriptBox["cc", "2"], "+", 
        SuperscriptBox["x", "2"], "-", 
        RowBox[{"2", " ", "x", " ", "y"}], "+", 
        SuperscriptBox["y", "2"], "-", 
        RowBox[{"2", " ", "x", " ", "z"}], "+", 
        RowBox[{"2", " ", "y", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.717984967614336*^9, 
  3.717984993340567*^9}},ExpressionUUID->"612276d9-0190-4fee-861f-\
82bf5b17f963"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abcSubRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ayz", " ", "\[Rule]", " ", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "+", "z"}], ")"}], "2"]}]}], ",", 
     RowBox[{"aayz", "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "z"}], ")"}], "2"]}]}], ",", 
     RowBox[{"bzx", "->", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "z"}], ")"}], "2"]}]}], ",", 
     RowBox[{"bbzx", "\[Rule]", " ", 
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "z"}], ")"}], "2"]}]}], ",", 
     RowBox[{"cxy", "\[Rule]", " ", 
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}], "2"]}]}], ",", 
     RowBox[{"ccxy", "\[Rule]", " ", 
      RowBox[{
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], "2"]}]}]}], "}"}]}], ";"}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.717787050168127*^9, 3.717787107597069*^9}, {
  3.717787161044856*^9, 3.717787209109095*^9}, {3.7177874018442383`*^9, 
  3.717787411130474*^9}, {3.717848746671935*^9, 
  3.717848770728828*^9}},ExpressionUUID->"ce054aeb-1623-4049-9751-\
3542413407c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"notEigList0", "=", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}], "2"]}]], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}], "2"]}]], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}], "2"]}]], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], "2"]}]]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7169923576359262`*^9, 3.71699239075135*^9}, {
  3.7169951074076233`*^9, 3.716995117080057*^9}, {3.7185647036020737`*^9, 
  3.718564703879819*^9}},ExpressionUUID->"48415baa-8bc8-413c-bd99-\
808551c99a94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"notVecList0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"eigVec01", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "+", "y", "+", "z", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "+", "y", "+", "z"}], ")"}], "2"]}]]}], ",", "a", 
        ",", "b", ",", "c"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"eigVecx1", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"x", "-", "y", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["bb", "2"], "+", 
           SuperscriptBox["cc", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "y", "-", "z"}], ")"}], "2"]}]], "-", "z"}], 
        ",", "cc", ",", "bb"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"eigVecy1", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"b", ",", "cc", ",", 
        RowBox[{
         RowBox[{"-", "x"}], "+", "y", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["aa", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["cc", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}], "2"]}]], "-", 
         "z"}], ",", "aa"}], "}"}]}], ",", 
     RowBox[{"eigVecz1", "=", 
      RowBox[{"{", 
       RowBox[{"c", ",", "bb", ",", "aa", ",", 
        RowBox[{
         RowBox[{"-", "x"}], "-", "y", "+", "z", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["aa", "2"], "+", 
           SuperscriptBox["bb", "2"], "+", 
           SuperscriptBox["c", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], "2"]}]]}]}], 
       "}"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.716935569790492*^9, 3.716935726738834*^9}, {
  3.716992283418057*^9, 3.716992285865204*^9}, {3.716992337305534*^9, 
  3.716992349425428*^9}, {3.716992397024171*^9, 3.716992471329784*^9}, {
  3.718564709739153*^9, 
  3.718564709938065*^9}},ExpressionUUID->"f73b4535-050e-463a-abd7-\
192084010358"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eigValTryOK", "/.", " ", 
    RowBox[{"{", 
     RowBox[{"xAplaneRule", ",", "yAplaneRule", ",", "zAplaneRule"}], "}"}]}],
    "//", "FullSimplify"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.7185651617479877`*^9, 
  3.718565185035321*^9}},ExpressionUUID->"ce48f801-5afa-477c-9b10-\
8c904674ada3"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "+", "z"}], ")"}], "2"]}]], 
     SqrtBox[
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "z"}], ")"}], "2"]}]], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["aa", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], "2"]}]]}], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}]},
    {
     SqrtBox[
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "z"}], ")"}], "2"]}]], 
     SqrtBox[
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "z"}], ")"}], "2"]}]], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "z"}], ")"}], "2"]}]]}], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["bb", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "z"}], ")"}], "2"]}]]}]},
    {
     SqrtBox[
      RowBox[{
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], "2"]}]], 
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}], "2"]}]], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "y"}], ")"}], "2"]}]]}], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["cc", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "y"}], ")"}], "2"]}]]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7185651867447977`*^9},ExpressionUUID->"4d7dd7ff-dba8-465f-b383-\
d73370b6533c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SqrtBox["ayz"], ",", " ", 
       SqrtBox["aayz"], ",", 
       RowBox[{"-", 
        SqrtBox["aayz"]}], ",", 
       RowBox[{"-", 
        SqrtBox["ayz"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SqrtBox["bbzx"], ",", " ", 
       SqrtBox["bzx"], ",", 
       RowBox[{"-", 
        SqrtBox[
         RowBox[{" ", "bzx"}]]}], ",", 
       RowBox[{"-", 
        SqrtBox["bbzx"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SqrtBox["ccxy"], ",", " ", 
       SqrtBox["cxy"], ",", 
       RowBox[{"-", 
        SqrtBox["cxy"]}], ",", 
       RowBox[{"-", 
        SqrtBox["ccxy"]}]}], "}"}]}], "}"}], "/.", "abcSubRule"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.718565277170767*^9, 
  3.718565410000881*^9}},ExpressionUUID->"2bb6254d-58dd-40ca-9a23-\
b432987db5ba"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "+", "z"}], ")"}], "2"]}]], 
     SqrtBox[
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "z"}], ")"}], "2"]}]], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["aa", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], "2"]}]]}], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}]},
    {
     SqrtBox[
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "z"}], ")"}], "2"]}]], 
     SqrtBox[
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "z"}], ")"}], "2"]}]], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "z"}], ")"}], "2"]}]]}], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["bb", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "z"}], ")"}], "2"]}]]}]},
    {
     SqrtBox[
      RowBox[{
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], "2"]}]], 
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}], "2"]}]], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "y"}], ")"}], "2"]}]]}], 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["cc", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "y"}], ")"}], "2"]}]]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.718565410339093*^9},ExpressionUUID->"ed6abd2c-98f5-4c6f-862f-\
854144a18db5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The  zz terms seem to vanish at  x,y,z=0 limits:\n     ** found  ",
 StyleBox["eigValTryOK ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " matches all these limits **"
}], "Subsubsection",
 CellChangeTimes->{{3.717855778421789*^9, 3.717855808365657*^9}, {
  3.717979051145473*^9, 3.717979059960596*^9}, {3.717979115648481*^9, 
  3.717979116656248*^9}, {3.717985004675267*^9, 3.7179850289351997`*^9}, {
  3.7185654924072104`*^9, 
  3.7185654971121063`*^9}},ExpressionUUID->"141104a3-bfc6-4ad0-9ab7-\
bf014443cb05"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"ee1", 
      RowBox[{
       SqrtBox["xx"], "+", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}], 
      RowBox[{"{", 
       RowBox[{"xxPlane", ",", "yyPlane", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         SqrtBox["ayz"], ",", 
         SqrtBox["bbzx"], ",", 
         SqrtBox["ccxy"]}], "}"}], "}"}]},
     {"ee2", 
      RowBox[{
       SqrtBox["xx"], "-", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], 
      RowBox[{"{", 
       RowBox[{"xxPlane", ",", "yyPlane", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         SqrtBox["aayz"], ",", 
         SqrtBox["bzx"], ",", 
         SqrtBox["cxy"]}], "}"}], "}"}]},
     {"ee3", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "+", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], 
      RowBox[{"{", 
       RowBox[{"xxPlane", ",", "yyPlane", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["aayz"]}], ",", 
         RowBox[{"-", 
          SqrtBox["bzx"]}], ",", 
         RowBox[{"-", 
          SqrtBox["cxy"]}]}], "}"}], "}"}]},
     {"ee4", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "-", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}], 
      RowBox[{"{", 
       RowBox[{"xxPlane", ",", "yyPlane", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["ayz"]}], ",", 
         RowBox[{"-", 
          SqrtBox["bbzx"]}], ",", 
         RowBox[{"-", 
          SqrtBox["ccxy"]}]}], "}"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.717853732427946*^9, {3.717853768152281*^9, 
   3.7178537750231237`*^9}},ExpressionUUID->"9b87f944-d618-4862-8a2c-\
36efc2ebaeaa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ranAll", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"aa", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"b", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"bb", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"c", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"cc", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"y", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}]}], "}"}]}], ",", 
   RowBox[{"ranXA", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"aa", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"y", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}]}], "}"}]}], ",", 
   RowBox[{"ranYB", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"b", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"bb", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}]}], "}"}]}], ",", 
   RowBox[{"ranZC", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"cc", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], ",", 
      RowBox[{"y", "\[Rule]", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}]}], "}"}]}]}], 
  "}"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7172930019768963`*^9, 3.7172930423302307`*^9}, {
   3.717365696887409*^9, 3.717365699973803*^9}, 3.717366124164773*^9, {
   3.7177834807123823`*^9, 
   3.717783551934558*^9}},ExpressionUUID->"499d196a-3a2c-4a96-8403-\
2e3c1f21c9ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "0.45164768451962056`"}], ",", 
     RowBox[{"aa", "\[Rule]", "0.19958023753625265`"}], ",", 
     RowBox[{"b", "\[Rule]", "0.6226196015202515`"}], ",", 
     RowBox[{"bb", "\[Rule]", "0.13329753636778918`"}], ",", 
     RowBox[{"c", "\[Rule]", "0.3117293408283498`"}], ",", 
     RowBox[{"cc", "\[Rule]", "0.6968413565444321`"}], ",", 
     RowBox[{"x", "\[Rule]", "0.8066123199085776`"}], ",", 
     RowBox[{"y", "\[Rule]", "0.20612014557685843`"}], ",", 
     RowBox[{"z", "\[Rule]", "0.3024365868862654`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "0.2345049139384937`"}], ",", 
     RowBox[{"aa", "\[Rule]", "0.4357060053543761`"}], ",", 
     RowBox[{"y", "\[Rule]", "0.1620672065856288`"}], ",", 
     RowBox[{"z", "\[Rule]", "0.3355042528628026`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", "\[Rule]", "0.18837278195886975`"}], ",", 
     RowBox[{"bb", "\[Rule]", "0.3481151308999174`"}], ",", 
     RowBox[{"x", "\[Rule]", "0.7582266495277147`"}], ",", 
     RowBox[{"z", "\[Rule]", "0.8581794040345699`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Rule]", "0.3037902693013449`"}], ",", 
     RowBox[{"cc", "\[Rule]", "0.14253385648812245`"}], ",", 
     RowBox[{"x", "\[Rule]", "0.33711979051354646`"}], ",", 
     RowBox[{"y", "\[Rule]", "0.24916555582329725`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.718646211703369*^9, 3.718673055107766*^9, 
  3.7188130270365953`*^9, 3.718992139150435*^9, 3.7191061081928053`*^9, 
  3.719249943310266*^9, 3.71928008367421*^9, 3.719332658436919*^9, 
  3.7193496030043707`*^9, 3.719423517885891*^9, 3.719673118256361*^9, 
  3.719703145013331*^9, 3.719872977856063*^9, 3.7199446737122717`*^9, 
  3.72512749886021*^9, 3.725482053327615*^9, 3.725483983845625*^9, 
  3.726256763186969*^9, 
  3.7290086276133823`*^9},ExpressionUUID->"6851f36c-7acc-47fa-b444-\
0c3830eb2ac3"]
}, Open  ]],

Cell["\<\
The purpose of this is to have  expressions of p2,p3,p4 that are \
\[OpenCurlyQuote]real\[CloseCurlyQuote] so they do not have imaginary parts:\
\>", "Text",
 CellChangeTimes->{{3.7260746036176357`*^9, 
  3.7260746349853773`*^9}},ExpressionUUID->"a506b88e-c482-4339-a2bc-\
43eedb371d02"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pnRandom", "=", 
  RowBox[{"thePRule", "/.", "ranAll"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725294966067128*^9, 
  3.7252950043233633`*^9}},ExpressionUUID->"33e78a90-8487-4c6a-9f10-\
4c35b2bf29e7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", "0.4195124973066313`"}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "1.1286147080412954`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "2.8011580379265553`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.72607466093052*^9, 3.726256763198083*^9, 
  3.729008627620781*^9},ExpressionUUID->"ef1ab93e-7036-4b93-9e5c-\
bb749b81df72"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining the solvable Cubic equations", "Subchapter",
 CellChangeTimes->{{3.718565754685601*^9, 
  3.7185657682691317`*^9}},ExpressionUUID->"d7a7c3ad-1a72-4ca4-9796-\
67d44c49bcc7"],

Cell[CellGroupData[{

Cell["\<\
Cache  solutions for  xx,  yy,  zz, 
  See  Test-Eval-Init-Cells.nb\
\>", "Section",
 CellChangeTimes->{{3.71856581313275*^9, 3.718565828540721*^9}, {
  3.7188130847048407`*^9, 3.718813091208867*^9}, {3.718995254141345*^9, 
  3.718995259789295*^9}, {3.719260276101296*^9, 3.719260285157463*^9}, {
  3.727633114031748*^9, 
  3.7276331222958717`*^9}},ExpressionUUID->"86ab74dd-59de-4932-ad76-\
11a70f563be4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cubeRtPhase", "[", "root3_", "]"}], " ", ":=", " ", 
  RowBox[{"Switch", "[", 
   RowBox[{"root3", ",", "\"\<x\>\"", ",", 
    FractionBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<y\>\"", ",", 
    FractionBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<z\>\"", ",", 
    RowBox[{"-", "1"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.728594674003961*^9, 
  3.7285947105399017`*^9}},ExpressionUUID->"308fbeb4-bd7c-44d0-89de-\
604d1e03470c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Call", " ", "with", " ", "root3"}], " ", "=", " ", 
     RowBox[{"string", " ", "\"\<x\>\""}]}], ",", " ", "\"\<y\>\"", ",", " ", 
    
    RowBox[{"or", " ", "\"\<z\>\"", "\[IndentingNewLine]", "  ", 
     RowBox[{"NOTE", "!"}], " ", "The", " ", "ORDER", " ", "of", " ", "X", 
     " ", "and", " ", "Y", " ", "had", " ", "to", " ", "be", " ", "switched", 
     " ", "to", " ", "agree", " ", "with", " ", "eigval", " ", "rank", " ", 
     "ordering"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"root3_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"qq3", ",", 
       RowBox[{"phi", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"root3", ",", "\"\<x\>\"", ",", 
          FractionBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<y\>\"", ",", 
          FractionBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<z\>\"", ",", 
          RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["p2", "6"]}], "+", 
        FractionBox[
         RowBox[{"  ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}], 
         RowBox[{"12", " ", "phi", "  ", "qq3"}]], "+", 
        RowBox[{
         FractionBox["phi", "12"], "  ", "qq3"}]}], ")"}], "/.", 
      RowBox[{"qq3", "\[Rule]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719597193946005*^9, 3.719597305370088*^9}, {
   3.7195973505286922`*^9, 3.719597382137249*^9}, {3.7195974123298903`*^9, 
   3.719597510213501*^9}, {3.719597604532134*^9, 3.719597613925857*^9}, {
   3.7195976910520077`*^9, 3.7195976921617413`*^9}, 3.7195984437457933`*^9, {
   3.719598546775992*^9, 3.719598570169475*^9}, {3.719801985921894*^9, 
   3.71980199062432*^9}, {3.719802071752438*^9, 3.719802072574925*^9}, 
   3.719802200937204*^9, {3.719802702899005*^9, 3.719802744546809*^9}, {
   3.719802897544032*^9, 
   3.719802919926641*^9}},ExpressionUUID->"bba538e6-4911-4493-923b-\
347d1e5322e6"],

Cell[TextData[StyleBox["Define alternatively the square roots of xx,yy,zz  as \
a function with args \[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote] \
\[OpenCurlyDoubleQuote]y\[CloseCurlyDoubleQuote] \[OpenCurlyDoubleQuote]z\
\[CloseCurlyDoubleQuote]",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7198019260623093`*^9, 3.719801948694252*^9}, {
  3.719802049876522*^9, 
  3.719802063309208*^9}},ExpressionUUID->"1ff41014-7646-4ae6-a380-\
deb88fab83e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Call", " ", "with", " ", "root3"}], " ", "=", " ", 
     RowBox[{"string", " ", "\"\<x\>\""}]}], ",", " ", "\"\<y\>\"", ",", " ", 
    
    RowBox[{"or", " ", "\"\<z\>\"", "\[IndentingNewLine]", "  ", 
     RowBox[{"NOTE", "!"}], " ", "The", " ", "ORDER", " ", "of", " ", "X", 
     " ", "and", " ", "Y", " ", "had", " ", "to", " ", "be", " ", "switched", 
     " ", "to", " ", "agree", " ", "with", " ", "eigval", " ", "rank", " ", 
     "ordering"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"xyzRoot", "[", 
    RowBox[{"root3_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"qq3", ",", 
       RowBox[{"phi", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"root3", ",", "\"\<x\>\"", ",", 
          FractionBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<y\>\"", ",", 
          FractionBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<z\>\"", ",", 
          RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"(", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["p2", "6"]}], "+", 
         FractionBox[
          RowBox[{"  ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p2", "2"], "+", 
             RowBox[{"12", " ", "p4"}]}], ")"}]}], 
          RowBox[{"12", " ", "phi", "  ", "qq3"}]], "+", 
         RowBox[{
          FractionBox["phi", "12"], "  ", "qq3"}]}]], ")"}], "/.", 
      RowBox[{"qq3", "\[Rule]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719597193946005*^9, 3.719597305370088*^9}, {
   3.7195973505286922`*^9, 3.719597382137249*^9}, {3.7195974123298903`*^9, 
   3.719597510213501*^9}, {3.719597604532134*^9, 3.719597613925857*^9}, {
   3.7195976910520077`*^9, 3.7195976921617413`*^9}, 3.7195984437457933`*^9, {
   3.719598546775992*^9, 3.719598570169475*^9}, {3.719801985921894*^9, 
   3.71980199062432*^9}, {3.719802071752438*^9, 3.719802072574925*^9}, 
   3.719802200937204*^9, {3.719802702899005*^9, 
   3.719802744546809*^9}},ExpressionUUID->"d12ad918-b48d-4d49-b2fe-\
dfc1e7d2bf31"],

Cell[BoxData[
 RowBox[{"subForee", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ee1", "\[Rule]", 
     RowBox[{"xE", "+", "yE", "+", "zE"}]}], ",", 
    RowBox[{"ee2", "\[Rule]", 
     RowBox[{"xE", "-", "yE", "-", "zE"}]}], ",", 
    RowBox[{"ee3", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}]}], ",", 
    RowBox[{"ee4", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.727633005029025*^9, 
  3.727633025237339*^9}},ExpressionUUID->"efad12e7-2d97-40d1-a8eb-\
ff1aa82e2484"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"ee1", ",", "ee2", ",", "ee3", ",", "ee4"}], "}"}], "/.", 
  "subForee"}]], "Input",
 CellChangeTimes->{{3.719802140388754*^9, 
  3.7198021664201612`*^9}},ExpressionUUID->"865565b0-cfeb-472e-8803-\
d893f22d2df4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"xE", "+", "yE", "+", "zE"}], ",", 
   RowBox[{"xE", "-", "yE", "-", "zE"}], ",", 
   RowBox[{
    RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}], ",", 
   RowBox[{
    RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7198021674399757`*^9},ExpressionUUID->"fdb7ed68-9720-491e-90db-\
4191e713d529"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"xE", "+", "yE", "+", "zE"}], ",", 
    RowBox[{"xE", "-", "yE", "-", "zE"}], ",", 
    RowBox[{
     RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}], ",", 
    RowBox[{
     RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"xE", "\[Rule]", 
     RowBox[{"xyzRoot", "[", 
      RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
    RowBox[{"yE", "->", 
     RowBox[{"xyzRoot", "[", 
      RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
    RowBox[{"zE", "->", 
     RowBox[{"xyzRoot", "[", 
      RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.719802178780096*^9, 3.7198022868787003`*^9}, {
  3.7276330499660053`*^9, 
  3.727633069733757*^9}},ExpressionUUID->"1b0525df-dbe0-4f01-8aa8-\
11a88e0df142"],

Cell["\<\
 4d roots = (a+b, a-b, -a + c,  -a -c)
       Sqrt[x] = \
xyzRoot[\[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote],p2,p3,p4]    =  a, 
       Sqrt[y]+Sqrt[z] = b,  Sqrt[y]- Sqrt[z] = c.\
\>", "Subsubsection",
 CellChangeTimes->{
  3.727633185792173*^9},ExpressionUUID->"035104c9-abf2-455d-8559-\
de93ffbd0093"],

Cell[CellGroupData[{

Cell["\<\
Define eig4D1... below: ORDER of largest eigvalues is 4,3,2,1
_________________________________________________\
\>", "Subsubsection",
 CellChangeTimes->{{3.727633202814292*^9, 3.7276332090229*^9}, {
  3.727633253342146*^9, 
  3.7276332677518377`*^9}},ExpressionUUID->"c58def6e-e417-4082-983b-\
0a37654b378b"],

Cell[CellGroupData[{

Cell["\<\
This solution from above in THIS file, also see Horn-Demo-4.2
   defined here:
       eig4D1[p1,p2,p3,p4] , eig4D2, eig4D3,eig4D4
       ============================================\
\>", "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725285909816786*^9, 3.725285932341865*^9}, {
  3.725285983128278*^9, 3.7252860222482977`*^9}, {3.725288697950091*^9, 
  3.725288754762532*^9}},ExpressionUUID->"07c4f485-a9d2-484c-9b60-\
e75f976d63a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"e41", ",", "e42", ",", "e43", ",", "e44"}], "}"}], "=", 
  RowBox[{"Table", "[", " ", 
   RowBox[{
    RowBox[{"e", "/.", 
     RowBox[{"eig4Dallp", " ", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.720239742493675*^9, 3.7202397873520927`*^9}, {
   3.7202398526659727`*^9, 3.7202398554830017`*^9}, {3.7217539714163103`*^9, 
   3.7217540422292013`*^9}, 
   3.725288691229576*^9},ExpressionUUID->"bf70c048-b9e9-4cb0-b6dd-\
82e3743e5dc1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "-", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "-", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.721753988667948*^9, {3.7217540214490023`*^9, 3.72175404326095*^9}, 
   3.725288691229886*^9},ExpressionUUID->"52f67b2f-e349-45bb-b974-\
e7485801f0ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plus", "@@", 
   RowBox[{"{", 
    RowBox[{"e41", ",", "e42", ",", "e43", ",", "e44"}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.720239799442054*^9, 3.7202398096329803`*^9}, {
   3.7202398676049128`*^9, 3.720239900124958*^9}, 3.720239987650872*^9, 
   3.721608385779869*^9, 3.7217540514534073`*^9, 
   3.725288691230052*^9},ExpressionUUID->"d5310281-82b8-4144-8b66-\
ae7f74eeaf20"],

Cell[BoxData[
 RowBox[{"-", "p1"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.720239878232045*^9, {3.72023998221875*^9, 3.720239989374425*^9}, 
   3.721754052943907*^9, 
   3.725288691230214*^9},ExpressionUUID->"9fd3955a-6c1a-4299-ab5a-\
326ddfd4cef8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"eig4D1", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "p1"}], "-", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", " ", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["p1", "2"]}], "-", 
                RowBox[{"8", " ", "p2"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"eig4D2", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "p1"}], "-", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", " ", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["p1", "2"]}], "-", 
                RowBox[{"8", " ", "p2"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"eig4D3", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "p1"}], "+", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", " ", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["p1", "2"]}], "-", 
                RowBox[{"8", " ", "p2"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"eig4D4", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "p1"}], "+", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", " ", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["p1", "2"]}], "-", 
                RowBox[{"8", " ", "p2"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}]}], ")"}]}]}]}], "}"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.725288497531535*^9, 3.725288545220022*^9}, 
   3.725288691231908*^9},ExpressionUUID->"cdd23bed-da3e-4592-90b6-\
bb10f2805342"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Null", ",", "Null", ",", "Null", ",", "Null"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7252885581935787`*^9, 3.725288691232088*^9, 
  3.725483984423604*^9, 3.7260726131420383`*^9, 
  3.729008627723577*^9},ExpressionUUID->"0a3eaf0c-32ed-469a-b1b4-\
0336961166a1"],

Cell[BoxData[
 RowBox[{"eig4D2", "[", 
  RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725288575418393*^9, 3.725288587935403*^9}, 
   3.7252886912322693`*^9},ExpressionUUID->"712f47e2-e02c-498e-8a07-\
fc786e3824db"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "12"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", "p2"}], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
           ")"}], 
          RowBox[{"1", "/", "3"}]]], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["2", 
          RowBox[{"2", "/", "3"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
           ")"}], 
          RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
    RowBox[{
     SqrtBox["6"], " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", "p2"}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
           ")"}], 
          RowBox[{"1", "/", "3"}]]], "-", 
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{"2", "/", "3"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
           ")"}], 
          RowBox[{"1", "/", "3"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"24", " ", 
           SqrtBox["3"], " ", "p3"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "p2"}], "+", 
             FractionBox[
              RowBox[{"4", " ", 
               SuperscriptBox["2", 
                RowBox[{"1", "/", "3"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "2"], "+", 
                 RowBox[{"12", " ", "p4"}]}], ")"}]}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                ")"}], 
               RowBox[{"1", "/", "3"}]]], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"2", "/", "3"}]], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                ")"}], 
               RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}]}], 
   ")"}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.725288589016996*^9, 
  3.725288691232442*^9},ExpressionUUID->"f883c9ff-4f9c-4142-88a9-\
7b9aaa64743d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eig4D1x", "[", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "-", 
   RowBox[{"eig4D1", "[", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725288613942575*^9, 3.7252886377275753`*^9}, 
   3.725288691232634*^9},ExpressionUUID->"1ab649bb-8308-4736-9f83-\
5d9203a3205f"],

Cell[BoxData["0"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.725288638953891*^9, 
  3.7252886912328033`*^9},ExpressionUUID->"346baf77-c55e-4537-8579-\
51faa67b6e6d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eig4D1x", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
  RowBox[{
   FractionBox["1", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", "p1"}], "-", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                 ")"}], "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                 ")"}], "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
     RowBox[{
      SqrtBox["6"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                 ")"}], "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], "-", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                 ")"}], "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SqrtBox["3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p1", "3"], "-", 
              RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
              RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"\[Sqrt]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["p1", "2"]}], "-", 
              RowBox[{"8", " ", "p2"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"\[Sqrt]", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"\[Sqrt]", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}]}],
     ")"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725285948872096*^9, 3.725285968318914*^9}, 
   3.725286022249996*^9, 
   3.725288601301757*^9},ExpressionUUID->"7b385e8d-9664-4ee4-9adc-\
141c70456321"]
}, {6}]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Where did the Quadratic solutions come from,  Show steps
   for the p2,p3,p4 solutions, then Simplify to a,aa,x form.\
\>", "Section",
 CellChangeTimes->{{3.718565872164432*^9, 3.718565881100749*^9}, {
  3.718966149402965*^9, 3.718966178755128*^9}, {3.718993586563897*^9, 
  3.7189936208758917`*^9}},ExpressionUUID->"96d38920-c3da-4b45-b338-\
8c172a5a31e0"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Preliminaries - more definitions",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.7182391925342283`*^9, 3.7182391954063883`*^9}, {
  3.718239780336259*^9, 3.7182397947198973`*^9}, {3.718240004181945*^9, 
  3.7182400529975863`*^9}, {3.718240732167471*^9, 3.718240769855392*^9}, {
  3.718565988962953*^9, 3.718565989595583*^9}, {3.7189955531868763`*^9, 
  3.718995560178279*^9}, {3.718995626393648*^9, 3.718995628113104*^9}, {
  3.719260341606401*^9, 
  3.7192603566465178`*^9}},ExpressionUUID->"8a555d77-ed5b-4ec7-b45d-\
f08b135eb9e8"],

Cell[CellGroupData[{

Cell[BoxData["eqPform"], "Input",
 CellChangeTimes->{{3.71896601792741*^9, 
  3.718966024655315*^9}},ExpressionUUID->"9dc3b45a-c31d-4b78-8a8e-\
377867a68f66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"p4", ",", "p3", ",", "p2", ",", "p1", ",", "p0"}], "}"}]], "Output",\

 CellChangeTimes->{
  3.718966025520658*^9},ExpressionUUID->"aec73414-b6ec-4bfa-b32b-\
e8f59b1c0a6c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["eqGenEig"], "Input",
 CellChangeTimes->{{3.718966080102405*^9, 
  3.718966083022871*^9}},ExpressionUUID->"897fda65-af50-40e2-8136-\
47244e99ea9f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ee1", " ", "ee2", " ", "ee3", " ", "ee4"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "ee1"}], " ", "ee2", " ", "ee3"}], "-", 
    RowBox[{"ee1", " ", "ee2", " ", "ee4"}], "-", 
    RowBox[{"ee1", " ", "ee3", " ", "ee4"}], "-", 
    RowBox[{"ee2", " ", "ee3", " ", "ee4"}]}], ",", 
   RowBox[{
    RowBox[{"ee1", " ", "ee2"}], "+", 
    RowBox[{"ee1", " ", "ee3"}], "+", 
    RowBox[{"ee2", " ", "ee3"}], "+", 
    RowBox[{"ee1", " ", "ee4"}], "+", 
    RowBox[{"ee2", " ", "ee4"}], "+", 
    RowBox[{"ee3", " ", "ee4"}]}], ",", 
   RowBox[{
    RowBox[{"-", "ee1"}], "-", "ee2", "-", "ee3", "-", "ee4"}], ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.71896608696172*^9},ExpressionUUID->"5e276b53-27b8-4081-a6ce-68ff10d48d7f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["eqLinear"], "Input",
 CellChangeTimes->{{3.718966035021964*^9, 
  3.718966047446783*^9}},ExpressionUUID->"0d33f367-fc7e-4233-86c7-\
79d78e38f959"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["xE", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["xE", "2"], " ", 
     SuperscriptBox["yE", "2"]}], "+", 
    SuperscriptBox["yE", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["xE", "2"], " ", 
     SuperscriptBox["zE", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["yE", "2"], " ", 
     SuperscriptBox["zE", "2"]}], "+", 
    SuperscriptBox["zE", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["xE", "2"], "+", 
      SuperscriptBox["yE", "2"], "+", 
      SuperscriptBox["zE", "2"]}], ")"}]}], ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.718966048247219*^9},ExpressionUUID->"2efb1e49-b768-44b6-b59e-\
86ac44a360d9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["eqQuadratic"], "Input",
 CellChangeTimes->{{3.718966090270321*^9, 
  3.718966093294553*^9}},ExpressionUUID->"1ae38b82-181f-42aa-b8d5-\
16854dcc402a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["xx", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
    SuperscriptBox["yy", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
    RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
    SuperscriptBox["zz", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SqrtBox["xx"], " ", 
    SqrtBox["yy"], " ", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.71896609398807*^9},ExpressionUUID->"d43ef1da-579c-43ab-87b2-d572014fe5fd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqHorn", "[", 
  RowBox[{"[", 
   RowBox[{"2", ";;", "5"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.718966108781541*^9, 
  3.718966130557736*^9}},ExpressionUUID->"77957f45-5ca2-46b9-844b-\
879274c78a59"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"aa", " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", "bb", " ", "c"}], "+", 
      RowBox[{"a", " ", "b", " ", "cc"}], "+", 
      RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["aa", "2"], " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "y"}], "-", 
      RowBox[{
       SuperscriptBox["bb", "2"], " ", "y"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["c", "2"], "-", 
         SuperscriptBox["cc", "2"], "+", 
         RowBox[{"4", " ", "x", " ", "y"}]}], ")"}], " ", "z"}]}], ")"}]}], 
   ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "-", 
    SuperscriptBox["aa", "2"], "-", 
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["bb", "2"], "-", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox["cc", "2"], "-", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], ")"}]}]}], ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.718966117555125*^9, 
  3.7189661318518457`*^9}},ExpressionUUID->"1ee04e31-cd24-4a12-b710-\
abce6b982e42"]
}, Open  ]],

Cell[TextData[StyleBox["Substitutions:",
 FontSize->18,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7192546786280613`*^9, 
  3.719254687000889*^9}},ExpressionUUID->"b7f6ae70-cebc-46bf-8b28-\
f68337991c25"],

Cell[CellGroupData[{

Cell[BoxData["subForee"], "Input",
 CellChangeTimes->{{3.719254690314378*^9, 
  3.7192546941544237`*^9}},ExpressionUUID->"fdbcc1b4-84de-4495-81d8-\
81cb5085fc04"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ee1", "\[Rule]", 
    RowBox[{"xE", "+", "yE", "+", "zE"}]}], ",", 
   RowBox[{"ee2", "\[Rule]", 
    RowBox[{"xE", "-", "yE", "-", "zE"}]}], ",", 
   RowBox[{"ee3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}]}], ",", 
   RowBox[{"ee4", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719254695300046*^9},ExpressionUUID->"b6477a22-6d00-485a-b404-\
a8999117e482"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["subForxx"], "Input",
 CellChangeTimes->{{3.71925469625007*^9, 
  3.719254710650133*^9}},ExpressionUUID->"c806a309-def9-40fa-8f81-\
bf011eaf5d8f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ee1", "\[Rule]", 
    RowBox[{
     SqrtBox["xx"], "+", 
     SqrtBox["yy"], "+", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee2", "\[Rule]", 
    RowBox[{
     SqrtBox["xx"], "-", 
     SqrtBox["yy"], "-", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["xx"]}], "+", 
     SqrtBox["yy"], "-", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee4", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["xx"]}], "-", 
     SqrtBox["yy"], "+", 
     SqrtBox["zz"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719254707572609*^9, 
  3.719254712218102*^9}},ExpressionUUID->"0cee07eb-716a-4a99-9c30-\
885f10f98a2d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigValListxx", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ee1", ",", "ee2", ",", "ee3", ",", "ee4"}], "}"}], "/.", 
   "subForxx"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719255723755843*^9, 
  3.719255768827073*^9}},ExpressionUUID->"a44ef51d-7641-4e6b-adc2-\
e376272a8c1d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SqrtBox["xx"], "+", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    SqrtBox["xx"], "-", 
    SqrtBox["yy"], "-", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "+", 
    SqrtBox["yy"], "-", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "-", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.719255769360116*^9, 3.7192800836914186`*^9, 
  3.719332658441865*^9, 3.719349603032776*^9, 3.719423517897994*^9, 
  3.719673118261302*^9, 3.71970314502379*^9, 3.7198729778752527`*^9, 
  3.7199446737204237`*^9, 3.725127498870111*^9, 3.7254820533365717`*^9, 
  3.725483983857376*^9, 3.7262567632406178`*^9, 
  3.729008627728325*^9},ExpressionUUID->"4c57dcde-24dd-4ca2-bbdf-\
9fe0f678e7fb"]
}, Open  ]],

Cell[TextData[{
 StyleBox[" These are set up to check the solutions: cannot use RandomReal on \
p2,p3,p4 because there\n   are constraints involving abc,aabbcc,xyz  that \
means ONLY  ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["randomabcxyz  ",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" gives real eigenvalues!",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.719000278375574*^9, 
  3.7190003499438887`*^9}},ExpressionUUID->"5ba0104a-3400-4ef0-a522-\
039da93dd071"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomabcxyz", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
       RowBox[{"b", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
       RowBox[{"c", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"aa", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
       RowBox[{"bb", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
       RowBox[{"cc", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"x", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
       RowBox[{"z", "\[Rule]", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}]}], "}"}], ",", "10"}], 
    "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718998560060046*^9, 
  3.7189986797936783`*^9}},ExpressionUUID->"727659cc-ceb5-4e9d-917e-\
06832c3654af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomPn", " ", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p4", "\[Rule]", " ", 
       RowBox[{"eqHorn", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"p3", "\[Rule]", 
       RowBox[{"eqHorn", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", 
      RowBox[{"p2", "\[Rule]", 
       RowBox[{"eqHorn", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}], "/.", "randomabcxyz"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718997934305015*^9, 3.7189979631256533`*^9}, {
  3.718998144542095*^9, 3.718998145828087*^9}, {3.718998412707078*^9, 
  3.718998430818447*^9}, {3.718998692681308*^9, 3.7189987331822853`*^9}, {
  3.718998766029374*^9, 3.718998789717503*^9}, {3.7192542349457006`*^9, 
  3.719254253572517*^9}},ExpressionUUID->"19e54979-864c-480e-a3d2-\
82ad906320f6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xAplaneRule", ",", "yAplaneRule", ",", "zAplaneRule"}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.719254294372039*^9, 
  3.7192543041625137`*^9}},ExpressionUUID->"049330ba-a237-4c92-9e23-\
601bd55886b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"b", "\[Rule]", "0"}], ",", 
     RowBox[{"bb", "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", "0"}], ",", 
     RowBox[{"cc", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y", "\[Rule]", "0"}], ",", 
     RowBox[{"a", "\[Rule]", "0"}], ",", 
     RowBox[{"aa", "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", "0"}], ",", 
     RowBox[{"cc", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "\[Rule]", "0"}], ",", 
     RowBox[{"a", "\[Rule]", "0"}], ",", 
     RowBox[{"aa", "\[Rule]", "0"}], ",", 
     RowBox[{"b", "\[Rule]", "0"}], ",", 
     RowBox[{"bb", "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719254305985013*^9},ExpressionUUID->"fdcfc7a7-610b-40d3-b8d4-\
8cc3e1c398dc"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomPnX", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", " ", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}], "/.", "xAplaneRule"}], "/.",
     "randomabcxyz"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718997934305015*^9, 3.7189979631256533`*^9}, {
  3.718998144542095*^9, 3.718998145828087*^9}, {3.718998412707078*^9, 
  3.718998430818447*^9}, {3.718998692681308*^9, 3.7189987331822853`*^9}, {
  3.718998766029374*^9, 3.718998789717503*^9}, {3.7191710754519787`*^9, 
  3.719171083703619*^9}, {3.7192542681782207`*^9, 
  3.719254273106147*^9}},ExpressionUUID->"1bab9c02-358f-4403-b425-\
47c08a183c35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomPnY", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", " ", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}], "/.", "yAplaneRule"}], "/.",
     "randomabcxyz"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718997934305015*^9, 3.7189979631256533`*^9}, {
  3.718998144542095*^9, 3.718998145828087*^9}, {3.718998412707078*^9, 
  3.718998430818447*^9}, {3.718998692681308*^9, 3.7189987331822853`*^9}, {
  3.718998766029374*^9, 3.718998789717503*^9}, {3.7191710754519787`*^9, 
  3.719171083703619*^9}, {3.7192542681782207`*^9, 3.719254273106147*^9}, {
  3.719254310547134*^9, 
  3.719254313954691*^9}},ExpressionUUID->"917dd72b-142c-4b88-96e4-\
97e7f4409807"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomPnZ", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", " ", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"eqHorn", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}], "/.", "zAplaneRule"}], "/.",
     "randomabcxyz"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718997934305015*^9, 3.7189979631256533`*^9}, {
  3.718998144542095*^9, 3.718998145828087*^9}, {3.718998412707078*^9, 
  3.718998430818447*^9}, {3.718998692681308*^9, 3.7189987331822853`*^9}, {
  3.718998766029374*^9, 3.718998789717503*^9}, {3.7191710754519787`*^9, 
  3.719171083703619*^9}, {3.7192542681782207`*^9, 3.719254273106147*^9}, {
  3.719254317443*^9, 
  3.719254321298993*^9}},ExpressionUUID->"bc0c8c1c-6c60-4701-92ed-\
ceed2c1f8ed7"],

Cell[TextData[StyleBox["Set up the analogs for symbolic  p2,p3,p4  limits as \
x,y,z=0",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7192595885059147`*^9, 
  3.719259608650423*^9}},ExpressionUUID->"64a7fb00-6003-4374-a3e5-\
3452ec2d6440"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Look at direct limits",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.719107267828803*^9, 3.7191072785163317`*^9}, 
   3.7192604293998623`*^9},ExpressionUUID->"5914b33c-a89d-42d0-ad65-\
312c4844a24e"],

Cell[CellGroupData[{

Cell[BoxData["thePRule"], "Input",
 CellChangeTimes->{{3.719259635277028*^9, 
  3.719259642380427*^9}},ExpressionUUID->"b703ee47-ec6e-4159-a6d1-\
f3f536b88628"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["aa", "2"]}], "-", 
     RowBox[{"2", " ", "a", " ", "aa", " ", "b", " ", "bb"}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["bb", "2"]}], "-", 
     RowBox[{"2", " ", "a", " ", "aa", " ", "c", " ", "cc"}], "-", 
     RowBox[{"2", " ", "b", " ", "bb", " ", "c", " ", "cc"}], "+", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox["cc", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["cc", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["bb", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["aa", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "b", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], "+", 
        RowBox[{"a", " ", "bb", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}], "+", 
        RowBox[{"a", " ", "b", " ", "cc", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "+", 
        RowBox[{"aa", " ", "bb", " ", "cc", " ", 
         RowBox[{"(", 
          RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", "x", " ", "y", " ", "z"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", "bb", " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "cc"}], "+", 
        RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["aa", "2"]}], ")"}], " ", "x"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["bb", "2"]}], ")"}], " ", "y"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["c", "2"], "-", 
           SuperscriptBox["cc", "2"]}], ")"}], " ", "z"}]}], ")"}]}]}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "-", 
     SuperscriptBox["aa", "2"], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["bb", "2"], "-", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox["cc", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719259643048561*^9},ExpressionUUID->"bd6f76eb-e1b0-4b57-8cc1-\
eb49d6d57390"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["pToxxRule"], "Input",ExpressionUUID->"3e5bb8f4-f0cc-49e9-bde8-529bc7f2a5b0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     SuperscriptBox["xx", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
     SuperscriptBox["yy", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
     RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
     SuperscriptBox["zz", "2"]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     SqrtBox["xx"], " ", 
     SqrtBox["yy"], " ", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726324324591346*^9},ExpressionUUID->"dff96e23-d74d-49e0-96e7-\
501ea4eb1221"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "All", " ", "subplanes", " ", "have", " ", "this", " ", "generic", " ", 
    RowBox[{"form", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"pToxxRule", "/.", 
    RowBox[{"zz", "\[Rule]", "0"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.719259731468493*^9, 3.7192597448924723`*^9}, {
   3.719778709984523*^9, 3.719778741158551*^9}, 
   3.726324342575688*^9},ExpressionUUID->"e33525b7-be81-4fa6-9898-\
0a8634118d77"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"xx", "-", "yy"}], ")"}], "2"]}], ",", 
   RowBox[{"p3", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"xx", "+", "yy"}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719259734360539*^9, 3.719259745883944*^9}, 
   3.719778711793008*^9, 
   3.726324343963481*^9},ExpressionUUID->"96b07a95-3280-4079-a885-\
83dfa4b91c55"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theXplane", " ", "=", " ", 
  RowBox[{
   RowBox[{"thePRule", "/.", "xAplaneRule"}], "//", "Simplify"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7191073286063137`*^9, 3.719107357151422*^9}, {
  3.7192597118362226`*^9, 
  3.719259713228365*^9}},ExpressionUUID->"e8cccc7b-8fa2-4142-bcb2-\
25a564bfae82"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "z"}], ")"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "+", "z"}], ")"}], "2"]}], ")"}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "-", 
     SuperscriptBox["aa", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}]}]}]}]}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.719107357883046*^9, 3.7191629341786137`*^9, 
  3.7192499433349113`*^9, 3.7192597136361437`*^9, 3.7192800838684797`*^9, 
  3.71933265849376*^9, 3.7193496035587597`*^9, 3.719423517992673*^9, 
  3.7196731183283663`*^9, 3.719703145144169*^9, 3.719872978102592*^9, 
  3.7199446738126497`*^9, 3.725127498949348*^9, 3.725482053445366*^9, 
  3.725483983948797*^9, 3.726256763332571*^9, 
  3.729008627784341*^9},ExpressionUUID->"0d01425d-ac7a-4a01-a63a-\
9f7b1c5b63d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theYplane", " ", "=", " ", 
  RowBox[{
   RowBox[{"thePRule", "/.", "yAplaneRule"}], "//", "Simplify"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7191073286063137`*^9, 3.719107372332056*^9}, {
  3.719259718124514*^9, 
  3.7192597194362593`*^9}},ExpressionUUID->"ad5996cd-ec1a-4a59-bdeb-\
fe1ca0e64c67"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "z"}], ")"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "z"}], ")"}], "2"]}], ")"}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["bb", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}]}]}]}]}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.719107390974196*^9, 3.719162934285103*^9, 
  3.719249943356365*^9, 3.719259719951827*^9, 3.719280083922983*^9, 
  3.719332658514599*^9, 3.719349603721579*^9, 3.7194235180225163`*^9, 
  3.719673118363578*^9, 3.719703145188157*^9, 3.719872978172221*^9, 
  3.7199446738499203`*^9, 3.725127498993013*^9, 3.725482053490493*^9, 
  3.7254839839869556`*^9, 3.726256763376239*^9, 
  3.729008627811487*^9},ExpressionUUID->"ff9bcc3c-a410-4bdd-8a19-\
c385578b9f32"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theZplane", " ", "=", " ", 
  RowBox[{
   RowBox[{"thePRule", "/.", "zAplaneRule"}], "//", "Simplify"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7191073286063137`*^9, 3.719107379766632*^9}, {
  3.719259722636435*^9, 
  3.7192597238682423`*^9}},ExpressionUUID->"72ceb395-04de-4a79-9742-\
abbabf10a0ec"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}], "2"]}], ")"}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["cc", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}], ")"}]}]}]}]}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.7191073950523157`*^9, 3.719162934297719*^9, 
  3.719249943377707*^9, 3.7192597243657913`*^9, 3.719280083979568*^9, 
  3.7193326585359087`*^9, 3.719349603793322*^9, 3.719423518052774*^9, 
  3.719673118403798*^9, 3.719703145239871*^9, 3.719872978251162*^9, 
  3.7199446738789177`*^9, 3.725127499039774*^9, 3.725482053535742*^9, 
  3.725483984025408*^9, 3.726256763419252*^9, 
  3.729008627837674*^9},ExpressionUUID->"bc358d57-fd7c-42bf-9acc-\
103c4c9b4860"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Now set up the 4th order equations for the xE,yE,zE \
variables: Cannot solve these:",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.7182391925342283`*^9, 3.7182391954063883`*^9}, {
  3.718239780336259*^9, 3.7182397947198973`*^9}, {3.718240004181945*^9, 
  3.7182400529975863`*^9}, {3.718240732167471*^9, 3.718240769855392*^9}, {
  3.718565988962953*^9, 3.718565989595583*^9}, {3.7189955531868763`*^9, 
  3.718995560178279*^9}, {3.718995626393648*^9, 
  3.718995628113104*^9}},ExpressionUUID->"73849663-b678-4fed-b6c0-\
290cd0cb7fef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eqGenEig", "/.", "subForxx"}], "//", "FullSimplify"}]], "Input",Exp\
ressionUUID->"9c888607-062a-43dc-b9f0-f7d87ccf6d19"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"xE", "-", "yE", "-", "zE"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"xE", "+", "yE", "-", "zE"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"xE", "-", "yE", "+", "zE"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"xE", "+", "yE", "+", "zE"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["xE", "2"], "+", 
      SuperscriptBox["yE", "2"], "+", 
      SuperscriptBox["zE", "2"]}], ")"}]}], ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.718566000146871*^9, 
  3.718566040908252*^9}},ExpressionUUID->"1c388e7a-a2ab-4406-ac30-\
5e4387d0c6c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.718566044342078*^9, 
  3.718566046146266*^9}},ExpressionUUID->"0d4bec01-3056-4e53-aec4-\
362cca3dedbd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["xE", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["xE", "2"], " ", 
     SuperscriptBox["yE", "2"]}], "+", 
    SuperscriptBox["yE", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["xE", "2"], " ", 
     SuperscriptBox["zE", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["yE", "2"], " ", 
     SuperscriptBox["zE", "2"]}], "+", 
    SuperscriptBox["zE", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["xE", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["yE", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["zE", "2"]}]}], ",", "0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.718566046591813*^9},ExpressionUUID->"b69c66a3-5bba-43fd-999b-\
e6b8264d2fa2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["These are the 4th order equations:", "Subsubsection",
 CellChangeTimes->{{3.7185660703224163`*^9, 
  3.718566084297824*^9}},ExpressionUUID->"efad827f-7d0c-42cf-96a2-\
d6f7e31eb03c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqnsxyzE", " ", "=", "  ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["xE", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["xE", "2"], " ", 
        SuperscriptBox["yE", "2"]}], "+", 
       SuperscriptBox["yE", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["xE", "2"], " ", 
        SuperscriptBox["zE", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["yE", "2"], " ", 
        SuperscriptBox["zE", "2"]}], "+", 
       SuperscriptBox["zE", "4"]}], " ", "\[Equal]", "p4"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}], " ", "\[Equal]",
       " ", "p3"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["xE", "2"], "+", 
         SuperscriptBox["yE", "2"], "+", 
         SuperscriptBox["zE", "2"]}], ")"}]}], "\[Equal]", "p2"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.718239887083992*^9, 3.7182399901036453`*^9}, 
   3.718240783423279*^9},ExpressionUUID->"5bece78e-bf95-4b67-a43c-\
59fb34c2efbc"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["  the set of equations in {xE, yE, zE}  runs for 10 \
hours without completing the Simplify:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.718268135077319*^9, 3.7182682029245033`*^9}, {
  3.718566109874337*^9, 
  3.718566135309482*^9}},ExpressionUUID->"0c090c69-ad9f-4f9b-8da1-\
78d98ed7c3ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"solnxyzE", " ", "=", " ", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"eqnsxyzE", ",", 
       RowBox[{"{", 
        RowBox[{"xE", ",", "yE", ",", "zE"}], "}"}]}], "]"}], "//", 
     "Simplify"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.718239798534914*^9, 3.718239820493342*^9}, {
   3.718240921823401*^9, 3.718240959317499*^9}, 
   3.718566135309844*^9},ExpressionUUID->"b2e64cae-5449-4c76-b9b4-\
4c17aa065c10"],

Cell[BoxData[
 TemplateBox[{
  "Simplify","time",
   "\"Time spent on a transformation exceeded \
\\!\\(\\*RowBox[{\\\"300.`\\\"}]\\) seconds, and the transformation was \
aborted. Increasing the value of TimeConstraint option may improve the result \
of simplification.\"",2,209,257,27174301211940677204,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7182567515381727`*^9, 
  3.718566135309951*^9},ExpressionUUID->"73efb13b-e767-4142-8127-\
9b8b61eda145"],

Cell[BoxData["$Aborted"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.718268124319985*^9, 
  3.718566135310294*^9},ExpressionUUID->"3c909a88-0b1a-43b6-8c39-\
472f2d7d14b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqnsxyzEE", " ", "=", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["xE", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["xE", "2"], " ", 
          SuperscriptBox["yE", "2"]}], "+", 
         SuperscriptBox["yE", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["xE", "2"], " ", 
          SuperscriptBox["zE", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["yE", "2"], " ", 
          SuperscriptBox["zE", "2"]}], "+", 
         SuperscriptBox["zE", "4"]}], " ", "\[Equal]", "p4"}], ",", 
       RowBox[{
        RowBox[{"64", " ", 
         SuperscriptBox["xE", "2"], " ", 
         SuperscriptBox["yE", "2"], 
         SuperscriptBox["zE", "2"]}], " ", "\[Equal]", " ", 
        SuperscriptBox["p3", "2"]}]}], "}"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["zE", "2"], "->", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "p2"}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["xE", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["yE", "2"]}]}], ")"}]}]}], ",", 
       RowBox[{
        SuperscriptBox["zE", "4"], "->", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "p2"}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["xE", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["yE", "2"]}]}], ")"}], "2"]}]}]}], "}"}]}], "//", 
    "Expand"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.718239887083992*^9, 3.7182399901036453`*^9}, 
   3.718240783423279*^9, {3.7189911710910788`*^9, 3.7189912204121933`*^9}, {
   3.7189912942364902`*^9, 3.7189913092660933`*^9}, {3.718991487232423*^9, 
   3.7189915563221416`*^9}, {3.718991620912928*^9, 
   3.718991634680422*^9}},ExpressionUUID->"e5df0962-e5e3-42b0-afcb-\
c233037fcd45"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"8", " ", "p2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["xE", "2"], "+", 
        SuperscriptBox["yE", "2"]}], ")"}]}], "+", 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["xE", "4"], "+", 
        RowBox[{
         SuperscriptBox["xE", "2"], " ", 
         SuperscriptBox["yE", "2"]}], "+", 
        SuperscriptBox["yE", "4"]}], ")"}]}]}], "\[Equal]", 
    RowBox[{"4", " ", "p4"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "32"}], " ", 
     SuperscriptBox["xE", "2"], " ", 
     SuperscriptBox["yE", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"p2", "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["xE", "2"], "+", 
          SuperscriptBox["yE", "2"]}], ")"}]}]}], ")"}]}], "\[Equal]", 
    SuperscriptBox["p3", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.718991621732215*^9, 3.7189916456603327`*^9}, 
   3.71899538189249*^9},ExpressionUUID->"8e7f67af-4750-4dd7-b2f6-\
b953f37b139e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"solnxyzEE", " ", "=", " ", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"eqnsxyzEE", ",", 
       RowBox[{"{", 
        RowBox[{"xE", ",", "yE"}], "}"}]}], "]"}], "//", "Simplify"}]}], 
   "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.718995360243908*^9, 
  3.7189953746442947`*^9}},ExpressionUUID->"84d01e6b-3ac6-430c-846c-\
54b8b58ffa6b"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{
  3.718995467695551*^9},ExpressionUUID->"6bec49ee-6841-42df-97a0-\
5bd5ea42dde5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Share", "[", "]"}]], "Input",
 CellChangeTimes->{{3.718991651082439*^9, 
  3.718991652790535*^9}},ExpressionUUID->"c4d3de55-a35a-410a-8999-\
938fdbedb23b"],

Cell[BoxData["4596136"], "Output",
 CellChangeTimes->{3.718991676155052*^9, 
  3.718995545473328*^9},ExpressionUUID->"dbddbcf6-8227-48f6-aa8b-\
63788cac3a6f"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["SOLVE for xx,yy,zz HERE-->\n    Set up the 3rd order equations for \
the  ",
  FontWeight->"Bold"],
 StyleBox["traceless ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["xx ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    SuperscriptBox["xE", "2"]}], TraditionalForm]],
  FontWeight->"Bold",ExpressionUUID->"4d7f29f4-3471-4d3e-b0d3-13ff09b30b54"],
 StyleBox[",  yy= ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["yE", "2"], TraditionalForm]],
  FontWeight->"Bold",ExpressionUUID->"c4fd0b89-e5b4-436a-b3bd-fcf0c519cbdf"],
 StyleBox[",  zz= ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["zE", "2"], TraditionalForm]],
  FontWeight->"Bold",ExpressionUUID->"9ee1ef39-7acf-48f6-ab48-cbbce10aa702"],
 StyleBox["  variables:\n --- ",
  FontWeight->"Bold"],
 "Solves in 1 minute, but checking values  for  positivity, and  zz -> 0 as \
p3->0\n        introduces other issues:  ",
 StyleBox["To find the right formulas, need Resultant method...",
  FontSlant->"Italic"]
}], "Subsection",
 CellChangeTimes->{{3.7182391925342283`*^9, 3.7182391954063883`*^9}, {
  3.718239780336259*^9, 3.7182397947198973`*^9}, {3.718240004181945*^9, 
  3.7182400529975863`*^9}, {3.718240732167471*^9, 3.718240769855392*^9}, {
  3.718565988962953*^9, 3.718565989595583*^9}, {3.718566201609515*^9, 
  3.7185662346173964`*^9}, {3.718995632105082*^9, 3.718995732457835*^9}, {
  3.71925481160674*^9, 3.7192548141076107`*^9}, {3.7192603955757627`*^9, 
  3.719260421480336*^9}},ExpressionUUID->"dd850bf1-4353-47e6-a545-\
8aa768a93124"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eqGenEig", "/.", "subForxx"}], "//", "Simplify"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.719254751387559*^9, 3.719254765178213*^9}, {
  3.719254877085609*^9, 
  3.719254878475793*^9}},ExpressionUUID->"5c15008c-47b0-4b29-9af3-\
5674aba9caaf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["xx", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
    SuperscriptBox["yy", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
    RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
    SuperscriptBox["zz", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SqrtBox["xx"], " ", 
    SqrtBox["yy"], " ", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "xx"}], "-", 
    RowBox[{"2", " ", "yy"}], "-", 
    RowBox[{"2", " ", "zz"}]}], ",", "0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{{3.7192547598872623`*^9, 3.719254765772128*^9}, 
   3.719254878853874*^9},ExpressionUUID->"47d93f9d-d048-4aea-9857-\
3e3ce19bf459"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "These", " ", "are", " ", "our", " ", "fundamental", " ", "equations"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"eqnsxxyyzz", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["xE", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["xE", "2"], " ", 
         SuperscriptBox["yE", "2"]}], "+", 
        SuperscriptBox["yE", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["xE", "2"], " ", 
         SuperscriptBox["zE", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["yE", "2"], " ", 
         SuperscriptBox["zE", "2"]}], "+", 
        SuperscriptBox["zE", "4"]}], " ", "\[Equal]", "p4"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}], " ", 
       "\[Equal]", " ", "p3"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["xE", "2"], "+", 
          SuperscriptBox["yE", "2"], "+", 
          SuperscriptBox["zE", "2"]}], ")"}]}], "\[Equal]", "p2"}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xE", "\[Rule]", 
       RowBox[{"Sqrt", "[", "xx", "]"}]}], ",", 
      RowBox[{"yE", "\[Rule]", 
       RowBox[{"Sqrt", "[", "yy", "]"}]}], ",", 
      RowBox[{"zE", "\[Rule]", 
       RowBox[{"Sqrt", "[", "zz", "]"}]}]}], "}"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.718240848270179*^9, 3.718240882645453*^9}, {
  3.7192544424227057`*^9, 
  3.719254458117587*^9}},ExpressionUUID->"1ee72016-c005-400e-9051-\
0b8d40cdf808"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["xx", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
     SuperscriptBox["yy", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
     RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
     SuperscriptBox["zz", "2"]}], "\[Equal]", "p4"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     SqrtBox["xx"], " ", 
     SqrtBox["yy"], " ", 
     SqrtBox["zz"]}], "\[Equal]", "p3"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], "\[Equal]", "p2"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7185662539924107`*^9, 3.719254513900728*^9, 
  3.7192801770810957`*^9, 3.7193326585608187`*^9, 3.719349603887506*^9, 
  3.7194235180674677`*^9, 3.719673118412808*^9, 3.7197031452598658`*^9, 
  3.719872978272283*^9, 3.71994467389097*^9, 3.725127499088006*^9, 
  3.725482053552253*^9, 3.725483984063407*^9, 3.726256763465027*^9, 
  3.7290086278662777`*^9},ExpressionUUID->"23271b87-9a59-4f56-b866-\
b07923964543"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Initial", " ", "solution"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Timing", "[", 
    RowBox[{"solnxxyyzzInit", " ", "=", " ", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"eqnsxxyyzz", ",", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}]}], "]"}], "//", 
      "Simplify"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7182409772892*^9, 3.718240991567073*^9}, {
   3.718242410990157*^9, 3.718242413268931*^9}, 3.718242612270728*^9, {
   3.718995863977365*^9, 3.718995870516295*^9}, {3.719254480437655*^9, 
   3.719254495429886*^9}, {3.719254526950562*^9, 
   3.719254549577064*^9}},ExpressionUUID->"e58b21b0-a69c-4a89-9b7c-\
f3ac1289be4d"],

Cell[BoxData["20.908595`"], "Output",
 CellChangeTimes->{3.718995911922669*^9, 
  3.719254575382291*^9},ExpressionUUID->"b3864e7f-b781-4e8a-aa4f-\
23ffd1e9104b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "solnxxyyzzInit", "]"}]], "Input",
 CellChangeTimes->{{3.719254577303197*^9, 
  3.7192545820072536`*^9}},ExpressionUUID->"e98d3c28-d15a-4668-8a0b-\
28e99773aa99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{
  3.719254582370717*^9},ExpressionUUID->"b1100980-7e9f-4e67-a7d2-\
08f184a5cb94"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check that the solutions reproduce  p2,p3,p4", "Subsubsection",
 CellChangeTimes->{{3.719254970925577*^9, 
  3.719255008637953*^9}},ExpressionUUID->"7d9497f7-9a27-4833-9eb1-\
e0563accf5d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Check", " ", "p2"}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"xx", "+", "yy", "+", "zz"}], "/.", 
    RowBox[{"solnxxyyzzInit", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "6"}], "]"}], "]"}]}], "//", "Simplify"}]}]], "Input",\

 CellChangeTimes->{{3.719001728803692*^9, 3.7190017755145597`*^9}, {
  3.7192550171985188`*^9, 
  3.719255075775868*^9}},ExpressionUUID->"613056c4-3040-44d4-acd0-\
0c39bcc4f3b7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["p2", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["p2", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["p2", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["p2", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["p2", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["p2", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.71925507627845*^9},ExpressionUUID->"d3bdda0f-8fff-43d9-8309-01bd799547e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Check", " ", "p4"}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["xx", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
     SuperscriptBox["yy", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
     RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
     SuperscriptBox["zz", "2"]}], "/.", 
    RowBox[{"solnxxyyzzInit", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "6"}], "]"}], "]"}]}], "//", "Simplify"}]}]], "Input",\

 CellChangeTimes->{{3.719255087391706*^9, 
  3.719255096082312*^9}},ExpressionUUID->"c7f62065-5bb1-4299-97d0-\
4abbb6e40a35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"p4", ",", "p4", ",", "p4", ",", "p4", ",", "p4", ",", "p4"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7192551021574306`*^9},ExpressionUUID->"214767c9-3c9b-4a38-87ad-\
b50b8c6a3d41"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Check", " ", "p3"}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"xx", "  ", "yy", " ", "zz"}], "/.", 
    RowBox[{"solnxxyyzzInit", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "//", "Simplify"}]}]], "Input",\

 CellChangeTimes->{{3.719255087391706*^9, 3.719255137984508*^9}, 
   3.719255302932873*^9, 
   3.719255388917004*^9},ExpressionUUID->"53ed8ab8-4a5b-4a94-8b8b-\
9d88822a545c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["p3", "2"], "64"], ",", 
   FractionBox[
    SuperscriptBox["p3", "2"], "64"]}], "}"}]], "Output",
 CellChangeTimes->{{3.719255131178402*^9, 3.719255146531971*^9}, 
   3.719255306618218*^9},ExpressionUUID->"2c43ebb8-6b86-4e0f-a3ac-\
5a56304d4828"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Past", " ", "solns", " ", "1", " ", "and", " ", "2"}], ",", " ", 
    
    RowBox[{
     RowBox[{"p3", "  ", "needs", " ", "FULLSimplify"}], " ", "-", " ", 
     RowBox[{"this", " ", "may", " ", "be", " ", "important"}]}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"xx", " ", "yy", " ", "zz"}], "/.", 
    RowBox[{"solnxxyyzzInit", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.719255319171688*^9, 
  3.7192553978609858`*^9}},ExpressionUUID->"ab9b2a7b-de76-4969-b8db-\
e036f5d2ea95"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["p3", "2"], "64"]], "Output",
 CellChangeTimes->{{3.719255321191525*^9, 
  3.719255332294751*^9}},ExpressionUUID->"0c55e234-40aa-40bd-97e7-\
3d6446a4dcf3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Check the properties of the six sets of  {xx,yy,zz} solutions, and pick one:
   The eigenvalues seem to be in rank order for solution [[1]], for all \
randomPn\[CloseCurlyQuote]s.
        \
\>", "Subsubsection",
 CellChangeTimes->{{3.719254605655403*^9, 3.719254628215953*^9}, {
  3.719256088656201*^9, 
  3.719256125664796*^9}},ExpressionUUID->"1f0219ed-ca91-45e3-b78a-\
fa92f01c9a3c"],

Cell[CellGroupData[{

Cell[BoxData["eigValListxx"], "Input",
 CellChangeTimes->{{3.719256215028391*^9, 
  3.719256216356798*^9}},ExpressionUUID->"2688636b-d65b-4f6d-80cf-\
2898756af5d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SqrtBox["xx"], "+", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    SqrtBox["xx"], "-", 
    SqrtBox["yy"], "-", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "+", 
    SqrtBox["yy"], "-", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "-", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.71925621679782*^9},ExpressionUUID->"63a5a5a5-0366-4b57-ae4b-b4b7819b1676"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"ByteCount", ",", "solnxxyyzzInit", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.718566621440036*^9, 3.718566631973278*^9}, 
   3.7189958794634733`*^9, 
   3.7192549288791523`*^9},ExpressionUUID->"af88f397-d775-43e2-bd9f-\
043143230d16"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4440", ",", "19304", ",", "21432"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4440", ",", "19544", ",", "21432"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5016", ",", "22392", ",", "28568"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5016", ",", "22320", ",", "28568"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5048", ",", "22392", ",", "28568"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5048", ",", "22320", ",", "28568"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7189959215153646`*^9, 
  3.719254930553783*^9},ExpressionUUID->"d3f94273-4144-4a38-95d6-\
faee21160032"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eigValListxx", "/.", "solnxxyyzzInit"}], "/.", 
   RowBox[{"randomPn", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"#", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "8"}]]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{
  3.71925608176045*^9},ExpressionUUID->"019d4e75-1d8e-46fe-8e62-a2866ce95c26"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.804565560053397`", ",", "0.302877961193073`", ",", 
     RowBox[{"-", "0.7887164110081375`"}], ",", 
     RowBox[{"-", "1.3187271102383324`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.8045655600533972`", ",", "0.30287796119307275`", ",", 
     RowBox[{"-", "1.3187271102383322`"}], ",", 
     RowBox[{"-", "0.7887164110081377`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.8045655600533972`", ",", 
     RowBox[{"-", "1.3187271102383318`"}], ",", "0.30287796119307286`", ",", 
     RowBox[{"-", "0.7887164110081382`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.804565560053397`", ",", 
     RowBox[{"-", "1.3187271102383318`"}], ",", 
     RowBox[{"-", "0.7887164110081382`"}], ",", "0.302877961193073`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"1.8045655600533967`", ",", 
     RowBox[{"-", "0.7887164110081376`"}], ",", "0.3028779611930731`", ",", 
     RowBox[{"-", "1.3187271102383322`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.8045655600533963`", ",", 
     RowBox[{"-", "0.788716411008137`"}], ",", 
     RowBox[{"-", "1.318727110238333`"}], ",", "0.30287796119307364`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7192560823426647`*^9},ExpressionUUID->"a985ae01-746a-4c34-9bb4-\
9595dfa01c2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eigValListxx", "/.", "solnxxyyzzInit"}], "/.", 
   RowBox[{"randomPn", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "5"}], "]"}], "]"}]}], "//", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"#", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "8"}]]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.719255819229154*^9, 3.7192559162855864`*^9}, {
  3.719256041936345*^9, 
  3.719256044255817*^9}},ExpressionUUID->"e70d44a5-317b-40d3-9327-\
317d08769a32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.804565560053397`", ",", "0.302877961193073`", ",", 
       RowBox[{"-", "0.7887164110081375`"}], ",", 
       RowBox[{"-", "1.3187271102383324`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.8045655600533972`", ",", "0.30287796119307275`", ",", 
       RowBox[{"-", "1.3187271102383322`"}], ",", 
       RowBox[{"-", "0.7887164110081377`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.8045655600533972`", ",", 
       RowBox[{"-", "1.3187271102383318`"}], ",", "0.30287796119307286`", ",", 
       RowBox[{"-", "0.7887164110081382`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.804565560053397`", ",", 
       RowBox[{"-", "1.3187271102383318`"}], ",", 
       RowBox[{"-", "0.7887164110081382`"}], ",", "0.302877961193073`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.8045655600533967`", ",", 
       RowBox[{"-", "0.7887164110081376`"}], ",", "0.3028779611930731`", ",", 
       
       RowBox[{"-", "1.3187271102383322`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.8045655600533963`", ",", 
       RowBox[{"-", "0.788716411008137`"}], ",", 
       RowBox[{"-", "1.318727110238333`"}], ",", "0.30287796119307364`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.1519602452686026`", ",", "0.40554813199876516`", ",", 
       RowBox[{"-", "0.9178941916865492`"}], ",", 
       RowBox[{"-", "1.6396141855808186`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1519602452686026`", ",", "0.40554813199876516`", ",", 
       RowBox[{"-", "1.6396141855808186`"}], ",", 
       RowBox[{"-", "0.9178941916865492`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1519602452686035`", ",", 
       RowBox[{"-", "1.6396141855808175`"}], ",", "0.40554813199876416`", ",", 
       RowBox[{"-", "0.91789419168655`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1519602452686035`", ",", 
       RowBox[{"-", "1.6396141855808177`"}], ",", 
       RowBox[{"-", "0.9178941916865505`"}], ",", "0.40554813199876494`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1519602452686035`", ",", 
       RowBox[{"-", "0.9178941916865506`"}], ",", "0.40554813199876394`", ",", 
       RowBox[{"-", "1.6396141855808168`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1519602452686035`", ",", 
       RowBox[{"-", "0.9178941916865506`"}], ",", 
       RowBox[{"-", "1.6396141855808177`"}], ",", "0.4055481319987648`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.061626714071008`", ",", 
       RowBox[{"-", "0.09484844635147005`"}], ",", 
       RowBox[{"-", "0.5399755934895973`"}], ",", 
       RowBox[{"-", "1.4268026742299404`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.0616267140710076`", ",", 
       RowBox[{"-", "0.09484844635147005`"}], ",", 
       RowBox[{"-", "1.4268026742299402`"}], ",", 
       RowBox[{"-", "0.5399755934895974`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.061626714071008`", ",", 
       RowBox[{"-", "1.4268026742299402`"}], ",", 
       RowBox[{"-", "0.09484844635147038`"}], ",", 
       RowBox[{"-", "0.5399755934895973`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.061626714071008`", ",", 
       RowBox[{"-", "1.4268026742299404`"}], ",", 
       RowBox[{"-", "0.5399755934895978`"}], ",", 
       RowBox[{"-", "0.09484844635147005`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.061626714071008`", ",", 
       RowBox[{"-", "0.5399755934895976`"}], ",", 
       RowBox[{"-", "0.09484844635147044`"}], ",", 
       RowBox[{"-", "1.42680267422994`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.061626714071008`", ",", 
       RowBox[{"-", "0.5399755934895977`"}], ",", 
       RowBox[{"-", "1.4268026742299407`"}], ",", 
       RowBox[{"-", "0.09484844635147005`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.5339267228214584`", ",", "0.3038211970013387`", ",", 
       RowBox[{"-", "0.6862409822511889`"}], ",", 
       RowBox[{"-", "1.1515069375716083`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.5339267228214584`", ",", "0.3038211970013387`", ",", 
       RowBox[{"-", "1.1515069375716083`"}], ",", 
       RowBox[{"-", "0.6862409822511889`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.5339267228214586`", ",", 
       RowBox[{"-", "1.1515069375716083`"}], ",", "0.30382119700133864`", ",", 
       RowBox[{"-", "0.6862409822511888`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.5339267228214584`", ",", 
       RowBox[{"-", "1.1515069375716083`"}], ",", 
       RowBox[{"-", "0.6862409822511893`"}], ",", "0.30382119700133925`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.5339267228214586`", ",", 
       RowBox[{"-", "0.6862409822511889`"}], ",", "0.3038211970013386`", ",", 
       
       RowBox[{"-", "1.151506937571608`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.5339267228214584`", ",", 
       RowBox[{"-", "0.6862409822511888`"}], ",", 
       RowBox[{"-", "1.151506937571609`"}], ",", "0.30382119700133936`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.0940732463522584`", ",", "0.09595444186667001`", ",", 
       RowBox[{"-", "0.895146733992614`"}], ",", 
       RowBox[{"-", "1.2948809542263142`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.0940732463522584`", ",", "0.09595444186667001`", ",", 
       RowBox[{"-", "1.2948809542263144`"}], ",", 
       RowBox[{"-", "0.8951467339926139`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.0940732463522584`", ",", 
       RowBox[{"-", "1.2948809542263144`"}], ",", "0.0959544418666699`", ",", 
       
       RowBox[{"-", "0.8951467339926139`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.0940732463522584`", ",", 
       RowBox[{"-", "1.2948809542263144`"}], ",", 
       RowBox[{"-", "0.8951467339926146`"}], ",", "0.09595444186667057`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.0940732463522584`", ",", 
       RowBox[{"-", "0.895146733992614`"}], ",", "0.09595444186667001`", ",", 
       
       RowBox[{"-", "1.2948809542263142`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.0940732463522584`", ",", 
       RowBox[{"-", "0.8951467339926142`"}], ",", 
       RowBox[{"-", "1.2948809542263149`"}], ",", "0.09595444186667068`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719255861213222*^9, 3.7192559167936487`*^9}, 
   3.7192560451165133`*^9},ExpressionUUID->"cee175df-4aa7-4566-a253-\
f1bfcc0876bb"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Subplanes:  first look at xx,yy,zz,   soln[[1]] and [[5]] have zz -> 0
      Next check eigValListxx\
\>", "Subsubsection",
 CellChangeTimes->{{3.719256190401853*^9, 3.719256211570108*^9}, {
  3.719256372100978*^9, 
  3.719256403877315*^9}},ExpressionUUID->"7163b380-a495-4d22-890e-\
dbdcc8b0db38"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}], "/.", 
   RowBox[{"(", 
    RowBox[{"solnxxyyzzInit", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"randomPnX", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"randomPnY", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"randomPnZ", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ")"}]}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.719256238804119*^9, 3.7192562953158607`*^9}, {
  3.719256338485818*^9, 
  3.719256353813304*^9}},ExpressionUUID->"acb057af-5495-49e6-ba7a-\
08c29804be99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3453638604040803`", ",", "0.029996120878100607`", ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3453638604040803`", ",", "0", ",", "0.029996120878100604`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.3453638604040803`", ",", "0.02999612087810084`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.0299961208781008`", ",", "0.34536386040408024`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.029996120878100822`", ",", "0.3453638604040804`", ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.029996120878100822`", ",", "0", ",", "0.34536386040408035`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.7054454056310849`", ",", "0.13077663899908898`", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7054454056310849`", ",", "0", ",", "0.13077663899908895`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.705445405631085`", ",", "0.13077663899908887`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.13077663899908876`", ",", "0.705445405631085`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.13077663899908887`", ",", "0.7054454056310852`", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.13077663899908887`", ",", "0", ",", "0.7054454056310853`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9655945497144418`", ",", "0.013420858411521436`", ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9655945497144418`", ",", "0", ",", "0.013420858411521443`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9655945497144419`", ",", "0.013420858411526643`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.013420858411526404`", ",", "0.9655945497144417`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.013420858411526626`", ",", "0.9655945497144417`", ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.013420858411526626`", ",", "0", ",", "0.9655945497144415`"}],
       "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719256275470311*^9, 3.719256295899412*^9}, 
   3.71925635429611*^9},ExpressionUUID->"92a1fc51-8fae-450b-bdfb-\
513551df0235"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eigValListxx", "/.", 
   RowBox[{"(", 
    RowBox[{"solnxxyyzzInit", "/.", 
     RowBox[{"randomPnX", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "//", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"#", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "8"}]]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{
  3.719256331300699*^9, {3.719256414231591*^9, 
   3.719256430072846*^9}},ExpressionUUID->"ff670a31-12a2-458b-8973-\
a00d2bcd12f7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.7608705604026812`", ",", "0.4144827658853424`", ",", 
     RowBox[{"-", "0.4144827957336582`"}], ",", 
     RowBox[{"-", "0.7608705305543654`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7608705608585674`", ",", "0.41448276542945617`", ",", 
     RowBox[{"-", "0.7608705300984792`"}], ",", 
     RowBox[{"-", "0.4144827961895444`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7608705509001129`", ",", 
     RowBox[{"-", "0.760870540056935`"}], ",", "0.4144827753879107`", ",", 
     RowBox[{"-", "0.4144827862310886`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7608705509001126`", ",", 
     RowBox[{"-", "0.7608705400569348`"}], ",", 
     RowBox[{"-", "0.4144827862310886`"}], ",", "0.4144827753879108`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.760870548967351`", ",", 
     RowBox[{"-", "0.41448278429832663`"}], ",", "0.41448277732067296`", ",", 
     
     RowBox[{"-", "0.7608705419896972`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7608705467583874`", ",", 
     RowBox[{"-", "0.4144827820893632`"}], ",", 
     RowBox[{"-", "0.7608705441986604`"}], ",", "0.4144827795296362`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719256332751511*^9, {3.719256422613469*^9, 
   3.719256431268982*^9}},ExpressionUUID->"aa0b64d0-0fcd-4b9d-89cc-\
adcdf7a2c3da"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p2", ",", "p3", ",", "p4"}], "}"}], "/.", "thePRule"}], "/.", 
   "xAplaneRule"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.719256566537932*^9, 
  3.719256610634975*^9}},ExpressionUUID->"248389d3-e6de-4206-9ac0-\
cf1365cb3ec4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "-", 
    SuperscriptBox["aa", "2"], "-", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], ")"}]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["aa", "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "-", "z"}], ")"}], "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "+", "z"}], ")"}], "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719256585779991*^9, 
  3.7192566114971867`*^9}},ExpressionUUID->"76f2b9db-67c3-4a19-85ba-\
767289ec43da"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Now define and cache the  \[OpenCurlyQuote]init\
\[CloseCurlyQuote] solutions  and their subplane reductions",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.719256661865624*^9, 
  3.7192566996101933`*^9}},ExpressionUUID->"d2d29c37-8d2b-4f2f-bf58-\
75e086cd0fba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", " ", 
   RowBox[{"mysolnInit", "=", 
    RowBox[{
     RowBox[{"solnxxyyzzInit", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "  ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "this", " ", "has", " ", "rank", " ", "ordered", " ", "eigenvalues", 
        " ", "and", " ", "zz", 
        RowBox[{"(", 
         RowBox[{"p3", "=", "0"}], ")"}]}], "\[Rule]", "0"}], " ", "*)"}], "//",
      "FullSimplify"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7192567076598377`*^9, 3.7192567429232197`*^9}, {
  3.719256774124448*^9, 3.719256818700547*^9}, {3.719257115026622*^9, 
  3.7192571321140823`*^9}},ExpressionUUID->"42bb45a5-cd3d-43a7-aa90-\
0112b32d5291"],

Cell[BoxData["1.028721`"], "Output",
 CellChangeTimes->{
  3.719256748672303*^9, 3.7192568664018383`*^9, {3.719257123331642*^9, 
   3.719257136394847*^9}},ExpressionUUID->"5ae2c121-5c94-419c-9f5b-\
88a55d557d8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cache mysolnInit = s0lnxxyyzzInit[[1]]", "Subsubsection",
 CellChangeTimes->{{3.719349867128644*^9, 
  3.7193498878402033`*^9}},ExpressionUUID->"784594f6-c3ee-4af0-abed-\
02cbfe789338"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Cache the initial values:  xx (p2,p3,p4), \
yy(p2,p3,p4), zz(p2,p3,p4) rules are here:",
 FontSize->24,
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.71900074735542*^9, 3.7190007658832483`*^9}, {
  3.71900110807262*^9, 
  3.719001148439435*^9}},ExpressionUUID->"9b982e08-57c1-4fa9-a175-\
28bf181a47dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mysolnInit", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xx", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "3"], "-", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]], "+", 
       RowBox[{
        FractionBox["1", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "3"], "-", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}]}], ",", 
     RowBox[{"yy", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], 
        RowBox[{"24", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "3"], "-", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]], "-", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "3"], "-", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], "+", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"16", " ", 
          SqrtBox["3"]}]], 
        RowBox[{"(", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               SuperscriptBox["p2", "4"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
              RowBox[{"72", " ", 
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", "p2", " ", "p4", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "96"}], " ", "p4"}], "+", 
                 RowBox[{
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                   RowBox[{"2", "/", "3"}]]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", " ", 
                  SuperscriptBox["p4", "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["2", 
                   RowBox[{"2", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "9"}], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                   RowBox[{"1", "/", "3"}]]}], "-", 
                 RowBox[{"8", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", "p4", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                   RowBox[{"2", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], ")"}]}], 
         ")"}]}]}]}], ",", 
     RowBox[{"zz", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]], " ", 
          SuperscriptBox["p2", "2"]}], "-", 
         RowBox[{"24", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]], " ", "p4"}], "-", 
         RowBox[{"8", " ", "p2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
            RowBox[{"6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"2", "/", "3"}]], "-", 
         RowBox[{
          SqrtBox["3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]], " ", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["1", 
              RowBox[{
               SuperscriptBox["p2", "2"], "+", 
               RowBox[{"12", " ", "p4"}]}]], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                SuperscriptBox["p2", "4"]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"72", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", "p2", " ", "p4", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "9"}], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"24", " ", "p4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"48", " ", "p4"}], "-", 
                  RowBox[{
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                    RowBox[{"2", "/", "3"}]]}]}], ")"}]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "96"}], " ", "p4"}], "+", 
                  RowBox[{
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                    RowBox[{"2", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], 
            ")"}]}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"48", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.719000712899892*^9, 3.7190007168392353`*^9}, {
  3.719001092080872*^9, 
  3.719001108073205*^9}},ExpressionUUID->"b59aed32-ea1c-4927-90f5-\
0ee79a21dcb6"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "Subsubsection",ExpressionUUID->"3b12fdc1-0f29-4d8b-b4a1-1e5219fcd92d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mysolnInit", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7192571518901463`*^9, 
  3.719257153346073*^9}},ExpressionUUID->"0f9b4e20-1c29-43cd-890a-\
b6e010d52007"],

Cell[BoxData[
 RowBox[{"xx", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["p2", "6"]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], 
    RowBox[{"12", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "3"], "-", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]], "+", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "3"], "-", 
       RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["p3", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"81", " ", 
             SuperscriptBox["p3", "4"]}], "-", 
            RowBox[{"48", " ", "p2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "3"], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["p2", "2"], " ", 
             SuperscriptBox["p4", "2"]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]}]}]], "Output",
 CellChangeTimes->{
  3.719349917086513*^9},ExpressionUUID->"6136a5eb-58d9-4c7e-a82f-\
4113be5da763"]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"xx", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "-", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "3"], "-", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}]}]}]], "Input",
 CellChangeTimes->{{3.719349914975176*^9, 
  3.719349914983964*^9}},ExpressionUUID->"89fabb60-3145-4d99-9d77-\
6c7417d38ce6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Cached xxarg0,yyargo,zzarg0 chosen to be rank-ordered and zz->0 with p3\
\>", "Subsubsection",
 CellChangeTimes->{{3.719256988831106*^9, 3.71925701694363*^9}, 
   3.71925755688859*^9},ExpressionUUID->"76f099e7-1c83-44de-853b-\
e29e3b026429"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"xxarg0", ",", "yyarg0", ",", "zzarg0"}], "}"}], "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}], "/.", 
   "mysolnInit"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7192568751833067`*^9, 3.7192568999035187`*^9}, 
   3.719256960479027*^9, {3.719257202963334*^9, 
   3.719257203810914*^9}},ExpressionUUID->"c2caf62d-62eb-455d-9b31-\
4aab30aa4f19"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xxarg0", ",", "yyarg0", ",", "zzarg0"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["p2", "6"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "3"], "-", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "-", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["p2", "6"]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"24", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "3"], "-", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "24"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "-", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"16", " ", 
         SqrtBox["3"]}]], 
       RowBox[{"(", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{
             SuperscriptBox["p2", "2"], "+", 
             RowBox[{"12", " ", "p4"}]}]], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", 
              SuperscriptBox["p2", "4"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"2", "/", "3"}]], " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], "+", 
             RowBox[{"72", " ", 
              SuperscriptBox["2", 
               RowBox[{"2", "/", "3"}]], " ", "p2", " ", "p4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "96"}], " ", "p4"}], "+", 
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                  RowBox[{"2", "/", "3"}]]}]}], ")"}]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"384", " ", 
                 SuperscriptBox["p4", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "9"}], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "-", 
                RowBox[{"8", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", "p4", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                  RowBox[{"2", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], ")"}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["2", 
          RowBox[{"1", "/", "3"}]], " ", 
         SuperscriptBox["p2", "2"]}], "-", 
        RowBox[{"24", " ", 
         SuperscriptBox["2", 
          RowBox[{"1", "/", "3"}]], " ", "p4"}], "-", 
        RowBox[{"8", " ", "p2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["p2", "3"]}], "-", 
           RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"2", "/", "3"}]], "-", 
        RowBox[{
         SqrtBox["3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]], " ", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               SuperscriptBox["p2", "4"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
              RowBox[{"72", " ", 
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", "p2", " ", "p4", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "9"}], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                   RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                   RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                   RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
              RowBox[{"24", " ", "p4", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"48", " ", "p4"}], "-", 
                 RowBox[{
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                   RowBox[{"2", "/", "3"}]]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "96"}], " ", "p4"}], "+", 
                 RowBox[{
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                   RowBox[{"2", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], 
           ")"}]}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"48", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "3"]}], "-", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}]}]}], "}"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.7192569235357924`*^9, 
  3.7192569604793158`*^9}},ExpressionUUID->"68b3a474-6e32-4651-a343-\
5bf1992e85df"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"mysolnInit", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xx", "\[Rule]", " ", "xxarg0"}], ",", 
     RowBox[{"yy", "\[Rule]", " ", "yyarg0"}], ",", 
     RowBox[{"zz", "\[Rule]", " ", "zzarg0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.719280558894816*^9, 
  3.7192805998371468`*^9}},ExpressionUUID->"93a10120-ec54-4564-ba72-\
9fec6c434f48"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mysolnInit", "[", 
  RowBox[{"[", "3", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.719280625764512*^9, 
  3.719280648622827*^9}},ExpressionUUID->"6e9f92a7-38e1-4150-8a48-\
9331171b1ad9"],

Cell[BoxData[
 RowBox[{"zz", "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["2", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["p2", "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["2", 
       RowBox[{"1", "/", "3"}]], " ", "p4"}], "-", 
     RowBox[{"8", " ", "p2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"2", "/", "3"}]], "-", 
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           RowBox[{"12", " ", "p4"}]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox["p2", "4"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"72", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", "p2", " ", "p4", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"24", " ", "p4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"48", " ", "p4"}], "-", 
              RowBox[{
               SuperscriptBox["2", 
                RowBox[{"1", "/", "3"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                RowBox[{"2", "/", "3"}]]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "96"}], " ", "p4"}], "+", 
              RowBox[{
               SuperscriptBox["2", 
                RowBox[{"1", "/", "3"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                RowBox[{"2", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], ")"}]}]}]}],
     ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"48", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.719280627178589*^9, 
  3.7192806493083563`*^9}},ExpressionUUID->"5004a6d6-b546-44fd-bfbb-\
b493aa989705"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fxx0", "[", 
   RowBox[{"p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", " ", 
  RowBox[{"Evaluate", "[", "xxarg0", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.71813370853843*^9, 3.7181337582882767`*^9}, 
   3.7181340234392633`*^9, {3.719000402719408*^9, 3.71900044091875*^9}, 
   3.7190011654313726`*^9, {3.7192572130113*^9, 
   3.719257217523027*^9}},ExpressionUUID->"cac4a47f-9b8b-4f1a-b36d-\
1db6b5206ad1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fyy0", "[", 
   RowBox[{"p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", " ", 
  RowBox[{"Evaluate", "[", "yyarg0", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.71813370853843*^9, 3.7181337582882767`*^9}, {
   3.71813398215097*^9, 3.71813398568682*^9}, 3.718134025855446*^9, {
   3.719000471570982*^9, 3.719000474437635*^9}, 3.7190011692399178`*^9, 
   3.719257225205813*^9},ExpressionUUID->"8df2d2e3-1d0b-4dd0-b547-\
5643c01a4291"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fzz0", "[", 
   RowBox[{"p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", " ", 
  RowBox[{"Evaluate", "[", "zzarg0", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.71813370853843*^9, 3.7181337582882767`*^9}, {
   3.71813399030217*^9, 3.7181339941257668`*^9}, 3.718134028255208*^9, {
   3.719000479082539*^9, 3.719000482797925*^9}, 3.719001179719289*^9, 
   3.719257229493621*^9},ExpressionUUID->"866af361-114a-4ece-b1ca-\
e8eb66a8dbab"],

Cell[CellGroupData[{

Cell[BoxData["eqQuadratic"], "Input",
 CellChangeTimes->{{3.7192573462305517`*^9, 
  3.71925736039097*^9}},ExpressionUUID->"239302ae-9676-411b-8ce5-\
e33bbed83ad0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["xx", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
    SuperscriptBox["yy", "2"], "-", 
    RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
    RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
    SuperscriptBox["zz", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SqrtBox["xx"], " ", 
    SqrtBox["yy"], " ", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7192573611413*^9},ExpressionUUID->"64f0ec53-8e67-40d2-af00-1fcb6c460f36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Checks", " ", ":", " ", 
    RowBox[{"pn", " ", "OK"}]}], "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "+", "yy", "+", "zz"}], ",", 
      RowBox[{"xx", " ", "yy", " ", "zz"}], ",", 
      RowBox[{
       SuperscriptBox["xx", "2"], "-", 
       RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
       SuperscriptBox["yy", "2"], "-", 
       RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
       RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
       SuperscriptBox["zz", "2"]}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "\[Rule]", 
       RowBox[{"fxx0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], ",", " ", 
      RowBox[{"yy", "\[Rule]", 
       RowBox[{"fyy0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], " ", ",", " ", 
      RowBox[{"zz", "\[Rule]", 
       RowBox[{"fzz0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}]}], " ", "}"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.719001728803692*^9, 3.7190017755145597`*^9}, {
  3.719257248979611*^9, 3.7192573303897943`*^9}, {3.719257376712579*^9, 
  3.7192574191429567`*^9}, {3.719257523288542*^9, 
  3.719257525576138*^9}},ExpressionUUID->"3b2e6a2b-1323-4ed6-82f7-\
72f937f4c04b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["p2", "2"]}], ",", 
   FractionBox[
    SuperscriptBox["p3", "2"], "64"], ",", "p4"}], "}"}]], "Output",
 CellChangeTimes->{{3.71925730024693*^9, 3.719257316028842*^9}, {
  3.719257408546028*^9, 
  3.7192574243533497`*^9}},ExpressionUUID->"7a7d2c23-8108-4771-9920-\
ff2285302c45"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Checks", ":", " ", 
    RowBox[{"rank", "-", 
     RowBox[{"order", " ", "OK"}]}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"eigValListxx", "/.", 
    RowBox[{"(", 
     RowBox[{"mysolnInit", "/.", " ", 
      RowBox[{"randomPn", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ")"}]}], "//", 
   "Chop"}]}]], "Input",
 CellChangeTimes->{{3.719257432968273*^9, 
  3.7192575377847433`*^9}},ExpressionUUID->"e018a5ac-4fe5-4949-9a08-\
4245300fc910"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.804565560053397`", ",", "0.3028779611930729`", ",", 
     RowBox[{"-", "0.7887164110081377`"}], ",", 
     RowBox[{"-", "1.318727110238332`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.1519602452686035`", ",", "0.4055481319987643`", ",", 
     RowBox[{"-", "0.9178941916865506`"}], ",", 
     RowBox[{"-", "1.6396141855808173`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.061626714071008`", ",", 
     RowBox[{"-", "0.09484844635147044`"}], ",", 
     RowBox[{"-", "0.5399755934895978`"}], ",", 
     RowBox[{"-", "1.42680267422994`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5339267228214581`", ",", "0.3038211970013388`", ",", 
     RowBox[{"-", "0.6862409822511886`"}], ",", 
     RowBox[{"-", "1.1515069375716085`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719257461921234*^9, 
  3.719257512096221*^9}},ExpressionUUID->"cc39b555-ce0c-4e30-abbf-\
2f407af8cc34"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Checks", ":", " ", "p3"}], " ", "=", 
     RowBox[{"0", " ", "OK", " ", "for", " ", "xx"}]}], ",", "yy", ",", 
    RowBox[{"zz", "\[Rule]", 
     RowBox[{"0", " ", "and", " ", "eigValList"}]}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}], ",", "eigValListxx"}], 
     "}"}], "/.", 
    RowBox[{"(", 
     RowBox[{"mysolnInit", "/.", " ", 
      RowBox[{"randomPnX", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ")"}]}], "//", 
   RowBox[{
    RowBox[{"Chop", "[", 
     RowBox[{"#", ",", 
      SuperscriptBox["10", 
       RowBox[{"(", 
        RowBox[{"-", "7"}], ")"}]]}], "]"}], "&"}]}]}]], "Input",
 CellChangeTimes->{{3.719257578313323*^9, 
  3.7192576641561403`*^9}},ExpressionUUID->"4f0f5b80-4e31-44a0-89bd-\
68fef8ecbf37"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3453638604040803`", ",", "0.029996120878100933`", ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7608705470040372`", ",", "0.41448277928398636`", ",", 
       RowBox[{"-", "0.41448278233501246`"}], ",", 
       RowBox[{"-", "0.7608705439530111`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.8189314288615321`", ",", "0.022692410854861372`", ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0555883273478728`", ",", "0.7543082761756901`", ",", 
       RowBox[{"-", "0.7543083190176725`"}], ",", 
       RowBox[{"-", "1.0555882845058904`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.5652178723091882`", ",", "0.1031709341670819`", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0730120586034095`", ",", "0.43060740430492644`", ",", 
       RowBox[{"-", "0.4306074067924753`"}], ",", 
       RowBox[{"-", "1.0730120561158607`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.5398295528115676`", ",", "0.005172872072511173`", ",", "0"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8066536204229684`", ",", "0.6628082576964576`", ",", 
       RowBox[{"-", "0.6628082580019132`"}], ",", 
       RowBox[{"-", "0.8066536201175127`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.719257642909336*^9, 
  3.719257664649308*^9}},ExpressionUUID->"14c99e67-b558-414a-8661-\
3d9efa3acbe9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Attempt a ",
 StyleBox["regular",
  FontWeight->"Bold"],
 "  reduction of zz:\n_________________________________"
}], "Subsubsection",
 CellChangeTimes->{{3.719280714250339*^9, 
  3.719280733706416*^9}},ExpressionUUID->"1b543b32-aa42-49de-b96d-\
5fc4ef82976c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqz0", "=", 
  RowBox[{"zzarg0", "-", "ttz"}]}]], "Input",
 CellChangeTimes->{{3.719280739617116*^9, 
  3.719280789530169*^9}},ExpressionUUID->"64b370c8-e2da-4336-9362-\
1edbb6f1c02d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["2", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["p2", "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["2", 
       RowBox[{"1", "/", "3"}]], " ", "p4"}], "-", 
     RowBox[{"8", " ", "p2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"2", "/", "3"}]], "-", 
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           RowBox[{"12", " ", "p4"}]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox["p2", "4"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"72", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", "p2", " ", "p4", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"24", " ", "p4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"48", " ", "p4"}], "-", 
              RowBox[{
               SuperscriptBox["2", 
                RowBox[{"1", "/", "3"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                RowBox[{"2", "/", "3"}]]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "96"}], " ", "p4"}], "+", 
              RowBox[{
               SuperscriptBox["2", 
                RowBox[{"1", "/", "3"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                RowBox[{"2", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], ")"}]}]}]}],
     ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"48", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], ")"}]}], "-", "ttz"}]], "Output",
 CellChangeTimes->{{3.719280780455061*^9, 
  3.71928079116905*^9}},ExpressionUUID->"47cf586c-c977-4302-a68b-\
d28f3ab2cdd1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqsForRules", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        RowBox[{"12", " ", 
         SuperscriptBox["p2", "3"], " ", 
         SuperscriptBox["p3", "2"]}], "+", 
        RowBox[{"81", " ", 
         SuperscriptBox["p3", "4"]}], "-", 
        RowBox[{"48", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "3"], "+", 
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
        RowBox[{"384", " ", 
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["p4", "2"]}], "-", 
        RowBox[{"768", " ", 
         SuperscriptBox["p4", "3"]}]}]], "\[Rule]", "qq1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"81", " ", 
             SuperscriptBox["p3", "4"]}], "-", 
            RowBox[{"48", " ", "p2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "3"], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["p2", "2"], " ", 
             SuperscriptBox["p4", "2"]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], "p_"], "\[Rule]", 
      SuperscriptBox["qq2", "p"]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c_", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "3"]}], "-", 
          RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], " ", "\[Rule]", 
      RowBox[{"c", " ", "qq2"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.719281043058256*^9, 3.7192811298562517`*^9}, {
  3.719281268647719*^9, 
  3.719281359844866*^9}},ExpressionUUID->"24f4d9c8-e216-4e35-ab8b-\
f62e38e8fe50"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"morerules1", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]], "\[Rule]", " ", "qq2"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", "p2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], "->", " ", 
     RowBox[{
      RowBox[{"-", "8"}], " ", "p2", " ", "qq2"}]}], ",", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
      RowBox[{"2", "/", "3"}]], "->", " ", 
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"2", "/", "3"}]], "qq2"}]}], ",", " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
      RowBox[{"2", "/", "3"}]], "\[Rule]", " ", 
     SuperscriptBox["qq2", "2"]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"48", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "3"]}], "-", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", 
               SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}]}], "\[Rule]", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"48", " ", "qq2"}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{"1", "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], "\[Rule]", 
     RowBox[{"1", "/", " ", "qq2"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.71928123118372*^9, 3.719281238124731*^9}, {
  3.719281373526829*^9, 3.719281421811448*^9}, {3.719281567732238*^9, 
  3.719281637650076*^9}, {3.719281792644855*^9, 3.7192818199209957`*^9}, {
  3.71928186931157*^9, 3.7192818694471188`*^9}, {3.7192819725903797`*^9, 
  3.719282030053564*^9}, {3.719282073511257*^9, 3.719282094590109*^9}, {
  3.719282155781151*^9, 3.719282201180982*^9}, {3.719282252381571*^9, 
  3.7192822532552223`*^9}, {3.719282300635067*^9, 3.7192823089151793`*^9}, {
  3.719282352435211*^9, 
  3.719282357548424*^9}},ExpressionUUID->"df896d09-d2db-4d4a-be5c-\
df05f34fc4b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], "\[Rule]", "qq2"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", "p2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "8"}], " ", "p2", " ", "qq2"}]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
     RowBox[{"2", "/", "3"}]], "\[Rule]", 
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"2", "/", "3"}]], " ", "qq2"}]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
     RowBox[{"2", "/", "3"}]], "\[Rule]", 
    SuperscriptBox["qq2", "2"]}], ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"48", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]], "\[Rule]", 
    FractionBox["1", 
     RowBox[{"48", " ", "qq2"}]]}], ",", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]], "\[Rule]", 
    FractionBox["1", "qq2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.719282032565092*^9, 3.7192821006456547`*^9, 
  3.719282163166943*^9, 3.719282202046034*^9, 
  3.7192823585681257`*^9},ExpressionUUID->"b9f3996d-4d49-4ccf-b978-\
b4ef07e4f29c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"eqz1", " ", "=", 
  RowBox[{"(", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"eqz0", "/.", "eqsForRules"}], "/.", "morerules1"}], "//", 
    "Simplify"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.719281142480091*^9, 3.7192811644647093`*^9}, {
  3.719281437340798*^9, 3.7192814400938463`*^9}, {3.7192814812113*^9, 
  3.7192814833620987`*^9}, {3.719281549539208*^9, 
  3.719281553394452*^9}},ExpressionUUID->"9c709c53-9afa-4a09-aff3-\
b12d4e8d354d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", 
    RowBox[{"48", " ", "qq2"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["2", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["p2", "2"]}], "+", 
      RowBox[{"24", " ", 
       SuperscriptBox["2", 
        RowBox[{"1", "/", "3"}]], " ", "p4"}], "+", 
      RowBox[{"8", " ", "p2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "3"]}], "-", 
          RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
       RowBox[{"2", "/", "3"}]], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "3"]}], "-", 
          RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}], " ", ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           RowBox[{"12", " ", "p4"}]}]], ")"}], "\[Rule]", "p2p4term"}], ",", 
       
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SuperscriptBox["p2", "4"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox["p2", "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"72", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", "p2", " ", "p4", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}], "+", "qq1"}], ")"}]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"24", " ", "p4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"48", " ", "p4"}], "-", 
             RowBox[{
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              SuperscriptBox["qq2", 
               RowBox[{"2", "/", "3"}]]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"96", " ", "p4"}], "-", 
             RowBox[{
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              SuperscriptBox["qq2", 
               RowBox[{"2", "/", "3"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    ")"}]}], "-", "ttz"}]], "Input",
 CellChangeTimes->{{3.719282406442252*^9, 3.7192825068971987`*^9}},
 EmphasizeSyntaxErrors->
  True,ExpressionUUID->"9a7fce60-9b5a-4d52-9522-cefffa89e3d2"],

Cell[BoxData[
 RowBox[{"rule1", "=", 
  RowBox[{"Resultant", "[", 
   RowBox[{"eqz1", ",", 
    RowBox[{"eqsForRules", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "qq2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7192808048621893`*^9, 3.719280805937302*^9}, {
  3.719280941584227*^9, 3.7192809533528347`*^9}, {3.719282532823258*^9, 
  3.719282576886437*^9}},ExpressionUUID->"82130228-851e-4e3f-9d75-\
092db577f58b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Now define the  ",
 StyleBox["subplane  ",
  FontWeight->"Bold"],
 " reductions"
}], "Subsubsection",
 CellChangeTimes->{{3.719257028095842*^9, 
  3.7192570394719057`*^9}},ExpressionUUID->"2f7ceb33-272f-440b-b95c-\
9dc31ba8413a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"eigValX0List", ",", "eigValY0List", ",", "eigValZ0List"}], "}"}], 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Last", " ", "3", " ", "are", " ", "out", " ", "of", " ", "order"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.719258464650095*^9, 3.719258493672419*^9}, {
  3.7192585437372637`*^9, 
  3.719258553385325*^9}},ExpressionUUID->"21700de6-c098-460b-b8a3-\
171cfecb6d7f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "+", "z"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "z"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["aa", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "z"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "z"}], ")"}], "2"]}]]}], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "z"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["bb", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "z"}], ")"}], "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "y"}], ")"}], "2"]}]]}], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["cc", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "y"}], ")"}], "2"]}]]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7192584756511383`*^9, 3.719258494236602*^9}, 
   3.719258553878543*^9},ExpressionUUID->"3680cfeb-dc5c-4603-a7a0-\
3a5196e2364a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["eigVecX0List"], "Input",
 CellChangeTimes->{{3.7192585072883053`*^9, 
  3.7192585076403847`*^9}},ExpressionUUID->"fb429649-379e-4a6f-ba73-\
1c2d8e52eee6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y", "+", "z", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}], ",", "a", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y", "+", "z", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}], ",", "a", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"y", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["aa", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], "2"]}]], "-", "z"}], ",", "aa"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"y", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["aa", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], "2"]}]], "-", "z"}], ",", "aa"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719258508579619*^9},ExpressionUUID->"19d4500c-4c38-478d-9c0a-\
5978967c2b11"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigValListxx", "/.", 
  RowBox[{"zz", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.719257800414352*^9, 
  3.719257813405156*^9}},ExpressionUUID->"4b9c121a-3d0d-44b3-a7f3-\
e7c9899fc6af"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SqrtBox["xx"], "+", 
    SqrtBox["yy"]}], ",", 
   RowBox[{
    SqrtBox["xx"], "-", 
    SqrtBox["yy"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "+", 
    SqrtBox["yy"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "-", 
    SqrtBox["yy"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719257814122427*^9},ExpressionUUID->"04f739b8-0559-4794-a678-\
eee5fcdfabb6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eigValListxx", "/.", 
   RowBox[{"(", 
    RowBox[{"mysolnInit", "/.", 
     RowBox[{"randomPnX", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], ")"}]}], "//", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"#", ",", 
     SuperscriptBox["10", 
      RowBox[{"(", 
       RowBox[{"-", "7"}], ")"}]]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.719257874877968*^9, 
  3.719257935089493*^9}},ExpressionUUID->"2acaf471-7744-41c3-a7f8-\
12f78b3f6b5a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.7608705470040372`", ",", "0.41448277928398636`", ",", 
     RowBox[{"-", "0.41448278233501246`"}], ",", 
     RowBox[{"-", "0.7608705439530111`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0555883273478728`", ",", "0.7543082761756901`", ",", 
     RowBox[{"-", "0.7543083190176725`"}], ",", 
     RowBox[{"-", "1.0555882845058904`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719257882162122*^9, {3.7192579195835943`*^9, 
   3.719257935969796*^9}},ExpressionUUID->"fa3b81b9-728c-474c-9ce0-\
b005b6cc9dba"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"eigValListxx", "/.", 
  RowBox[{"(", 
   RowBox[{"mysolnInit", "/.", 
    RowBox[{"randomPnX", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], ")"}]}]], "Input",ExpressionUU\
ID->"7b7edf81-8439-4c4d-a6c8-2795bb31e84f"],

Cell[TextData[StyleBox["  So we have  ee1, ee2,  -ee2, -ee1  in that order, \
with ee1 = Max[ee[i]]]",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.719257828253194*^9, 
  3.71925785991754*^9}},ExpressionUUID->"85cbdd26-c899-4f34-a2f4-\
a2c4613f47e6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xx2ee12Rule", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ee1", " ", "\[Equal]", " ", 
        RowBox[{
         SqrtBox["xx"], "+", 
         SqrtBox["yy"]}]}], ",", 
       RowBox[{"ee2", " ", "==", " ", 
        RowBox[{
         SqrtBox["xx"], "-", 
         SqrtBox["yy"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "yy"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719194200200136*^9, 3.719194247393017*^9}, {
  3.719257990144203*^9, 
  3.719258038561406*^9}},ExpressionUUID->"5b143e7c-3e1f-4e22-8710-\
cc9bb0c339dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"xx", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"ee1", "+", "ee2"}], ")"}], "2"]}]}], ",", 
   RowBox[{"yy", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"ee1", "-", "ee2"}], ")"}], "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719194234329796*^9, 3.719194247897105*^9}, {
   3.7192580153312902`*^9, 3.7192580398832073`*^9}, 3.71928008416003*^9, 
   3.7193326586754208`*^9, 3.719349604072064*^9, 3.7194235183585377`*^9, 
   3.719673118565415*^9, 3.719703145573763*^9, 3.719872978797085*^9, 
   3.7199446742088823`*^9, 3.7251274992744226`*^9, 3.725482053882927*^9, 
   3.72548398424854*^9, 3.726256763662228*^9, 
   3.729008628013815*^9},ExpressionUUID->"496718b7-7619-45fa-a51c-\
e8301a465c81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"eqPform", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", " ", 
       RowBox[{"eqQuadratic", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "/.", 
      RowBox[{"zz", "\[Rule]", "0"}]}], "/.", "xx2ee12Rule"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.719258099426714*^9, 
  3.719258192754921*^9}},ExpressionUUID->"60df9774-1599-450f-8026-\
d75df9dbb0c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     SuperscriptBox["ee1", "2"], " ", 
     SuperscriptBox["ee2", "2"]}]}], ",", 
   RowBox[{"p3", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["ee1", "2"]}], "-", 
     SuperscriptBox["ee2", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719258140928095*^9, 
  3.719258193085429*^9}},ExpressionUUID->"cf6bc4f1-3899-4c22-95ad-\
f565000ef291"]
}, Open  ]],

Cell[TextData[StyleBox["Now define  the subplane reductions: \n     with ee1= \
Sqrt[a^2 +(y+z)^2-> u  and   ee2= Sqrt[aa^2 +(y-z)^2->  v",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.719256649193474*^9, 3.719256651497319*^9}, {
  3.719258226067463*^9, 3.719258235795907*^9}, {3.7192583858782063`*^9, 
  3.71925838922225*^9}, {3.719258746124061*^9, 
  3.7192588236134663`*^9}},ExpressionUUID->"9df28f4e-05b1-4221-a760-\
9666a416be93"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xxarg1", ",", "yyarg1", ",", "zzarg1"}], "}"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fxx0", "[", 
         RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], ",", " ", 
        RowBox[{"fyy0", "[", 
         RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], " ", ",", " ", 
        RowBox[{"fzz0", "[", 
         RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], " ", "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"p2", "\[Rule]", " ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["u", "2"], "+", 
            SuperscriptBox["v", "2"]}], ")"}]}]}], ",", 
        RowBox[{"p3", "\[Rule]", "0"}], ",", " ", 
        RowBox[{"p4", " ", "\[Rule]", " ", 
         RowBox[{
          SuperscriptBox["u", "2"], 
          SuperscriptBox["v", "2"]}]}]}], "}"}]}], "//", "FullSimplify"}]}], 
   "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.719258302341166*^9, 3.719258380102455*^9}, {
  3.719258681548347*^9, 3.719258736300734*^9}, {3.7192588347824383`*^9, 
  3.719258840477844*^9}},ExpressionUUID->"32642c59-42bf-46c3-a69c-\
1da7f1b3caa6"],

Cell[BoxData["28.509078`"], "Output",
 CellChangeTimes->{
  3.7192588749561033`*^9},ExpressionUUID->"09b4d44b-01f3-4e93-83ab-\
609dd1d0562f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Check", " ", "-", " ", "zz"}], " ", "=", " ", 
     RowBox[{"0", " ", "as", " ", "required"}]}], ";", "  ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ee1", ",", "ee2"}], "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SqrtBox["xx"], "+", 
         SqrtBox["yy"]}], ",", 
        RowBox[{
         SqrtBox["xx"], "-", 
         SqrtBox["yy"]}]}], "}"}], " ", "=", 
      RowBox[{"{", 
       RowBox[{"u", ",", "v"}], "}"}]}]}]}], "  ", "*)"}], 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xxarg1", ",", "yyarg1", ",", "zzarg1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Sqrt", "[", "xxarg1", "]"}], "+", 
           RowBox[{"Sqrt", "[", "yyarg1", "]"}]}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "xxarg1", "]"}], "-", 
           RowBox[{"Sqrt", "[", "yyarg1", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "v"}], "}"}]}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"u", "\[Rule]", 
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
        RowBox[{"v", "\[Rule]", 
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}]}], "}"}]}], "//", 
     "Chop"}], ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.719259016130289*^9, 3.719259093489596*^9}, {
  3.719259126003378*^9, 3.719259145683014*^9}, {3.719259175860441*^9, 
  3.719259331974318*^9}, {3.719260801983163*^9, 3.7192608160784473`*^9}, {
  3.7192609022253942`*^9, 
  3.719260909840274*^9}},ExpressionUUID->"023c7e39-5e8b-4018-b70f-\
82064c2429d1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.43819859473766193`", ",", "0.008117013323800982`", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.7520601739926156`", ",", "0.5718712362211644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7520601739926203`", ",", "0.5718712362211598`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.24039306673263142`", ",", "0.001722795691174089`", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.5318055305591531`", ",", "0.44879238241564307`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.5318055305591884`", ",", "0.4487923824156076`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.4840206170801388`", ",", "0.00563108480374795`", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7707564569577101`", ",", "0.6206753481698557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6206753481699416`", ",", "0.770756456957624`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.3919387105722762`", ",", "0.0005144944088529989`", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.6487325555093719`", ",", "0.6033676171162472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6033676171181768`", ",", "0.6487325555074424`"}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7192590184877253`*^9, {3.719259087741293*^9, 3.7192590940405617`*^9}, 
   3.719259146152647*^9, 3.719259292621724*^9, {3.719259333107439*^9, 
   3.719259351748991*^9}, {3.719260804504568*^9, 3.71926081938422*^9}, 
   3.71926091041197*^9},ExpressionUUID->"1e410786-48d6-4cba-98e1-\
4ceb41ae8d6c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["  Cache the subplane arguments ",
  FontSize->16,
  FontSlant->"Italic"],
 StyleBox["here:",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n_______________________________________",
  FontSize->16,
  FontSlant->"Italic"]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.719258854258403*^9, 3.719258874043511*^9}, {
  3.719258984932843*^9, 
  3.7192589939204483`*^9}},ExpressionUUID->"ed96d342-a82d-4481-8a07-\
f8dc8c5368be"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xxarg1", ",", "yyarg1", ",", "zzarg1"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "4"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["v", "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], ")"}], "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"7", " ", 
            SuperscriptBox["v", "2"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"12", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "6"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "4"], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["v", "4"]}], "-", 
           SuperscriptBox["v", "6"], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "2"]}], " ", 
              SuperscriptBox["v", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["u", "2"], "-", 
                 SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["u", "4"]}], "-", 
        SuperscriptBox["v", "4"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "6"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "4"], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["v", "4"]}], "-", 
           SuperscriptBox["v", "6"], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "2"]}], " ", 
              SuperscriptBox["v", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["u", "2"], "-", 
                 SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
         RowBox[{"2", "/", "3"}]], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["v", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "2"]}], "+", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "7"}], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "6"]}], "+", 
               RowBox[{"33", " ", 
                SuperscriptBox["u", "4"], " ", 
                SuperscriptBox["v", "2"]}], "+", 
               RowBox[{"33", " ", 
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox["v", "4"]}], "-", 
               SuperscriptBox["v", "6"], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "2"]}], " ", 
                  SuperscriptBox["v", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "2"]}], "+", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]], " ", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["u", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["v", "4"]}], "+", 
            FractionBox[
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "2"]}], " ", 
                SuperscriptBox["v", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["u", "2"], "-", 
                   SuperscriptBox["v", "2"]}], ")"}], "4"]}]], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "6"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "4"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "4"]}], "-", 
                 SuperscriptBox["v", "6"], "+", 
                 RowBox[{"6", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], 
             RowBox[{
              SuperscriptBox["u", "4"], "+", 
              RowBox[{"14", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              SuperscriptBox["v", "4"]}]], "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "6"]}], "+", 
               RowBox[{"33", " ", 
                SuperscriptBox["u", "4"], " ", 
                SuperscriptBox["v", "2"]}], "+", 
               RowBox[{"33", " ", 
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox["v", "4"]}], "-", 
               SuperscriptBox["v", "6"], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "2"]}], " ", 
                  SuperscriptBox["v", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
             RowBox[{"2", "/", "3"}]], "-", 
            RowBox[{"47", " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "6"]}], "+", 
                RowBox[{"33", " ", 
                 SuperscriptBox["u", "4"], " ", 
                 SuperscriptBox["v", "2"]}], "+", 
                RowBox[{"33", " ", 
                 SuperscriptBox["u", "2"], " ", 
                 SuperscriptBox["v", "4"]}], "-", 
                SuperscriptBox["v", "6"], "+", 
                RowBox[{"6", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                   SuperscriptBox["v", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
              RowBox[{"1", "/", "3"}]]}], "+", 
            FractionBox[
             RowBox[{"48", " ", 
              SuperscriptBox["v", "6"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "6"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "4"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "4"]}], "-", 
                 SuperscriptBox["v", "6"], "+", 
                 RowBox[{"6", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], 
             RowBox[{
              SuperscriptBox["u", "4"], "+", 
              RowBox[{"14", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              SuperscriptBox["v", "4"]}]], "+", 
            RowBox[{
             SuperscriptBox["u", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"28", " ", 
                SuperscriptBox["v", "2"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "6"]}], "+", 
                  RowBox[{"33", " ", 
                   SuperscriptBox["u", "4"], " ", 
                   SuperscriptBox["v", "2"]}], "+", 
                  RowBox[{"33", " ", 
                   SuperscriptBox["u", "2"], " ", 
                   SuperscriptBox["v", "4"]}], "-", 
                  SuperscriptBox["v", "6"], "+", 
                  RowBox[{"6", " ", 
                   SqrtBox["3"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]], "+", 
               FractionBox[
                RowBox[{"624", " ", 
                 SuperscriptBox["v", "4"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "6"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "4"], " ", 
                    SuperscriptBox["v", "2"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "2"], " ", 
                    SuperscriptBox["v", "4"]}], "-", 
                    SuperscriptBox["v", "6"], "+", 
                    RowBox[{"6", " ", 
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], 
                RowBox[{
                 SuperscriptBox["u", "4"], "+", 
                 RowBox[{"14", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 SuperscriptBox["v", "4"]}]]}], ")"}]}]}], ")"}]}]}]}], ")"}],
       "/", 
      RowBox[{"(", 
       RowBox[{"24", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "6"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "4"], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["v", "4"]}], "-", 
           SuperscriptBox["v", "6"], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "2"]}], " ", 
              SuperscriptBox["v", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["u", "2"], "-", 
                 SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["u", "4"]}], "-", 
        SuperscriptBox["v", "4"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "6"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "4"], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["v", "4"]}], "-", 
           SuperscriptBox["v", "6"], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "2"]}], " ", 
              SuperscriptBox["v", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["u", "2"], "-", 
                 SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
         RowBox[{"2", "/", "3"}]], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["v", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "2"]}], "+", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "7"}], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "6"]}], "+", 
               RowBox[{"33", " ", 
                SuperscriptBox["u", "4"], " ", 
                SuperscriptBox["v", "2"]}], "+", 
               RowBox[{"33", " ", 
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox["v", "4"]}], "-", 
               SuperscriptBox["v", "6"], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "2"]}], " ", 
                  SuperscriptBox["v", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "-", 
        RowBox[{
         SqrtBox["3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "2"]}], "+", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]], " ", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["u", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["v", "4"]}], "+", 
            FractionBox[
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "2"]}], " ", 
                SuperscriptBox["v", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["u", "2"], "-", 
                   SuperscriptBox["v", "2"]}], ")"}], "4"]}]], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "6"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "4"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "4"]}], "-", 
                 SuperscriptBox["v", "6"], "+", 
                 RowBox[{"6", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], 
             RowBox[{
              SuperscriptBox["u", "4"], "+", 
              RowBox[{"14", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              SuperscriptBox["v", "4"]}]], "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "6"]}], "+", 
               RowBox[{"33", " ", 
                SuperscriptBox["u", "4"], " ", 
                SuperscriptBox["v", "2"]}], "+", 
               RowBox[{"33", " ", 
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox["v", "4"]}], "-", 
               SuperscriptBox["v", "6"], "+", 
               RowBox[{"6", " ", 
                SqrtBox["3"], " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "2"]}], " ", 
                  SuperscriptBox["v", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
             RowBox[{"2", "/", "3"}]], "-", 
            RowBox[{"47", " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "6"]}], "+", 
                RowBox[{"33", " ", 
                 SuperscriptBox["u", "4"], " ", 
                 SuperscriptBox["v", "2"]}], "+", 
                RowBox[{"33", " ", 
                 SuperscriptBox["u", "2"], " ", 
                 SuperscriptBox["v", "4"]}], "-", 
                SuperscriptBox["v", "6"], "+", 
                RowBox[{"6", " ", 
                 SqrtBox["3"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                   SuperscriptBox["v", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
              RowBox[{"1", "/", "3"}]]}], "+", 
            FractionBox[
             RowBox[{"48", " ", 
              SuperscriptBox["v", "6"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "6"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "4"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "4"]}], "-", 
                 SuperscriptBox["v", "6"], "+", 
                 RowBox[{"6", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], 
             RowBox[{
              SuperscriptBox["u", "4"], "+", 
              RowBox[{"14", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              SuperscriptBox["v", "4"]}]], "+", 
            RowBox[{
             SuperscriptBox["u", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"28", " ", 
                SuperscriptBox["v", "2"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["u", "6"]}], "+", 
                  RowBox[{"33", " ", 
                   SuperscriptBox["u", "4"], " ", 
                   SuperscriptBox["v", "2"]}], "+", 
                  RowBox[{"33", " ", 
                   SuperscriptBox["u", "2"], " ", 
                   SuperscriptBox["v", "4"]}], "-", 
                  SuperscriptBox["v", "6"], "+", 
                  RowBox[{"6", " ", 
                   SqrtBox["3"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]], "+", 
               FractionBox[
                RowBox[{"624", " ", 
                 SuperscriptBox["v", "4"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "6"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "4"], " ", 
                    SuperscriptBox["v", "2"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "2"], " ", 
                    SuperscriptBox["v", "4"]}], "-", 
                    SuperscriptBox["v", "6"], "+", 
                    RowBox[{"6", " ", 
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], 
                RowBox[{
                 SuperscriptBox["u", "4"], "+", 
                 RowBox[{"14", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 SuperscriptBox["v", "4"]}]]}], ")"}]}]}], ")"}]}]}]}], ")"}],
       "/", 
      RowBox[{"(", 
       RowBox[{"24", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "6"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "4"], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["v", "4"]}], "-", 
           SuperscriptBox["v", "6"], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "2"]}], " ", 
              SuperscriptBox["v", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["u", "2"], "-", 
                 SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}]}]}], "}"}]}], ";"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.719258902287878*^9, 
  3.719258984934127*^9}},ExpressionUUID->"343b6896-465a-45ce-b219-\
89423080d75b"]
}, Closed]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"u", " ", "and", " ", "v", " ", "are", " ", "precisely", "  ", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ee1", ",", "ee2"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SqrtBox["xx"], "+", 
       SqrtBox["yy"]}], ",", 
      RowBox[{
       SqrtBox["xx"], "-", 
       SqrtBox["yy"]}]}], "}"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.719260507546361*^9, 
  3.719260612698988*^9}},ExpressionUUID->"c1147e3c-8cec-4071-9d50-\
ce75d917ee22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fxx1", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{"Evaluate", "[", "xxarg1", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.71813370853843*^9, 3.7181337582882767`*^9}, 
   3.7181340234392633`*^9, {3.719000402719408*^9, 3.71900044091875*^9}, 
   3.7190011654313726`*^9, {3.7192572130113*^9, 3.719257217523027*^9}, 
   3.719258262084494*^9, {3.7192587141239843`*^9, 3.719258714299693*^9}, {
   3.7192605270180063`*^9, 3.719260531657908*^9}, 
   3.7192606173552103`*^9},ExpressionUUID->"0ddb7dba-d647-4d9a-b1c5-\
53865c2ae716"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fyy1", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{"Evaluate", "[", "yyarg1", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.71813370853843*^9, 3.7181337582882767`*^9}, {
   3.71813398215097*^9, 3.71813398568682*^9}, 3.718134025855446*^9, {
   3.719000471570982*^9, 3.719000474437635*^9}, 3.7190011692399178`*^9, 
   3.719257225205813*^9, 3.719258267332788*^9, {3.719258717387896*^9, 
   3.7192587175638227`*^9}, {3.719260625678678*^9, 
   3.71926062913126*^9}},ExpressionUUID->"59a85797-a9bd-461d-9ee6-\
11d1d4fa5434"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fzz1", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{"Evaluate", "[", "zzarg1", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.71813370853843*^9, 3.7181337582882767`*^9}, {
   3.71813399030217*^9, 3.7181339941257668`*^9}, 3.718134028255208*^9, {
   3.719000479082539*^9, 3.719000482797925*^9}, 3.719001179719289*^9, 
   3.719257229493621*^9, 3.719258270660569*^9, {3.719258720843874*^9, 
   3.719258721003846*^9}, {3.719260633741542*^9, 
   3.7192606463800173`*^9}},ExpressionUUID->"e42dfe64-e594-4e85-bfb7-\
4c861ac1009a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["OUR PROBLEM now is to get the FUNCTIONAL forms to \
agree with eigValX0...",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.719258610313837*^9, 
  3.7192586329701433`*^9}},ExpressionUUID->"b94e480c-96d6-49ce-8567-\
265e3d90d821"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"we", " ", "can", " ", "use", " ", "either", " ", "xxarg0"}], ",", 
   "  ", 
   RowBox[{"or", " ", "fxx0"}], ",", "  ", 
   RowBox[{"or", " ", "xxarg1", " ", "or", " ", "fxx1"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.719260483499178*^9, 3.719260498889237*^9}, {
  3.7192606518834763`*^9, 3.719260664283545*^9}, {3.725136235132214*^9, 
  3.725136238300345*^9}},ExpressionUUID->"a203e57c-4542-4db8-9b30-\
a38643245614"],

Cell[CellGroupData[{

Cell[BoxData["eigValX0List"], "Input",
 CellChangeTimes->{{3.7192586355961313`*^9, 
  3.719258644444195*^9}},ExpressionUUID->"79111f10-660f-47a1-856d-\
d794d44cb7e2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"y", "+", "z"}], ")"}], "2"]}]], ",", 
   RowBox[{"-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "+", "z"}], ")"}], "2"]}]]}], ",", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["aa", "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"y", "-", "z"}], ")"}], "2"]}]], ",", 
   RowBox[{"-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["aa", "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "-", "z"}], ")"}], "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719258646358284*^9},ExpressionUUID->"c6392880-f850-43ea-9fd3-\
158c6498016d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"fxx0", "[", 
    RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], ",", "xxarg0"}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.719259402216539*^9, 3.719259403559013*^9}, {
  3.719260673180751*^9, 
  3.719260688572089*^9}},ExpressionUUID->"8f3f5671-a8ec-4711-a395-\
b33f8e103990"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["p2", "2"], "+", 
      RowBox[{"12", " ", "p4"}]}], 
     RowBox[{"12", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "3"], "-", 
         RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]], "+", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "3"], "-", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["p2", "2"], "+", 
      RowBox[{"12", " ", "p4"}]}], 
     RowBox[{"12", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "3"], "-", 
         RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]], "+", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "3"], "-", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.719259404724424*^9, 
  3.7192606888723917`*^9},ExpressionUUID->"ec05cfec-8ce6-48ab-8b96-\
870f455973aa"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"fxx1", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "xxarg1"}], "}"}]], "Input",
 CellChangeTimes->{{3.719260710156496*^9, 3.7192607130846157`*^9}, {
  3.7192607457742453`*^9, 
  3.7192607463970127`*^9}},ExpressionUUID->"f977a199-b2f3-4653-8504-\
5d1652b086b1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "4"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["v", "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["u", "2"], "-", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}], "2"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["u", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"7", " ", 
          SuperscriptBox["v", "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["u", "2"], "-", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"12", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "6"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "4"], " ", 
          SuperscriptBox["v", "2"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["v", "4"]}], "-", 
         SuperscriptBox["v", "6"], "+", 
         RowBox[{"6", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["u", "2"], "-", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "4"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["v", "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["u", "2"], "-", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}], "2"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["u", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"7", " ", 
          SuperscriptBox["v", "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["u", "2"], "-", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"12", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "6"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "4"], " ", 
          SuperscriptBox["v", "2"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["v", "4"]}], "-", 
         SuperscriptBox["v", "6"], "+", 
         RowBox[{"6", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["u", "2"], "-", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719260746948807*^9},ExpressionUUID->"e872081f-f8fc-428c-9514-\
94e3d6c84ce2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "We need the algebraic expressions to match for the  ",
 StyleBox["subplane limits,\n   but they do not easily do this: and u,v are \
NOT always in eig1, eig2 order?",
  FontSlant->"Italic"]
}], "Subsubsection",
 CellChangeTimes->{{3.719260958848323*^9, 3.7192609999692793`*^9}, {
  3.719261088722631*^9, 
  3.7192611011229773`*^9}},ExpressionUUID->"956ce4f5-b0e7-4a51-a2b4-\
522f69c355f6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xxarg1", ",", "yyarg1", ",", "zzarg1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "xxarg1", "]"}], "+", 
        RowBox[{"Sqrt", "[", "yyarg1", "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "xxarg1", "]"}], "-", 
        RowBox[{"Sqrt", "[", "yyarg1", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "v"}], "}"}]}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{"{", 
        RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}], ",", 
     RowBox[{"v", "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{"{", 
        RowBox[{"0.2", ",", "0.8"}], "}"}], "]"}]}]}], "}"}]}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.719261009346361*^9, 
  3.719261010800997*^9}},ExpressionUUID->"f66d22a1-eba9-4113-a0e5-\
e5a5bb03fd2e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.4849389375720252`", ",", "0.008383298639978318`", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7879359273870021`", ",", "0.6048152170347505`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6048152170347783`", ",", "0.7879359273869739`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7192610057395287`*^9, 
  3.719261049307255*^9}},ExpressionUUID->"4e0d8ee8-58ea-4b93-933e-\
3b9d6e88cb8b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make xx/planar work", "Subsubsection",
 CellChangeTimes->{{3.719261288501648*^9, 
  3.719261302389801*^9}},ExpressionUUID->"cd2abf52-45ca-419c-a391-\
91972834049f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"This", " ", "should", " ", "be", " ", "xx"}], "=", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"u", "+", "v"}], ")"}], "2"]}]}], " ", ",", "  ", 
    RowBox[{"yy", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"u", "-", "v"}], ")"}], "2"]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"testx1", "=", "xxarg1"}]}]], "Input",
 CellChangeTimes->{{3.719259424824383*^9, 3.71925942715924*^9}, {
  3.7192611303719378`*^9, 3.7192612104368353`*^9}, {3.719261256726091*^9, 
  3.719261271877659*^9}},ExpressionUUID->"1aead640-1db1-477e-a132-\
ef3eab07fdff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["u", "4"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["v", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "6"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "4"]}], "-", 
          SuperscriptBox["v", "6"], "+", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["u", "2"]}], " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["u", "2"], "-", 
                SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}], "2"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["u", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"7", " ", 
        SuperscriptBox["v", "2"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "6"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "4"]}], "-", 
          SuperscriptBox["v", "6"], "+", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["u", "2"]}], " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["u", "2"], "-", 
                SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"12", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["u", "6"]}], "+", 
       RowBox[{"33", " ", 
        SuperscriptBox["u", "4"], " ", 
        SuperscriptBox["v", "2"]}], "+", 
       RowBox[{"33", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["v", "4"]}], "-", 
       SuperscriptBox["v", "6"], "+", 
       RowBox[{"6", " ", 
        SqrtBox["3"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "2"]}], " ", 
          SuperscriptBox["v", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["u", "2"], "-", 
             SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.719259427749503*^9, 
  3.719261273633691*^9},ExpressionUUID->"56431e38-de66-42f2-8a58-\
ac228cd95b9d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make yplanar work", "Subsubsection",
 CellChangeTimes->{{3.719261288501648*^9, 
  3.719261323142078*^9}},ExpressionUUID->"3d979113-2693-48fa-93d2-\
3475c1b27589"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"This", " ", "should", " ", "be", " ", "xx"}], "=", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"u", "+", "v"}], ")"}], "2"]}]}], " ", ",", "  ", 
    RowBox[{"yy", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"u", "-", "v"}], ")"}], "2"]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"testy1", "=", 
   RowBox[{"yyarg1", "//", "Together"}]}]}]], "Input",
 CellChangeTimes->{{3.719261247399918*^9, 3.719261248629058*^9}, {
  3.719261313673479*^9, 3.719261334422752*^9}, {3.719261615611845*^9, 
  3.719261617403245*^9}},ExpressionUUID->"9cc67419-87db-4dfa-b99e-\
c0074da94e01"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["u", "4"]}], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["v", "2"]}], "-", 
    SuperscriptBox["v", "4"], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["u", "6"]}], "+", 
        RowBox[{"33", " ", 
         SuperscriptBox["u", "4"], " ", 
         SuperscriptBox["v", "2"]}], "+", 
        RowBox[{"33", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["v", "4"]}], "-", 
        SuperscriptBox["v", "6"], "+", 
        RowBox[{"6", " ", 
         SqrtBox["3"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "2"]}], " ", 
           SuperscriptBox["v", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["v", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["u", "6"]}], "+", 
        RowBox[{"33", " ", 
         SuperscriptBox["u", "4"], " ", 
         SuperscriptBox["v", "2"]}], "+", 
        RowBox[{"33", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["v", "4"]}], "-", 
        SuperscriptBox["v", "6"], "+", 
        RowBox[{"6", " ", 
         SqrtBox["3"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "2"]}], " ", 
           SuperscriptBox["v", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["u", "6"]}], "+", 
       RowBox[{"33", " ", 
        SuperscriptBox["u", "4"], " ", 
        SuperscriptBox["v", "2"]}], "+", 
       RowBox[{"33", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["v", "4"]}], "-", 
       SuperscriptBox["v", "6"], "+", 
       RowBox[{"6", " ", 
        SqrtBox["3"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "2"]}], " ", 
          SuperscriptBox["v", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["u", "2"], "-", 
             SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
     RowBox[{"2", "/", "3"}]], "+", 
    RowBox[{
     SqrtBox["3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["u", "6"]}], "+", 
        RowBox[{"33", " ", 
         SuperscriptBox["u", "4"], " ", 
         SuperscriptBox["v", "2"]}], "+", 
        RowBox[{"33", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["v", "4"]}], "-", 
        SuperscriptBox["v", "6"], "+", 
        RowBox[{"6", " ", 
         SqrtBox["3"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "2"]}], " ", 
           SuperscriptBox["v", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]], " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          SuperscriptBox["u", "4"], "+", 
          RowBox[{"14", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          SuperscriptBox["v", "4"]}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["u", "8"]}], "+", 
          RowBox[{"56", " ", 
           SuperscriptBox["u", "6"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          RowBox[{"396", " ", 
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["v", "4"]}], "+", 
          RowBox[{"56", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "6"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["v", "8"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "6"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["v", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{
           SuperscriptBox["v", "6"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["u", "2"]}], " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["u", "2"], "-", 
                SuperscriptBox["v", "2"]}], ")"}], "4"]}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"2", "/", "3"}]]}], "-", 
          RowBox[{"14", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"2", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["v", "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "6"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "4"], " ", 
               SuperscriptBox["v", "2"]}], "+", 
              RowBox[{"33", " ", 
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["v", "4"]}], "-", 
              SuperscriptBox["v", "6"], "+", 
              RowBox[{"6", " ", 
               SqrtBox["3"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "2"]}], " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["u", "2"], "-", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
            RowBox[{"2", "/", "3"}]]}]}], ")"}]}], ")"}]}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"24", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["u", "6"]}], "+", 
       RowBox[{"33", " ", 
        SuperscriptBox["u", "4"], " ", 
        SuperscriptBox["v", "2"]}], "+", 
       RowBox[{"33", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["v", "4"]}], "-", 
       SuperscriptBox["v", "6"], "+", 
       RowBox[{"6", " ", 
        SqrtBox["3"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "2"]}], " ", 
          SuperscriptBox["v", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["u", "2"], "-", 
             SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.719261250343218*^9, 3.719261336454564*^9, 
  3.719261618087543*^9},ExpressionUUID->"5ccee4ad-023e-4a8d-9ac1-\
789a23c93f74"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rule1", " ", "=", " ", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "6"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "4"], " ", 
          SuperscriptBox["v", "2"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["v", "4"]}], "-", 
         SuperscriptBox["v", "6"], "+", 
         RowBox[{"6", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]], "\[Rule]", "  ", "qq1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "6"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "4"]}], "-", 
          SuperscriptBox["v", "6"], "+", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["u", "2"]}], " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "2"]}], "+", 
                SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "\[Rule]", "  ", 
      RowBox[{"-", "qq1"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "6"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "4"]}], "-", 
          SuperscriptBox["v", "6"], "+", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["u", "2"]}], " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "2"]}], "+", 
                SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "\[Rule]", 
      RowBox[{"1", "/", "qq1"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "6"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "4"], " ", 
          SuperscriptBox["v", "2"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["v", "4"]}], "-", 
         SuperscriptBox["v", "6"], "+", 
         RowBox[{"6", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
       RowBox[{"2", "/", "3"}]], "\[Rule]", 
      SuperscriptBox["qq1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "6"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "4"]}], "-", 
          SuperscriptBox["v", "6"], "+", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["u", "2"]}], " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "2"]}], "+", 
                SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
        RowBox[{"2", "/", "3"}]]}], "\[Rule]", 
      RowBox[{"1", "/", 
       SuperscriptBox["qq1", "2"]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.719261367721197*^9, 3.719261500747414*^9}, {
  3.719261578717266*^9, 3.7192615885091467`*^9}, {3.719261630910232*^9, 
  3.719261646990395*^9}},ExpressionUUID->"2e1d65b9-9c28-4a0c-8a38-\
5a4429ba8eba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testy2", "=", 
  RowBox[{
   RowBox[{"testy1", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"c_", "  ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "6"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "4"], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["v", "4"]}], "-", 
           SuperscriptBox["v", "6"], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "2"]}], " ", 
              SuperscriptBox["v", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["u", "2"], "-", 
                 SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], "\[Rule]", " ", 
       RowBox[{"c", " ", "qq1"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "6"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "4"], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{"33", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["v", "4"]}], "-", 
           SuperscriptBox["v", "6"], "+", 
           RowBox[{"6", " ", 
            SqrtBox["3"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "2"]}], " ", 
              SuperscriptBox["v", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["u", "2"], "-", 
                 SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
         RowBox[{"2", "/", "3"}]]}], "\[Rule]", " ", 
       RowBox[{"-", " ", 
        SuperscriptBox["qq1", "2"]}]}]}], "}"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.719261393559565*^9, 3.719261399847699*^9}, {
  3.7192615108740873`*^9, 3.719261514969562*^9}, {3.71926154709966*^9, 
  3.719261547754706*^9}, {3.719261595740369*^9, 3.719261595930835*^9}, {
  3.7192616852299433`*^9, 3.7192617998385887`*^9}, {3.719261833570079*^9, 
  3.719261835279768*^9}},ExpressionUUID->"1d1855d5-0805-4178-9866-\
a4cbcfe71cd9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["qq1", "2"]}], "-", 
    SuperscriptBox["u", "4"], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["v", "2"]}], "-", 
    SuperscriptBox["v", "4"], "+", 
    RowBox[{"qq1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["u", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["v", "2"]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{
             SuperscriptBox["u", "4"], "+", 
             RowBox[{"14", " ", 
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox["v", "2"]}], "+", 
             SuperscriptBox["v", "4"]}]], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["u", "8"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["v", "8"]}], "+", 
             RowBox[{
              SuperscriptBox["v", "6"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "6"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "4"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "4"]}], "-", 
                 SuperscriptBox["v", "6"], "+", 
                 RowBox[{"6", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], "+", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "2"]}], " ", 
                SuperscriptBox["v", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                   SuperscriptBox["v", "2"]}], ")"}], "4"]}]], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "6"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "4"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "4"]}], "-", 
                 SuperscriptBox["v", "6"], "+", 
                 RowBox[{"6", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], "-", 
             RowBox[{
              SuperscriptBox["v", "4"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["u", "6"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "4"], " ", 
                  SuperscriptBox["v", "2"]}], "+", 
                 RowBox[{"33", " ", 
                  SuperscriptBox["u", "2"], " ", 
                  SuperscriptBox["v", "4"]}], "-", 
                 SuperscriptBox["v", "6"], "+", 
                 RowBox[{"6", " ", 
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
               RowBox[{"2", "/", "3"}]]}], "+", 
             RowBox[{
              SuperscriptBox["u", "6"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"56", " ", 
                 SuperscriptBox["v", "2"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["u", "6"]}], "+", 
                   RowBox[{"33", " ", 
                    SuperscriptBox["u", "4"], " ", 
                    SuperscriptBox["v", "2"]}], "+", 
                   RowBox[{"33", " ", 
                    SuperscriptBox["u", "2"], " ", 
                    SuperscriptBox["v", "4"]}], "-", 
                   SuperscriptBox["v", "6"], "+", 
                   RowBox[{"6", " ", 
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["u", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "396"}], " ", 
                 SuperscriptBox["v", "4"]}], "+", 
                RowBox[{"33", " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "6"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "4"], " ", 
                    SuperscriptBox["v", "2"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "2"], " ", 
                    SuperscriptBox["v", "4"]}], "-", 
                    SuperscriptBox["v", "6"], "+", 
                    RowBox[{"6", " ", 
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["u", "6"]}], "+", 
                   RowBox[{"33", " ", 
                    SuperscriptBox["u", "4"], " ", 
                    SuperscriptBox["v", "2"]}], "+", 
                   RowBox[{"33", " ", 
                    SuperscriptBox["u", "2"], " ", 
                    SuperscriptBox["v", "4"]}], "-", 
                   SuperscriptBox["v", "6"], "+", 
                   RowBox[{"6", " ", 
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                 RowBox[{"2", "/", "3"}]]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "56"}], " ", 
                 SuperscriptBox["v", "6"]}], "+", 
                RowBox[{"33", " ", 
                 SuperscriptBox["v", "4"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "6"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "4"], " ", 
                    SuperscriptBox["v", "2"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "2"], " ", 
                    SuperscriptBox["v", "4"]}], "-", 
                    SuperscriptBox["v", "6"], "+", 
                    RowBox[{"6", " ", 
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"14", " ", 
                 SuperscriptBox["v", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "6"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "4"], " ", 
                    SuperscriptBox["v", "2"]}], "+", 
                    RowBox[{"33", " ", 
                    SuperscriptBox["u", "2"], " ", 
                    SuperscriptBox["v", "4"]}], "-", 
                    SuperscriptBox["v", "6"], "+", 
                    RowBox[{"6", " ", 
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], " ", 
                    SuperscriptBox["v", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                    SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
                  RowBox[{"2", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], 
          ")"}]}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"24", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["u", "6"]}], "+", 
       RowBox[{"33", " ", 
        SuperscriptBox["u", "4"], " ", 
        SuperscriptBox["v", "2"]}], "+", 
       RowBox[{"33", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["v", "4"]}], "-", 
       SuperscriptBox["v", "6"], "+", 
       RowBox[{"6", " ", 
        SqrtBox["3"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "2"]}], " ", 
          SuperscriptBox["v", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["u", "2"], "-", 
             SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.719261400666486*^9, {3.7192615043586683`*^9, 3.719261515523217*^9}, 
   3.7192615491319227`*^9, 3.719261596930047*^9, 3.719261652629375*^9, {
   3.7192616985037727`*^9, 3.719261801227298*^9}, 
   3.719261837535961*^9},ExpressionUUID->"9ab0923b-b8ea-41a8-ad0e-\
afbf8c8408d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testy2", "=", 
  RowBox[{"testy2", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["u", "6"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          RowBox[{"33", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "4"]}], "-", 
          SuperscriptBox["v", "6"], "+", 
          RowBox[{"6", " ", 
           SqrtBox["3"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["u", "2"]}], " ", 
             SuperscriptBox["v", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "2"]}], "+", 
                SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "\[Rule]", 
      RowBox[{"1", "/", "qq1"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "6"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "4"], " ", 
          SuperscriptBox["v", "2"]}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["v", "4"]}], "-", 
         SuperscriptBox["v", "6"], "+", 
         RowBox[{"6", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
       RowBox[{"2", "/", "3"}]], "\[Rule]", "  ", 
      SuperscriptBox["qq1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"24", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "6"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "4"], " ", 
             SuperscriptBox["v", "2"]}], "+", 
            RowBox[{"33", " ", 
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["v", "4"]}], "-", 
            SuperscriptBox["v", "6"], "+", 
            RowBox[{"6", " ", 
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], " ", 
               SuperscriptBox["v", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["u", "2"], "-", 
                  SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}], "\[Rule]", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"24", " ", "qq1"}], ")"}]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.719261883007627*^9, 3.7192619114750338`*^9}, {
  3.719261949507226*^9, 
  3.719261995282887*^9}},ExpressionUUID->"3edb1027-787a-41dd-8abb-\
7c4a0508d3a4"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"24", " ", "qq1"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["qq1", "2"]}], "-", 
    SuperscriptBox["u", "4"], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["v", "2"]}], "-", 
    SuperscriptBox["v", "4"], "+", 
    RowBox[{"qq1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["u", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["v", "2"]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{
             SuperscriptBox["u", "4"], "+", 
             RowBox[{"14", " ", 
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox["v", "2"]}], "+", 
             SuperscriptBox["v", "4"]}]], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["u", "8"]}], "-", 
             RowBox[{
              SuperscriptBox["qq1", "2"], " ", 
              SuperscriptBox["v", "4"]}], "+", 
             RowBox[{"qq1", " ", 
              SuperscriptBox["v", "6"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["v", "8"]}], "+", 
             RowBox[{"6", " ", 
              SqrtBox["3"], " ", "qq1", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["u", "2"]}], " ", 
                SuperscriptBox["v", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["u", "2"]}], "+", 
                   SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}], "+", 
             RowBox[{
              SuperscriptBox["u", "6"], " ", 
              RowBox[{"(", 
               RowBox[{"qq1", "+", 
                RowBox[{"56", " ", 
                 SuperscriptBox["v", "2"]}]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["u", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["qq1", "2"], "+", 
                RowBox[{"33", " ", "qq1", " ", 
                 SuperscriptBox["v", "2"]}], "-", 
                RowBox[{"396", " ", 
                 SuperscriptBox["v", "4"]}]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"14", " ", 
                 SuperscriptBox["qq1", "2"], " ", 
                 SuperscriptBox["v", "2"]}], "+", 
                RowBox[{"33", " ", "qq1", " ", 
                 SuperscriptBox["v", "4"]}], "-", 
                RowBox[{"56", " ", 
                 SuperscriptBox["v", "6"]}]}], ")"}]}]}], ")"}]}], 
          ")"}]}]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.719261912832596*^9, 3.7192619532518*^9, 
  3.719261996644187*^9},ExpressionUUID->"07e3df2e-ef7d-46f9-ac53-\
196838429652"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["u", "6"]}], "+", 
      RowBox[{"33", " ", 
       SuperscriptBox["u", "4"], " ", 
       SuperscriptBox["v", "2"]}], "+", 
      RowBox[{"33", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["v", "4"]}], "-", 
      SuperscriptBox["v", "6"], "+", 
      RowBox[{"6", " ", 
       SqrtBox["3"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "2"]}], " ", 
         SuperscriptBox["v", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], "+", 
            SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]], ")"}], "3"]], "Input",
 CellChangeTimes->{{3.719262219205093*^9, 
  3.7192622250133467`*^9}},ExpressionUUID->"3d2c2156-4882-4cdf-ad43-\
839c50c57aa7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["u", "6"]}], "+", 
  RowBox[{"33", " ", 
   SuperscriptBox["u", "4"], " ", 
   SuperscriptBox["v", "2"]}], "+", 
  RowBox[{"33", " ", 
   SuperscriptBox["u", "2"], " ", 
   SuperscriptBox["v", "4"]}], "-", 
  SuperscriptBox["v", "6"], "+", 
  RowBox[{"6", " ", 
   SqrtBox["3"], " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["u", "2"]}], " ", 
     SuperscriptBox["v", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["u", "2"]}], "+", 
        SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}]], "Output",
 CellChangeTimes->{
  3.719262225911277*^9},ExpressionUUID->"3a9da2f8-276b-44ce-9658-\
0ef3b4cddfd2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testy2n", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Numerator", "[", 
       RowBox[{"Together", "[", "testy2", "]"}], "]"}], "//", "Simplify"}], 
     ")"}], "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "6"], "-", 
        RowBox[{"33", " ", 
         SuperscriptBox["u", "4"], " ", 
         SuperscriptBox["v", "2"]}], "-", 
        RowBox[{"33", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["v", "4"]}], "+", 
        SuperscriptBox["v", "6"], "+", 
        RowBox[{"6", " ", 
         SqrtBox["3"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["u", "2"]}], " ", 
           SuperscriptBox["v", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["u", "2"]}], "+", 
              SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}], 
      "\[Rule]", " ", 
      RowBox[{"-", 
       SuperscriptBox["qq1", "3"]}]}], "}"}]}], "//", "Simplify"}]}]], "Input",\

 CellChangeTimes->{{3.7192620294739647`*^9, 3.71926207454657*^9}, {
  3.7192621460374126`*^9, 3.7192621715250893`*^9}, {3.719262202533596*^9, 
  3.719262207413102*^9}, {3.719262239573909*^9, 
  3.719262278614666*^9}},ExpressionUUID->"db3667b0-3e9c-42a9-ad6f-\
f5ff58256ae9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["qq1", "2"]}], "-", 
  SuperscriptBox["u", "4"], "-", 
  RowBox[{"14", " ", 
   SuperscriptBox["u", "2"], " ", 
   SuperscriptBox["v", "2"]}], "-", 
  SuperscriptBox["v", "4"], "+", 
  RowBox[{"qq1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["u", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["v", "2"]}], "+", 
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox["qq1", "2"]}], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["qq1", "4"]}], 
        RowBox[{
         SuperscriptBox["u", "4"], "+", 
         RowBox[{"14", " ", 
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["v", "2"]}], "+", 
         SuperscriptBox["v", "4"]}]], "+", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["u", "4"], "+", 
          RowBox[{"14", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          SuperscriptBox["v", "4"]}], ")"}]}]}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.719262049977453*^9, 3.7192620795562267`*^9}, {
  3.719262240452276*^9, 
  3.7192622794000397`*^9}},ExpressionUUID->"8ce98167-b734-41f1-972d-\
cfcd0a23ee8f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testy3", "=", 
  RowBox[{"testy2n", "/.", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox["qq1", "2"]}], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["qq1", "4"]}], 
        RowBox[{
         SuperscriptBox["u", "4"], "+", 
         RowBox[{"14", " ", 
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["v", "2"]}], "+", 
         SuperscriptBox["v", "4"]}]], "+", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["u", "4"], "+", 
          RowBox[{"14", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          SuperscriptBox["v", "4"]}], ")"}]}]}]], "\[Rule]", "qq2"}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.71926237410343*^9, 
  3.7192624224567127`*^9}},ExpressionUUID->"de654cd4-eebe-4929-a36c-\
f65ff37e7778"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["qq1", "2"]}], "-", 
  SuperscriptBox["u", "4"], "-", 
  RowBox[{"14", " ", 
   SuperscriptBox["u", "2"], " ", 
   SuperscriptBox["v", "2"]}], "-", 
  SuperscriptBox["v", "4"], "+", 
  RowBox[{"qq1", " ", 
   RowBox[{"(", 
    RowBox[{"qq2", "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["u", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["v", "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.719262422778483*^9},ExpressionUUID->"81386f91-d140-4d4a-be36-\
249fe7c08f8e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqy1", "=", " ", 
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["qq1", "2"]}], "-", 
   SuperscriptBox["u", "4"], "-", 
   RowBox[{"14", " ", 
    SuperscriptBox["u", "2"], " ", 
    SuperscriptBox["v", "2"]}], "-", 
   SuperscriptBox["v", "4"], "+", 
   RowBox[{"qq1", " ", 
    RowBox[{"(", 
     RowBox[{"qq2", "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["u", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["v", "2"]}]}], ")"}]}], " ", "-", "tty"}]}]], "Input",
 CellChangeTimes->{{3.719262451050515*^9, 
  3.719262489145746*^9}},ExpressionUUID->"8682e5a5-e151-4721-84f3-\
8868a8b5c7c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["qq1", "2"]}], "-", "tty", "-", 
  SuperscriptBox["u", "4"], "-", 
  RowBox[{"14", " ", 
   SuperscriptBox["u", "2"], " ", 
   SuperscriptBox["v", "2"]}], "-", 
  SuperscriptBox["v", "4"], "+", 
  RowBox[{"qq1", " ", 
   RowBox[{"(", 
    RowBox[{"qq2", "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["u", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["v", "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.719262549932267*^9},ExpressionUUID->"47d9290b-81dc-4019-a208-\
3b21d76ab099"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruleEqns", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["u", "6"]}], "+", 
      RowBox[{"33", " ", 
       SuperscriptBox["u", "4"], " ", 
       SuperscriptBox["v", "2"]}], "+", 
      RowBox[{"33", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["v", "4"]}], "-", 
      SuperscriptBox["v", "6"], "+", 
      RowBox[{"6", " ", 
       SqrtBox["3"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "2"]}], " ", 
         SuperscriptBox["v", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], "+", 
            SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}], "-", 
      SuperscriptBox["qq1", "3"]}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["qq1", "2"]}], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["qq1", "4"]}], 
         RowBox[{
          SuperscriptBox["u", "4"], "+", 
          RowBox[{"14", " ", 
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          SuperscriptBox["v", "4"]}]], "+", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["u", "4"], "+", 
           RowBox[{"14", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["v", "2"]}], "+", 
           SuperscriptBox["v", "4"]}], ")"}]}]}], ")"}], "-", 
      SuperscriptBox["qq2", "2"]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.719262307048943*^9, 3.71926234779991*^9}, {
   3.719262388600441*^9, 3.719262402409294*^9}, 
   3.7192627861912613`*^9},ExpressionUUID->"8f4e7c18-e944-45d6-b661-\
c26887fd13ac"],

Cell[TextData[StyleBox[" Three equations in tty, qq1, qq2: how to resolve \
these with Resultant?\n   eqy1[tty,qq1,qq2],  ruleEqns{ [qq1],  [qq1,qq2]}",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.719262634235621*^9, 
  3.719262712204966*^9}},ExpressionUUID->"7d4ebcfd-5e8b-4790-9a16-\
8adcd8f7571d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res1", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Resultant", "[", 
     RowBox[{"eqy1", ",", 
      RowBox[{"ruleEqns", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", "qq2"}], "]"}], "//", 
    "Simplify"}], "//", "Factor"}]}]], "Input",
 CellChangeTimes->{{3.719262718991973*^9, 3.719262720173308*^9}, {
  3.719262771902063*^9, 
  3.7192628126386766`*^9}},ExpressionUUID->"f79180d3-1fe2-4e54-9cfb-\
b547798b4c58"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["u", "4"], "+", 
     RowBox[{"14", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     SuperscriptBox["v", "4"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["qq1", "6"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["qq1", "4"], " ", 
      SuperscriptBox["u", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["qq1", "2"], " ", "tty", " ", 
      SuperscriptBox["u", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["tty", "2"], " ", 
      SuperscriptBox["u", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["qq1", "3"], " ", 
      SuperscriptBox["u", "6"]}], "-", 
     RowBox[{"8", " ", "qq1", " ", "tty", " ", 
      SuperscriptBox["u", "6"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["qq1", "2"], " ", 
      SuperscriptBox["u", "8"]}], "+", 
     RowBox[{"2", " ", "tty", " ", 
      SuperscriptBox["u", "8"]}], "-", 
     RowBox[{"8", " ", "qq1", " ", 
      SuperscriptBox["u", "10"]}], "+", 
     SuperscriptBox["u", "12"], "+", 
     RowBox[{"56", " ", 
      SuperscriptBox["qq1", "4"], " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     RowBox[{"28", " ", 
      SuperscriptBox["qq1", "2"], " ", "tty", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     RowBox[{"14", " ", 
      SuperscriptBox["tty", "2"], " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "2"]}], "-", 
     RowBox[{"120", " ", 
      SuperscriptBox["qq1", "3"], " ", 
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["v", "2"]}], "-", 
     RowBox[{"120", " ", "qq1", " ", "tty", " ", 
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     RowBox[{"144", " ", 
      SuperscriptBox["qq1", "2"], " ", 
      SuperscriptBox["u", "6"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     RowBox[{"56", " ", "tty", " ", 
      SuperscriptBox["u", "6"], " ", 
      SuperscriptBox["v", "2"]}], "-", 
     RowBox[{"232", " ", "qq1", " ", 
      SuperscriptBox["u", "8"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     RowBox[{"42", " ", 
      SuperscriptBox["u", "10"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["qq1", "4"], " ", 
      SuperscriptBox["v", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["qq1", "2"], " ", "tty", " ", 
      SuperscriptBox["v", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["tty", "2"], " ", 
      SuperscriptBox["v", "4"]}], "-", 
     RowBox[{"120", " ", 
      SuperscriptBox["qq1", "3"], " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "4"]}], "-", 
     RowBox[{"120", " ", "qq1", " ", "tty", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "4"]}], "-", 
     RowBox[{"312", " ", 
      SuperscriptBox["qq1", "2"], " ", 
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["v", "4"]}], "+", 
     RowBox[{"396", " ", "tty", " ", 
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["v", "4"]}], "-", 
     RowBox[{"1808", " ", "qq1", " ", 
      SuperscriptBox["u", "6"], " ", 
      SuperscriptBox["v", "4"]}], "+", 
     RowBox[{"591", " ", 
      SuperscriptBox["u", "8"], " ", 
      SuperscriptBox["v", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["qq1", "3"], " ", 
      SuperscriptBox["v", "6"]}], "-", 
     RowBox[{"8", " ", "qq1", " ", "tty", " ", 
      SuperscriptBox["v", "6"]}], "+", 
     RowBox[{"144", " ", 
      SuperscriptBox["qq1", "2"], " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "6"]}], "+", 
     RowBox[{"56", " ", "tty", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "6"]}], "-", 
     RowBox[{"1808", " ", "qq1", " ", 
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["v", "6"]}], "+", 
     RowBox[{"2828", " ", 
      SuperscriptBox["u", "6"], " ", 
      SuperscriptBox["v", "6"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["qq1", "2"], " ", 
      SuperscriptBox["v", "8"]}], "+", 
     RowBox[{"2", " ", "tty", " ", 
      SuperscriptBox["v", "8"]}], "-", 
     RowBox[{"232", " ", "qq1", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "8"]}], "+", 
     RowBox[{"591", " ", 
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["v", "8"]}], "-", 
     RowBox[{"8", " ", "qq1", " ", 
      SuperscriptBox["v", "10"]}], "+", 
     RowBox[{"42", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "10"]}], "+", 
     SuperscriptBox["v", "12"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.719262804593561*^9, 
  3.719262813048729*^9}},ExpressionUUID->"488bdd90-167e-4654-ab38-\
c0888051d166"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2", " ", "=", " ", 
  RowBox[{
   RowBox[{"Resultant", "[", 
    RowBox[{"res1", ",", 
     RowBox[{"ruleEqns", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "qq1"}], "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.719262821761001*^9, 
  3.7192628606089973`*^9}},ExpressionUUID->"8240d31d-81b3-4740-bb13-\
c2b9499dcba7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["tty", "6"]}], "-", 
  RowBox[{"6", " ", 
   SuperscriptBox["tty", "5"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["u", "4"], "+", 
     RowBox[{"14", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     SuperscriptBox["v", "4"]}], ")"}]}], "-", 
  RowBox[{"216", " ", 
   SuperscriptBox["tty", "3"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "2"], "-", 
      SuperscriptBox["v", "2"]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["u", "2"], "+", 
     SuperscriptBox["v", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["u", "6"], "-", 
     RowBox[{"33", " ", 
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["v", "2"]}], "-", 
     RowBox[{"33", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "4"]}], "+", 
     SuperscriptBox["v", "6"], "-", 
     RowBox[{"6", " ", 
      SqrtBox["3"], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["u", "2"]}], " ", 
        SuperscriptBox["v", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["u", "2"], "-", 
           SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["u", "4"], "+", 
       RowBox[{"14", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["v", "2"]}], "+", 
       SuperscriptBox["v", "4"]}], ")"}], "2"]], 
   RowBox[{"1296", " ", 
    SuperscriptBox["tty", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["u", "24"]}], "+", 
      RowBox[{"71", " ", 
       SuperscriptBox["u", "22"], " ", 
       SuperscriptBox["v", "2"]}], "+", 
      RowBox[{"616", " ", 
       SuperscriptBox["u", "20"], " ", 
       SuperscriptBox["v", "4"]}], "-", 
      SuperscriptBox["v", "24"], "+", 
      RowBox[{"9", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["v", "18"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "2"]}], " ", 
         SuperscriptBox["v", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], "+", 
            SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["u", "12"], " ", 
       SuperscriptBox["v", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"13636", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"5535", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"15", " ", 
       SuperscriptBox["u", "6"], " ", 
       SuperscriptBox["v", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2261", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"2952", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["u", "18"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"11305", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["v", "16"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"71", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"37", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["u", "4"], " ", 
       SuperscriptBox["v", "14"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"77", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"296", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["u", "14"], " ", 
       SuperscriptBox["v", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6625"}], " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"1184", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["u", "10"], " ", 
       SuperscriptBox["v", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6625", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"44603", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["u", "8"], " ", 
       SuperscriptBox["v", "10"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"75895", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"89206", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "16"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "75895"}], " ", 
          SuperscriptBox["v", "8"]}], "+", 
         RowBox[{"37", " ", 
          SqrtBox["3"], " ", 
          SuperscriptBox["v", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}]}], 
     ")"}]}]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["u", "4"], "+", 
     RowBox[{"14", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     SuperscriptBox["v", "4"]}]], 
   RowBox[{"36", " ", 
    SuperscriptBox["tty", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "14"}], " ", 
       SuperscriptBox["u", "10"], " ", 
       SuperscriptBox["v", "2"]}], "+", 
      RowBox[{"952", " ", 
       SuperscriptBox["u", "8"], " ", 
       SuperscriptBox["v", "4"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["v", "6"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "2"]}], " ", 
         SuperscriptBox["v", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], "+", 
            SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}], "+", 
      RowBox[{
       SuperscriptBox["u", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2220", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["v", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "14"}], " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"159", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"952", " ", 
          SuperscriptBox["v", "8"]}], "+", 
         RowBox[{"159", " ", 
          SqrtBox["3"], " ", 
          SuperscriptBox["v", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}]}], 
     ")"}]}]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["u", "4"], "+", 
     RowBox[{"14", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["v", "2"]}], "+", 
     SuperscriptBox["v", "4"]}]], 
   RowBox[{"7776", " ", "tty", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "-", "v"}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "+", "v"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"39", " ", 
       SuperscriptBox["u", "18"], " ", 
       SuperscriptBox["v", "2"]}], "-", 
      RowBox[{"1824", " ", 
       SuperscriptBox["u", "16"], " ", 
       SuperscriptBox["v", "4"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["v", "14"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "2"]}], " ", 
         SuperscriptBox["v", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], "+", 
            SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}], "+", 
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["v", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"39", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"209", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "14"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"7860", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["u", "10"], " ", 
       SuperscriptBox["v", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1810"}], " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"847", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["u", "4"], " ", 
       SuperscriptBox["v", "10"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "608"}], " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"847", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "8"], " ", 
       SuperscriptBox["v", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3360"}], " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"1763", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "6"], " ", 
       SuperscriptBox["v", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"7860", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"1763", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["u", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3360", " ", 
          SuperscriptBox["v", "8"]}], "+", 
         RowBox[{"209", " ", 
          SqrtBox["3"], " ", 
          SuperscriptBox["v", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}]}], 
     ")"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["u", "4"], "+", 
       RowBox[{"14", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["v", "2"]}], "+", 
       SuperscriptBox["v", "4"]}], ")"}], "3"]], 
   RowBox[{"139968", " ", 
    SuperscriptBox["u", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "-", "v"}], ")"}], "4"], " ", 
    SuperscriptBox["v", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "+", "v"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "24"], "-", 
      RowBox[{"370", " ", 
       SuperscriptBox["u", "22"], " ", 
       SuperscriptBox["v", "2"]}], "+", 
      RowBox[{"9854", " ", 
       SuperscriptBox["u", "20"], " ", 
       SuperscriptBox["v", "4"]}], "+", 
      SuperscriptBox["v", "24"], "-", 
      RowBox[{"17", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["v", "18"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "2"]}], " ", 
         SuperscriptBox["v", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], "+", 
            SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["u", "6"], " ", 
       SuperscriptBox["v", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3611", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"39810", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["u", "10"], " ", 
       SuperscriptBox["v", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"19594", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"7533", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["u", "12"], " ", 
       SuperscriptBox["v", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"13259", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"6635", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["u", "4"], " ", 
       SuperscriptBox["v", "14"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4927", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"3834", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["u", "14"], " ", 
       SuperscriptBox["v", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"9797", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"639", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "18"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"7222", " ", 
          SuperscriptBox["v", "6"]}], "-", 
         RowBox[{"17", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["v", "16"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "370"}], " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"1431", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["u", "8"], " ", 
       SuperscriptBox["v", "10"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"71275", " ", 
          SuperscriptBox["v", "6"]}], "+", 
         RowBox[{"15066", " ", 
          SqrtBox["3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["u", "16"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "71275"}], " ", 
          SuperscriptBox["v", "8"]}], "+", 
         RowBox[{"477", " ", 
          SqrtBox["3"], " ", 
          SuperscriptBox["v", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["u", "2"]}], " ", 
            SuperscriptBox["v", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["u", "2"]}], "+", 
               SuperscriptBox["v", "2"]}], ")"}], "4"]}]]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.71926285512463*^9, 
  3.719262919730465*^9},ExpressionUUID->"ce66026c-75cb-49bd-b7d8-\
af69d018900f"]
}, Closed]],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"res2", "\[Equal]", "0"}], ",", "tty"}], "]"}]], "Input",
 CellChangeTimes->{{3.719262963875205*^9, 
  3.719262977201467*^9}},ExpressionUUID->"e41fa25b-528c-43bc-a793-\
c6734b1ec706"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["**Here are the calculations from scratch **", "Section",
 CellChangeTimes->{{3.718565872164432*^9, 3.718565881100749*^9}, {
  3.718966149402965*^9, 3.718966178755128*^9}, {3.718993586563897*^9, 
  3.7189936208758917`*^9}, {3.719778791358123*^9, 
  3.719778804701685*^9}},ExpressionUUID->"2b662d35-dca6-4397-846b-\
26944d959c90"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Defined", " ", "at", " ", "top", " ", "of", " ", "file"}], " ", 
   "*)"}], " ", "hornEigValEqn"}]], "Input",
 CellChangeTimes->{{3.7197789245800457`*^9, 
  3.719778930555977*^9}},ExpressionUUID->"9bfa4c40-2f94-40fb-8598-\
c87a5ad18396"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p2", "\[Equal]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}], ",", 
   RowBox[{"p3", "\[Equal]", 
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     SqrtBox["xx"], " ", 
     SqrtBox["yy"], " ", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"p4", "\[Equal]", 
    RowBox[{
     SuperscriptBox["xx", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
     SuperscriptBox["yy", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
     RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
     SuperscriptBox["zz", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719778931178005*^9},ExpressionUUID->"11b6479d-4420-4f23-ba3d-\
93a5aaad29c6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Elementary variable manipulations:  ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["pn   to   ee  or xx,   ee   to   xE   or   sqrt[xx]",
  FontSize->16,
  FontSlant->"Italic"]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.719779012268005*^9, 
  3.719779088235301*^9}},ExpressionUUID->"ca15be02-6c36-4cd6-be83-\
0c21f88aba69"],

Cell[BoxData["subForee"], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7197789646334248`*^9, 3.719778969756528*^9}, 
   3.71977902886663*^9},ExpressionUUID->"a3166c3d-3c42-48ab-9805-\
31627af81fea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ee1", "\[Rule]", 
    RowBox[{"xE", "+", "yE", "+", "zE"}]}], ",", 
   RowBox[{"ee2", "\[Rule]", 
    RowBox[{"xE", "-", "yE", "-", "zE"}]}], ",", 
   RowBox[{"ee3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}]}], ",", 
   RowBox[{"ee4", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.719778970584692*^9, 
  3.7197790288668833`*^9},ExpressionUUID->"9acc49f5-20b1-479c-8e96-\
95c9dc117c84"],

Cell[BoxData["subForxx"], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.719778971904418*^9, 3.719778975091569*^9}, 
   3.719779028867134*^9},ExpressionUUID->"f2cfe403-0b2c-492e-8f38-\
f1f99a119818"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ee1", "\[Rule]", 
    RowBox[{
     SqrtBox["xx"], "+", 
     SqrtBox["yy"], "+", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee2", "\[Rule]", 
    RowBox[{
     SqrtBox["xx"], "-", 
     SqrtBox["yy"], "-", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["xx"]}], "+", 
     SqrtBox["yy"], "-", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"ee4", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["xx"]}], "-", 
     SqrtBox["yy"], "+", 
     SqrtBox["zz"]}]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.719778975665185*^9, 
  3.719779028867385*^9},ExpressionUUID->"f47eef85-3397-455d-b099-\
4628470e69cf"],

Cell[BoxData["pToeeRule"], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7197789772858543`*^9, 3.719778989103922*^9}, 
   3.7197790288676367`*^9},ExpressionUUID->"2a94b3fe-1c03-464c-b490-\
35378b01f5ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"ee1", " ", "ee2"}], "+", 
     RowBox[{"ee1", " ", "ee3"}], "+", 
     RowBox[{"ee2", " ", "ee3"}], "+", 
     RowBox[{"ee1", " ", "ee4"}], "+", 
     RowBox[{"ee2", " ", "ee4"}], "+", 
     RowBox[{"ee3", " ", "ee4"}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "ee1"}], " ", "ee2", " ", "ee3"}], "-", 
     RowBox[{"ee1", " ", "ee2", " ", "ee4"}], "-", 
     RowBox[{"ee1", " ", "ee3", " ", "ee4"}], "-", 
     RowBox[{"ee2", " ", "ee3", " ", "ee4"}]}]}], ",", 
   RowBox[{"p4", "\[Rule]", 
    RowBox[{"ee1", " ", "ee2", " ", "ee3", " ", "ee4"}]}]}], "}"}]], "Output",\

 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7197789896957912`*^9, 
  3.719779028867877*^9},ExpressionUUID->"a524cffe-afef-4364-a1af-\
0fe64463b857"],

Cell[BoxData["pToxxRule"], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.719778990622691*^9, 3.719778993135069*^9}, 
   3.719779028868127*^9},ExpressionUUID->"859435cd-b9b6-46c9-9a67-\
85aa429b4644"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     SuperscriptBox["xx", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
     SuperscriptBox["yy", "2"], "-", 
     RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
     RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
     SuperscriptBox["zz", "2"]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     SqrtBox["xx"], " ", 
     SqrtBox["yy"], " ", 
     SqrtBox["zz"]}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7197789937887278`*^9, 
  3.719779028868375*^9},ExpressionUUID->"ab556633-cd31-4f4d-bf87-\
46be67df8b2b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Here is the ",
 StyleBox["actual original solution,",
  FontWeight->"Bold"],
 " along with checks to show how it works, but\n   it is useless until you \
pick a certain set of phases, in next section:"
}], "Subsubsection",
 CellChangeTimes->{{3.719779121011076*^9, 
  3.719779171667005*^9}},ExpressionUUID->"103acbd7-a683-4719-b35f-\
aa984a77144e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornEigValRules", " ", "=", " ", 
   RowBox[{"Solve", "[", 
    RowBox[{"hornEigValEqn", ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.719675233171204*^9, 
  3.7196752674906387`*^9}},ExpressionUUID->"a73e7163-467a-44d7-a5d2-\
ee12368b0ab0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"hornEigValRules", "//", "Dimensions"}], ",", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"ByteCount", ",", "hornEigValRules", ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.719675273987878*^9, 
  3.719675306019141*^9}},ExpressionUUID->"15a18862-8bd7-4dd3-8899-\
095914c66af3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4288", ",", "18256", ",", "19832"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4288", ",", "18328", ",", "19832"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4928", ",", "20816", ",", "27976"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4928", ",", "20888", ",", "27976"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4928", ",", "20816", ",", "27976"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4928", ",", "20888", ",", "27976"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7196753065610523`*^9},ExpressionUUID->"56b57a82-a9a3-4a5a-bc92-\
46c139207a2d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Check", " ", "*)"}], " ", 
  RowBox[{
   RowBox[{"hornEigValRules", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "//", "Short"}]}]], "Input",
 CellChangeTimes->{{3.719678814507456*^9, 
  3.719678837675918*^9}},ExpressionUUID->"d9c6532b-45c7-47be-9c96-\
6f4cb1296fe1"],

Cell[BoxData[
 TagBox[
  RowBox[{"xx", "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "256"}], " ", 
       SuperscriptBox["p2", "2"]}], "-", 
      RowBox[{"3072", " ", "p4"}]}], 
     RowBox[{"96", " ", 
      SuperscriptBox["2", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]], "+", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8192", " ", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"\[LeftSkeleton]", "3", "\[RightSkeleton]"}], "+", 
        SqrtBox[
         RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]]}], ")"}], 
      RowBox[{"1", "/", "3"}]], 
     RowBox[{"192", " ", 
      SuperscriptBox["2", 
       RowBox[{"1", "/", "3"}]]}]]}]}],
  Short]], "Output",
 CellChangeTimes->{{3.719678816265958*^9, 3.7196788233155117`*^9}, 
   3.719780424568591*^9},ExpressionUUID->"9708764f-95a7-40a6-8d26-\
87cd9f74d486"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Note", " ", "that", " ", 
     RowBox[{"soln", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", "is", " ", "rank"}], "-", 
    "ordered"}], " ", "*)"}], 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Last", "[", "#", "]"}], "/.", 
        RowBox[{"randomPn", " ", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "//", "Chop"}], ")"}], "&"}], ",", 
    "hornEigValRules", ",", 
    RowBox[{"{", "2", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.719675845467655*^9, 3.7196758899645033`*^9}, {
  3.7196759785268908`*^9, 3.719675982237919*^9}, {3.719676150561565*^9, 
  3.719676164417194*^9}},ExpressionUUID->"75847604-ce41-415a-a2a9-\
4dc119850728"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1.0100412460233583`", ",", "0.2833804434444893`", ",", 
     "0.23502598724075566`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.0100412460233583`", ",", "0.23502598724075566`", ",", 
     "0.2833804434444893`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.23502598724076126`", ",", "1.0100412460233588`", ",", 
     "0.2833804434444834`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.23502598724076126`", ",", "0.2833804434444834`", ",", 
     "1.0100412460233588`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.28338044344448365`", ",", "1.0100412460233585`", ",", 
     "0.23502598724076096`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.28338044344448365`", ",", "0.23502598724076113`", ",", 
     "1.0100412460233583`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719675877557252*^9, 3.719675890415245*^9}, 
   3.719675983189946*^9},ExpressionUUID->"6a8951eb-2e70-44c3-909a-\
4ef36dd94c0b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ee1", ",", "ee2", ",", "ee3", ",", "ee4"}], "}"}], "/.", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"subForxx", "/.", 
      RowBox[{"hornEigValRules", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "/.", 
     RowBox[{"randomPn", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ")"}]}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.71967877450828*^9, 3.719678802379339*^9}, {
  3.7196788486860437`*^9, 3.719678901292651*^9}, {3.719780439401867*^9, 
  3.719780451300581*^9}, {3.7197805251937923`*^9, 
  3.719780525632584*^9}},ExpressionUUID->"5832725c-6012-4c01-8231-\
06a43114a692"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.246292821490885`", ",", 
       RowBox[{"-", "0.34124208254305555`"}], ",", 
       RowBox[{"-", "0.6026705273796603`"}], ",", 
       RowBox[{"-", "1.302380211568169`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.246292821490885`", ",", 
       RowBox[{"-", "0.34124208254305566`"}], ",", 
       RowBox[{"-", "1.302380211568169`"}], ",", 
       RowBox[{"-", "0.6026705273796605`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.0247568239785876`", ",", 
       RowBox[{"-", "0.2326394324622728`"}], ",", 
       RowBox[{"-", "0.4776862131685068`"}], ",", 
       RowBox[{"-", "1.314431178347808`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.0247568239785876`", ",", 
       RowBox[{"-", "0.2326394324622728`"}], ",", 
       RowBox[{"-", "1.3144311783478075`"}], ",", 
       RowBox[{"-", "0.4776862131685071`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.1201922809196`", ",", "0.2119549866136824`", ",", 
       RowBox[{"-", "1.0200105562976276`"}], ",", 
       RowBox[{"-", "1.3121367112356546`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1201922809196`", ",", "0.2119549866136824`", ",", 
       RowBox[{"-", "1.3121367112356546`"}], ",", 
       RowBox[{"-", "1.0200105562976276`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.090060886047424`", ",", "0.41811257425446746`", ",", 
       RowBox[{"-", "0.9691816431478324`"}], ",", 
       RowBox[{"-", "1.5389918171540593`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.090060886047425`", ",", "0.41811257425446724`", ",", 
       RowBox[{"-", "1.5389918171540593`"}], ",", 
       RowBox[{"-", "0.9691816431478328`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.719678896002103*^9, 3.7196789018922577`*^9}, {
   3.719780442778926*^9, 3.719780452089243*^9}, 
   3.71978052700941*^9},ExpressionUUID->"9fb6e0c2-24d6-4e0f-85ac-\
5e994d577852"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "We", " ", "can", " ", "actually", " ", "check", " ", "the", " ", 
     "eigenvalues", " ", "numerically", " ", "using", " ", "the", " ", 
     RowBox[{"randomabc", "'"}], "s", "\[IndentingNewLine]", "YES"}], "  ", 
    "-", " ", 
    RowBox[{"they", " ", 
     RowBox[{"match", "!"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Eigenvalues", "/@", 
   RowBox[{"(", 
    RowBox[{"hornAmat", "/.", 
     RowBox[{"randomabcxyz", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.719779245370996*^9, 3.719779406553837*^9}, 
   3.719779934850993*^9, {3.7197805669275017`*^9, 
   3.719780572399403*^9}},ExpressionUUID->"39ecf648-09a4-4c9f-9408-\
2d42380f4c25"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.2462928214908855`", ",", 
     RowBox[{"-", "1.3023802115681693`"}], ",", 
     RowBox[{"-", "0.6026705273796606`"}], ",", 
     RowBox[{"-", "0.34124208254305577`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.0247568239785867`", ",", 
     RowBox[{"-", "1.3144311783478078`"}], ",", 
     RowBox[{"-", "0.4776862131685072`"}], ",", 
     RowBox[{"-", "0.23263943246227292`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.1201922809196003`", ",", 
     RowBox[{"-", "1.3121367112356523`"}], ",", 
     RowBox[{"-", "1.0200105562976296`"}], ",", "0.21195498661368187`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.090060886047427`", ",", 
     RowBox[{"-", "1.5389918171540529`"}], ",", 
     RowBox[{"-", "0.9691816431478391`"}], ",", "0.41811257425446513`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719779386169465*^9, 3.719779407566844*^9}, 
   3.7197802255698147`*^9},ExpressionUUID->"54264e24-fb7a-4496-a8b8-\
d249d5a3ad5d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"randomabcxyz", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.719779697493545*^9, 
  3.719779698318637*^9}},ExpressionUUID->"5a06f251-01b4-4dd2-b9f5-\
bcfa1e3de799"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "0.6165073333488962`"}], ",", 
   RowBox[{"b", "\[Rule]", "0.7537066948725346`"}], ",", 
   RowBox[{"c", "\[Rule]", "0.6843900834577643`"}], ",", 
   RowBox[{"aa", "\[Rule]", "0.24925368079094157`"}], ",", 
   RowBox[{"bb", "\[Rule]", "0.31809576900866243`"}], ",", 
   RowBox[{"cc", "\[Rule]", "0.5229614308434458`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.509131066857544`"}], ",", 
   RowBox[{"y", "\[Rule]", "0.32676653580083004`"}], ",", 
   RowBox[{"z", "\[Rule]", "0.7160706428131662`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719779698772485*^9},ExpressionUUID->"76e058dd-72d5-4f81-84e4-\
f8a16a5ce9a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Verify", " ", "that", " ", "prestored", " ", "randomPn", " ", "matches", 
    " ", "abcxyz"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"randomPn", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "4"}], "]"}], "]"}], ",", 
    RowBox[{"thePRule", "/.", 
     RowBox[{"randomabcxyz", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "4"}], "]"}], "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7197797479660873`*^9, 3.719779758239538*^9}, {
  3.71978017937989*^9, 3.7197802130584393`*^9}, {3.719780264171067*^9, 
  3.719780304386735*^9}},ExpressionUUID->"b3a3c7ff-0b74-4bbb-8724-\
1b62840cff81"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", 
        RowBox[{"-", "0.6016538434420748`"}]}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"-", "2.9555639350546095`"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"-", "3.6108417894181155`"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", 
        RowBox[{"-", "0.2957581765791444`"}]}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"-", "1.9694006877309675`"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"-", "3.05483737132415`"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", "0.6014543086803754`"}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"-", "2.073297508622827`"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"-", "3.6511322541761886`"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", "1.3034478406395165`"}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"-", "1.5492533001477802`"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"-", "3.9254907514084647`"}]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", 
        RowBox[{"-", "0.6016538434420748`"}]}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"-", "2.95556393505461`"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"-", "3.6108417894181155`"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", 
        RowBox[{"-", "0.2957581765791443`"}]}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"-", "1.9694006877309673`"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"-", "3.05483737132415`"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", "0.6014543086803754`"}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"-", "2.073297508622827`"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"-", "3.6511322541761886`"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p4", "\[Rule]", "1.3034478406395165`"}], ",", 
       RowBox[{"p3", "\[Rule]", 
        RowBox[{"-", "1.5492533001477802`"}]}], ",", 
       RowBox[{"p2", "\[Rule]", 
        RowBox[{"-", "3.9254907514084647`"}]}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.719780305103043*^9},ExpressionUUID->"c14d972b-a035-489c-aa28-\
057b37b5039e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"From", " ", "above"}], ",", " ", 
    RowBox[{"we", " ", "see", " ", 
     RowBox[{
      RowBox[{"that", " ", "[", 
       RowBox[{"[", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3", ",", "5"}], "}"}], "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", "are", " ", "distinct"}], ",", " ",
     "short", ",", " ", 
    RowBox[{
     RowBox[{"solutions", ".", "\[IndentingNewLine]", "Thus"}], " ", "the", 
     " ", "following", "  ", "are", " ", "very", " ", "close", " ", "to", " ",
      "the", " ", "simplified", " ", "solutions"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hornEigValRules", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"hornEigValRules", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "1", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"hornEigValRules", "[", 
      RowBox[{"[", 
       RowBox[{"5", ",", "1", ",", "2"}], "]"}], "]"}]}], "}"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7196753402118073`*^9, 3.719675466133576*^9}, {
  3.719675741227029*^9, 3.719675788491083*^9}, {3.719676043886984*^9, 
  3.719676101983965*^9}},ExpressionUUID->"e649c6f5-9920-450e-83af-\
7d390d46496d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "-", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", 
                SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
               RowBox[{"432", " ", "p2", " ", 
                SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "3"], "-", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", 
              SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
             RowBox[{"432", " ", "p2", " ", 
              SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "+", 
         SqrtBox["3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "-", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", 
                SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
               RowBox[{"432", " ", "p2", " ", 
                SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "24"], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"\[ImaginaryI]", "+", 
       SqrtBox["3"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "3"], "-", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", 
              SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
             RowBox[{"432", " ", "p2", " ", 
              SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", "+", 
         SqrtBox["3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "3"], "-", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", 
                SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
               RowBox[{"432", " ", "p2", " ", 
                SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "24"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "3"], "-", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", 
              SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
             RowBox[{"432", " ", "p2", " ", 
              SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7196753458638897`*^9, 3.719675384516449*^9}, {
  3.7196754494972*^9, 3.719675467881303*^9}, {3.7196757422061243`*^9, 
  3.7196757685864487`*^9}},ExpressionUUID->"37170fbf-c94f-4b4c-bdf0-\
9eb58e797428"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["HERE is the reduce phase-utilizing solution",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.719779121011076*^9, 3.719779171667005*^9}, {
  3.719780679961512*^9, 
  3.719780697405572*^9}},ExpressionUUID->"116842f2-a940-413d-ae56-\
20c627068455"],

Cell[BoxData[
 RowBox[{
  RowBox[{"answerXXRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"zz", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["1", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}]}], ",", 
     RowBox[{"xx", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"24", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}]}], ",", 
     RowBox[{"yy", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"24", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719680836011992*^9, 3.719680845968569*^9}, {
  3.719780708054776*^9, 
  3.719780720275622*^9}},ExpressionUUID->"4fcfdc0d-853f-4f75-8fb9-\
ff28c495390d"],

Cell[TextData[StyleBox["Roots:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.719874457778788*^9, 
  3.719874459097662*^9}},ExpressionUUID->"750b2897-9777-418b-bac8-\
6d8d28b98383"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rz", ",", "ry", ",", "rx"}], "}"}], "\[Rule]", " ", 
    RowBox[{"First", "/@", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "\[Equal]", 
        SuperscriptBox["z", "3"]}], ",", "z"}], "]"}]}]}], "//", 
   "ComplexExpand"}], "//", "Together"}]], "Input",
 CellChangeTimes->{{3.719874463629141*^9, 3.719874518692501*^9}, {
  3.719874709633624*^9, 3.719874715047686*^9}, {3.719874775786837*^9, 
  3.7198747773595123`*^9}},ExpressionUUID->"3ad64b2b-11ed-4bc7-8fd2-\
38c2b3a3571c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qrtRule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"rz", "\[Rule]", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{"ry", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}]}]}], ",", 
    RowBox[{"rx", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.719874793036364*^9, 
  3.7198748128786707`*^9}},ExpressionUUID->"134a5dad-c6af-496b-aead-\
fde272d81889"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"rz", "\[Rule]", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{"ry", "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}]}]}], ",", 
   RowBox[{"rx", "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719874813930354*^9},ExpressionUUID->"1f8471e1-ee22-405d-8443-\
235ec6c18541"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox["rx", "2"], ",", 
       SuperscriptBox["ry", "2"], ",", 
       SuperscriptBox["rz", "2"]}], "}"}], "/.", "qrtRule"}], " ", "//", 
    "ComplexExpand"}], "//", "Expand"}], "//", "Together"}]], "Input",
 CellChangeTimes->{{3.719874732810688*^9, 3.7198747579109592`*^9}, {
  3.719874821111924*^9, 
  3.719874880294105*^9}},ExpressionUUID->"58513c2e-d800-4acc-9031-\
1298451834e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], "   ", 
    RowBox[{"(", 
     RowBox[{"1", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       SqrtBox["3"]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], "   ", 
    RowBox[{"(", " ", 
     RowBox[{"1", "-", " ", 
      RowBox[{"\[ImaginaryI]", 
       SqrtBox["3"]}]}], ")"}]}], ",", "1"}], "}"}]], "Input",
 CellChangeTimes->{{3.719874896252618*^9, 
  3.719874940428639*^9}},ExpressionUUID->"d81b5cbd-b17d-4556-a6b5-\
18fe698ff83c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Call", " ", "with", " ", "root3"}], " ", "=", " ", 
     RowBox[{"string", " ", "\"\<x\>\""}]}], ",", " ", "\"\<y\>\"", ",", " ", 
    
    RowBox[{"or", " ", "\"\<z\>\"", "\[IndentingNewLine]", "  ", 
     RowBox[{"NOTE", "!"}], " ", "The", " ", "ORDER", " ", "of", " ", "X", 
     " ", "and", " ", "Y", " ", "had", " ", "to", " ", "be", " ", "switched", 
     " ", "to", " ", "agree", " ", "with", " ", "eigval", " ", "rank", " ", 
     "ordering"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"root3_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"qq3", ",", 
       RowBox[{"phi", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"root3", ",", "\"\<x\>\"", ",", 
          FractionBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<y\>\"", ",", 
          FractionBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<z\>\"", ",", 
          RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["p2", "6"]}], "+", 
        FractionBox[
         RowBox[{"  ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}], 
         RowBox[{"12", " ", "phi", "  ", "qq3"}]], "+", 
        RowBox[{
         FractionBox["phi", "12"], "  ", "qq3"}]}], ")"}], "/.", 
      RowBox[{"qq3", "\[Rule]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719597193946005*^9, 3.719597305370088*^9}, {
   3.7195973505286922`*^9, 3.719597382137249*^9}, {3.7195974123298903`*^9, 
   3.719597510213501*^9}, {3.719597604532134*^9, 3.719597613925857*^9}, {
   3.7195976910520077`*^9, 3.7195976921617413`*^9}, 3.7195984437457933`*^9, {
   3.719598546775992*^9, 3.719598570169475*^9}, {3.719801985921894*^9, 
   3.71980199062432*^9}, {3.719802071752438*^9, 3.719802072574925*^9}, 
   3.719802200937204*^9, {3.719802702899005*^9, 3.719802744546809*^9}, {
   3.719802897544032*^9, 
   3.719802919926641*^9}},ExpressionUUID->"11f4f4ab-a51e-4864-93e8-\
121dd0114402"],

Cell[TextData[StyleBox["Define alternatively the square roots of xx,yy,zz  as \
a function with args \[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote] \
\[OpenCurlyDoubleQuote]y\[CloseCurlyDoubleQuote] \[OpenCurlyDoubleQuote]z\
\[CloseCurlyDoubleQuote]",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7198019260623093`*^9, 3.719801948694252*^9}, {
  3.719802049876522*^9, 
  3.719802063309208*^9}},ExpressionUUID->"529ba78f-60a6-4ecc-a728-\
a3f2637023bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Call", " ", "with", " ", "root3"}], " ", "=", " ", 
     RowBox[{"string", " ", "\"\<x\>\""}]}], ",", " ", "\"\<y\>\"", ",", " ", 
    
    RowBox[{"or", " ", "\"\<z\>\"", "\[IndentingNewLine]", "  ", 
     RowBox[{"NOTE", "!"}], " ", "The", " ", "ORDER", " ", "of", " ", "X", 
     " ", "and", " ", "Y", " ", "had", " ", "to", " ", "be", " ", "switched", 
     " ", "to", " ", "agree", " ", "with", " ", "eigval", " ", "rank", " ", 
     "ordering"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"xyzRoot", "[", 
    RowBox[{"root3_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"qq3", ",", 
       RowBox[{"phi", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"root3", ",", "\"\<x\>\"", ",", 
          FractionBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<y\>\"", ",", 
          FractionBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<z\>\"", ",", 
          RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"(", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["p2", "6"]}], "+", 
         FractionBox[
          RowBox[{"  ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p2", "2"], "+", 
             RowBox[{"12", " ", "p4"}]}], ")"}]}], 
          RowBox[{"12", " ", "phi", "  ", "qq3"}]], "+", 
         RowBox[{
          FractionBox["phi", "12"], "  ", "qq3"}]}]], ")"}], "/.", 
      RowBox[{"qq3", "\[Rule]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719597193946005*^9, 3.719597305370088*^9}, {
   3.7195973505286922`*^9, 3.719597382137249*^9}, {3.7195974123298903`*^9, 
   3.719597510213501*^9}, {3.719597604532134*^9, 3.719597613925857*^9}, {
   3.7195976910520077`*^9, 3.7195976921617413`*^9}, 3.7195984437457933`*^9, {
   3.719598546775992*^9, 3.719598570169475*^9}, {3.719801985921894*^9, 
   3.71980199062432*^9}, {3.719802071752438*^9, 3.719802072574925*^9}, 
   3.719802200937204*^9, {3.719802702899005*^9, 
   3.719802744546809*^9}},ExpressionUUID->"b9c65a37-46c7-4256-9ba5-\
755daeafb963"],

Cell[TextData[StyleBox["Do these match the numerical eigenvalues?  Yes.",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.719780871420451*^9, 3.719780874867676*^9}, {
  3.719781037369985*^9, 
  3.719781051722106*^9}},ExpressionUUID->"e9e72fa1-cd64-4d31-8856-\
ffa3fbb07751"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"ee1", ",", "ee2", ",", "ee3", ",", "ee4"}], "}"}], "/.", 
  "subForxx"}]], "Input",ExpressionUUID->"a999a4b1-2ec6-4d66-9af9-\
ae0558e459a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SqrtBox["xx"], "+", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    SqrtBox["xx"], "-", 
    SqrtBox["yy"], "-", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "+", 
    SqrtBox["yy"], "-", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "-", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719780879594652*^9},ExpressionUUID->"bcf2f9d4-0d0d-4724-ba21-\
5053463ed6d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ee1", ",", "ee2", ",", "ee3", ",", "ee4"}], "}"}], "/.", 
    "subForxx"}], "/.", 
   RowBox[{"(", 
    RowBox[{"answerXXRule", "/.", 
     RowBox[{"randomPn", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ")"}]}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{
  3.719780851416201*^9, {3.71978088456421*^9, 
   3.719780898891922*^9}},ExpressionUUID->"9c11b120-52b4-4077-a54d-\
8496616b6e8c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.246292821490885`", ",", 
     RowBox[{"-", "0.34124208254305605`"}], ",", 
     RowBox[{"-", "0.6026705273796602`"}], ",", 
     RowBox[{"-", "1.3023802115681689`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.0247568239785876`", ",", 
     RowBox[{"-", "0.23263943246227298`"}], ",", 
     RowBox[{"-", "0.4776862131685072`"}], ",", 
     RowBox[{"-", "1.3144311783478075`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.1201922809196003`", ",", "0.21195498661368195`", ",", 
     RowBox[{"-", "1.0200105562976307`"}], ",", 
     RowBox[{"-", "1.3121367112356515`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.090060886047427`", ",", "0.4181125742544652`", ",", 
     RowBox[{"-", "0.9691816431478393`"}], ",", 
     RowBox[{"-", "1.5389918171540526`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7197808860229177`*^9, 
  3.719780899274747*^9}},ExpressionUUID->"c171cbbe-6ea6-4100-bfc2-\
41868a2dd3c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"ee1", ",", "ee2", ",", "ee3", ",", "ee4"}], "}"}], "/.", 
  "subForee"}]], "Input",
 CellChangeTimes->{{3.719802140388754*^9, 
  3.7198021664201612`*^9}},ExpressionUUID->"908faae1-ae63-477f-9bbd-\
c36b14ef807b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"xE", "+", "yE", "+", "zE"}], ",", 
   RowBox[{"xE", "-", "yE", "-", "zE"}], ",", 
   RowBox[{
    RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}], ",", 
   RowBox[{
    RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7198021674399757`*^9},ExpressionUUID->"75d2e25b-5384-4c3d-8ee3-\
8d49a66af3af"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ee1", ",", "ee2", ",", "ee3", ",", "ee4"}], "}"}], "/.", 
     "subForee"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xE", "\[Rule]", 
       RowBox[{"xyzRoot", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"yE", "->", 
       RowBox[{"xyzRoot", "[", 
        RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"zE", "->", 
       RowBox[{"xyzRoot", "[", 
        RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
     "}"}]}], "/.", 
   RowBox[{"randomPn", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.719802178780096*^9, 
  3.7198022868787003`*^9}},ExpressionUUID->"ff6357d0-f1df-423a-83cb-\
3095dabbcf4d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.2462928214908855`", ",", 
     RowBox[{"-", "0.34124208254305605`"}], ",", 
     RowBox[{"-", "0.6026705273796603`"}], ",", 
     RowBox[{"-", "1.302380211568169`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.0247568239785876`", ",", 
     RowBox[{"-", "0.23263943246227292`"}], ",", 
     RowBox[{"-", "0.4776862131685071`"}], ",", 
     RowBox[{"-", "1.3144311783478075`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.1201922809196003`", ",", "0.21195498661368195`", ",", 
     RowBox[{"-", "1.0200105562976307`"}], ",", 
     RowBox[{"-", "1.3121367112356515`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.090060886047427`", ",", "0.41811257425446513`", ",", 
     RowBox[{"-", "0.9691816431478393`"}], ",", 
     RowBox[{"-", "1.5389918171540526`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7198022717267942`*^9, 3.7198022880285892`*^9}, 
   3.719802764133223*^9},ExpressionUUID->"23c87fb0-acf5-464f-9121-\
7ff2c1cb0f30"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Check", " ", "the", " ", 
     RowBox[{"order", "?", "  ", 
      RowBox[{"-", " ", "Wanted"}]}], " ", "x", " ", "to", " ", "be", " ", 
     "the", " ", "1", "st", " ", "quadrant", " ", "root"}], ",", " ", 
    RowBox[{
    "but", " ", "for", " ", "order", "\[IndentingNewLine]", "    ", 
     "consistency"}], ",", " ", 
    RowBox[{
     RowBox[{"xyzRoot", "[", "x", "]"}], " ", "is", " ", "4", "th", " ", 
     "quadrant", " ", "root"}]}], "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox["xx"], ",", 
         SqrtBox["yy"], ",", 
         SqrtBox["zz"]}], "}"}], "/.", "answerXXRule"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xyzRoot", "[", 
         RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
        RowBox[{"xyzRoot", "[", 
         RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
        RowBox[{"xyzRoot", "[", 
         RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], 
       "}"}]}], "}"}], "/.", 
    RowBox[{"randomPn", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.719802404901026*^9, 3.719802416329557*^9}, {
  3.719802463234136*^9, 3.719802514608634*^9}, {3.7198025536884212`*^9, 
  3.719802614884021*^9}, {3.7198027880156507`*^9, 
  3.719802830990568*^9}},ExpressionUUID->"8a4260ca-a088-4b35-9021-\
fe3107cf9d1b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.9525253694739146`", ",", "0.8218111470556125`", ",", 
       "0.47195630496135815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.9525253694739146`", ",", "0.8218111470556125`", ",", 
       "0.47195630496135815`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.8960586957581573`", ",", "0.7735353054050402`", ",", 
       "0.3551628228153901`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.8960586957581573`", ",", "0.7735353054050402`", ",", 
       "0.3551628228153901`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1.166073633766641`", ",", "0.5500908623109848`", ",", 
       "0.4040277848419743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1.166073633766641`", ",", "0.5500908623109848`", ",", 
       "0.4040277848419743`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1.254086730150946`", ",", "0.5604396214497938`", ",", 
       "0.275534534446687`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1.254086730150946`", ",", "0.5604396214497938`", ",", 
       "0.275534534446687`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719802587931881*^9, 3.719802617516766*^9}, 
   3.7198027775246563`*^9},ExpressionUUID->"d98127c9-7600-44a9-a094-\
f65e13a20109"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}], "/.", "answerXXRule"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xxyyzzRoot", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
       RowBox[{"xxyyzzRoot", "[", 
        RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
       RowBox[{"xxyyzzRoot", "[", 
        RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], 
      "}"}]}], "}"}], "/.", 
   RowBox[{"randomPn", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.719802945389715*^9, 
  3.719802975839137*^9}},ExpressionUUID->"121f447e-6127-4289-8fc7-\
766e92cea6a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.9073045794914176`", ",", "0.6753735614248616`", ",", 
       "0.2227427537927785`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.9073045794914176`", ",", "0.6753735614248617`", ",", 
       "0.2227427537927785`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.8029211862438099`", ",", "0.5983568687080689`", ",", 
       "0.12614063071019616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.8029211862438099`", ",", "0.5983568687080689`", ",", 
       "0.12614063071019616`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1.3597277193657387`", ",", "0.30259995679804286`", ",", 
       "0.16323845092431266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1.3597277193657387`", ",", "0.3025999567980429`", ",", 
       "0.16323845092431266`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1.5727335267406917`", ",", "0.31409256929078816`", ",", 
       "0.07591927967275258`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1.5727335267406917`", ",", "0.31409256929078816`", ",", 
       "0.07591927967275258`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719802977958654*^9},ExpressionUUID->"b6c3664c-ebc6-48ed-b190-\
6281b9b05c1b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "..", "and", " ", "check", " ", "these", " ", "forms", " ", "of", "  ", 
     "eigenvalues", " ", "numerically", " ", "using", " ", "the", " ", 
     RowBox[{"randomabc", "'"}], "s", "\[IndentingNewLine]", "YES"}], "  ", 
    "-", " ", 
    RowBox[{"they", " ", 
     RowBox[{"match", "!"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Eigenvalues", "/@", 
   RowBox[{"(", 
    RowBox[{"hornAmat", "/.", 
     RowBox[{"randomabcxyz", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.719779245370996*^9, 3.719779406553837*^9}, 
   3.719779934850993*^9, {3.7197805669275017`*^9, 3.719780572399403*^9}, {
   3.719780918635845*^9, 
   3.719780929532901*^9}},ExpressionUUID->"25cdcf5d-6b3f-45c7-8b1c-\
1ef194929ee1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.2462928214908855`", ",", 
     RowBox[{"-", "1.3023802115681693`"}], ",", 
     RowBox[{"-", "0.6026705273796606`"}], ",", 
     RowBox[{"-", "0.34124208254305577`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.0247568239785867`", ",", 
     RowBox[{"-", "1.3144311783478078`"}], ",", 
     RowBox[{"-", "0.4776862131685072`"}], ",", 
     RowBox[{"-", "0.23263943246227292`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.1201922809196003`", ",", 
     RowBox[{"-", "1.3121367112356523`"}], ",", 
     RowBox[{"-", "1.0200105562976296`"}], ",", "0.21195498661368187`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.090060886047427`", ",", 
     RowBox[{"-", "1.5389918171540529`"}], ",", 
     RowBox[{"-", "0.9691816431478391`"}], ",", "0.41811257425446513`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719780906036851*^9},ExpressionUUID->"ab296eaf-7b2a-4bd5-b4e7-\
1f6aad8273b2"]
}, Open  ]],

Cell[TextData[StyleBox["HERE is the calculation of the algebraic equation \
solved by  answer XX rule",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.719781104834304*^9, 
  3.719781132345359*^9}},ExpressionUUID->"2623e09e-2199-4f29-a5c6-\
c1bbeddffeb9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Try to see if you can get eig solutions to compare to xx,yy,zz?
   ** Really would like to see these answers, jog the space in which
           we see the xx,yy,zz expressions [p2,p3,p4].
       It actually ran, 2.85 HOURS, and got 40 GB of algebraic answers,
          which crashed the kernel..\
\>", "Section",
 CellChangeTimes->{{3.719335170260228*^9, 3.719335191780765*^9}, {
  3.719335652796036*^9, 3.719335706093314*^9}, {3.719362252580803*^9, 
  3.719362309826956*^9}},ExpressionUUID->"ce8bc90a-56de-4ede-9614-\
42fe375e1e42"],

Cell[CellGroupData[{

Cell[BoxData["eqGenEig"], "Input",
 CellChangeTimes->{{3.7193352047906857`*^9, 
  3.719335206085906*^9}},ExpressionUUID->"a9e5ea41-6811-4a1b-8f14-\
97affa81c7b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ee1", " ", "ee2", " ", "ee3", " ", "ee4"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "ee1"}], " ", "ee2", " ", "ee3"}], "-", 
    RowBox[{"ee1", " ", "ee2", " ", "ee4"}], "-", 
    RowBox[{"ee1", " ", "ee3", " ", "ee4"}], "-", 
    RowBox[{"ee2", " ", "ee3", " ", "ee4"}]}], ",", 
   RowBox[{
    RowBox[{"ee1", " ", "ee2"}], "+", 
    RowBox[{"ee1", " ", "ee3"}], "+", 
    RowBox[{"ee2", " ", "ee3"}], "+", 
    RowBox[{"ee1", " ", "ee4"}], "+", 
    RowBox[{"ee2", " ", "ee4"}], "+", 
    RowBox[{"ee3", " ", "ee4"}]}], ",", 
   RowBox[{
    RowBox[{"-", "ee1"}], "-", "ee2", "-", "ee3", "-", "ee4"}], ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.719335208167886*^9},ExpressionUUID->"bc7e68e0-2303-42df-be2b-\
24ee783e5426"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigSolveEqn", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"eqGenEig", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ee2", "\[Rule]", "ex"}], ",", 
           RowBox[{"ee3", "\[Rule]", "ey"}], ",", 
           RowBox[{"ee4", "\[Rule]", "ez"}], ",", 
           RowBox[{"ee1", "\[Rule]", 
            RowBox[{
             RowBox[{"-", "ex"}], "-", "ey", "-", "ez"}]}]}], "}"}]}], ")"}], 
       "\[Equal]", " ", 
       RowBox[{"eqPform", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", " ", "4"}], "}"}]}], "]"}], "//", 
    "Expand"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.719335220151238*^9, 
  3.7193353277529078`*^9}},ExpressionUUID->"873efcf1-8c79-4f7d-bdb7-\
836d0ab3ae7a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ex", " ", "ey", " ", "ez", " ", 
      RowBox[{"(", 
       RowBox[{"ex", "+", "ey", "+", "ez"}], ")"}]}], "+", "p4"}], "\[Equal]",
     "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"ex", "+", "ey"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"ex", "+", "ez"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"ey", "+", "ez"}], ")"}]}], "\[Equal]", "p3"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["ex", "2"], "+", 
     SuperscriptBox["ey", "2"], "+", 
     RowBox[{"ey", " ", "ez"}], "+", 
     SuperscriptBox["ez", "2"], "+", 
     RowBox[{"ex", " ", 
      RowBox[{"(", 
       RowBox[{"ey", "+", "ez"}], ")"}]}], "+", "p2"}], "\[Equal]", "0"}], 
   ",", 
   RowBox[{"p1", "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719335247327818*^9, {3.719335297754538*^9, 3.719335328367041*^9}, 
   3.719349952462317*^9},ExpressionUUID->"9c08a036-d274-4692-8b87-\
92eb76cf06bc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigSolveEqn", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "3"}], "]"}], "]"}]], "Input",ExpressionUUID->"c79948ee-\
043d-4d83-b6a8-1f4300577823"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ex", " ", "ey", " ", "ez", " ", 
      RowBox[{"(", 
       RowBox[{"ex", "+", "ey", "+", "ez"}], ")"}]}], "+", "p4"}], "\[Equal]",
     "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"ex", "+", "ey"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"ex", "+", "ez"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"ey", "+", "ez"}], ")"}]}], "\[Equal]", "p3"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["ex", "2"], "+", 
     SuperscriptBox["ey", "2"], "+", 
     RowBox[{"ey", " ", "ez"}], "+", 
     SuperscriptBox["ez", "2"], "+", 
     RowBox[{"ex", " ", 
      RowBox[{"(", 
       RowBox[{"ey", "+", "ez"}], ")"}]}], "+", "p2"}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7193499946534233`*^9},ExpressionUUID->"e67644e0-d7ad-4e50-a695-\
fea658c1de62"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"eigSolnForm", " ", "=", " ", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"eigSolveEqn", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "3"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ex", ",", "ey", ",", "ez"}], "}"}]}], "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.719335368137907*^9, 3.719335416312669*^9}, {
  3.7193354676572733`*^9, 3.719335469257084*^9}, {3.719349958268528*^9, 
  3.719349984369123*^9}},ExpressionUUID->"648816ec-1d1c-4d6c-8c17-\
1c562aafbdd9"],

Cell[BoxData["10243.679724`"], "Output",
 CellChangeTimes->{
  3.719360238974456*^9},ExpressionUUID->"302721bd-92b5-4d49-96ca-\
902ec250fc88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigSolnForm", "//", "Dimensions"}]], "Input",
 CellChangeTimes->{{3.719335445144652*^9, 
  3.719335448232703*^9}},ExpressionUUID->"eafba17b-14dc-4183-a9eb-\
a6d8cbfcde05"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"24", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{
  3.719360239124503*^9},ExpressionUUID->"ebde61d2-365f-4a4d-b3ac-\
01b5f7c763e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"ByteCount", ",", "eigSolnForm", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.719335452521867*^9, 
  3.719335459784857*^9}},ExpressionUUID->"953f8e1b-7ca3-4e86-8571-\
f55acc6a6ba7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"12808", ",", "363825944", ",", "1455355312"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363825944", ",", "1455355240"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826584", ",", "1455357872"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826584", ",", "1455357800"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826584", ",", "1455357872"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826584", ",", "1455357800"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363825416", ",", "1455353152"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363825416", ",", "1455353080"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826056", ",", "1455355712"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826056", ",", "1455355640"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826056", ",", "1455355712"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826056", ",", "1455355640"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826376", ",", "1455357088"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826376", ",", "1455357016"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363827016", ",", "1455359648"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363827016", ",", "1455359576"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363827016", ",", "1455359648"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363827016", ",", "1455359576"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363825848", ",", "1455354928"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363825848", ",", "1455354856"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826488", ",", "1455357488"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826488", ",", "1455357416"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826488", ",", "1455357488"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12808", ",", "363826488", ",", "1455357416"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.719360287523219*^9},ExpressionUUID->"ffd1e0fc-739b-4407-b8ca-\
72255155de60"]
}, Open  ]],

Cell[TextData[StyleBox[" Got to here, and then lost the kernel...",
 FontSize->16,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.71936241018657*^9, 
  3.719362418762869*^9}},ExpressionUUID->"c08cd79c-8a23-45fc-a05a-\
2cdb188006e0"],

Cell[BoxData[
 RowBox[{"eigSolnForm", "/.", 
  RowBox[{"randomPn", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.71933551666695*^9, 3.719335527706709*^9}, {
  3.719335564554715*^9, 
  3.719335567514678*^9}},ExpressionUUID->"fb574f50-80e9-4a59-93d8-\
8831eaf2ae1a"],

Cell[BoxData[
 RowBox[{"eigSolnForm", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"randomPnZ", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"randomPnY", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"randomPnZ", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.719335538426169*^9, 
  3.719335575914866*^9}},ExpressionUUID->"544c3816-e595-4a47-8eee-\
079a6161bf9b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"10243.679724`", "/", "3600"}]], "Input",
 CellChangeTimes->{{3.7193621665393333`*^9, 
  3.719362168788827*^9}},ExpressionUUID->"c9cda687-2180-4998-98c7-\
3e755b4c024e"],

Cell[BoxData["2.84546659`"], "Output",
 CellChangeTimes->{
  3.719362197333879*^9},ExpressionUUID->"250854fd-faac-44fd-a7d1-\
d74c93302aa1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here are the eigenvalues: have a slightly simpler version, but
   really not much better than the sqrt[xx]+sqrt[yy]+sqrt[zz]\
\>", "Section",
 CellChangeTimes->{{3.719974377634037*^9, 
  3.719974420097732*^9}},ExpressionUUID->"e24839de-a86b-4af5-a1e7-\
08accb866d49"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subForRoots", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xE", "\[Rule]", 
      RowBox[{"xyzRoot", "[", 
       RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
     RowBox[{"yE", "->", 
      RowBox[{"xyzRoot", "[", 
       RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
     RowBox[{"zE", "->", 
      RowBox[{"xyzRoot", "[", 
       RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
    "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.719873145856341*^9, 
  3.719873167323889*^9}},ExpressionUUID->"9d1f0985-7a18-4253-baad-\
ad5e1fd02cdd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenValues", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xE", "+", "yE", "+", "zE"}], ",", 
      RowBox[{"xE", "-", "yE", "-", "zE"}], ",", 
      RowBox[{
       RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}], ",", 
      RowBox[{
       RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}], "}"}], "/.", 
    "subForRoots"}]}], ";"}]], "Input",
 CellChangeTimes->{3.719974611065427*^9},
 FontWeight->"Plain",ExpressionUUID->"c842ba0a-ac10-45fb-b98d-cbd5a1378ecf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ansTry2", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Resultant", "[", 
      RowBox[{"resq", ",", "res3", ",", "qq3"}], "]"}], "//", "Together"}], "//",
     "Numerator"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.719973343444317*^9, 
  3.719973379358008*^9}},ExpressionUUID->"70e6a672-ce97-4727-93df-\
9eb9f7b60e6d"],

Cell[BoxData[
 RowBox[{"387420489", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["ee1", "4"], "+", 
     RowBox[{
      SuperscriptBox["ee1", "2"], " ", "p2"}], "-", 
     RowBox[{"ee1", " ", "p3"}], "+", "p4"}], ")"}], "6"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ee1", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["ee1", "3"], "+", 
        RowBox[{"ee1", " ", "p2"}], "+", "p3"}], ")"}]}], "+", "p4"}], ")"}], 
   "6"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], ")"}], "9"]}]], "Output",
 CellChangeTimes->{
  3.719973386544373*^9},ExpressionUUID->"e903fd41-5e97-47de-a0e1-\
0af507234db9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
**HERE **  Amazing - we have an algebraic equation for the EigenValue!!!\
\>", "Subsubsection",
 CellChangeTimes->{{3.719973593713811*^9, 
  3.719973617937381*^9}},ExpressionUUID->"f4497281-db92-45b7-9f97-\
8aea9fef7ed2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res3", " ", "=", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Resultant", "[", 
        RowBox[{"res2", ",", 
         RowBox[{"ruleEqnsqx", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", "qy"}], "]"}], "//", 
       "Together"}], "//", "Numerator"}], "//", "Simplify"}], ")"}], "[", 
   RowBox[{"[", 
    RowBox[{"-", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.719973181622169*^9, 3.719973198943789*^9}, {
  3.719973263103176*^9, 
  3.719973268645348*^9}},ExpressionUUID->"35614563-8e85-47fc-92ad-\
d17288d5dc9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"27", " ", 
   SuperscriptBox["ee1", "8"], " ", 
   SuperscriptBox["qq3", "3"]}], "+", 
  RowBox[{"54", " ", 
   SuperscriptBox["ee1", "6"], " ", "p2", " ", 
   SuperscriptBox["qq3", "3"]}], "+", 
  RowBox[{"27", " ", 
   SuperscriptBox["p4", "2"], " ", 
   SuperscriptBox["qq3", "3"]}], "+", 
  RowBox[{"27", " ", 
   SuperscriptBox["ee1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"2", " ", "p4"}]}], ")"}], " ", 
   SuperscriptBox["qq3", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["ee1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "6"], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
     RowBox[{"432", " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p4", "2"]}], "+", 
     RowBox[{"1728", " ", 
      SuperscriptBox["p4", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["p2", "3"], " ", 
      SuperscriptBox["qq3", "3"]}], "-", 
     RowBox[{"18", " ", "p2", " ", "p4", " ", 
      SuperscriptBox["qq3", "3"]}], "+", 
     SuperscriptBox["qq3", "6"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.719973200581293*^9, {3.719973248738265*^9, 
   3.7199732692630663`*^9}},ExpressionUUID->"26cbaf65-daaf-4871-917b-\
e6d82864a560"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"resq", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Resultant", "[", 
      RowBox[{
       RowBox[{"ruleEqs1", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"ruleEqs1", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", "qq2"}], "]"}], "//", 
     "Together"}], "//", "Numerator"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7199732756755657`*^9, 
  3.719973337524746*^9}},ExpressionUUID->"891877f0-95be-4794-a5e0-\
80c4d77d33af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p2", "2"], "+", 
      RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["p2", "3"]}], "-", 
     RowBox[{"27", " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], " ", 
   SuperscriptBox["qq3", "3"]}], "-", 
  SuperscriptBox["qq3", "6"]}]], "Output",
 CellChangeTimes->{{3.719973332155373*^9, 
  3.7199733380554333`*^9}},ExpressionUUID->"f5cb505f-1580-453b-bd56-\
dbc84cae80b6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ansTry2", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Resultant", "[", 
      RowBox[{"resq", ",", "res3", ",", "qq3"}], "]"}], "//", "Together"}], "//",
     "Numerator"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.719973343444317*^9, 
  3.719973379358008*^9}},ExpressionUUID->"d0b68d97-72c3-4801-9798-\
0566f842975f"],

Cell[BoxData[
 RowBox[{"387420489", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["ee1", "4"], "+", 
     RowBox[{
      SuperscriptBox["ee1", "2"], " ", "p2"}], "-", 
     RowBox[{"ee1", " ", "p3"}], "+", "p4"}], ")"}], "6"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ee1", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["ee1", "3"], "+", 
        RowBox[{"ee1", " ", "p2"}], "+", "p3"}], ")"}]}], "+", "p4"}], ")"}], 
   "6"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], ")"}], "9"]}]], "Output",
 CellChangeTimes->{
  3.719973386544373*^9},ExpressionUUID->"8d65456d-e11b-4b80-8f39-\
53134e43bb00"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
THESE are the reduced equations, coming out very similar to the raw
     eigenvalues, with the remarkable fact that they SOLVE A SIMPLE EQUATION:\
\
\>", "Subsubsection",
 CellChangeTimes->{{3.719974712790853*^9, 
  3.719974748502646*^9}},ExpressionUUID->"56abce51-0622-4c67-8724-\
1557152abd44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"ee1", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["ee1", "3"], "+", 
       RowBox[{"ee1", " ", "p2"}], "+", "p3"}], ")"}]}], "+", "p4"}], ")"}], "//",
   "Expand"}]], "Input",
 CellChangeTimes->{{3.71997354964325*^9, 
  3.7199735762296124`*^9}},ExpressionUUID->"d08456c5-7c52-449a-ae53-\
49e55f6f5da5"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ee1", "4"], "+", 
  RowBox[{
   SuperscriptBox["ee1", "2"], " ", "p2"}], "+", 
  RowBox[{"ee1", " ", "p3"}], "+", "p4"}]], "Output",
 CellChangeTimes->{{3.719973552417322*^9, 
  3.719973576687958*^9}},ExpressionUUID->"8773145a-9063-4b21-9795-\
436fc656bb25"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["ee1", "4"], "+", 
    RowBox[{
     SuperscriptBox["ee1", "2"], " ", "p2"}], "-", 
    RowBox[{"ee1", " ", "p3"}], "+", "p4"}], ")"}], "//", "Expand"}]], "Input",\

 CellChangeTimes->{{3.719973528563374*^9, 3.719973533598547*^9}, {
  3.719973566403458*^9, 
  3.719973580789345*^9}},ExpressionUUID->"e3372279-7c3e-4711-92f5-\
e3a2337e612c"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ee1", "4"], "+", 
  RowBox[{
   SuperscriptBox["ee1", "2"], " ", "p2"}], "-", 
  RowBox[{"ee1", " ", "p3"}], "+", "p4"}]], "Output",
 CellChangeTimes->{
  3.71997353422211*^9, {3.7199735685515223`*^9, 
   3.719973581192021*^9}},ExpressionUUID->"99b7f510-a198-48f6-8a98-\
27bf6b1e36f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"answerEig1a", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ee1", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["ee1", "3"], "+", 
          RowBox[{"ee1", " ", "p2"}], "+", "p3"}], ")"}]}], "+", "p4"}], 
      "\[Equal]", "0"}], ",", "ee1"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.719973401013043*^9, 3.719973415987743*^9}, {
  3.719973446382205*^9, 
  3.7199734705383368`*^9}},ExpressionUUID->"a07aede9-5809-4081-80a7-\
723deb6c2f83"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ee1", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["6"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", "p2"}], "+", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]], "+", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "-", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", "p2"}], "-", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"12", " ", 
              SqrtBox["6"], " ", "p3"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", "p2"}], "+", 
                FractionBox[
                 RowBox[{"2", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                   ")"}], 
                  RowBox[{"1", "/", "3"}]]], "+", 
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                   ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}],
        ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ee1", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["6"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", "p2"}], "+", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]], "+", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", "p2"}], "-", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"12", " ", 
              SqrtBox["6"], " ", "p3"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", "p2"}], "+", 
                FractionBox[
                 RowBox[{"2", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                   ")"}], 
                  RowBox[{"1", "/", "3"}]]], "+", 
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                   ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}],
        ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ee1", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", 
         SqrtBox["6"]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "p2"}], "+", 
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["p2", "3"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "-", 
                RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
               ")"}], 
              RowBox[{"1", "/", "3"}]]], "+", 
            RowBox[{
             SuperscriptBox["2", 
              RowBox[{"2", "/", "3"}]], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["p2", "3"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "-", 
                RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
               ")"}], 
              RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "p2"}], "-", 
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["p2", "3"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "-", 
                RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
               ")"}], 
              RowBox[{"1", "/", "3"}]]], "-", 
            RowBox[{
             SuperscriptBox["2", 
              RowBox[{"2", "/", "3"}]], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["p2", "3"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "-", 
                RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
               ")"}], 
              RowBox[{"1", "/", "3"}]]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"12", " ", 
               SqrtBox["6"], " ", "p3"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"\[Sqrt]", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", "p2"}], "+", 
                 FractionBox[
                  RowBox[{"2", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                    ")"}], 
                   RowBox[{"1", "/", "3"}]]], "+", 
                 RowBox[{
                  SuperscriptBox["2", 
                   RowBox[{"2", "/", "3"}]], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                    ")"}], 
                   RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ee1", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["6"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "p2"}], "+", 
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["p2", "3"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "-", 
                RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
               ")"}], 
              RowBox[{"1", "/", "3"}]]], "+", 
            RowBox[{
             SuperscriptBox["2", 
              RowBox[{"2", "/", "3"}]], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["p2", "3"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "-", 
                RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
               ")"}], 
              RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", "p2"}], "-", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"12", " ", 
              SqrtBox["6"], " ", "p3"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", "p2"}], "+", 
                FractionBox[
                 RowBox[{"2", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                   ")"}], 
                  RowBox[{"1", "/", "3"}]]], "+", 
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                   ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}],
        ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.71997346258648*^9, 
  3.719973480999364*^9}},ExpressionUUID->"c5f52691-502a-4b76-b4e2-\
71aa6634db4d"]
}, Closed]],

Cell[BoxData[
 RowBox[{"answerEig1b", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["ee1", "4"], "+", 
       RowBox[{
        SuperscriptBox["ee1", "2"], " ", "p2"}], "-", 
       RowBox[{"ee1", " ", "p3"}], "+", "p4"}], "\[Equal]", "0"}], ",", 
     "ee1"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.719973491371152*^9, 3.7199735057424717`*^9}, {
   3.719973669962884*^9, 3.719973673961466*^9}, 
   3.719973727964731*^9},ExpressionUUID->"26883152-c541-4b78-b992-\
59645f528c3b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Check", " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ee1", "/.", "answerEig1a"}], "/.", 
    RowBox[{"randomPn", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.7199737410775003`*^9, 
  3.719973808171208*^9}},ExpressionUUID->"b403f1e4-32c2-40a5-8ee3-\
4210075e3d0a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.13871463276260884`", ",", "1.9475163770783297`", ",", 
     RowBox[{"-", "1.3792892603069313`"}], ",", 
     RowBox[{"-", "0.706941749534007`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2362231387920139`", ",", "1.9871194129758007`", ",", 
     RowBox[{"-", "1.5823421002019982`"}], ",", 
     RowBox[{"-", "0.6410004515658162`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.20576841427614972`", ",", "1.5825399475373916`", ",", 
     RowBox[{"-", "1.0823407180012994`"}], ",", 
     RowBox[{"-", "0.705967643812242`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.12488159770618121`", ",", "2.333235752177227`", ",", 
     RowBox[{"-", "1.5453632724223552`"}], ",", 
     RowBox[{"-", "0.912754077461053`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.719973772908298*^9, 
  3.7199738092331142`*^9}},ExpressionUUID->"fe93dbe4-fc12-45f0-978d-\
dc3c69608088"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "-", " ", 
    RowBox[{"so", " ", "the", " ", "negatives", " ", 
     RowBox[{"of", " ", "'"}], 
     RowBox[{"b", "'"}], " ", "are", " ", "right"}]}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ee1", "/.", "answerEig1b"}], "/.", 
    RowBox[{"randomPn", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{
  3.719973819984709*^9, {3.719974772814191*^9, 
   3.719974784166026*^9}},ExpressionUUID->"582df10e-c21e-4bf0-8040-\
8694c2de634b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9475163770783297`"}], ",", 
     RowBox[{"-", "0.13871463276260884`"}], ",", "0.706941749534007`", ",", 
     "1.3792892603069313`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9871194129758007`"}], ",", 
     RowBox[{"-", "0.2362231387920139`"}], ",", "0.6410004515658162`", ",", 
     "1.5823421002019982`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.5825399475373916`"}], ",", 
     RowBox[{"-", "0.20576841427614972`"}], ",", "0.705967643812242`", ",", 
     "1.0823407180012994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.333235752177227`"}], ",", 
     RowBox[{"-", "0.12488159770618121`"}], ",", "0.912754077461053`", ",", 
     "1.5453632724223552`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719973820770499*^9},ExpressionUUID->"fb2caa82-16c4-4be3-af4c-\
3cc66a85926d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenValues", "/.", 
   RowBox[{"randomPn", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.719973826185019*^9, 
  3.7199738373216143`*^9}},ExpressionUUID->"2ab353f5-0cca-404b-a339-\
d891c45aef34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.947516377078329`", ",", "0.13871463276260898`", ",", 
     RowBox[{"-", "0.7069417495340071`"}], ",", 
     RowBox[{"-", "1.3792892603069309`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.9871194129758`", ",", "0.23622313879201395`", ",", 
     RowBox[{"-", "0.641000451565816`"}], ",", 
     RowBox[{"-", "1.582342100201998`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5825399475373914`", ",", "0.20576841427614984`", ",", 
     RowBox[{"-", "0.705967643812242`"}], ",", 
     RowBox[{"-", "1.0823407180012992`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.333235752177227`", ",", "0.1248815977061809`", ",", 
     RowBox[{"-", "0.9127540774610527`"}], ",", 
     RowBox[{"-", "1.545363272422355`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719973838551197*^9},ExpressionUUID->"c6c015d4-366e-4430-b0c5-\
e791aa47fe65"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The canonical eigenvalues are thus here:",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.719974654151861*^9, 
  3.7199746682391663`*^9}},ExpressionUUID->"51088bd8-a758-47d2-8185-\
4e8eb85cff53"],

Cell[CellGroupData[{

Cell[BoxData["eigenValues"], "Input",ExpressionUUID->"63f30ff6-e3ef-4e25-9b11-5632f559d533"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]], "-", 
       RowBox[{
        FractionBox["1", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["p2", "6"]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}]], "-", 
        RowBox[{
         FractionBox["1", "12"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "-", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["p2", "6"]}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}]], "-", 
        RowBox[{
         FractionBox["1", "12"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", "p2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]], "-", 
       RowBox[{
        FractionBox["1", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "-", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "-", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719974428627981*^9},ExpressionUUID->"6f644f43-ec5f-47fe-a7c2-\
c2715f87e945"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenValuesProcessed", " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "ee1"}], "/.", "answerEig1b"}]}]], "Input",
 CellChangeTimes->{{3.7199744628929768`*^9, 
  3.719974485833839*^9}},ExpressionUUID->"100bebe7-74b7-4cda-a7bc-\
c7bc5ce2187c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      SqrtBox["6"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", "p2"}], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"1", "/", "3"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p2", "2"], "+", 
             RowBox[{"12", " ", "p4"}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
            ")"}], 
           RowBox[{"1", "/", "3"}]]], "+", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
            ")"}], 
           RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", "p2"}], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"1", "/", "3"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p2", "2"], "+", 
             RowBox[{"12", " ", "p4"}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
            ")"}], 
           RowBox[{"1", "/", "3"}]]], "-", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
            ")"}], 
           RowBox[{"1", "/", "3"}]]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"12", " ", 
            SqrtBox["6"], " ", "p3"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"\[Sqrt]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", "p2"}], "+", 
              FractionBox[
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"1", "/", "3"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}]}], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                 ")"}], 
                RowBox[{"1", "/", "3"}]]], "+", 
              RowBox[{
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                 ")"}], 
                RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SqrtBox["6"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", "p2"}], "+", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]], "+", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
              ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "p2"}], "-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"12", " ", 
             SqrtBox["6"], " ", "p3"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "p2"}], "+", 
               FractionBox[
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                  ")"}], 
                 RowBox[{"1", "/", "3"}]]], "+", 
               RowBox[{
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                  ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SqrtBox["6"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "p2"}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]], "+", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "-", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "p2"}], "-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"12", " ", 
             SqrtBox["6"], " ", "p3"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "p2"}], "+", 
               FractionBox[
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                  ")"}], 
                 RowBox[{"1", "/", "3"}]]], "+", 
               RowBox[{
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                  ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SqrtBox["6"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "p2"}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]], "+", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "p2"}], "-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"12", " ", 
             SqrtBox["6"], " ", "p3"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "p2"}], "+", 
               FractionBox[
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                  ")"}], 
                 RowBox[{"1", "/", "3"}]]], "+", 
               RowBox[{
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                  ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719974487969706*^9},ExpressionUUID->"70d42414-460a-4856-a9c5-\
54bf22cb6975"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "check", " ", "*)"}], " ", 
  RowBox[{
   RowBox[{"eigenValues", "/.", 
    RowBox[{"randomPn", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.7199744966447287`*^9, 
  3.719974515971364*^9}},ExpressionUUID->"40d099a9-e806-44b2-a06f-\
64fb435ac2b8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.947516377078329`", ",", "0.13871463276260898`", ",", 
     RowBox[{"-", "0.7069417495340071`"}], ",", 
     RowBox[{"-", "1.3792892603069309`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.9871194129758`", ",", "0.23622313879201395`", ",", 
     RowBox[{"-", "0.641000451565816`"}], ",", 
     RowBox[{"-", "1.582342100201998`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5825399475373914`", ",", "0.20576841427614984`", ",", 
     RowBox[{"-", "0.705967643812242`"}], ",", 
     RowBox[{"-", "1.0823407180012992`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.333235752177227`", ",", "0.1248815977061809`", ",", 
     RowBox[{"-", "0.9127540774610527`"}], ",", 
     RowBox[{"-", "1.545363272422355`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719974517481246*^9},ExpressionUUID->"9b1571b9-1b87-4749-85ff-\
3e81b0ddd52e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "check", " ", "*)"}], " ", 
  RowBox[{
   RowBox[{"eigenValuesProcessed", "/.", 
    RowBox[{"randomPn", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{
  3.7199745324106817`*^9},ExpressionUUID->"7f424ef7-9517-4842-838d-\
e61241b1f361"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.9475163770783297`", ",", "0.13871463276260884`", ",", 
     RowBox[{"-", "0.706941749534007`"}], ",", 
     RowBox[{"-", "1.3792892603069313`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.9871194129758007`", ",", "0.2362231387920139`", ",", 
     RowBox[{"-", "0.6410004515658162`"}], ",", 
     RowBox[{"-", "1.5823421002019982`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5825399475373916`", ",", "0.20576841427614972`", ",", 
     RowBox[{"-", "0.705967643812242`"}], ",", 
     RowBox[{"-", "1.0823407180012994`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.333235752177227`", ",", "0.12488159770618121`", ",", 
     RowBox[{"-", "0.912754077461053`"}], ",", 
     RowBox[{"-", "1.5453632724223552`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.719974533812133*^9},ExpressionUUID->"217e7da8-2565-48dc-88c3-\
de9b3f402c5f"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4D roots are derived in Horn-Demo-4.nb and Horn-Demo-4.2.nb,
    and are numerically the same as 3D roots at p1=0,  for
    reasons that I now understand as simply
    4d roots = (a+b, a-b, -a + c,  -a -c)
       Sqrt[x] = \
xyzRoot[\[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote],p2,p3,p4]    =  a, 
       Sqrt[y]+Sqrt[z] = b,  Sqrt[y]- Sqrt[z] = c.\
\>", "Subchapter",
 CellChangeTimes->{{3.725294167170281*^9, 3.725294222906283*^9}, {
  3.725482225476597*^9, 
  3.72548234659062*^9}},ExpressionUUID->"0e5d5f38-e69f-4b42-aca8-\
31d273396768"],

Cell[CellGroupData[{

Cell["Define  eig4D1,2,3,4[p1,p2,p3,p4] below.", "Section",
 CellChangeTimes->{{3.7252943829041224`*^9, 
  3.725294398936428*^9}},ExpressionUUID->"bb0c565f-72c4-48fe-b24b-\
549b82909420"],

Cell[CellGroupData[{

Cell["\<\
This solution from above in THIS file, also see Horn-Demo-4.2
   defined here:
       eig4D1[p1,p2,p3,p4] , eig4D2, eig4D3,eig4D4
       ============================================\
\>", "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725285909816786*^9, 3.725285932341865*^9}, {
  3.725285983128278*^9, 3.7252860222482977`*^9}, {3.725288697950091*^9, 
  3.725288754762532*^9}},ExpressionUUID->"928014f0-8b14-409c-9640-\
f60a15176f73"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"e41", ",", "e42", ",", "e43", ",", "e44"}], "}"}], "=", 
  RowBox[{"Table", "[", " ", 
   RowBox[{
    RowBox[{"e", "/.", 
     RowBox[{"eig4Dallp", " ", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.720239742493675*^9, 3.7202397873520927`*^9}, {
   3.7202398526659727`*^9, 3.7202398554830017`*^9}, {3.7217539714163103`*^9, 
   3.7217540422292013`*^9}, 
   3.725288691229576*^9},ExpressionUUID->"0b807712-d511-43c2-8c38-\
e4e7b6777d4b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "-", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "-", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.721753988667948*^9, {3.7217540214490023`*^9, 3.72175404326095*^9}, 
   3.725288691229886*^9},ExpressionUUID->"59435f09-5886-447c-be0a-\
bd5573bc41fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plus", "@@", 
   RowBox[{"{", 
    RowBox[{"e41", ",", "e42", ",", "e43", ",", "e44"}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.720239799442054*^9, 3.7202398096329803`*^9}, {
   3.7202398676049128`*^9, 3.720239900124958*^9}, 3.720239987650872*^9, 
   3.721608385779869*^9, 3.7217540514534073`*^9, 
   3.725288691230052*^9},ExpressionUUID->"7165341b-6151-4b79-8781-\
5eec4ee8940b"],

Cell[BoxData[
 RowBox[{"-", "p1"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.720239878232045*^9, {3.72023998221875*^9, 3.720239989374425*^9}, 
   3.721754052943907*^9, 
   3.725288691230214*^9},ExpressionUUID->"cf7790ea-128e-4db4-bda9-\
9c5544c5e6ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"eig4D1", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "p1"}], "-", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", " ", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["p1", "2"]}], "-", 
                RowBox[{"8", " ", "p2"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"eig4D2", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "p1"}], "-", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", " ", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["p1", "2"]}], "-", 
                RowBox[{"8", " ", "p2"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"eig4D3", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "p1"}], "+", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", " ", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["p1", "2"]}], "-", 
                RowBox[{"8", " ", "p2"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"eig4D4", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "p1"}], "+", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"1", "/", "3"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "2"], "-", 
                RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", "/", "3"}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["p2", "3"]}], "-", 
               RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"27", " ", 
                SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
               RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                   ")"}], "2"]}]]}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", " ", 
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p1", "3"], "-", 
                RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
                RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["p1", "2"]}], "-", 
                RowBox[{"8", " ", "p2"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["2", 
                    RowBox[{"1", "/", "3"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"2", "/", "3"}]], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                  RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}]}], ")"}]}]}]}], "}"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.725288497531535*^9, 3.725288545220022*^9}, 
   3.725288691231908*^9},ExpressionUUID->"9c634a09-9018-486f-b479-\
254d15138ad6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Null", ",", "Null", ",", "Null", ",", "Null"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7252885581935787`*^9, 3.725288691232088*^9, 
  3.725483984423604*^9, 3.726256763918625*^9, 
  3.729008628186081*^9},ExpressionUUID->"bd89b38d-89e9-41ce-976b-\
570965e0f57b"],

Cell[BoxData[
 RowBox[{"eig4D2", "[", 
  RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725288575418393*^9, 3.725288587935403*^9}, 
   3.7252886912322693`*^9},ExpressionUUID->"d7fac020-17fd-4586-a4dc-\
f27f646ccbcf"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "12"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", "p2"}], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
           ")"}], 
          RowBox[{"1", "/", "3"}]]], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["2", 
          RowBox[{"2", "/", "3"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
           ")"}], 
          RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
    RowBox[{
     SqrtBox["6"], " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", "p2"}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
           ")"}], 
          RowBox[{"1", "/", "3"}]]], "-", 
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{"2", "/", "3"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "2"], "+", 
                  RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
           ")"}], 
          RowBox[{"1", "/", "3"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"24", " ", 
           SqrtBox["3"], " ", "p3"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "p2"}], "+", 
             FractionBox[
              RowBox[{"4", " ", 
               SuperscriptBox["2", 
                RowBox[{"1", "/", "3"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "2"], "+", 
                 RowBox[{"12", " ", "p4"}]}], ")"}]}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                ")"}], 
               RowBox[{"1", "/", "3"}]]], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["2", 
               RowBox[{"2", "/", "3"}]], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"27", " ", 
                  SuperscriptBox["p3", "2"]}], "-", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                ")"}], 
               RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}]}], 
   ")"}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.725288589016996*^9, 
  3.725288691232442*^9},ExpressionUUID->"c1b00209-e44b-482f-ab22-\
1b51201d791e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eig4D1x", "[", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "-", 
   RowBox[{"eig4D1", "[", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725288613942575*^9, 3.7252886377275753`*^9}, 
   3.725288691232634*^9},ExpressionUUID->"dbbd2e03-ea60-4a0e-af17-\
c6193a2dad92"],

Cell[BoxData["0"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.725288638953891*^9, 
  3.7252886912328033`*^9},ExpressionUUID->"e7d36695-8e3f-40f9-9273-\
7d99372fa1f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eig4D1x", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
  RowBox[{
   FractionBox["1", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", "p1"}], "-", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                 ")"}], "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                 ")"}], "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "-", 
     RowBox[{
      SqrtBox["6"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                 ")"}], "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], "-", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                 ")"}], "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SqrtBox["3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p1", "3"], "-", 
              RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
              RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"\[Sqrt]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["p1", "2"]}], "-", 
              RowBox[{"8", " ", "p2"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"\[Sqrt]", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"\[Sqrt]", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}]}],
     ")"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725285948872096*^9, 3.725285968318914*^9}, 
   3.725286022249996*^9, 
   3.725288601301757*^9},ExpressionUUID->"042ca01b-65e4-43fe-91d2-\
f1337d35b769"]
}, {6}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       SqrtBox["xx"], "+", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}], ",", " ", 
      RowBox[{
       SqrtBox["xx"], "-", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", " ", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "+", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", " ", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "-", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "\[Rule]", 
       RowBox[{"fxx0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], ",", " ", 
      RowBox[{"yy", "\[Rule]", 
       RowBox[{"fyy0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], " ", ",", " ", 
      RowBox[{"zz", "\[Rule]", 
       RowBox[{"fzz0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}]}], " ", "}"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p4", "\[Rule]", "0.2621670574518047`"}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{"-", "2.347438927680793`"}]}], ",", 
     RowBox[{"p2", "\[Rule]", 
      RowBox[{"-", "3.589172779025842`"}]}]}], "}"}]}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.725287853806384*^9, 3.725287860647037*^9}, {
  3.725288009026163*^9, 
  3.725288064860168*^9}},ExpressionUUID->"4a346d1d-9ee5-4083-be49-\
04ecd457e139"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.1503762928315973`", ",", "0.09725764045079988`", ",", 
   RowBox[{"-", "1.0267624468283354`"}], ",", 
   RowBox[{"-", "1.2208714864540617`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7252880492896433`*^9, 
  3.725288065457803*^9}},ExpressionUUID->"a2eaef17-1f5e-45ac-90a8-\
2ee96e378f21"]
}, Open  ]],

Cell[TextData[StyleBox["Compare to the 4D p1 = 0 solutions:  THEY ARE THE \
SAME",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.725288774076647*^9, 3.725288782940756*^9}, {
  3.725288860172613*^9, 
  3.7252888633556757`*^9}},ExpressionUUID->"53b8c3e2-5748-4e28-84ab-\
65f6d3daefc5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"eig4D1", "[", 
      RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
     RowBox[{"eig4D2", "[", 
      RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
     RowBox[{"eig4D3", "[", 
      RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
     RowBox[{"eig4D4", "[", 
      RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p4", "\[Rule]", "0.2621670574518047`"}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{"-", "2.347438927680793`"}]}], ",", 
     RowBox[{"p2", "\[Rule]", 
      RowBox[{"-", "3.589172779025842`"}]}]}], "}"}]}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.725288788005452*^9, 
  3.7252888253185997`*^9}},ExpressionUUID->"c1d8c447-cc96-4959-bca2-\
a9da416a9158"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.2208714864540626`"}], ",", 
   RowBox[{"-", "1.0267624468283343`"}], ",", "0.09725764045079957`", ",", 
   "2.1503762928315973`"}], "}"}]], "Output",
 CellChangeTimes->{{3.7252888143266907`*^9, 
  3.725288826287141*^9}},ExpressionUUID->"9477bbb4-c81c-4081-a478-\
7d3c0d832d49"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Building Utilities for data - imported from inits in Horn-Data-5.nb\
\>", "Section",
 CellChangeTimes->{{3.726073068831285*^9, 
  3.726073088694704*^9}},ExpressionUUID->"45d6d7f0-1139-41bb-9701-\
1001c726f0b0"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Graphics Utilities for Frames",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.726073125942054*^9, 
  3.7260731341658707`*^9}},ExpressionUUID->"a1434f94-1714-4fb4-9472-\
316da32423d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeAxes", "[", 
   RowBox[{
    RowBox[{"center_:", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"scale_:", "1.0"}], ",", 
    RowBox[{"th_:", "0.02"}], ",", 
    RowBox[{"ah_:", "0.06"}], ",", 
    RowBox[{"sh_:", "-", "0.082"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"Arrowheads", "[", "ah", "]"}], ",", "\[IndentingNewLine]", "Red",
     ",", 
    RowBox[{"Arrow", "[", " ", 
     RowBox[{
      RowBox[{"Tube", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"center", ",", 
          RowBox[{"center", "+", 
           RowBox[{"{", 
            RowBox[{"scale", ",", "0", ",", "0"}], "}"}]}]}], "}"}], ",", 
        "th"}], "]"}], ",", "sh"}], "]"}], ",", "\[IndentingNewLine]", 
    "Green", ",", 
    RowBox[{"Arrow", "[", 
     RowBox[{
      RowBox[{"Tube", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"center", ",", 
          RowBox[{"center", "+", 
           RowBox[{"{", 
            RowBox[{"0", ",", "scale", ",", "0"}], "}"}]}]}], "}"}], ",", 
        "th"}], "]"}], ",", "sh"}], "]"}], ",", "\[IndentingNewLine]", "Blue",
     ",", 
    RowBox[{"Arrow", "[", 
     RowBox[{
      RowBox[{"Tube", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"center", ",", 
          RowBox[{"center", "+", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "scale"}], "}"}]}]}], "}"}], ",", 
        "th"}], "]"}], ",", "sh"}], "]"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.739294188855904*^9, {3.739294236516034*^9, 3.739294286699285*^9}, {
   3.739296150367877*^9, 3.739296158596237*^9}},
 CellLabel->
  "In[176]:=",ExpressionUUID->"8e9fab91-9d36-4ace-a1b8-c663b53933a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Tuning", " ", "*)"}], 
  RowBox[{"Manipulate", "[", " ", 
   RowBox[{
    RowBox[{"Graphics3D", "[", 
     RowBox[{
      RowBox[{"makeAxes", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1", ",", "tn", ",", 
        "ah", ",", "sh"}], "]"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"1.2", "*", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"tn", ",", ".02"}], "}"}], ",", "0", ",", ".2", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ah", ",", "0.06"}], "}"}], ",", "0", ",", ".2", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sh", ",", 
        RowBox[{"-", "0.08"}]}], "}"}], ",", 
      RowBox[{"-", ".3"}], ",", ".3", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.725137452168457*^9, 3.725137588288416*^9}, {
  3.7251376237905483`*^9, 3.725137629904738*^9}, {3.739290811200447*^9, 
  3.739290896255929*^9}, {3.739291013051208*^9, 3.7392910818240633`*^9}, {
  3.739291150186244*^9, 3.7392911729346952`*^9}, {3.739291278231447*^9, 
  3.739291312365653*^9}, {3.739291554101982*^9, 3.739291596107678*^9}, {
  3.739291861571826*^9, 3.739291887798648*^9}, {3.739294310902046*^9, 
  3.73929433198003*^9}, {3.739296016240944*^9, 3.7392960295008163`*^9}, {
  3.739296084409746*^9, 3.739296091029848*^9}, {3.739296124471066*^9, 
  3.739296125036955*^9}, {3.7392961843594847`*^9, 3.739296186562296*^9}},
 CellLabel->
  "In[792]:=",ExpressionUUID->"6c7b0d4c-e65e-46cb-a153-1028c0f80e31"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{"makeAxes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1.0", ",", "0.01"}], 
     "]"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", 
    RowBox[{"1.2", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.724962648545063*^9, 3.724962692712298*^9}, 
   3.724963021172517*^9, {3.7249630886580353`*^9, 3.724963106506175*^9}},
 CellLabel->
  "In[177]:=",ExpressionUUID->"82ba6b7a-d672-484b-aa35-35ba76a9bf29"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[1, 0, 0], Arrowheads[0.06], 
   Arrow3DBox[TubeBox[{{{0., 0., 0.}, {1., 0., 0.}}}, 0.01], -0.082], 
   {RGBColor[0, 1, 0], 
    Arrow3DBox[TubeBox[{{{0., 0., 0.}, {0., 1., 0.}}}, 0.01], -0.082]}, 
   {RGBColor[0, 0, 1], 
    Arrow3DBox[TubeBox[{{{0., 0., 0.}, {0., 0., 1.}}}, 0.01], -0.082]}},
  PlotRange->{{-1.2, 1.2}, {-1.2, 1.2}, {-1.2, 1.2}}]], "Output",
 CellChangeTimes->{3.741712897563332*^9},
 CellLabel->
  "Out[177]=",ExpressionUUID->"f31b7adc-27da-4468-974d-ef878cad5079"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Note", ":", "  ", 
     RowBox[{
     "COLUMNS", " ", "of", " ", "frameMat", " ", "are", " ", "the", " ", 
      "x"}]}], ",", "y", ",", 
    RowBox[{"z", " ", "axes"}], ",", " ", 
    RowBox[{"so", " ", "multiply", " ", "by", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], " ", "etc", " ", "to", " ", 
     "pull", " ", "out", " ", "columns"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeFrame", "[", 
    RowBox[{"frameMat_", ",", "center_", ",", 
     RowBox[{"scale_:", "1.0"}], ",", 
     RowBox[{"th_:", "0.02"}], ",", 
     RowBox[{"ah_:", "0.06"}], ",", 
     RowBox[{"sh_:", "-", "0.082"}]}], "]"}], " ", ":=", " ", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"Arrowheads", "[", "ah", "]"}], ",", "\[IndentingNewLine]", 
     "Red", ",", 
     RowBox[{"Arrow", "[", " ", 
      RowBox[{
       RowBox[{"Tube", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"center", ",", 
           RowBox[{"center", "+", 
            RowBox[{"scale", "*", 
             RowBox[{"frameMat", ".", 
              RowBox[{"{", 
               RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]}]}]}], "}"}], ",", 
         "th"}], "]"}], ",", "sh"}], "]"}], ",", "\[IndentingNewLine]", 
     "Green", ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{
       RowBox[{"Tube", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"center", ",", 
           RowBox[{"center", "+", 
            RowBox[{"scale", "*", 
             RowBox[{"frameMat", ".", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1", ",", "0"}], "}"}]}]}]}]}], "}"}], ",", 
         "th"}], "]"}], ",", "sh"}], "]"}], ",", "\[IndentingNewLine]", 
     "Blue", ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{
       RowBox[{"Tube", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"center", ",", 
           RowBox[{"center", "+", 
            RowBox[{"scale", "*", 
             RowBox[{"frameMat", ".", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}]}]}], "}"}], ",", 
         "th"}], "]"}], ",", "sh"}], "]"}]}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.724962266380808*^9, 3.724962415241776*^9}, {
  3.724962579528475*^9, 3.724962643425647*^9}, {3.724962701864367*^9, 
  3.7249627200643597`*^9}, {3.724962772639485*^9, 3.724962774862871*^9}, {
  3.724962831319848*^9, 3.7249630084048777`*^9}, {3.724963121195372*^9, 
  3.724963154378106*^9}, {3.725126836537148*^9, 3.72512699133139*^9}, {
  3.725127193972063*^9, 3.725127292447865*^9}, {3.7392962632103558`*^9, 
  3.7392962941704206`*^9}},
 CellLabel->
  "In[167]:=",ExpressionUUID->"225e7529-bda3-493f-a13a-900523259659"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{"makeFrame", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "0"}], "}"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1", ",", ".02", ",", 
     "0.1"}], "]"}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.725137452168457*^9, 3.725137588288416*^9}, {
  3.7251376237905483`*^9, 3.725137629904738*^9}, {3.741714486001102*^9, 
  3.741714577008316*^9}},
 CellLabel->
  "In[210]:=",ExpressionUUID->"fe9e6967-7451-4a2b-b081-b8c793ad060d"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[1, 0, 0], Arrowheads[0.1], 
   Arrow3DBox[TubeBox[{{{0., 0., 0.}, {0.7071067811865475, 0.7071067811865475,
     0.}}}, 0.02], -0.082], 
   {RGBColor[0, 1, 0], 
    Arrow3DBox[TubeBox[{{{0., 0., 0.}, {-0.7071067811865475, 
     0.7071067811865475, 0.}}}, 0.02], -0.082]}, 
   {RGBColor[0, 0, 1], 
    Arrow3DBox[TubeBox[{{{0., 0., 0.}, {0., 0., 1.}}}, 0.02], -0.082]}},
  Axes->True,
  AxesLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]}]], "Output",
 CellChangeTimes->{
  3.741712637814645*^9, {3.741714487332015*^9, 3.741714518877061*^9}, {
   3.741714555356848*^9, 3.741714577460156*^9}},
 CellLabel->
  "Out[210]=",ExpressionUUID->"667883d9-6673-47b1-8fef-25e2c721ffc9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Perform Ref->Target plots  for Point data, and for q0 Sign = +/-1 Frame data,
     sign flagged by lighter or darker color.\
\>", "Subsubsection",
 CellChangeTimes->{{3.742318397897814*^9, 
  3.742318455361815*^9}},ExpressionUUID->"f127affe-bd70-4170-9409-\
724f7ec39747"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotPntDataSet", "[", 
   RowBox[{"xTgt_", ",", "xRef_"}], "]"}], ":=", " ", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"len", " ", "=", " ", 
      RowBox[{"Length", "[", "xTgt", "]"}]}], "}"}], ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Point", "[", "xRef", "]"}], ",", "Blue", ",", 
        RowBox[{"Point", "[", "xTgt", "]"}], ",", " ", "Green", ",", 
        "\[IndentingNewLine]", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xRef", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"xTgt", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", "\[IndentingNewLine]", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "1.1796283886036965`", ",", "1.794089082592766`", ",", 
         "2.6152860701119676`"}], "}"}]}], ",", 
      RowBox[{"ViewVertical", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03479293219612456`"}], ",", 
         RowBox[{"-", "0.27347051171334985`"}], ",", "1.0087127821538848`"}], 
        "}"}]}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742303900913327*^9, 3.7423040039663258`*^9}, {
  3.742304036079156*^9, 3.742304094808536*^9}},
 CellLabel->
  "In[494]:=",ExpressionUUID->"38f3ba01-6fa8-4290-8e06-718c7ac59104"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotFrmDataSet", "[", 
   RowBox[{"qTgt_", ",", "qRef_"}], "]"}], ":=", " ", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"len", " ", "=", " ", 
      RowBox[{"Length", "[", "qTgt", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xyzTgtN", "=", 
         RowBox[{"Rest", "/@", 
          RowBox[{"Select", "[", 
           RowBox[{"qTgt", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[GreaterEqual]", "0"}], 
              ")"}], "&"}]}], "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"xyzTgtS", "=", 
         RowBox[{"Rest", "/@", 
          RowBox[{"Select", "[", 
           RowBox[{"qTgt", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], ")"}], "&"}]}], 
           "]"}]}]}], ",", 
        RowBox[{"xyzRefN", "=", 
         RowBox[{"Rest", "/@", 
          RowBox[{"Select", "[", 
           RowBox[{"qRef", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[GreaterEqual]", "0"}], 
              ")"}], "&"}]}], "]"}]}]}], ",", 
        RowBox[{"xyzRefS", "=", 
         RowBox[{"Rest", "/@", 
          RowBox[{"Select", "[", 
           RowBox[{"qRef", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], ")"}], "&"}]}], 
           "]"}]}]}]}], "}"}], ",", 
      RowBox[{"Graphics3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
          RowBox[{"Point", "[", "xyzRefN", "]"}], ",", 
          RowBox[{"Darker", "@", 
           RowBox[{"Darker", "@", "Red"}]}], ",", 
          RowBox[{"Point", "[", "xyzRefS", "]"}], ",", "\[IndentingNewLine]", 
          "Green", ",", 
          RowBox[{"Point", "[", "xyzTgtN", "]"}], ",", " ", 
          RowBox[{"Darker", "@", 
           RowBox[{"Darker", "@", "Green"}]}], ",", 
          RowBox[{"Point", "[", "xyzTgtS", "]"}], ",", "\[IndentingNewLine]", 
          "Blue", ",", 
          RowBox[{"Line", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Rest", "[", 
                RowBox[{"qRef", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
               RowBox[{"Rest", "[", 
                RowBox[{"qTgt", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}], "]"}]}], 
         "}"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", "\[IndentingNewLine]", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "1.1796283886036965`", ",", "1.794089082592766`", ",", 
           "2.6152860701119676`"}], "}"}]}], ",", 
        RowBox[{"ViewVertical", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.03479293219612456`"}], ",", 
           RowBox[{"-", "0.27347051171334985`"}], ",", 
           "1.0087127821538848`"}], "}"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742303900913327*^9, 3.7423040039663258`*^9}, {
   3.742304036079156*^9, 3.742304388399639*^9}, {3.742304449785973*^9, 
   3.742304571693617*^9}, 3.742318087272897*^9, 3.7423251761806307`*^9, {
   3.74232522330156*^9, 3.742325228452056*^9}, {3.74232540140236*^9, 
   3.742325412543606*^9}},
 CellLabel->
  "In[493]:=",ExpressionUUID->"d2f034f3-7e42-4aac-881a-d942e9d62d85"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Build combined samples:  Helix with X plus Quat \
Frenet frames",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.726073125942054*^9, 3.7260731341658707`*^9}, {
  3.7260732643483763`*^9, 
  3.7260732867717953`*^9}},ExpressionUUID->"64a81cbe-a3fc-45e9-a09b-\
088f7e939180"],

Cell[BoxData[
 RowBox[{
  RowBox[{"helix", "[", 
   RowBox[{"t_", ",", 
    RowBox[{"zscale_:", ".2"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cos", "[", "t", "]"}], ",", 
    RowBox[{"Sin", "[", "t", "]"}], ",", 
    RowBox[{"zscale", " ", "t"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7251385371241093`*^9, 
  3.725138586914123*^9}},ExpressionUUID->"21f7e861-24d7-48a9-850a-\
8b865fe2ecd9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"frenet", "[", 
   RowBox[{"curve_", ",", "t_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], " ", "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"z", " ", "=", " ", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "tt", "]"}], ",", "tt"}], "]"}], "/.", 
       RowBox[{"tt", "\[Rule]", "t"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"y", " ", "=", 
      RowBox[{
       RowBox[{"-", " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"curve", "[", "tt", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tt", ",", "2"}], "}"}]}], "]"}]}], "/.", 
       RowBox[{"tt", "\[Rule]", "t"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"Cross", "[", 
       RowBox[{"y", ",", "z"}], "]"}]}], ";", " ", 
     RowBox[{"Normalize", "/@", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7251379006989927`*^9, 3.725138006952518*^9}, {
  3.725138078240834*^9, 3.725138122383572*^9}, {3.725138160887253*^9, 
  3.7251382119828587`*^9}},ExpressionUUID->"f8c24c6d-ee62-478f-96be-\
836d8a3366d4"],

Cell[BoxData[
 RowBox[{"tf", "=", 
  RowBox[{"frenet", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "#", "]"}], ",", 
       RowBox[{"Sin", "[", "#", "]"}], ",", 
       RowBox[{"0", " ", "#"}]}], "}"}], "&"}], ",", " ", "0"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.725138217111611*^9, 3.725138284893187*^9}, {
  3.725139036125721*^9, 
  3.725139062830402*^9}},ExpressionUUID->"7e40dfe0-faa5-4321-bc0e-\
92f03f710474"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Graphics3D", "[", " ", 
   RowBox[{"makeFrame", "[", 
    RowBox[{"tf", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1", ",", "0.01", ",", 
     "0.1"}], "]"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.7251382781730833`*^9, 
  3.725138376318783*^9}},ExpressionUUID->"9994aa8b-3d01-4fc9-aff9-\
e8c2a55092d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"frenet", "[", 
  RowBox[{"helix", ",", ".2"}], "]"}]], "Input",
 CellChangeTimes->{{3.72513864842521*^9, 3.725138653064045*^9}, {
  3.7251387036187763`*^9, 
  3.725138731880065*^9}},ExpressionUUID->"c342a626-9fa1-4d43-935f-\
9120a601046d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.038962261326016816`", ",", 
     RowBox[{"-", "0.1922068694243305`"}], ",", "0.9805806756909201`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9800665778412418`", ",", "0.19866933079506127`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.19481130663008409`"}], ",", "0.9610343471216527`", ",", 
     "0.19611613513818407`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.725138710119536*^9, 
  3.725138732372232*^9}},ExpressionUUID->"1902fbd4-8ca8-4cde-98bf-\
8ceca08066b4"]
}, Open  ]],

Cell[TextData[{
 StyleBox["NOTE that you have to  ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["transpose",
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox["  the Frenet frame to get the axis\nlist correct for makeFrame, \
which assumes it is given the x,y,z directions:\n  Those are the COLUMNS of a \
Frenet frame.",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.725564529707691*^9, 3.72556457421973*^9}, {
  3.726073389499349*^9, 
  3.726073391098743*^9}},ExpressionUUID->"557ba19b-5628-4e2c-8f8d-\
bfc6cd4b4afd"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"makeFrame", "[", 
       RowBox[{
        RowBox[{"Transpose", "@", 
         RowBox[{"frenet", "[", 
          RowBox[{"helix", ",", " ", "t"}], "]"}]}], ",", 
        RowBox[{"helix", "[", 
         RowBox[{"t", ",", ".2"}], "]"}], ",", ".5", ",", "0.01", ",", 
        "0.02"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", 
        RowBox[{"4", "Pi"}], ",", 
        RowBox[{"Pi", "/", "8"}]}], "}"}]}], "]"}], ",", "Black", ",", 
    RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
    RowBox[{"Point", "[", 
     RowBox[{"helix", "[", "0", "]"}], "]"}], ",", 
    RowBox[{"Line", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"helix", "[", 
        RowBox[{"t", ",", ".2"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"4", "Pi"}], ",", 
         RowBox[{"Pi", "/", "16"}]}], "}"}]}], "]"}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7251382781730833`*^9, 3.725138307980713*^9}, {
   3.7251383946197433`*^9, 3.725138474712187*^9}, {3.725138505974959*^9, 
   3.725138522371131*^9}, 3.725138567422477*^9, {3.7251385991780043`*^9, 
   3.7251386208176403`*^9}, {3.725138741218871*^9, 3.725138828918745*^9}, {
   3.7251388947535753`*^9, 3.7251389053105917`*^9}, {3.7251389375914297`*^9, 
   3.7251389850246353`*^9}, {3.72556450430965*^9, 
   3.725564507277555*^9}},ExpressionUUID->"e3c5e168-bd9b-4dbe-a329-\
467a1a7203d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Random uniform spherical distributions of  X-clouds \
and Quaternion-clouds",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.726073125942054*^9, 3.7260731341658707`*^9}, {
  3.726073172605892*^9, 
  3.726073215084929*^9}},ExpressionUUID->"b37350dd-eb45-4da0-9e36-\
272c4784e8d3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"genUniformXradialSample", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"scale_:", "1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"scale", "*", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", "3"}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "scale"}], ",", 
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", "test"}], "]"}]}]}], "]"}]}]}], "]"}], ";", 
     "out"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{" "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725126678664934*^9, 3.725126747221231*^9}, {
  3.725126784293984*^9, 3.7251268188772497`*^9}, {3.725136303100024*^9, 
  3.725136377027377*^9}, {3.72513641438743*^9, 3.7251365562100897`*^9}, {
  3.726073595595655*^9, 
  3.7260736770269547`*^9}},ExpressionUUID->"01bf7736-05d3-4d8d-a4b6-\
e53282146db6"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], "+", " ", "#"}], "&"}], ",", 
   RowBox[{"genUniformXradialSample", "[", "10", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.726075355516843*^9, 
  3.7260754188016243`*^9}},ExpressionUUID->"04c087fe-3a64-4489-aca5-\
6ba7ff264860"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPointPlot3D", "[", " ", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], "+", " ", "#"}], 
        "&"}], ",", 
       RowBox[{"genUniformXradialSample", "[", "200", "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], "+", " ", "#"}], "&"}], 
       ",", 
       RowBox[{"genUniformXradialSample", "[", "200", "]"}]}], "]"}]}], "]"}],
    ",", 
   RowBox[{"BoxRatios", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", " ", "1", ",", " ", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.726074918338038*^9, 3.7260749208542852`*^9}, {
  3.726075339666028*^9, 3.726075350186654*^9}, {3.726075458784301*^9, 
  3.726075578608756*^9}},ExpressionUUID->"c01d5973-068b-49d7-bc9e-\
1a9b1e0ca7a9"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.3315753, 0.4561011, 0.6388182], Point3DBox[CompressedData["
1:eJwVmnk0lO8bxkelKBVRWcpSlLKkCPVV96SFIlFa7UuipEEipSZtKtUkoUK2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    "]]},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{2, 1, 1},
  FaceGridsStyle->Automatic,
  ImageSize->{350.0068648761803, 192.84536642815925`},
  ImageSizeRaw->Automatic,
  PlotRange->{{-1.9395846204968508`, 
    1.9470800929870427`}, {-0.9606730655263576, 0.9605779599440809}, 
    Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {Automatic, Automatic}},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{0.2356999613243164, -3.3248554999808193`, 0.582907739251257},
  ViewVertical->{0.01600102083249206, -0.8373113520049189, 
   1.8160081412628546`}]], "Output",
 CellChangeTimes->{{3.7260755000270653`*^9, 
  3.7260755792202587`*^9}},ExpressionUUID->"9dcf100e-0575-4ea5-8425-\
f817a33706da"]
}, Closed]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"genUniformX4DradialSample", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"scale_:", "1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"scale", "*", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", "4"}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "scale"}], ",", 
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", "test"}], "]"}]}]}], "]"}]}]}], "]"}], ";", 
     "out"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{" "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725126678664934*^9, 3.725126747221231*^9}, {
  3.725126784293984*^9, 3.7251268188772497`*^9}, {3.725136303100024*^9, 
  3.725136377027377*^9}, {3.72513641438743*^9, 3.7251365562100897`*^9}, {
  3.726073595595655*^9, 3.7260736770269547`*^9}, {3.7263221770976887`*^9, 
  3.726322188098936*^9}},ExpressionUUID->"1b4eb2fd-172f-454f-8148-\
8eebb4a211d6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPointPlot3D", "[", " ", 
  RowBox[{
   RowBox[{"Most", "/@", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], "+", 
          " ", "#"}], "&"}], ",", 
        RowBox[{"genUniformX4DradialSample", "[", "200", "]"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], "+", " ", 
          "#"}], "&"}], ",", 
        RowBox[{"genUniformX4DradialSample", "[", "200", "]"}]}], "]"}]}], 
     "]"}]}], ",", 
   RowBox[{"BoxRatios", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", " ", "1", ",", " ", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.726074918338038*^9, 3.7260749208542852`*^9}, {
  3.726075339666028*^9, 3.726075350186654*^9}, {3.726075458784301*^9, 
  3.726075578608756*^9}, {3.72632220673002*^9, 
  3.726322296544767*^9}},ExpressionUUID->"44475253-dbe5-44f0-8a93-\
272162e239f9"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.3315753, 0.4561011, 0.6388182], Point3DBox[CompressedData["
1:eJwVmHlYTO0bx+dNiIoQhWRkS0gIId1DUbaEMCTviLQoUiTLy5QokhZFWkeL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    "]]},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{2, 1, 1},
  FaceGridsStyle->Automatic,
  ImageSize->{362.83780232393843`, 223.37766409050144`},
  ImageSizeRaw->Automatic,
  PlotRange->{{-1.849606867341452, 1.9342941886789018`}, {-0.9628698006522143,
     0.9002651283588352}, Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {Automatic, Automatic}},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{0.6722235048065014, -3.1072590647366862`, 1.1589032160613575`},
  ViewVertical->{0.08660369199103178, -0.5338798156985229, 
   1.91962797034316}]], "Output",
 CellChangeTimes->{{3.726322270669992*^9, 
  3.7263222972394037`*^9}},ExpressionUUID->"a1a125ef-160d-4fea-b100-\
7059781e4b53"]
}, Closed]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"genUniformQuatSample", "[", "n_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"0.2", "\[LessEqual]", " ", 
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "1.0"}], ",", 
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", 
             RowBox[{"Normalize", "[", "test", "]"}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", "out"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{" "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725126678664934*^9, 3.725126747221231*^9}, {
  3.725126784293984*^9, 3.7251268188772497`*^9}, {3.725136303100024*^9, 
  3.725136377027377*^9}, {3.72513641438743*^9, 
  3.7251365562100897`*^9}},ExpressionUUID->"0955d75f-974f-4043-8229-\
765cb07389f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPointPlot3D", "[", 
  RowBox[{
   RowBox[{"Rest", "/@", 
    RowBox[{"genUniformQuatSample", "[", "200", "]"}]}], ",", 
   RowBox[{"BoxRatios", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "1", ",", " ", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.725561815426713*^9, 3.725561857530032*^9}, {
  3.7260756167376966`*^9, 
  3.726075617142681*^9}},ExpressionUUID->"02b7029a-dbab-476c-ba33-\
b574471a6e21"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.3315753, 0.4561011, 0.6388182], Point3DBox[CompressedData["
1:eJwNl2k4FAwXhikJeVtMJGt2lUSi4q0TabFF1kirj4qKlLJmK9UbQoutrCFC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    "]]},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 1},
  FaceGridsStyle->Automatic,
  ImageSize->{338.9590288119383, 351.8275331492104},
  ImageSizeRaw->Automatic,
  PlotRange->{{-0.9355157175070974, 0.9787974315477774}, {-0.9347819062837582,
     0.9730804093667487}, Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {Automatic, Automatic}},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{1.206375080051266, -2.8526182421511934`, 1.3628016476279796`},
  ViewVertical->{0.07511186048350826, -0.2029263937328002, 
   0.9763089096906299}]], "Output",
 CellChangeTimes->{{3.726075609765834*^9, 
  3.726075618445036*^9}},ExpressionUUID->"3d03023e-1057-45fa-b2e2-\
f01ebb117f3e"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Build the actual data sets - arrange so you can do hundreds \
easily.\n  derivation of the X 3D version - ",
  FontWeight->"Bold"],
 StyleBox["here.",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox["..",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}], "Subsection",
 CellChangeTimes->{{3.7260756816862297`*^9, 3.726075695965968*^9}, {
  3.7263219408591137`*^9, 
  3.726321956691012*^9}},ExpressionUUID->"0b59c1c4-0563-4ea6-ab68-\
212e3414da71"],

Cell[CellGroupData[{

Cell[TextData[{
 "Use the  genUniformXradialSample[n,scale]  for the jittered X data sets.\n\
Remark -- are we forgetting translating to the ",
 StyleBox["center of mass? ",
  FontWeight->"Bold"],
 " Not needed\n   in quaternions, but definitely essential in the X-data RMSD \
calculation...."
}], "Subsubsection",
 CellChangeTimes->{{3.72607572501357*^9, 3.7260757603652067`*^9}, {
  3.726076135034535*^9, 
  3.726076178282269*^9}},ExpressionUUID->"c9fd29f4-f536-4bdb-9956-\
94e1c4126fdd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Considered", " ", "this"}], ",", " ", 
    RowBox[{
    "but", " ", "Xradial", " ", "should", " ", "be", " ", "better", " ", 
     RowBox[{"(", 
      RowBox[{"May", " ", "even", " ", "want", " ", "Gaussian", " ", 
       RowBox[{"falloff", "?"}]}], ")"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xRef", " ", "[", 
    RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
   RowBox[{
    RowBox[{"RandomReal", "[", 
     RowBox[{"{", 
      RowBox[{"rmin", ",", "rmax"}], "}"}], "]"}], "*", " ", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xmin", ",", "xmax"}], "}"}], ",", "3"}], "]"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.726075864351965*^9, 
  3.726075897040011*^9}},ExpressionUUID->"92ae226f-e829-42e7-a5dc-\
255bf2cc7ac1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"WRONG", " ", "ORDER", " ", "of", " ", "ref"}], ",", "tgt"}], " ",
    "*)"}], 
  RowBox[{
   RowBox[{"buildXRMSDdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"baseAngle_:", 
      RowBox[{"Pi", "/", "8"}]}], ",", 
     RowBox[{"xmin_:", "-", "1"}], ",", 
     RowBox[{"xmax_:", "+", "1"}], ",", 
     RowBox[{"rmin_:", "0.01"}], ",", 
     RowBox[{"rmax_:", "0.2"}]}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xRef", " ", "=", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"npts", ",", "3"}], "}"}]}], "]"}]}], ",", "xTgt", ",", 
       "xTgtInit", ",", "qTgt", ",", "rotTgt"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
          RowBox[{
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"rmin", ",", "rmax"}], "}"}], "]"}], "*", " ", 
           RowBox[{"RandomReal", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"xmin", ",", "xmax"}], "}"}], ",", "3"}], "]"}]}]}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"qTgt", " ", "=", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{"RandomReal", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], 
            "]"}]}]}], "]"}], "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotTgt", " ", "=", " ", 
       RowBox[{"QuatToRot", "[", "qTgt", "]"}]}], ";", "  ", 
      RowBox[{"xTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotTgt", ".", "#"}], ")"}], "&"}], ",", "xTgtInit"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"xRef", ",", "xTgt", ",", 
        RowBox[{"{", 
         RowBox[{"qTgt", ",", "rotTgt", ",", "xTgtInit"}], "}"}]}], "}"}]}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7257171807590647`*^9, 3.72571752922749*^9}, {
  3.725717604609919*^9, 3.7257176877148323`*^9}, {3.725717874890616*^9, 
  3.725717879127853*^9}, {3.7257179506953497`*^9, 3.725718126207859*^9}, {
  3.727628501361609*^9, 
  3.727628513986947*^9}},ExpressionUUID->"82c4ae53-b9b8-47a1-9530-\
fd0184ba247c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plus", "@@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"d", ",", "e", ",", "f"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.726159605798009*^9, 
  3.726159639601593*^9}},ExpressionUUID->"8aba0a8c-d29a-4fb1-b7c2-\
ba8e94be113f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "d", "+", "i"}], ",", 
   RowBox[{"b", "+", "e", "+", "j"}], ",", 
   RowBox[{"c", "+", "f", "+", "k"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726159639900962*^9},ExpressionUUID->"b1d839ad-7c0f-4bfc-aaf2-\
9b05d5023878"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Match", " ", "order", " ", "of", " ", "makeExxmat"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"buildXRMSDdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"baseAngle_:", 
      RowBox[{"Pi", "/", "8"}]}], ",", 
     RowBox[{"xmin_:", "-", "1"}], ",", 
     RowBox[{"xmax_:", "+", "1"}], ",", 
     RowBox[{"rmax_:", "0.2"}]}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xRef", " ", "=", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"npts", ",", "3"}], "}"}]}], "]"}]}], ",", "xRefCtr", ",", 
       "xTgtCtr", ",", "\[IndentingNewLine]", 
       RowBox[{"xJitter", "=", 
        RowBox[{"genUniformXradialSample", "[", 
         RowBox[{"npts", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "2"}]}], "]"}]}], ",", 
       "xTgt", ",", "xTgtInit", ",", "qTgt", ",", "rotTgt"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
          RowBox[{"rmax", "*", 
           RowBox[{"xJitter", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xRefCtr", "=", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Plus", "@@", "xRef"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xRef", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xRefCtr"}], " ", ")"}], "&"}], ",", "xRef"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xTgtCtr", "=", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"Plus", "@@", "xTgtInit"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xTgtInit", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xTgtCtr"}], ")"}], " ", "&"}], ",", 
         "xTgtInit"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"qTgt", " ", "=", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{"RandomReal", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], 
            "]"}]}]}], "]"}], "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotTgt", " ", "=", " ", 
       RowBox[{"QuatToRot", "[", "qTgt", "]"}]}], ";", "  ", 
      RowBox[{"xTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotTgt", ".", "#"}], ")"}], "&"}], ",", "xTgtInit"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"xTgt", ",", "xRef", ",", 
        RowBox[{"{", 
         RowBox[{"qTgt", ",", "rotTgt", ",", "xTgtInit"}], "}"}]}], "}"}]}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7257171807590647`*^9, 3.72571752922749*^9}, {
  3.725717604609919*^9, 3.7257176877148323`*^9}, {3.725717874890616*^9, 
  3.725717879127853*^9}, {3.7257179506953497`*^9, 3.725718126207859*^9}, {
  3.726075963402713*^9, 3.726076069067973*^9}, {3.726076099612719*^9, 
  3.726076107028638*^9}, {3.726159190322667*^9, 3.726159242663053*^9}, {
  3.726159523365271*^9, 3.7261596014100027`*^9}, {3.7261596719996147`*^9, 
  3.7261598285278597`*^9}, {3.726159873403098*^9, 3.726159973233931*^9}, {
  3.726160492590303*^9, 
  3.726160519996932*^9}},ExpressionUUID->"ec1424eb-e0a9-4e2f-96b8-\
a9419c517d18"],

Cell[BoxData[
 RowBox[{"?", "makeExxmat[tgt,ref]"}]], "Input",
 CellChangeTimes->{{3.726159270398952*^9, 
  3.726159286148991*^9}},ExpressionUUID->"63f0ce34-4bf9-4bb2-a65c-\
3a17a5dcc988"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeExxmat", "@@", " ", 
  RowBox[{
   RowBox[{"buildXRMSDdataset", "[", "10", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7261589533461933`*^9, 3.726158969527532*^9}, {
  3.7261590686980467`*^9, 
  3.726159085070462*^9}},ExpressionUUID->"4b0b3dc3-5341-44f9-bca0-\
cb050f1e120b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3.5899040289579482`", ",", 
     RowBox[{"-", "2.226268910653647`"}], ",", "3.049560028597174`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"2.5933077152958357`", ",", "2.8983987340532256`", ",", 
     RowBox[{"-", "0.27199152639996965`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0239697545217754`"}], ",", 
     RowBox[{"-", "0.5944288824237702`"}], ",", "2.8667179410896506`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726159086493627*^9},ExpressionUUID->"c44a6ead-5bea-4b9c-b81c-\
d7b6bceef2c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Usage", " ", "to", " ", "get", " ", "random", " ", 
    RowBox[{"test", ":"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"makePnNumRule", "[", 
   RowBox[{"makeXYZnumRule", "[", 
    RowBox[{"makeMxxmat", "[", 
     RowBox[{"makeExxmat", "@@", " ", 
      RowBox[{
       RowBox[{"buildXRMSDdataset", "[", "10", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.726156517993895*^9, 3.7261566050459557`*^9}, 
   3.726159122636169*^9},ExpressionUUID->"3741a0a3-6525-40ee-8979-\
94ab0ff093b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "83.29198666471424`"}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "192.2441317071169`"}]}], ",", 
   RowBox[{"p4", "\[Rule]", "432.51086254513564`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726160232099567*^9},ExpressionUUID->"60847a7d-5a94-42ae-8577-\
2595dcb2262d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"npts", "=", "100"}], "}"}], ",", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tgt", ",", "ref", ",", "q", ",", "r", ",", "tgtInit"}], "}"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tgt", ",", "ref", ",", 
         RowBox[{"{", " ", 
          RowBox[{"q", ",", " ", "r", ",", "tgtInit"}], "}"}]}], " ", "}"}], 
       "=", " ", 
       RowBox[{"buildXRMSDdataset", "[", "npts", "]"}]}], ";", 
      RowBox[{"Graphics3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"Line", "[", "ref", "]"}], ",", 
          RowBox[{"Darker", "@", "Green"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"ref", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{"tgtInit", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}], "]"}], 
          ",", "\[IndentingNewLine]", "Red", ",", 
          RowBox[{"Line", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"ref", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{"tgt", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}], "]"}]}], 
         "}"}], ",", 
        RowBox[{"BoxRatios", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"1", ",", " ", "1", ",", " ", "1"}], "}"}]}]}], "]"}]}]}], 
    "]"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.72571815549325*^9, 3.725718328352738*^9}, {
   3.726160023079417*^9, 3.726160040694379*^9}, 3.726160205124838*^9, {
   3.7261602543328238`*^9, 3.726160313036262*^9}, {3.7261603797275553`*^9, 
   3.72616039940322*^9}, {3.7261604344973507`*^9, 3.726160447515239*^9}, {
   3.726160544462031*^9, 3.726160578066366*^9}, {3.726160641337425*^9, 
   3.7261606691375017`*^9}},ExpressionUUID->"a06eaf49-52d3-401d-9630-\
585f08b029e5"]
}, Open  ]],

Cell["\<\
Use the  genUniformQuatSample[n,scale]  for the jittered Q data sets.\
\>", "Subsubsection",
 CellChangeTimes->{{3.72607572501357*^9, 
  3.7260757832046824`*^9}},ExpressionUUID->"a7a9d3bb-0a9c-44ae-a41c-\
b60172a75f36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Build the  3D and 4D  simple \
\[OpenCurlyDoubleQuote]E[ij]\[CloseCurlyDoubleQuote] matrices,\n             \
then build the quaternion 3D and 4D coefficient matrices \
\[OpenCurlyDoubleQuote]M[ab]\[CloseCurlyDoubleQuote]\n                      \
and then the quaternion-only  4D Vector analogous to M[ab], \
\[OpenCurlyDoubleQuote]V[a]\[CloseCurlyDoubleQuote]",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.726073125942054*^9, 3.7260731341658707`*^9}, {
  3.7260734654985237`*^9, 
  3.726073542331126*^9}},ExpressionUUID->"78f9eaeb-0c4d-4578-a8e4-\
04e97687ce37"],

Cell[CellGroupData[{

Cell["0. Build Randomized  target and reference data", "Subsubsection",
 CellChangeTimes->{{3.7256255343963337`*^9, 3.725625557004238*^9}, {
  3.72632161802258*^9, 
  3.726321628062242*^9}},ExpressionUUID->"6212d223-1e45-4c40-9ca6-\
d469c15d6e30"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Returns", "  ", "qTgt"}], ",", " ", 
    RowBox[{"qRef", " ", 
     RowBox[{"(", 
      RowBox[{"match", " ", "makeV", " ", "order"}], ")"}], " ", "and", " ", 
     RowBox[{"{", 
      RowBox[{"qrot", ",", "rot", ",", "qTgtInit"}], " "}]}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"buildQRMSDdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"baseAngle_:", 
      RowBox[{"Pi", "/", "8"}]}], ",", 
     RowBox[{"dqscale_:", "0.1"}]}], " ", "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"qRef", " ", "=", "  ", 
        RowBox[{"genUniformQuatSample", "[", "npts", " ", "]"}]}], ",", 
       RowBox[{"qDelta", "=", " ", 
        RowBox[{"genUniformQuatSample", "[", "npts", "]"}]}], ",", "qTgt", 
       ",", "qTgtInit", ",", "qrot", ",", "rot"}], " ", "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"qrot", " ", "=", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", "baseAngle", "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", "baseAngle", "]"}], " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{"RandomReal", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], 
            "]"}]}]}], "]"}], "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rot", "  ", "=", " ", 
       RowBox[{"QuatToRot", "[", "qrot", "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"qTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{
           RowBox[{"slerp", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"qDelta", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "dqscale"}], "]"}], ",", 
           RowBox[{"qRef", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"qTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"qprod", "[", 
            RowBox[{"qrot", ",", "#"}], "]"}], ")"}], "&"}], ",", 
         "qTgtInit"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"qTgt", ",", "qRef", ",", 
        RowBox[{"{", 
         RowBox[{"qrot", ",", "rot", ",", "qTgtInit"}], "}"}]}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7257171807590647`*^9, 3.72571752922749*^9}, {
   3.725717604609919*^9, 3.7257176877148323`*^9}, {3.725717874890616*^9, 
   3.725717879127853*^9}, {3.7257179506953497`*^9, 3.725718126207859*^9}, {
   3.725736618679571*^9, 3.725736619487074*^9}, {3.725738030004346*^9, 
   3.725738094204225*^9}, {3.725738165399274*^9, 3.725738246907651*^9}, {
   3.725738279578199*^9, 3.725738326697905*^9}, {3.725738488344606*^9, 
   3.725738615991049*^9}, {3.725819778195614*^9, 3.725819778825992*^9}, {
   3.725819811258387*^9, 3.725819812154367*^9}, {3.725819865769597*^9, 
   3.725819871953495*^9}, {3.725819925425205*^9, 3.7258199394409657`*^9}, 
   3.725820031765926*^9, {3.725821614642239*^9, 3.725821648327612*^9}, {
   3.726322031973763*^9, 
   3.72632207341035*^9}},ExpressionUUID->"b7cd2f07-6b3d-4c4f-aa3d-\
4825f3117f9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Match", " ", "order", " ", "of", " ", "makeExxmat"}], ";", " ", 
    RowBox[{
    "REMEMBER", " ", "move", " ", "to", " ", "center", " ", "of", " ", 
     "mass"}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"buildXRMSDdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"baseAngle_:", 
      RowBox[{"Pi", "/", "8"}]}], ",", 
     RowBox[{"xmin_:", "-", "1"}], ",", 
     RowBox[{"xmax_:", "+", "1"}], ",", 
     RowBox[{"rmax_:", "0.2"}]}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xRef", " ", "=", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"npts", ",", "3"}], "}"}]}], "]"}]}], ",", "xRefCtr", ",", 
       "xTgtCtr", ",", "\[IndentingNewLine]", 
       RowBox[{"xJitter", "=", 
        RowBox[{"genUniformXradialSample", "[", 
         RowBox[{"npts", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "2"}]}], "]"}]}], ",", 
       "xTgt", ",", "xTgtInit", ",", "qTgt", ",", "rotTgt"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
          RowBox[{"rmax", "*", 
           RowBox[{"xJitter", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xRefCtr", "=", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Plus", "@@", "xRef"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xRef", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xRefCtr"}], " ", ")"}], "&"}], ",", "xRef"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xTgtCtr", "=", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"Plus", "@@", "xTgtInit"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xTgtInit", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xTgtCtr"}], ")"}], " ", "&"}], ",", 
         "xTgtInit"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"qTgt", " ", "=", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{"RandomReal", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], 
            "]"}]}]}], "]"}], "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotTgt", " ", "=", " ", 
       RowBox[{"QuatToRot", "[", "qTgt", "]"}]}], ";", "  ", 
      RowBox[{"xTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotTgt", ".", "#"}], ")"}], "&"}], ",", "xTgtInit"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"xTgt", ",", "xRef", ",", 
        RowBox[{"{", 
         RowBox[{"qTgt", ",", "rotTgt", ",", "xTgtInit"}], "}"}]}], "}"}]}]}],
     "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7257171807590647`*^9, 3.72571752922749*^9}, {
  3.725717604609919*^9, 3.7257176877148323`*^9}, {3.725717874890616*^9, 
  3.725717879127853*^9}, {3.7257179506953497`*^9, 3.725718126207859*^9}, {
  3.726075963402713*^9, 3.726076069067973*^9}, {3.726076099612719*^9, 
  3.726076107028638*^9}, {3.726159190322667*^9, 3.726159242663053*^9}, {
  3.726159523365271*^9, 3.7261596014100027`*^9}, {3.7261596719996147`*^9, 
  3.7261598285278597`*^9}, {3.726159873403098*^9, 3.726159973233931*^9}, {
  3.726160492590303*^9, 3.726160519996932*^9}, {3.726322330794754*^9, 
  3.726322354113688*^9}},ExpressionUUID->"7f02ee15-ad8a-4275-9e38-\
e56c29f27f3b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "4", "D", " ", "Euclidean", " ", "Match", " ", "order", " ", "of", " ", 
     "makeEwwmat"}], ";", " ", 
    RowBox[{"apply", " ", "SO4", " ", "rotation"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"buildX4DRMSDdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"baseAngle_:", 
      RowBox[{"Pi", "/", "8"}]}], ",", 
     RowBox[{"xmin_:", "-", "1"}], ",", 
     RowBox[{"xmax_:", "+", "1"}], ",", 
     RowBox[{"rmax_:", "0.2"}]}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xRef", " ", "=", "  ", 
        RowBox[{"RandomReal", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"npts", ",", "4"}], "}"}]}], "]"}]}], ",", "xRefCtr", ",", 
       "xTgtCtr", ",", "\[IndentingNewLine]", 
       RowBox[{"xJitter", "=", 
        RowBox[{"genUniformX4DradialSample", "[", 
         RowBox[{"npts", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "2"}]}], "]"}]}], ",", 
       "xTgt", ",", "xTgtInit", ",", "\[IndentingNewLine]", "   ", "qLTgt", 
       ",", "qRTgt", ",", "rot4DTgt"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
          RowBox[{"rmax", "*", 
           RowBox[{"xJitter", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xRefCtr", "=", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Plus", "@@", "xRef"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xRef", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xRefCtr"}], " ", ")"}], "&"}], ",", "xRef"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xTgtCtr", "=", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"Plus", "@@", "xTgtInit"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xTgtInit", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xTgtCtr"}], ")"}], " ", "&"}], ",", 
         "xTgtInit"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"qLTgt", " ", "=", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{"RandomReal", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], 
            "]"}]}]}], "]"}], "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"qRTgt", " ", "=", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"Pi", "/", "8"}], "]"}], " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{"RandomReal", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], 
            "]"}]}]}], "]"}], "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rot4DTgt", " ", "=", " ", 
       RowBox[{"PQbTo4DRot", "[", 
        RowBox[{"qLTgt", ",", "qRTgt"}], "]"}]}], ";", "  ", 
      RowBox[{"xTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rot4DTgt", ".", "#"}], ")"}], "&"}], ",", "xTgtInit"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"xTgt", ",", "xRef", ",", 
        RowBox[{"{", 
         RowBox[{"qLTgt", ",", "qRTgt", ",", "rot4DTgt", ",", "xTgtInit"}], 
         "}"}]}], "}"}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7257171807590647`*^9, 3.72571752922749*^9}, {
   3.725717604609919*^9, 3.7257176877148323`*^9}, {3.725717874890616*^9, 
   3.725717879127853*^9}, {3.7257179506953497`*^9, 3.725718126207859*^9}, {
   3.726075963402713*^9, 3.726076069067973*^9}, {3.726076099612719*^9, 
   3.726076107028638*^9}, {3.726159190322667*^9, 3.726159242663053*^9}, {
   3.726159523365271*^9, 3.7261596014100027`*^9}, {3.7261596719996147`*^9, 
   3.7261598285278597`*^9}, {3.726159873403098*^9, 3.726159973233931*^9}, {
   3.726160492590303*^9, 3.726160519996932*^9}, {3.726322085926227*^9, 
   3.726322112579319*^9}, {3.726322745197925*^9, 3.726322746006166*^9}, {
   3.7263228238539457`*^9, 3.7263228641257553`*^9}, {3.726322895260705*^9, 
   3.726322927788044*^9}, {3.726322992212755*^9, 3.726323057563422*^9}, 
   3.728743957184299*^9},ExpressionUUID->"278b9420-2336-43d3-a1e4-\
f6adc01f3403"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"PQbTo4DRot", "  ", "vs", "  ", "QQTo4DRot"}], " ", "*)"}]], "Input",\

 CellChangeTimes->{{3.728743942542791*^9, 
  3.728743952666038*^9}},ExpressionUUID->"c2288df7-09b0-4b64-a1c8-\
e44a09e6ffa2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"buildXRMSDdataset", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.726426725490617*^9, 
  3.7264267260104*^9}},ExpressionUUID->"fc56b136-f1e7-4676-9021-8ff5e4249f9f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.5000692013016108`", ",", 
       RowBox[{"-", "0.26314322272526125`"}], ",", "0.43437805263540996`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5000692013016108`"}], ",", "0.26314322272526125`", ",", 
       RowBox[{"-", "0.43437805263540996`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.8154919969155963`", ",", "0.08622056594385241`", ",", 
       "0.029620961930717504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.8154919969155963`"}], ",", 
       RowBox[{"-", "0.08622056594385241`"}], ",", 
       RowBox[{"-", "0.029620961930717504`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9238795325112867`", ",", 
       RowBox[{"-", "0.05825870421484351`"}], ",", 
       RowBox[{"-", "0.2780786286346814`"}], ",", 
       RowBox[{"-", "0.2563685025243713`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.7138949344201326`", ",", "0.506108225673864`", ",", 
         RowBox[{"-", "0.483950913331639`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.44130622337747516`"}], ",", "0.8617622285932376`", 
         ",", "0.250229252043654`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.5436937003659178`", ",", "0.034933154384762174`", ",", 
         "0.8385563993597247`"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.7092922222920919`", ",", "0.041496441704041875`", ",", 
         "0.056395417277001814`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.7092922222920919`"}], ",", 
         RowBox[{"-", "0.041496441704041875`"}], ",", 
         RowBox[{"-", "0.056395417277001814`"}]}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.726426726658269*^9},ExpressionUUID->"f6ff81d3-de6a-4b7a-8c3f-\
1e4085088395"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"buildX4DRMSDdataset", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.726323087375875*^9, 3.726323088287725*^9}, 
   3.7264267327175283`*^9},ExpressionUUID->"d9d6fff1-8285-4804-8a63-\
e9acfa47c8c6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.4290644783555603`"}], ",", "0.34863597368997035`", ",", 
       RowBox[{"-", "0.2920691363949561`"}], ",", 
       RowBox[{"-", "1.0068530294964395`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.4290644783555603`", ",", 
       RowBox[{"-", "0.34863597368997035`"}], ",", "0.292069136394956`", ",", 
       "1.0068530294964397`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6038226124983028`"}], ",", "0.4063123303623555`", ",", 
       "0.596332217696564`", ",", 
       RowBox[{"-", "0.707666051175226`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6038226124983028`", ",", 
       RowBox[{"-", "0.4063123303623555`"}], ",", 
       RowBox[{"-", "0.596332217696564`"}], ",", "0.707666051175226`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9238795325112867`", ",", 
       RowBox[{"-", "0.22938331171728077`"}], ",", 
       RowBox[{"-", "0.15990238573676874`"}], ",", 
       RowBox[{"-", "0.26126831562213715`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9238795325112867`", ",", 
       RowBox[{"-", "0.2132668602459968`"}], ",", "0.30184000931360105`", ",", 
       RowBox[{"-", "0.0992797285708713`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.8801469591351282`", ",", "0.07984663662348522`", ",", 
         RowBox[{"-", "0.3936475876512634`"}], ",", 
         RowBox[{"-", "0.25299688077414095`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.10962595592554657`", ",", "0.9247995394169658`", ",", 
         "0.2979677773236916`", ",", "0.20962625159639933`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.45954110850829155`", ",", 
         RowBox[{"-", "0.3682381397100991`"}], ",", "0.7304299468513127`", 
         ",", "0.34596926857252003`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.046318999380033726`", ",", 
         RowBox[{"-", "0.05264027903545429`"}], ",", 
         RowBox[{"-", "0.47194159930642715`"}], ",", "0.8788371169696882`"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.520274443560778`"}], ",", "0.4487110522745673`", ",",
          "0.53462226826019`", ",", 
         RowBox[{"-", "0.8042715321347882`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.520274443560778`", ",", 
         RowBox[{"-", "0.4487110522745673`"}], ",", 
         RowBox[{"-", "0.5346222682601901`"}], ",", "0.8042715321347882`"}], 
        "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.726323088950028*^9, 
  3.7264267333271027`*^9},ExpressionUUID->"7b4e8489-9e6d-4644-b487-\
6adca9a5909f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
I. Make numerical matrices from the target and reference data\
\>", "Subsubsection",
 CellChangeTimes->{{3.7256255343963337`*^9, 
  3.725625557004238*^9}},ExpressionUUID->"b20e3063-22dd-485d-b7d3-\
1698e99c3821"],

Cell[TextData[StyleBox["2D constructions for profile matrices",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.740743744673183*^9, 
  3.740743762601137*^9}},ExpressionUUID->"d3c273c4-6211-4d97-b078-\
9bfb6d4d6ae7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Output", " ", "=", " ", 
    RowBox[{"2", "x2", " ", "numerical", " ", "matrix", " ", 
     RowBox[{"E", "[", "ij", "]"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeEaamat", "[", 
    RowBox[{"targetList_", ",", "refList_"}], "]"}], ":=", " ", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "refList", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "Exx", ",", "Exy", ",", "Eyx", ",", "Eyy", ",", "n", ",", "i", ",", 
         "j"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Exx", ",", "Exy"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Eyx", ",", "Eyy"}], "}"}]}], "}"}], " ", "=", 
        "\[IndentingNewLine]", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"Sum", " ", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"targetList", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "i"}], "]"}], "]"}], " ", 
             RowBox[{"refList", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "j"}], "]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "1", ",", "len"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}]}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725625081905693*^9, 3.725625121223707*^9}, 
   3.725625324043811*^9, {3.740743651036841*^9, 
   3.740743713147522*^9}},ExpressionUUID->"cd0269e6-3f10-4836-963c-\
6154352a646f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Output", " ", "=", " ", 
    RowBox[{
    "2", "x2", " ", "numerical", " ", "Horn", " ", "2", "D", " ", "matrix", 
     " ", 
     RowBox[{"M2", "[", "ab", "]"}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{
   RowBox[{"makeMaamat", "[", "Eaamat_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exx", "=", 
        RowBox[{"Eaamat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exy", "=", 
        RowBox[{"Eaamat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Eyx", "=", 
        RowBox[{"Eaamat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyy", "=", 
        RowBox[{"Eaamat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], "  ", "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Exx", "+", "Eyy"}], " ", ",", " ", 
         RowBox[{"Exy", "-", "Eyx"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Exy", "-", "Eyx"}], ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"Exx", "+", "Eyy"}], ")"}]}]}], "}"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740743797451082*^9, 
  3.740743920520352*^9}},ExpressionUUID->"4fbc9b90-b183-4a06-85c8-\
97e313423616"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Output", " ", "=", " ", 
     RowBox[{"For", " ", "2", "D"}]}], ",", " ", 
    RowBox[{
     RowBox[{"really", " ", "only", " ", "need", " ", "a", " ", "2"}], "-", 
     "vector"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeMaaVec", "[", "Eaamat_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exx", "=", 
        RowBox[{"Eaamat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exy", "=", 
        RowBox[{"Eaamat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Eyx", "=", 
        RowBox[{"Eaamat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyy", "=", 
        RowBox[{"Eaamat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], "  ", "}"}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exx", "+", "Eyy"}], " ", ",", " ", 
       RowBox[{"Exy", "-", "Eyx"}]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740743797451082*^9, 3.740743884577099*^9}, {
  3.740743929680385*^9, 
  3.7407439944006643`*^9}},ExpressionUUID->"2321b27b-8c47-46e5-a8cd-\
db2d6295ef02"],

Cell[TextData[{
 "Alternates:  ",
 StyleBox["Horn",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.7407598944664707`*^9, 3.740759896346673*^9}, {
  3.740760073866384*^9, 3.740760097977466*^9}, {3.740923452859926*^9, 
  3.7409234534208384`*^9}},ExpressionUUID->"f7f03bd2-c84f-4f28-a556-\
687ee6a7a417"],

Cell[BoxData[
 RowBox[{
  RowBox[{"make2DEEmat", "[", 
   RowBox[{"xTgt_", ",", "xRef_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"xTgt", "[", 
         RowBox[{"[", 
          RowBox[{"k", ",", "a"}], "]"}], "]"}], ")"}], "*", 
       RowBox[{"xRef", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "b"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", 
        RowBox[{"Length", "[", "xRef", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "1", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.738094183993504*^9, 3.7380941955513973`*^9}, {
  3.738094233674822*^9, 3.738094246689187*^9}, {3.738094280108324*^9, 
  3.738094337227502*^9}, {3.73809463639093*^9, 3.738094639267817*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"3ce06a9b-fb35-4832-8968-06d876d75191"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solve2DRMSDTheta", "[", "EE2Dmat_", "]"}], ":=", " ", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"EE2Dmat", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
     RowBox[{"EE2Dmat", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"EE2Dmat", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", 
     RowBox[{"EE2Dmat", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1"}], "]"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73809436071655*^9, 3.7380943822284193`*^9}, {
  3.738094416126671*^9, 3.7380945041918697`*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"42c7601c-233a-49ac-a78c-44d7478d9a85"],

Cell[TextData[StyleBox[" 3D and 4D",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.740743731497032*^9, 
  3.740743735801345*^9}},ExpressionUUID->"d24bc4ba-d798-45ac-bbe3-\
75c9689f8b9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Output", " ", "=", " ", 
    RowBox[{"3", "x3", " ", "numerical", " ", "matrix", " ", 
     RowBox[{"E", "[", "ij", "]"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeExxmat", "[", 
    RowBox[{"targetList_", ",", "refList_"}], "]"}], ":=", " ", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "refList", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "Exx", ",", "Exy", ",", "Exz", ",", "Eyx", ",", "Eyy", ",", "Eyz", 
         ",", "Ezx", ",", "Ezy", ",", "Ezz", ",", "n", ",", "i", ",", "j"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], "}"}], " ", "=", 
        "\[IndentingNewLine]", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"Sum", " ", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"targetList", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "i"}], "]"}], "]"}], " ", 
             RowBox[{"refList", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "j"}], "]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "1", ",", "len"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725625081905693*^9, 3.725625121223707*^9}, 
   3.725625324043811*^9},
 CellLabel->
  "In[256]:=",ExpressionUUID->"d0291087-5f9f-4744-a296-3edab177661f"],

Cell[TextData[StyleBox[" This can be used for either Euclidean or quaternion  \
target and reference lists",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.72632148552775*^9, 
  3.7263215132951097`*^9}},ExpressionUUID->"233cbc9a-ef05-4d7b-9196-\
0867e1e4c088"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Input", ":", " ", 
     RowBox[{"any", " ", "4", "D", " ", "data"}]}], ",", " ", 
    RowBox[{
     RowBox[{"quat", " ", "or", " ", 
      RowBox[{"space", ".", " ", "Output"}]}], " ", "=", " ", 
     RowBox[{"4", "x4", " ", "numerical", " ", "matrix", " ", 
      RowBox[{"E", "[", "ij", "]"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeEwwmat", "[", 
    RowBox[{"qtargetList_", ",", "qrefList_"}], "]"}], ":=", " ", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "qrefList", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz", ",", "Exw", ",", "Exx", 
         ",", "Exy", ",", "Exz", ",", "Eyw", ",", "Eyx", ",", "Eyy", ",", 
         "Eyz", ",", "Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz", ",", "n", ",",
          "i", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Exw", ",", "Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Eyw", ",", "Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], 
         "}"}], "=", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"Sum", " ", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"qtargetList", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "i"}], "]"}], "]"}], " ", 
             RowBox[{"qrefList", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "j"}], "]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "1", ",", "len"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}]}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725625081905693*^9, 3.725625121223707*^9}, 
   3.725625324043811*^9, {3.7258203358129387`*^9, 3.7258203452435303`*^9}, {
   3.725820514339226*^9, 3.7258205675155163`*^9}, {3.725821365162904*^9, 
   3.725821379419127*^9}, {3.7258219228319893`*^9, 3.725821950678454*^9}, {
   3.726323168183408*^9, 3.726323183831029*^9}},
 CellLabel->
  "In[257]:=",ExpressionUUID->"337e2fe3-dbf8-4e29-91d3-1602f362f54f"],

Cell[TextData[StyleBox["This is needed for the quatFrame RRRinv chord \
measure, feeds 3x3 into  makeMxxmat[S].",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.741710583083473*^9, 
  3.741710621907811*^9}},ExpressionUUID->"42053f00-0580-4035-940e-\
245bd8248238"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Output", " ", "=", " ", 
    RowBox[{
     RowBox[{"3", "x3", " ", "numerical", " ", "matrix", " ", 
      RowBox[{"S", "[", "ij", "]"}]}], "=", 
     RowBox[{
      RowBox[{"R", "[", 
       RowBox[{"p", "[", "k", "]"}], "]"}], ".", 
      RowBox[{"R", "[", 
       RowBox[{"rbar", "[", "k", "]"}], "]"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeSxxmat", "[", 
    RowBox[{"qtargetListP_", ",", "qrefListR_"}], "]"}], ":=", " ", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "qrefListR", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "k", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"QuatToRot", "[", 
           RowBox[{"qtargetListP", "[", 
            RowBox[{"[", "k", "]"}], "]"}], "]"}], ".", 
          RowBox[{"QuatToRot", "[", 
           RowBox[{"qinverse", "[", 
            RowBox[{"qrefListR", "[", 
             RowBox[{"[", "k", "]"}], "]"}], "]"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741707216490459*^9, 3.741707355353816*^9}, {
  3.74170743370501*^9, 3.741707495680418*^9}, {3.741708165762628*^9, 
  3.741708220520344*^9}},
 CellLabel->
  "In[258]:=",ExpressionUUID->"8901fa69-a9f4-49a7-bafd-69b90487165e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" Turn the  canonical E[ij] data into Horn matrices:  \
3D Exx,  4D Eww, and quat-only 4D Vww",
 FontSize->16,
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.726323467195813*^9, 
  3.7263235373630238`*^9}},ExpressionUUID->"f226df65-a2ff-4d93-b97e-\
e76ae11f0af5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Output", " ", "=", " ", 
    RowBox[{
    "4", "x4", " ", "numerical", " ", "Horn", " ", "3", "D", " ", "matrix", 
     " ", 
     RowBox[{"M3", "[", "ab", "]"}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{
   RowBox[{"makeMxxmat", "[", "Exxmat_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exx", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exy", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exz", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Eyx", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyy", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyz", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ezx", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ezy", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ezz", "=", 
        RowBox[{"Exxmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}], " ", "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ",", 
         RowBox[{"Eyz", " ", "-", "Ezy"}], ",", " ", 
         RowBox[{"Ezx", " ", "-", " ", "Exz"}], ",", 
         RowBox[{"Exy", "-", "Eyx"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"Eyz", " ", "-", "Ezy"}], ",", 
         RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ",", 
         RowBox[{"Exy", " ", "+", " ", "Eyx"}], ",", " ", 
         RowBox[{"Ezx", "+", "Exz"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Ezx", " ", "-", " ", "Exz"}], ",", 
         RowBox[{"Exy", " ", "+", " ", "Eyx"}], " ", ",", 
         RowBox[{
          RowBox[{"-", "Exx"}], "+", "Eyy", "-", "Ezz"}], ",", 
         RowBox[{"Eyz", "+", "Ezy"}]}], " ", "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"Exy", "-", "Eyx"}], ",", " ", 
         RowBox[{"Ezx", "+", "Exz"}], " ", ",", 
         RowBox[{"Eyz", "+", "Ezy"}], " ", ",", 
         RowBox[{
          RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}]}], " ", "}"}]}], 
      "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725625081905693*^9, 3.725625177255262*^9}, {
  3.72562537895212*^9, 3.725625480685306*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"ec42596e-1d4b-4c85-947b-7848a490c949"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"PQbTo4DRot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".", 
     
     RowBox[{"{", 
      RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}]}], "-", 
    RowBox[{"qprod", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"qprod", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", 
          RowBox[{"-", "q1"}], ",", 
          RowBox[{"-", "q2"}], ",", 
          RowBox[{"-", "q3"}]}], "}"}]}], "]"}]}], "]"}]}], ")"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.74208211784585*^9, 3.742082121234069*^9}, {
  3.7421445731318617`*^9, 3.74214467680346*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"7b8e80c8-2a9d-44c6-a0e2-5f2db208cdf3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.742995991714766*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"8df6f92b-b78b-4e06-847c-98c02694bcb3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["hornE4mat"], "Input",
 CellChangeTimes->{{3.742996020537652*^9, 3.742996024427443*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"656a5abc-2824-4fed-a0f4-9b3ad7faca3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Exw", ",", "Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Eyw", ",", "Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7429960250178556`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"09c6487d-2de3-4ef7-83d8-b07228d75499"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["hornM4mat"], "Input",
 CellChangeTimes->{{3.7429981513840857`*^9, 3.742998154751299*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"ebdbcd98-274b-49fa-817c-c0c39401a0f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742998155407208*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"37b5bfe3-792a-4a63-95ff-bd0dfba6f800"]
}, Open  ]],

Cell[TextData[StyleBox["NOTE: it is NONtrivial to make a transformation from \
E4 to M4:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7471032265148*^9, 
  3.747103245435204*^9}},ExpressionUUID->"8c9cc8c7-e3e0-4e48-85a5-\
63f7d2b4c3a0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mapE4ToM4", " ", "=", " ", 
  RowBox[{
   RowBox[{"hornM4mat", ".", 
    RowBox[{"Inverse", "[", "hornE4mat", "]"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.747103251587056*^9, 3.747103272767865*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"a1fd190c-0786-4419-bfa2-75148f5f04b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewy", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "+", 
        RowBox[{
         SuperscriptBox["Exz", "2"], " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Exz", " ", "Eyw", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Exw", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Exx", " ", "Eyx", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Exx", " ", "Exz", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Exx", " ", "Eyw", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Exz", " ", "Eyy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Exx", " ", "Eyy", " ", 
         SuperscriptBox["Ezw", "2"]}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{
         SuperscriptBox["Exz", "2"], " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{"Exz", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Exx", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Exw", " ", "Eyx", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Exz", " ", 
         SuperscriptBox["Eyy", "2"], " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Exw", " ", "Exz", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Exw", " ", "Eyw", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Exz", " ", "Eyx", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Exw", " ", "Eyy", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Exx", " ", "Eyz", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Exz", " ", "Eyw", " ", 
         SuperscriptBox["Ezx", "2"]}], "-", 
        RowBox[{"Exw", " ", "Eyz", " ", 
         SuperscriptBox["Ezx", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["Exy", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Eyw", " ", "Ezx"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Exw", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Exx", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Exx", " ", "Eyw", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Exw", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezy"}], "+", 
        RowBox[{"Exz", " ", "Eyx", " ", "Eyy", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{
         SuperscriptBox["Exw", "2"], " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{
         SuperscriptBox["Exx", "2"], " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Exz", " ", "Eyw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Exx", " ", "Eyy", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Exw", " ", 
         SuperscriptBox["Eyz", "2"], " ", "Ezy"}], "+", 
        RowBox[{"Exx", " ", "Eyw", " ", "Ezw", " ", "Ezy"}], "-", 
        RowBox[{"Exw", " ", "Eyx", " ", "Ezw", " ", "Ezy"}], "-", 
        RowBox[{"Exz", " ", "Eyy", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{"Exz", " ", "Eyw", " ", 
         SuperscriptBox["Ezy", "2"]}], "-", 
        RowBox[{"Exw", " ", "Eyz", " ", 
         SuperscriptBox["Ezy", "2"]}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exy"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Exx", " ", "Exz", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Exx", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Exw", " ", "Exz", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Exw", " ", "Eyw", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{
         SuperscriptBox["Exw", "2"], " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Exx", "2"], " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Exx", " ", 
         SuperscriptBox["Eyy", "2"], " ", "Ezz"}], "-", 
        RowBox[{"Exw", " ", "Eyy", " ", "Eyz", " ", "Ezz"}], "-", 
        RowBox[{"Exx", " ", "Eyw", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{"Exw", " ", "Eyx", " ", "Ezx", " ", "Ezz"}], "-", 
        RowBox[{"Exz", " ", "Eyy", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{"Exz", " ", "Eyx", " ", "Ezy", " ", "Ezz"}], "+", 
        RowBox[{"Exw", " ", "Eyy", " ", "Ezy", " ", "Ezz"}], "-", 
        RowBox[{"Exx", " ", "Eyz", " ", "Ezy", " ", "Ezz"}], "+", 
        RowBox[{"Exx", " ", "Eyy", " ", 
         SuperscriptBox["Ezz", "2"]}], "+", 
        RowBox[{"Exy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["Eyx", "2"]}], " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{"Ewx", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{
            SuperscriptBox["Eyz", "2"], " ", "Ezw"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Eww", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Eyy", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Eyw", " ", "Ezw", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "+", 
           RowBox[{"Eyz", " ", "Ezw", " ", "Ezy"}], "-", 
           RowBox[{"Ewx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Eyw", " ", "Eyz", " ", "Ezz"}], "+", 
           RowBox[{"Eyz", " ", "Ezx", " ", "Ezz"}], "-", 
           RowBox[{"Eyw", " ", "Ezy", " ", "Ezz"}], "+", 
           RowBox[{"Eyx", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["Ezw", "2"], "+", 
              RowBox[{"Eyw", " ", "Ezx"}], "-", 
              RowBox[{"Exw", " ", "Ezy"}], "-", 
              RowBox[{"Eww", " ", "Ezz"}], "-", 
              RowBox[{"Exx", " ", "Ezz"}], "-", 
              RowBox[{"Eyy", " ", "Ezz"}], "-", 
              SuperscriptBox["Ezz", "2"]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exy", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Eyx", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Eyw", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Eyy", " ", 
         SuperscriptBox["Ezw", "2"]}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Eyx", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Eyw", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Eyy", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Eyz", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Eyz", " ", 
         SuperscriptBox["Ezx", "2"]}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Eyw", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezy"}], "+", 
        RowBox[{"2", " ", "Eww", " ", "Ewx", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Eyy", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", 
         SuperscriptBox["Eyz", "2"], " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Eyw", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Eyx", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Eyz", " ", 
         SuperscriptBox["Ezy", "2"]}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Eyw", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"2", " ", "Eww", " ", "Ewx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", 
         SuperscriptBox["Eyy", "2"], " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Eyy", " ", "Eyz", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Eyw", " ", "Ezx", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Eyx", " ", "Ezx", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Eyy", " ", "Ezy", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Eyz", " ", "Ezy", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Eyy", " ", 
         SuperscriptBox["Ezz", "2"]}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exw"}], " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Eyy", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{
            SuperscriptBox["Eyw", "2"], " ", "Ezx"}], "+", 
           RowBox[{"2", " ", "Eww", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{
            SuperscriptBox["Eyy", "2"], " ", "Ezx"}], "+", 
           RowBox[{"Eyx", " ", "Ezw", " ", "Ezx"}], "+", 
           RowBox[{"Exz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
              RowBox[{"Eyw", " ", "Ezx"}]}], ")"}]}], "-", 
           RowBox[{"2", " ", "Eww", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Exx", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Eyx", " ", "Eyy", " ", "Ezy"}], "+", 
           RowBox[{"Eyy", " ", "Ezw", " ", "Ezy"}], "+", 
           RowBox[{"Eyw", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Eyx", " ", "Ezw"}], "-", 
              SuperscriptBox["Ezx", "2"], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Exw", "+", "Eyz", "-", "Ezy"}], ")"}], " ", 
               "Ezy"}]}], ")"}]}], "+", 
           RowBox[{"Eyy", " ", "Ezx", " ", "Ezz"}], "-", 
           RowBox[{"Eyx", " ", "Ezy", " ", "Ezz"}]}], ")"}]}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Eyx", "2"], " ", "Ezw"}], "+", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{
            SuperscriptBox["Eyz", "2"], " ", "Ezw"}], "-", 
           RowBox[{"2", " ", "Eww", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Eyy", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Eyw", " ", "Ezw", " ", "Ezx"}], "+", 
           RowBox[{"Exy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
              RowBox[{"Eyw", " ", "Ezx"}]}], ")"}]}], "-", 
           RowBox[{"Eyz", " ", "Ezw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Eyw", " ", "Eyz", " ", "Ezz"}], "-", 
           RowBox[{"Eyz", " ", "Ezx", " ", "Ezz"}], "+", 
           RowBox[{"Eyw", " ", "Ezy", " ", "Ezz"}], "+", 
           RowBox[{"Eyx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["Ezw", "2"]}], "-", 
              RowBox[{"Eyw", " ", "Ezx"}], "+", 
              RowBox[{"Ezz", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "Eww"}], "+", "Exx", "+", "Eyy", "+", 
                 "Ezz"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Ewx"}], " ", 
         SuperscriptBox["Exy", "2"], " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", 
         SuperscriptBox["Exz", "2"], " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", 
         SuperscriptBox["Ezw", "2"]}], "+", 
        RowBox[{"Eww", " ", 
         SuperscriptBox["Exy", "2"], " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", 
         SuperscriptBox["Exz", "2"], " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", 
         SuperscriptBox["Ezx", "2"]}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Exy", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Exy", " ", "Ezy"}], "-", 
        RowBox[{"2", " ", "Eww", " ", "Ewx", " ", "Exz", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exw", " ", "Exz", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Exx", " ", "Exz", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Ezw", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Ezw", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", 
         SuperscriptBox["Ezy", "2"]}], "+", 
        RowBox[{"2", " ", "Eww", " ", "Ewx", " ", "Exy", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exw", " ", "Exy", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exx", " ", "Exy", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Exz", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Exz", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Ezy", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Ezy", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", 
         SuperscriptBox["Ezz", "2"]}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["Exw", "2"]}], " ", "Ezy"}], "+", 
           RowBox[{
            SuperscriptBox["Exx", "2"], " ", "Ezy"}], "+", 
           RowBox[{"Exw", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exy", " ", "Ezw"}], "-", 
              RowBox[{"Exz", " ", "Ezx"}], "+", 
              RowBox[{"Eyw", " ", "Ezx"}], "+", 
              SuperscriptBox["Ezx", "2"], "-", 
              RowBox[{"Eyz", " ", "Ezy"}], "+", 
              SuperscriptBox["Ezy", "2"]}], ")"}]}], "+", 
           RowBox[{"Exy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Eyz", " ", "Ezw"}], "-", 
              RowBox[{"2", " ", "Eww", " ", "Ezx"}], "-", 
              RowBox[{"Eyy", " ", "Ezx"}], "-", 
              RowBox[{"Ezw", " ", "Ezy"}], "-", 
              RowBox[{"Ezx", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Exx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exz", " ", "Ezw"}], "-", 
              RowBox[{"Eyw", " ", "Ezw"}], "-", 
              RowBox[{"Exy", " ", "Ezx"}], "-", 
              RowBox[{"Ezw", " ", "Ezx"}], "+", 
              RowBox[{"2", " ", "Eww", " ", "Ezy"}], "+", 
              RowBox[{"Eyy", " ", "Ezy"}], "+", 
              RowBox[{"Ezy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Exw", "2"], " ", "Ezz"}], "-", 
           RowBox[{
            SuperscriptBox["Exx", "2"], " ", "Ezz"}], "+", 
           RowBox[{"Exz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Eyz"}], " ", "Ezw"}], "+", 
              RowBox[{"2", " ", "Eww", " ", "Ezx"}], "+", 
              RowBox[{"Eyy", " ", "Ezx"}], "+", 
              RowBox[{"Ezw", " ", "Ezy"}], "+", 
              RowBox[{"Ezx", " ", "Ezz"}]}], ")"}]}], "-", 
           RowBox[{"Exw", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exz", " ", "Ezw"}], "+", 
              RowBox[{"Exy", " ", "Ezx"}], "-", 
              RowBox[{"Eyx", " ", "Ezx"}], "+", 
              RowBox[{"Ezw", " ", "Ezx"}], "-", 
              RowBox[{"Eyz", " ", "Ezz"}], "+", 
              RowBox[{"Ezy", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Exx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exy", " ", "Ezw"}], "-", 
              RowBox[{"Eyx", " ", "Ezw"}], "+", 
              SuperscriptBox["Ezw", "2"], "+", 
              RowBox[{"Exz", " ", "Ezx"}], "-", 
              RowBox[{"2", " ", "Eww", " ", "Ezz"}], "-", 
              RowBox[{"Eyy", " ", "Ezz"}], "-", 
              SuperscriptBox["Ezz", "2"]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", 
         SuperscriptBox["Exy", "2"], " ", "Eyw"}], "+", 
        RowBox[{"Ewx", " ", 
         SuperscriptBox["Exz", "2"], " ", "Eyw"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", 
         SuperscriptBox["Eyw", "2"]}], "-", 
        RowBox[{"Eww", " ", 
         SuperscriptBox["Exy", "2"], " ", "Eyx"}], "-", 
        RowBox[{"Eww", " ", 
         SuperscriptBox["Exz", "2"], " ", "Eyx"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Eyx"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyw", " ", "Eyx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", 
         SuperscriptBox["Eyx", "2"]}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Exy", " ", "Eyy"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Exy", " ", "Eyy"}], "+", 
        RowBox[{"2", " ", "Eww", " ", "Ewx", " ", "Exz", " ", "Eyy"}], "-", 
        RowBox[{"Eww", " ", "Exw", " ", "Exz", " ", "Eyy"}], "+", 
        RowBox[{"Ewx", " ", "Exx", " ", "Exz", " ", "Eyy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyx", " ", "Eyy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyx", " ", "Eyy"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", 
         SuperscriptBox["Eyy", "2"]}], "-", 
        RowBox[{"2", " ", "Eww", " ", "Ewx", " ", "Exy", " ", "Eyz"}], "+", 
        RowBox[{"Eww", " ", "Exw", " ", "Exy", " ", "Eyz"}], "-", 
        RowBox[{"Ewx", " ", "Exx", " ", "Exy", " ", "Eyz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Exz", " ", "Eyz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Exz", " ", "Eyz"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyw", " ", "Eyz"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyw", " ", "Eyz"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyy", " ", "Eyz"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Eyz"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", 
         SuperscriptBox["Eyz", "2"]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezx"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezz"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Exw", "2"], " ", "Eyy"}], "-", 
           RowBox[{
            SuperscriptBox["Exx", "2"], " ", "Eyy"}], "-", 
           RowBox[{"Exw", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exy", " ", "Eyw"}], "-", 
              RowBox[{"Exz", " ", "Eyx"}], "+", 
              RowBox[{"Eyw", " ", "Eyx"}], "-", 
              RowBox[{"Eyy", " ", "Eyz"}], "+", 
              RowBox[{"Eyx", " ", "Ezx"}], "+", 
              RowBox[{"Eyy", " ", "Ezy"}]}], ")"}]}], "+", 
           RowBox[{"Exx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exz"}], " ", "Eyw"}], "+", 
              SuperscriptBox["Eyw", "2"], "+", 
              RowBox[{"Exy", " ", "Eyx"}], "-", 
              RowBox[{"2", " ", "Eww", " ", "Eyy"}], "-", 
              SuperscriptBox["Eyy", "2"], "+", 
              RowBox[{"Eyw", " ", "Ezx"}], "-", 
              RowBox[{"Eyy", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Exy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "Eww", " ", "Eyx"}], "+", 
              RowBox[{"Eyw", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "Eyz"}], "+", "Ezy"}], ")"}]}], "+", 
              RowBox[{"Eyx", " ", 
               RowBox[{"(", 
                RowBox[{"Eyy", "+", "Ezz"}], ")"}]}]}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["Exw", "2"]}], " ", "Eyz"}], "+", 
           RowBox[{
            SuperscriptBox["Exx", "2"], " ", "Eyz"}], "+", 
           RowBox[{"Exw", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exz", " ", "Eyw"}], "+", 
              RowBox[{"Exy", " ", "Eyx"}], "-", 
              SuperscriptBox["Eyx", "2"], "-", 
              SuperscriptBox["Eyz", "2"], "+", 
              RowBox[{"Eyx", " ", "Ezw"}], "+", 
              RowBox[{"Eyz", " ", "Ezy"}]}], ")"}]}], "+", 
           RowBox[{"Exx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exy"}], " ", "Eyw"}], "-", 
              RowBox[{"Exz", " ", "Eyx"}], "+", 
              RowBox[{"Eyw", " ", "Eyx"}], "+", 
              RowBox[{"2", " ", "Eww", " ", "Eyz"}], "+", 
              RowBox[{"Eyy", " ", "Eyz"}], "-", 
              RowBox[{"Eyw", " ", "Ezw"}], "+", 
              RowBox[{"Eyz", " ", "Ezz"}]}], ")"}]}], "-", 
           RowBox[{"Exz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "Eww", " ", "Eyx"}], "+", 
              RowBox[{"Eyw", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "Eyz"}], "+", "Ezy"}], ")"}]}], "+", 
              RowBox[{"Eyx", " ", 
               RowBox[{"(", 
                RowBox[{"Eyy", "+", "Ezz"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exy", " ", "Eyw", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Exz", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezw"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Exx", " ", "Eyw", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Exz", " ", 
         SuperscriptBox["Eyy", "2"], " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Exx", " ", "Eyx", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Exy", " ", "Eyy", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Exz", " ", "Eyx", " ", 
         SuperscriptBox["Ezw", "2"]}], "-", 
        RowBox[{"Exx", " ", "Eyz", " ", 
         SuperscriptBox["Ezw", "2"]}], "-", 
        RowBox[{"Exy", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezx"}], "+", 
        RowBox[{"Exz", " ", "Eyw", " ", "Eyx", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"2", " ", "Exw", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Exw", " ", "Eyw", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"2", " ", "Exw", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Exw", " ", "Eyx", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Exz", " ", "Eyy", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Exy", " ", 
         SuperscriptBox["Eyz", "2"], " ", "Ezx"}], "-", 
        RowBox[{"Exz", " ", "Eyw", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Exy", " ", "Eyx", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"Exx", " ", "Eyy", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Exw", " ", "Eyz", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"Exy", " ", "Eyw", " ", 
         SuperscriptBox["Ezx", "2"]}], "+", 
        RowBox[{"Exw", " ", "Eyy", " ", 
         SuperscriptBox["Ezx", "2"]}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Exx", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"2", " ", "Exw", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Exw", " ", "Eyw", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Exz", " ", "Eyw", " ", "Eyy", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"2", " ", "Exw", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Exz", " ", "Eyx", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Exw", " ", "Eyy", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Exx", " ", 
         SuperscriptBox["Eyz", "2"], " ", "Ezy"}], "+", 
        RowBox[{"Exx", " ", "Eyw", " ", "Ezx", " ", "Ezy"}], "-", 
        RowBox[{"Exw", " ", "Eyx", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{"Exz", " ", "Eyy", " ", "Ezx", " ", "Ezy"}], "-", 
        RowBox[{"Exy", " ", "Eyz", " ", "Ezx", " ", "Ezy"}], "-", 
        RowBox[{"Exz", " ", "Eyx", " ", 
         SuperscriptBox["Ezy", "2"]}], "+", 
        RowBox[{"Exx", " ", "Eyz", " ", 
         SuperscriptBox["Ezy", "2"]}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"2", " ", "Exw", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Exx", " ", "Eyw", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Exw", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"2", " ", "Exw", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Exy", " ", "Eyw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Exw", " ", 
         SuperscriptBox["Eyy", "2"], " ", "Ezz"}], "-", 
        RowBox[{"Exy", " ", "Eyx", " ", "Eyz", " ", "Ezz"}], "+", 
        RowBox[{"Exx", " ", "Eyy", " ", "Eyz", " ", "Ezz"}], "+", 
        RowBox[{"Exx", " ", "Eyw", " ", "Ezw", " ", "Ezz"}], "-", 
        RowBox[{"Exw", " ", "Eyx", " ", "Ezw", " ", "Ezz"}], "-", 
        RowBox[{"Exz", " ", "Eyy", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{"Exy", " ", "Eyz", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{"Exz", " ", "Eyw", " ", "Ezy", " ", "Ezz"}], "+", 
        RowBox[{"Exy", " ", "Eyx", " ", "Ezy", " ", "Ezz"}], "-", 
        RowBox[{"Exx", " ", "Eyy", " ", "Ezy", " ", "Ezz"}], "-", 
        RowBox[{"Exw", " ", "Eyz", " ", "Ezy", " ", "Ezz"}], "-", 
        RowBox[{"Exy", " ", "Eyw", " ", 
         SuperscriptBox["Ezz", "2"]}], "+", 
        RowBox[{"Exw", " ", "Eyy", " ", 
         SuperscriptBox["Ezz", "2"]}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exz", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Eyw", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Eyx", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Eyz", " ", 
         SuperscriptBox["Ezw", "2"]}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Eyw", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Eyx", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Ewx", " ", "Eyy", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Eyz", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Eyy", " ", 
         SuperscriptBox["Ezx", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
           RowBox[{"Eyw", " ", "Ezx"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
           RowBox[{"Eyw", " ", "Ezx"}]}], ")"}]}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Eyw", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Eyy", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", 
         SuperscriptBox["Eyz", "2"], " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Eyw", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Eyx", " ", "Ezx", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Eyz", " ", 
         SuperscriptBox["Ezy", "2"]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Eyw", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", 
         SuperscriptBox["Eyy", "2"], " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Eyy", " ", "Eyz", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Eyw", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Eyx", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Eyy", " ", "Ezy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Eyz", " ", "Ezy", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Eyy", " ", 
         SuperscriptBox["Ezz", "2"]}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Eyx", "2"], " ", "Ezw"}], "-", 
           RowBox[{"Eww", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{
            SuperscriptBox["Eyy", "2"], " ", "Ezw"}], "+", 
           RowBox[{"Ewx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Ewx", " ", "Eyy", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "-", 
           RowBox[{"Eww", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Eyy", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Eyw", " ", "Ezw", " ", "Ezx"}], "+", 
           RowBox[{"Exy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Eyx", " ", "Ezw"}], "-", 
              RowBox[{"Eyw", " ", "Ezx"}]}], ")"}]}], "+", 
           RowBox[{"Eww", " ", "Eyw", " ", "Ezy"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Eyw", " ", "Eyy", " ", "Ezy"}], "-", 
           RowBox[{"Eyy", " ", "Ezx", " ", "Ezy"}], "-", 
           RowBox[{"Ewx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Eyy", " ", "Ezw", " ", "Ezz"}], "-", 
           RowBox[{"Eyw", " ", "Ezy", " ", "Ezz"}], "-", 
           RowBox[{"Eyx", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["Ezw", "2"], "+", 
              RowBox[{"Eyw", " ", "Ezx"}], "+", 
              RowBox[{"Ewx", " ", "Ezy"}], "-", 
              RowBox[{"Exw", " ", "Ezy"}], "+", 
              RowBox[{"Eyz", " ", "Ezy"}], "-", 
              SuperscriptBox["Ezy", "2"], "-", 
              RowBox[{"Eww", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Ewx", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{"Eww", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{"Eyy", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{
            SuperscriptBox["Eyw", "2"], " ", "Ezx"}], "-", 
           RowBox[{"Eww", " ", "Eyy", " ", "Ezx"}], "-", 
           RowBox[{"Ewx", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{
            SuperscriptBox["Eyz", "2"], " ", "Ezx"}], "-", 
           RowBox[{"Eyx", " ", "Ezw", " ", "Ezx"}], "+", 
           RowBox[{"Exz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
              RowBox[{"Eyw", " ", "Ezx"}]}], ")"}]}], "+", 
           RowBox[{"Eww", " ", "Eyx", " ", "Ezy"}], "+", 
           RowBox[{"Eyz", " ", "Ezx", " ", "Ezy"}], "+", 
           RowBox[{"Ewx", " ", "Eyx", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}], "+", 
           RowBox[{"Eyx", " ", "Eyz", " ", "Ezz"}], "-", 
           RowBox[{"Eyz", " ", "Ezw", " ", "Ezz"}], "-", 
           RowBox[{"Eyx", " ", "Ezy", " ", "Ezz"}], "+", 
           RowBox[{"Eyw", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
              SuperscriptBox["Ezx", "2"], "-", 
              RowBox[{"Ewx", " ", "Ezy"}], "-", 
              RowBox[{"Eww", " ", "Ezz"}], "-", 
              RowBox[{"Exx", " ", "Ezz"}], "+", 
              RowBox[{"Eyy", " ", "Ezz"}], "+", 
              SuperscriptBox["Ezz", "2"]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Ewx"}], " ", "Exy", " ", "Eyw", " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", 
         SuperscriptBox["Ezw", "2"]}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", 
         SuperscriptBox["Ezx", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exx", " ", "Ezw"}], "-", 
           RowBox[{"Exw", " ", "Ezx"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exx", " ", "Ezw"}], "-", 
           RowBox[{"Exw", " ", "Ezx"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", "Exz", " ", "Ezy"}], "-", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", "Exz", " ", "Ezy"}], "+", 
        RowBox[{"2", " ", "Ewx", " ", "Exw", " ", "Exz", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezy"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Ezx", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", 
         SuperscriptBox["Ezy", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", "Exy", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", "Exy", " ", "Ezz"}], "-", 
        RowBox[{"2", " ", "Ewx", " ", "Exw", " ", "Exy", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Ezw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Ezw", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Ezy", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Ezy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", 
         SuperscriptBox["Ezz", "2"]}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exx"}], " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", 
            SuperscriptBox["Ezw", "2"]}], "+", 
           RowBox[{"2", " ", "Exw", " ", "Exy", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezx"}], "-", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Ezw", " ", "Ezx"}], "-", 
           RowBox[{"2", " ", "Exw", " ", "Exx", " ", "Ezy"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezy"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "+", 
           RowBox[{"Exy", " ", "Ezx", " ", "Ezy"}], "-", 
           RowBox[{"Exx", " ", 
            SuperscriptBox["Ezy", "2"]}], "-", 
           RowBox[{"Exy", " ", "Ezw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Ezy", " ", "Ezz"}], "+", 
           RowBox[{"Ewx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exz"}], " ", "Ezw"}], "-", 
              RowBox[{"Exy", " ", "Ezx"}], "+", 
              RowBox[{"Exx", " ", "Ezy"}], "+", 
              RowBox[{"Exw", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Eww", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exy", " ", "Ezw"}], "+", 
              RowBox[{"Exz", " ", "Ezx"}], "-", 
              RowBox[{"Exw", " ", "Ezy"}], "-", 
              RowBox[{"Exx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exx", " ", "Eyw", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"2", " ", "Exw", " ", "Exz", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exz", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Ezw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", 
            SuperscriptBox["Ezx", "2"]}], "-", 
           RowBox[{"Exz", " ", "Ezx", " ", "Ezy"}], "+", 
           RowBox[{"2", " ", "Exw", " ", "Exx", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezz"}], "-", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezz"}], "+", 
           RowBox[{"Exz", " ", "Ezw", " ", "Ezz"}], "+", 
           RowBox[{"Exx", " ", "Ezy", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", 
            SuperscriptBox["Ezz", "2"]}], "+", 
           RowBox[{"Eww", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exz"}], " ", "Ezw"}], "+", 
              RowBox[{"Exy", " ", "Ezx"}], "-", 
              RowBox[{"Exx", " ", "Ezy"}], "+", 
              RowBox[{"Exw", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Ewx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exy"}], " ", "Ezw"}], "+", 
              RowBox[{"Exz", " ", "Ezx"}], "+", 
              RowBox[{"Exw", " ", "Ezy"}], "-", 
              RowBox[{"Exx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exy", " ", 
         SuperscriptBox["Eyw", "2"]}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyw", " ", "Eyx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Eyx"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", 
         SuperscriptBox["Eyx", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exx"}], " ", "Eyw"}], "+", 
           RowBox[{"Exw", " ", "Eyx"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exx"}], " ", "Eyw"}], "+", 
           RowBox[{"Exw", " ", "Eyx"}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", "Exz", " ", "Eyy"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", "Exz", " ", "Eyy"}], "-", 
        RowBox[{"2", " ", "Ewx", " ", "Exw", " ", "Exz", " ", "Eyy"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyw", " ", "Eyy"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyw", " ", "Eyy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", 
         SuperscriptBox["Eyy", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", "Exy", " ", "Eyz"}], "-", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", "Exy", " ", "Eyz"}], "+", 
        RowBox[{"2", " ", "Ewx", " ", "Exw", " ", "Exy", " ", "Eyz"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyx", " ", "Eyz"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyx", " ", "Eyz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyy", " ", "Eyz"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Eyz"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", 
         SuperscriptBox["Eyz", "2"]}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezz"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "Exw", " ", "Exy", " ", "Eyx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Eyx"}], "-", 
           RowBox[{"Exw", " ", 
            SuperscriptBox["Eyx", "2"]}], "+", 
           RowBox[{"2", " ", "Exw", " ", "Exx", " ", "Eyy"}], "+", 
           RowBox[{"Exy", " ", "Eyw", " ", "Eyy"}], "-", 
           RowBox[{"Exw", " ", 
            SuperscriptBox["Eyy", "2"]}], "+", 
           RowBox[{"Exy", " ", "Eyx", " ", "Eyz"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Eyz"}], "+", 
           RowBox[{"Ewx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exz", " ", "Eyw"}], "+", 
              RowBox[{"Exy", " ", "Eyx"}], "-", 
              RowBox[{"Exx", " ", "Eyy"}], "-", 
              RowBox[{"Exw", " ", "Eyz"}]}], ")"}]}], "+", 
           RowBox[{"Eww", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exy"}], " ", "Eyw"}], "-", 
              RowBox[{"Exz", " ", "Eyx"}], "+", 
              RowBox[{"Exw", " ", "Eyy"}], "+", 
              RowBox[{"Exx", " ", "Eyz"}]}], ")"}]}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezw"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyx", " ", "Ezy"}], "+", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezy"}], "+", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezz"}]}], ")"}]}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exx"}], " ", 
            SuperscriptBox["Eyw", "2"]}], "+", 
           RowBox[{"2", " ", "Exw", " ", "Exz", " ", "Eyx"}], "+", 
           RowBox[{"Exw", " ", "Eyw", " ", "Eyx"}], "-", 
           RowBox[{"Exz", " ", "Eyw", " ", "Eyy"}], "-", 
           RowBox[{"2", " ", "Exw", " ", "Exx", " ", "Eyz"}], "-", 
           RowBox[{"Exz", " ", "Eyx", " ", "Eyz"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Eyz"}], "+", 
           RowBox[{"Exx", " ", 
            SuperscriptBox["Eyz", "2"]}], "+", 
           RowBox[{"Eww", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exz", " ", "Eyw"}], "-", 
              RowBox[{"Exy", " ", "Eyx"}], "+", 
              RowBox[{"Exx", " ", "Eyy"}], "-", 
              RowBox[{"Exw", " ", "Eyz"}]}], ")"}]}], "+", 
           RowBox[{"Ewx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exy", " ", "Eyw"}], "-", 
              RowBox[{"Exz", " ", "Eyx"}], "-", 
              RowBox[{"Exw", " ", "Eyy"}], "+", 
              RowBox[{"Exx", " ", "Eyz"}]}], ")"}]}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezx"}], "+", 
           RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "-", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezz"}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Eww"}], " ", "Exz", " ", "Eyx", " ", "Ezw"}], "+", 
        RowBox[{"Exx", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Exy", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{
         SuperscriptBox["Exx", "2"], " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{
         SuperscriptBox["Exy", "2"], " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Exz", " ", "Eyy", " ", 
         SuperscriptBox["Ezw", "2"]}], "-", 
        RowBox[{"Exy", " ", "Eyz", " ", 
         SuperscriptBox["Ezw", "2"]}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Exx", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{
         SuperscriptBox["Exz", "2"], " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"2", " ", "Exz", " ", "Eyw", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Exy", " ", "Exz", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"2", " ", "Exy", " ", "Eyw", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Exz", " ", "Eyy", " ", 
         SuperscriptBox["Ezx", "2"]}], "+", 
        RowBox[{"Exy", " ", "Eyz", " ", 
         SuperscriptBox["Ezx", "2"]}], "-", 
        RowBox[{"Ewz", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Exy", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{
         SuperscriptBox["Exz", "2"], " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"2", " ", "Exz", " ", "Eyw", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Exx", " ", "Exz", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"2", " ", "Exx", " ", "Eyw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Exz", " ", "Eyw", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{"Exy", " ", "Eyx", " ", "Ezw", " ", "Ezy"}], "-", 
        RowBox[{"Exx", " ", "Eyy", " ", "Ezw", " ", "Ezy"}], "-", 
        RowBox[{"Exy", " ", "Eyw", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{"Exz", " ", "Eyx", " ", "Ezx", " ", "Ezy"}], "-", 
        RowBox[{"Exx", " ", "Eyz", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{"Exx", " ", "Eyw", " ", 
         SuperscriptBox["Ezy", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["Exw", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Eyy"}], " ", "Ezx"}], "+", 
           RowBox[{"Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exy"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Exx", "2"], " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Exy", "2"], " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Exy", " ", "Exz", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"2", " ", "Exy", " ", "Eyw", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Exx", " ", "Exz", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"2", " ", "Exx", " ", "Eyw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Exy", " ", "Eyw", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{"Exz", " ", "Eyx", " ", "Ezw", " ", "Ezz"}], "-", 
        RowBox[{"Exx", " ", "Eyz", " ", "Ezw", " ", "Ezz"}], "-", 
        RowBox[{"Exz", " ", "Eyw", " ", "Ezx", " ", "Ezz"}], "-", 
        RowBox[{"Exy", " ", "Eyx", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{"Exx", " ", "Eyy", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{"Exx", " ", "Eyw", " ", 
         SuperscriptBox["Ezz", "2"]}], "+", 
        RowBox[{"Exw", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Eww"}], " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Ewz", " ", "Eyz", " ", "Ezy"}], "+", 
           RowBox[{"Eyz", " ", "Ezw", " ", "Ezy"}], "+", 
           RowBox[{"Eyy", " ", "Ezx", " ", "Ezy"}], "-", 
           RowBox[{"Eyx", " ", 
            SuperscriptBox["Ezy", "2"]}], "+", 
           RowBox[{"Eww", " ", "Eyx", " ", "Ezz"}], "-", 
           RowBox[{"Ewz", " ", "Eyy", " ", "Ezz"}], "-", 
           RowBox[{"Eyy", " ", "Ezw", " ", "Ezz"}], "+", 
           RowBox[{"Eyz", " ", "Ezx", " ", "Ezz"}], "-", 
           RowBox[{"Eyx", " ", 
            SuperscriptBox["Ezz", "2"]}], "+", 
           RowBox[{"Exx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Eyy", " ", "Ezw"}], "+", 
              RowBox[{"Eyz", " ", "Ezx"}], "-", 
              RowBox[{"Eyw", " ", "Ezy"}], "-", 
              RowBox[{"Eyx", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Exy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
              RowBox[{"Eyw", " ", "Ezx"}], "+", 
              RowBox[{"Eyz", " ", "Ezy"}], "-", 
              RowBox[{"Eyy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewy", " ", "Exw", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Eyy", " ", 
         SuperscriptBox["Ezw", "2"]}], "+", 
        RowBox[{"Ewy", " ", "Eyz", " ", 
         SuperscriptBox["Ezw", "2"]}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Ewz", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"2", " ", "Ewz", " ", "Eyw", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"2", " ", "Ewy", " ", "Eyw", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Eyy", " ", 
         SuperscriptBox["Ezx", "2"]}], "-", 
        RowBox[{"Ewy", " ", "Eyz", " ", 
         SuperscriptBox["Ezx", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"2", " ", "Ewz", " ", "Eyw", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", "Eyw", " ", "Ezw", " ", "Ezy"}], "-", 
        RowBox[{"Ewy", " ", "Eyx", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{"Ewy", " ", "Eyw", " ", "Ezx", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Eyx", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Eyy"}], " ", "Ezw"}], "+", 
           RowBox[{"Eyw", " ", "Ezy"}]}], ")"}]}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"2", " ", "Ewy", " ", "Eyw", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Eyw", " ", "Ezw", " ", "Ezz"}], "-", 
        RowBox[{"Ewz", " ", "Eyx", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{"Ewz", " ", "Eyw", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Eyx", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Eyx", " ", "Ezz"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exw"}], " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Eww", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Eww", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Eww", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Exz", " ", "Eyz", " ", "Ezy"}], "-", 
           RowBox[{"2", " ", "Eyw", " ", "Eyz", " ", "Ezy"}], "+", 
           RowBox[{"Eyy", " ", "Ezw", " ", "Ezy"}], "+", 
           RowBox[{"Eyz", " ", "Ezx", " ", "Ezy"}], "-", 
           RowBox[{"Eyw", " ", 
            SuperscriptBox["Ezy", "2"]}], "+", 
           RowBox[{"Eww", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezz"}], "+", 
           RowBox[{"2", " ", "Eyw", " ", "Eyy", " ", "Ezz"}], "+", 
           RowBox[{"Eyz", " ", "Ezw", " ", "Ezz"}], "-", 
           RowBox[{"Eyy", " ", "Ezx", " ", "Ezz"}], "-", 
           RowBox[{"Eyw", " ", 
            SuperscriptBox["Ezz", "2"]}], "+", 
           RowBox[{"Ewy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Eyx", " ", "Ezw"}], "-", 
              RowBox[{"Eyw", " ", "Ezx"}], "+", 
              RowBox[{"Eyz", " ", "Ezy"}], "-", 
              RowBox[{"Eyy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"Eww", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezy"}], "-", 
           RowBox[{"Eyz", " ", "Ezw", " ", "Ezy"}], "-", 
           RowBox[{"Eyy", " ", "Ezx", " ", "Ezy"}], "+", 
           RowBox[{"Eyx", " ", 
            SuperscriptBox["Ezy", "2"]}], "+", 
           RowBox[{"Exx", " ", "Eyx", " ", "Ezz"}], "+", 
           RowBox[{"Exy", " ", "Eyy", " ", "Ezz"}], "+", 
           RowBox[{"Eyy", " ", "Ezw", " ", "Ezz"}], "-", 
           RowBox[{"Eyz", " ", "Ezx", " ", "Ezz"}], "+", 
           RowBox[{"Eyx", " ", 
            SuperscriptBox["Ezz", "2"]}], "+", 
           RowBox[{"Ewz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Eyx", " ", "Ezw"}], "-", 
              RowBox[{"Eyw", " ", "Ezx"}], "-", 
              RowBox[{"Eyz", " ", "Ezy"}], "+", 
              RowBox[{"Eyy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Ewy"}], " ", "Exw", " ", "Exx", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Exx", "2"], " ", "Ezw"}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Exy", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Exy", "2"], " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exz", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Exy", " ", "Exz", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", 
         SuperscriptBox["Ezw", "2"]}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", 
         SuperscriptBox["Ezw", "2"]}], "+", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Exw", "2"], " ", "Ezx"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Exx", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exy", " ", "Ezx"}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Exz", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Exz", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Exz", "2"], " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", 
         SuperscriptBox["Ezx", "2"]}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", 
         SuperscriptBox["Ezx", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Exw", " ", "Ezy"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exx", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Exy", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Exz", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Ezw", " ", "Ezy"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Ezw"}], "-", 
           RowBox[{"Exw", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exw", " ", "Ezz"}], "-", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Exx", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Exy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Exz", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Ezw", " ", "Ezz"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Ezx", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Ezx", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Ezz"}]}], ")"}]}], "+", 
        RowBox[{"Eww", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exw"}], " ", "Exy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Exz", " ", "Ezx"}], "-", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Exx", " ", "Ezy"}], "+", 
           RowBox[{"Exy", " ", "Exz", " ", "Ezy"}], "+", 
           RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "+", 
           RowBox[{"Exz", " ", "Ezw", " ", "Ezy"}], "+", 
           RowBox[{"Exy", " ", "Ezx", " ", "Ezy"}], "-", 
           RowBox[{"Exx", " ", 
            SuperscriptBox["Ezy", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["Exx", "2"], " ", "Ezz"}], "-", 
           RowBox[{
            SuperscriptBox["Exy", "2"], " ", "Ezz"}], "-", 
           RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "+", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezz"}], "-", 
           RowBox[{"Exy", " ", "Ezw", " ", "Ezz"}], "+", 
           RowBox[{"Exz", " ", "Ezx", " ", "Ezz"}], "-", 
           RowBox[{"Exx", " ", 
            SuperscriptBox["Ezz", "2"]}], "+", 
           RowBox[{"Ewz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exx"}], " ", "Ezw"}], "+", 
              RowBox[{"Exw", " ", "Ezx"}], "+", 
              RowBox[{"Exz", " ", "Ezy"}], "-", 
              RowBox[{"Exy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Eww", " ", "Exz", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Exz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{"Eww", " ", "Exy", " ", "Ezx"}], "-", 
           RowBox[{
            SuperscriptBox["Exw", "2"], " ", "Ezy"}], "+", 
           RowBox[{"Eww", " ", "Exx", " ", "Ezy"}], "+", 
           RowBox[{
            SuperscriptBox["Exz", "2"], " ", "Ezy"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exy", " ", "Ezw", " ", "Ezy"}], "-", 
           RowBox[{"Exz", " ", "Ezx", " ", "Ezy"}], "-", 
           RowBox[{"Exy", " ", "Exz", " ", "Ezz"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Exz", " ", "Ezw", " ", "Ezz"}], "+", 
           RowBox[{"Exy", " ", "Ezx", " ", "Ezz"}], "+", 
           RowBox[{"Ewy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exx"}], " ", "Ezw"}], "+", 
              RowBox[{"Exw", " ", "Ezx"}], "-", 
              RowBox[{"Exz", " ", "Ezy"}], "+", 
              RowBox[{"Exy", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Exw", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exy", " ", "Ezw"}], "+", 
              RowBox[{"Eyz", " ", "Ezy"}], "+", 
              SuperscriptBox["Ezy", "2"], "-", 
              RowBox[{"Eww", " ", "Ezz"}], "+", 
              RowBox[{"Exx", " ", "Ezz"}], "-", 
              RowBox[{"Eyy", " ", "Ezz"}], "+", 
              SuperscriptBox["Ezz", "2"]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewy", " ", "Exw", " ", "Exx", " ", "Eyw"}], "-", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Exx", "2"], " ", "Eyw"}], "-", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Exy", " ", "Eyw"}], "-", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Exy", "2"], " ", "Eyw"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exz", " ", "Eyw"}], "+", 
        RowBox[{"Ewy", " ", "Exy", " ", "Exz", " ", "Eyw"}], "-", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Exw", "2"], " ", "Eyx"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Exx", " ", "Eyx"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exy", " ", "Eyx"}], "-", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Exz", " ", "Eyx"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Exz", " ", "Eyx"}], "+", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Exz", "2"], " ", "Eyx"}], "-", 
        RowBox[{"2", " ", "Ewz", " ", "Exy", " ", "Eyw", " ", "Eyx"}], "+", 
        RowBox[{"2", " ", "Ewy", " ", "Exz", " ", "Eyw", " ", "Eyx"}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Exw", " ", "Eyy"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exx", " ", "Eyy"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Exy", " ", "Eyy"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Exz", " ", "Eyy"}], "+", 
        RowBox[{"2", " ", "Ewz", " ", "Exx", " ", "Eyw", " ", "Eyy"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exy"}], " ", "Eyw"}], "+", 
           RowBox[{"Exw", " ", "Eyy"}]}], ")"}]}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exw", " ", "Eyz"}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Exx", " ", "Eyz"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Exy", " ", "Eyz"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Exz", " ", "Eyz"}], "-", 
        RowBox[{"2", " ", "Ewy", " ", "Exx", " ", "Eyw", " ", "Eyz"}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exz", " ", "Eyx"}], "-", 
           RowBox[{"Exx", " ", "Eyz"}]}], ")"}]}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyw", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyw", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyx", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyx", " ", "Ezx"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exw", " ", "Exy", " ", "Eyx"}], "-", 
           RowBox[{"Exx", " ", "Exz", " ", "Eyx"}], "-", 
           RowBox[{"Exw", " ", "Exx", " ", "Eyy"}], "-", 
           RowBox[{"Exy", " ", "Exz", " ", "Eyy"}], "+", 
           RowBox[{
            SuperscriptBox["Exx", "2"], " ", "Eyz"}], "+", 
           RowBox[{
            SuperscriptBox["Exy", "2"], " ", "Eyz"}], "+", 
           RowBox[{"Ewz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exx", " ", "Eyw"}], "-", 
              RowBox[{"Exw", " ", "Eyx"}], "-", 
              RowBox[{"Exz", " ", "Eyy"}], "+", 
              RowBox[{"Exy", " ", "Eyz"}]}], ")"}]}], "-", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyx", " ", "Ezy"}], "+", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezy"}], "-", 
           RowBox[{"Exz", " ", "Eyx", " ", "Ezz"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezz"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Eww"}], " ", "Exz", " ", "Eyw"}], "+", 
           RowBox[{"Exx", " ", "Exz", " ", "Eyw"}], "+", 
           RowBox[{"Eww", " ", "Exy", " ", "Eyx"}], "+", 
           RowBox[{
            SuperscriptBox["Exw", "2"], " ", "Eyy"}], "-", 
           RowBox[{"Eww", " ", "Exx", " ", "Eyy"}], "-", 
           RowBox[{
            SuperscriptBox["Exz", "2"], " ", "Eyy"}], "-", 
           RowBox[{"2", " ", "Exz", " ", "Eyw", " ", "Eyy"}], "+", 
           RowBox[{"Exy", " ", "Exz", " ", "Eyz"}], "+", 
           RowBox[{"2", " ", "Exy", " ", "Eyw", " ", "Eyz"}], "+", 
           RowBox[{"Ewy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exx", " ", "Eyw"}], "-", 
              RowBox[{"Exw", " ", "Eyx"}], "+", 
              RowBox[{"Exz", " ", "Eyy"}], "-", 
              RowBox[{"Exy", " ", "Eyz"}]}], ")"}]}], "+", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "-", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezy"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exy", " ", "Eyw"}], "-", 
              RowBox[{"Eww", " ", "Eyz"}], "+", 
              RowBox[{"Exx", " ", "Eyz"}], "+", 
              RowBox[{"Eyy", " ", "Ezy"}], "+", 
              RowBox[{"Eyz", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Ewx"}], " ", "Exz", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Exw", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{
         SuperscriptBox["Exz", "2"], " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Exz", " ", "Eyw", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Exy", " ", "Eyx", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Exy", " ", "Exz", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Exy", " ", "Eyw", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Exz", " ", "Eyx", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{"Exw", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Ewz", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Exy", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Exy", " ", "Eyw", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Exz", " ", "Eyx", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Exw", " ", 
         SuperscriptBox["Eyy", "2"], " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{
         SuperscriptBox["Exw", "2"], " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{
         SuperscriptBox["Exy", "2"], " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Exz", " ", "Eyw", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Exy", " ", "Eyx", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Exw", " ", 
         SuperscriptBox["Eyz", "2"], " ", "Ezx"}], "+", 
        RowBox[{"2", " ", "Exz", " ", "Eyy", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"2", " ", "Exy", " ", "Eyz", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{
         SuperscriptBox["Exz", "2"], " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Exz", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Exy", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Exz", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezy"}], "+", 
        RowBox[{"Exw", " ", "Eyx", " ", "Eyy", " ", "Ezy"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Exw", " ", "Exz", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Exw", " ", "Eyw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"2", " ", "Exz", " ", "Eyx", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{
         SuperscriptBox["Exx", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Eyw", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Eww", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "-", 
        RowBox[{"Ewy", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Exy", " ", "Exz", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Exy", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Exw", "2"], " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{
         SuperscriptBox["Exy", "2"], " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Exy", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "-", 
        RowBox[{"Exw", " ", "Exz", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Exw", " ", "Eyw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Exw", " ", "Eyx", " ", "Eyz", " ", "Ezz"}], "+", 
        RowBox[{"2", " ", "Exy", " ", "Eyx", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{"Exx", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Eyy", "2"], " ", "Ezw"}], "+", 
           RowBox[{"Ewx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{
            SuperscriptBox["Eyz", "2"], " ", "Ezw"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Ewz", " ", "Eyz", " ", "Ezy"}], "+", 
           RowBox[{"Eyx", " ", "Eyz", " ", "Ezy"}], "+", 
           RowBox[{"2", " ", "Eyz", " ", "Ezw", " ", "Ezy"}], "-", 
           RowBox[{"Ewx", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Eyw", " ", "Eyz", " ", "Ezz"}], "+", 
           RowBox[{"Exy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
              RowBox[{"Eyw", " ", "Ezx"}], "-", 
              RowBox[{"Eyz", " ", "Ezy"}], "+", 
              RowBox[{"Eyy", " ", "Ezz"}]}], ")"}]}], "-", 
           RowBox[{"Eyy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exw", " ", "Ezx"}], "+", 
              RowBox[{"Eyw", " ", "Ezy"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "Ewz"}], "+", "Eyx", "+", 
                 RowBox[{"2", " ", "Ezw"}]}], ")"}], " ", "Ezz"}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewz", " ", "Exw", " ", "Eyx", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyx", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Eyw", " ", "Eyy", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Eyx", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Eyw", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Eyx", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Eyw", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Ewz", " ", "Eyx", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewz", " ", "Eyw", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Eyx", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"2", " ", "Ewz", " ", "Eyy", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"2", " ", "Ewy", " ", "Eyz", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezy"}], "-", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezy"}], "+", 
        RowBox[{"2", " ", "Ewz", " ", "Eyx", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Eyy"}], " ", "Ezx"}], "+", 
           RowBox[{"Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Eyw", "2"], " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Eyx", "2"], " ", "Ezz"}], "-", 
        RowBox[{"2", " ", "Ewy", " ", "Eyx", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Eyz"}], " ", "Ezw"}], "+", 
           RowBox[{"Eyw", " ", "Ezz"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exx"}], " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{
            SuperscriptBox["Eyy", "2"], " ", "Ezw"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{
            SuperscriptBox["Eyz", "2"], " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "+", 
           RowBox[{"Eyw", " ", "Eyy", " ", "Ezy"}], "+", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezy"}], "-", 
           RowBox[{"Eyx", " ", "Eyz", " ", "Ezy"}], "-", 
           RowBox[{"2", " ", "Eyz", " ", "Ezw", " ", "Ezy"}], "+", 
           RowBox[{"Exw", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Exy", " ", "Eyy", " ", "Ezz"}], "+", 
           RowBox[{"Eyx", " ", "Eyy", " ", "Ezz"}], "+", 
           RowBox[{"Eyw", " ", "Eyz", " ", "Ezz"}], "+", 
           RowBox[{"2", " ", "Eyy", " ", "Ezw", " ", "Ezz"}], "+", 
           RowBox[{"Ewz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Eyx", " ", "Ezw"}], "-", 
              RowBox[{"Eyw", " ", "Ezx"}], "+", 
              RowBox[{"Eyz", " ", "Ezy"}], "-", 
              RowBox[{"Eyy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"Eww", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exx", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{
            SuperscriptBox["Eyy", "2"], " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{
            SuperscriptBox["Eyz", "2"], " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Eyx", " ", "Eyy", " ", "Ezy"}], "-", 
           RowBox[{"Exz", " ", "Eyz", " ", "Ezy"}], "+", 
           RowBox[{"Eyw", " ", "Eyz", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}], "+", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezz"}], "-", 
           RowBox[{"Eyw", " ", "Eyy", " ", "Ezz"}], "-", 
           RowBox[{"Eyx", " ", "Eyz", " ", "Ezz"}], "+", 
           RowBox[{"Ewx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Eyy", " ", "Ezw"}], "+", 
              RowBox[{"Eyz", " ", "Ezx"}], "-", 
              RowBox[{"Eyw", " ", "Ezy"}], "-", 
              RowBox[{"Eyx", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Ewy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Eyx"}], " ", "Ezw"}], "+", 
              RowBox[{"Eyw", " ", "Ezx"}], "+", 
              RowBox[{"Eyz", " ", "Ezy"}], "-", 
              RowBox[{"Eyy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Ewz"}], " ", "Exw", " ", "Exx", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Exx", "2"], " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exy", " ", "Ezw"}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Exz", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Exz", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Exz", "2"], " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyw", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyw", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyz", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Exw", "2"], " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Exx", " ", "Ezx"}], "-", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Exy", " ", "Ezx"}], "-", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Exy", "2"], " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exz", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exy", " ", "Exz", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyx", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyx", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"2", " ", "Ewz", " ", "Exy", " ", "Ezw", " ", "Ezx"}], "-", 
        RowBox[{"2", " ", "Ewy", " ", "Exz", " ", "Ezw", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exw", " ", "Ezy"}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Exx", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Exy", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Exz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"2", " ", "Ewz", " ", "Exx", " ", "Ezw", " ", "Ezy"}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Ezy"}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Exw", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exx", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Exy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Exz", " ", "Ezz"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"2", " ", "Ewy", " ", "Exx", " ", "Ezw", " ", "Ezz"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exz", " ", "Ezw"}], "-", 
           RowBox[{"Exw", " ", "Ezz"}]}], ")"}]}], "+", 
        RowBox[{"Eww", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exx"}], " ", "Exy", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Exz", " ", "Ezx"}], "-", 
           RowBox[{"Exy", " ", "Eyy", " ", "Ezx"}], "-", 
           RowBox[{"Exz", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{
            SuperscriptBox["Exx", "2"], " ", "Ezy"}], "+", 
           RowBox[{
            SuperscriptBox["Exz", "2"], " ", "Ezy"}], "-", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezy"}], "+", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezy"}], "+", 
           RowBox[{"Exw", " ", "Exx", " ", "Ezz"}], "-", 
           RowBox[{"Exy", " ", "Exz", " ", "Ezz"}], "+", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezz"}], "+", 
           RowBox[{"Ewx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exy"}], " ", "Ezw"}], "-", 
              RowBox[{"Exz", " ", "Ezx"}], "+", 
              RowBox[{"Exw", " ", "Ezy"}], "+", 
              RowBox[{"Exx", " ", "Ezz"}]}], ")"}]}], "+", 
           RowBox[{"Ewy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exx", " ", "Ezw"}], "-", 
              RowBox[{"Exw", " ", "Ezx"}], "-", 
              RowBox[{"Exz", " ", "Ezy"}], "+", 
              RowBox[{"Exy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exx", " ", "Exy", " ", "Ezw"}], "+", 
           RowBox[{"Exw", " ", "Exz", " ", "Ezw"}], "+", 
           RowBox[{"Exy", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{"Exw", " ", "Exx", " ", "Ezy"}], "-", 
           RowBox[{"Exy", " ", "Exz", " ", "Ezy"}], "+", 
           RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezy"}], "+", 
           RowBox[{"2", " ", "Exz", " ", "Ezw", " ", "Ezy"}], "-", 
           RowBox[{
            SuperscriptBox["Exw", "2"], " ", "Ezz"}], "+", 
           RowBox[{
            SuperscriptBox["Exy", "2"], " ", "Ezz"}], "-", 
           RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezz"}], "-", 
           RowBox[{"2", " ", "Exy", " ", "Ezw", " ", "Ezz"}], "+", 
           RowBox[{"Ewz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exx"}], " ", "Ezw"}], "+", 
              RowBox[{"Exw", " ", "Ezx"}], "-", 
              RowBox[{"Exz", " ", "Ezy"}], "+", 
              RowBox[{"Exy", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewz", " ", "Exw", " ", "Exx", " ", "Eyw"}], "+", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Exx", "2"], " ", "Eyw"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exy", " ", "Eyw"}], "-", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Exz", " ", "Eyw"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Exz", " ", "Eyw"}], "+", 
        RowBox[{"Ewy", " ", 
         SuperscriptBox["Exz", "2"], " ", "Eyw"}], "+", 
        RowBox[{"Ewz", " ", "Exy", " ", 
         SuperscriptBox["Eyw", "2"]}], "-", 
        RowBox[{"Ewy", " ", "Exz", " ", 
         SuperscriptBox["Eyw", "2"]}], "-", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Exw", "2"], " ", "Eyx"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Exx", " ", "Eyx"}], "+", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Exy", " ", "Eyx"}], "+", 
        RowBox[{"Ewz", " ", 
         SuperscriptBox["Exy", "2"], " ", "Eyx"}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exz", " ", "Eyx"}], "-", 
        RowBox[{"Ewy", " ", "Exy", " ", "Exz", " ", "Eyx"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", 
         SuperscriptBox["Eyx", "2"]}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", 
         SuperscriptBox["Eyx", "2"]}], "-", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exw", " ", "Eyy"}], "-", 
        RowBox[{
         SuperscriptBox["Ewz", "2"], " ", "Exx", " ", "Eyy"}], "-", 
        RowBox[{"Ewz", " ", "Exx", " ", "Exy", " ", "Eyy"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Exz", " ", "Eyy"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyw", " ", "Eyy"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyw", " ", "Eyy"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyx", " ", "Eyy"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyx", " ", "Eyy"}], "+", 
        RowBox[{
         SuperscriptBox["Eww", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exy"}], " ", "Eyx"}], "+", 
           RowBox[{"Exx", " ", "Eyy"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["Ewy", "2"], " ", "Exw", " ", "Eyz"}], "+", 
        RowBox[{"Ewy", " ", "Ewz", " ", "Exx", " ", "Eyz"}], "+", 
        RowBox[{"Ewy", " ", "Exx", " ", "Exy", " ", "Eyz"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Exz", " ", "Eyz"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyw", " ", "Eyz"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyw", " ", "Eyz"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyx", " ", "Eyz"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyx", " ", "Eyz"}], "+", 
        RowBox[{
         SuperscriptBox["Ewx", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyw"}], "+", 
           RowBox[{"Exw", " ", "Eyz"}]}], ")"}]}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyx", " ", "Ezw"}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Ewz", " ", "Exy", " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{"Ewy", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyy", " ", "Ezx"}], "-", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyz", " ", "Ezx"}], "+", 
        RowBox[{"Ewz", " ", "Exx", " ", "Eyw", " ", "Ezy"}], "-", 
        RowBox[{"Ewz", " ", "Exw", " ", "Eyx", " ", "Ezy"}], "-", 
        RowBox[{"Ewy", " ", "Exx", " ", "Eyw", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", "Exw", " ", "Eyx", " ", "Ezz"}], "+", 
        RowBox[{"Ewx", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exx"}], " ", "Exy", " ", "Eyw"}], "-", 
           RowBox[{"Exw", " ", "Exz", " ", "Eyw"}], "+", 
           RowBox[{"Exw", " ", "Exx", " ", "Eyy"}], "+", 
           RowBox[{"Exy", " ", "Exz", " ", "Eyy"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Eyy"}], "-", 
           RowBox[{"Exz", " ", "Eyx", " ", "Eyy"}], "+", 
           RowBox[{"Exw", " ", 
            SuperscriptBox["Eyy", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["Exw", "2"], " ", "Eyz"}], "-", 
           RowBox[{
            SuperscriptBox["Exy", "2"], " ", "Eyz"}], "-", 
           RowBox[{"Exz", " ", "Eyw", " ", "Eyz"}], "+", 
           RowBox[{"Exy", " ", "Eyx", " ", "Eyz"}], "+", 
           RowBox[{"Exw", " ", 
            SuperscriptBox["Eyz", "2"]}], "+", 
           RowBox[{"Ewz", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exx", " ", "Eyw"}], "-", 
              RowBox[{"Exw", " ", "Eyx"}], "+", 
              RowBox[{"Exz", " ", "Eyy"}], "-", 
              RowBox[{"Exy", " ", "Eyz"}]}], ")"}]}], "-", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezw"}], "+", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezw"}], "-", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezy"}], "+", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezy"}], "+", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezz"}], "-", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezz"}]}], ")"}]}], "+", 
        RowBox[{"Eww", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exx", " ", "Exy", " ", "Eyx"}], "+", 
           RowBox[{"Exw", " ", "Exz", " ", "Eyx"}], "-", 
           RowBox[{
            SuperscriptBox["Exx", "2"], " ", "Eyy"}], "-", 
           RowBox[{
            SuperscriptBox["Exz", "2"], " ", "Eyy"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Eyy"}], "+", 
           RowBox[{"Exy", " ", "Eyx", " ", "Eyy"}], "-", 
           RowBox[{"Exx", " ", 
            SuperscriptBox["Eyy", "2"]}], "-", 
           RowBox[{"Exw", " ", "Exx", " ", "Eyz"}], "+", 
           RowBox[{"Exy", " ", "Exz", " ", "Eyz"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Eyz"}], "+", 
           RowBox[{"Exz", " ", "Eyx", " ", "Eyz"}], "-", 
           RowBox[{"Exx", " ", 
            SuperscriptBox["Eyz", "2"]}], "+", 
           RowBox[{"Ewx", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Exy", " ", "Eyw"}], "+", 
              RowBox[{"Exz", " ", "Eyx"}], "-", 
              RowBox[{"Exw", " ", "Eyy"}], "-", 
              RowBox[{"Exx", " ", "Eyz"}]}], ")"}]}], "+", 
           RowBox[{"Ewy", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Exx"}], " ", "Eyw"}], "+", 
              RowBox[{"Exw", " ", "Eyx"}], "+", 
              RowBox[{"Exz", " ", "Eyy"}], "-", 
              RowBox[{"Exy", " ", "Eyz"}]}], ")"}]}], "-", 
           RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "+", 
           RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "-", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "-", 
           RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "+", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezz"}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "-", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyz", " ", "Ezw"}], "-", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "+", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyz", " ", "Ezx"}], "-", 
        RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
        RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "-", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "+", 
        RowBox[{"Ewz", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Exy", " ", "Eyx", " ", "Ezw"}], "-", 
           RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "-", 
           RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "+", 
           RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "-", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
        RowBox[{"Ewx", " ", "Exy", " ", "Eyw", " ", "Ezz"}], "-", 
        RowBox[{"Eww", " ", "Exy", " ", "Eyx", " ", "Ezz"}], "-", 
        RowBox[{"Ewx", " ", "Exw", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Eww", " ", "Exx", " ", "Eyy", " ", "Ezz"}], "+", 
        RowBox[{"Ewy", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "Exz"}], " ", "Eyx", " ", "Ezw"}], "+", 
           RowBox[{"Exx", " ", "Eyz", " ", "Ezw"}], "+", 
           RowBox[{"Exz", " ", "Eyw", " ", "Ezx"}], "-", 
           RowBox[{"Exw", " ", "Eyz", " ", "Ezx"}], "-", 
           RowBox[{"Exx", " ", "Eyw", " ", "Ezz"}], "+", 
           RowBox[{"Exw", " ", "Eyx", " ", "Ezz"}]}], ")"}]}]}], ")"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.747103294548884*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"ea7f79be-bb6b-4dbe-815e-fae0e8453851"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"mapE4ToM4", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "//", "Numerator"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7471033053226643`*^9, 3.747103339777055*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"d051315b-7a77-4257-a9d1-749285d6ecfe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ewy", " ", "Exz", " ", "Eyx", " ", "Ezw"}], "+", 
  RowBox[{
   SuperscriptBox["Exz", "2"], " ", "Eyx", " ", "Ezw"}], "-", 
  RowBox[{"Exz", " ", "Eyw", " ", "Eyx", " ", "Ezw"}], "-", 
  RowBox[{"Ewx", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
  RowBox[{"Exw", " ", "Exz", " ", "Eyy", " ", "Ezw"}], "+", 
  RowBox[{"Exx", " ", "Eyx", " ", "Eyy", " ", "Ezw"}], "-", 
  RowBox[{"Ewy", " ", "Exx", " ", "Eyz", " ", "Ezw"}], "-", 
  RowBox[{"Exx", " ", "Exz", " ", "Eyz", " ", "Ezw"}], "+", 
  RowBox[{"Exx", " ", "Eyw", " ", "Eyz", " ", "Ezw"}], "+", 
  RowBox[{"Exz", " ", "Eyy", " ", "Eyz", " ", "Ezw"}], "-", 
  RowBox[{"Exx", " ", "Eyy", " ", 
   SuperscriptBox["Ezw", "2"]}], "-", 
  RowBox[{"Ewy", " ", "Exz", " ", "Eyw", " ", "Ezx"}], "-", 
  RowBox[{
   SuperscriptBox["Exz", "2"], " ", "Eyw", " ", "Ezx"}], "+", 
  RowBox[{"Exz", " ", 
   SuperscriptBox["Eyw", "2"], " ", "Ezx"}], "-", 
  RowBox[{"Eww", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "-", 
  RowBox[{"Exx", " ", "Exz", " ", "Eyy", " ", "Ezx"}], "-", 
  RowBox[{"Exw", " ", "Eyx", " ", "Eyy", " ", "Ezx"}], "-", 
  RowBox[{"Exz", " ", 
   SuperscriptBox["Eyy", "2"], " ", "Ezx"}], "+", 
  RowBox[{"Ewy", " ", "Exw", " ", "Eyz", " ", "Ezx"}], "+", 
  RowBox[{"Exw", " ", "Exz", " ", "Eyz", " ", "Ezx"}], "-", 
  RowBox[{"Exw", " ", "Eyw", " ", "Eyz", " ", "Ezx"}], "-", 
  RowBox[{"Exz", " ", "Eyx", " ", "Ezw", " ", "Ezx"}], "+", 
  RowBox[{"Exw", " ", "Eyy", " ", "Ezw", " ", "Ezx"}], "+", 
  RowBox[{"Exx", " ", "Eyz", " ", "Ezw", " ", "Ezx"}], "+", 
  RowBox[{"Exz", " ", "Eyw", " ", 
   SuperscriptBox["Ezx", "2"]}], "-", 
  RowBox[{"Exw", " ", "Eyz", " ", 
   SuperscriptBox["Ezx", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["Exy", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Eyx", " ", "Ezw"}], "-", 
     RowBox[{"Eyw", " ", "Ezx"}]}], ")"}]}], "+", 
  RowBox[{"Ewx", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "-", 
  RowBox[{"Exw", " ", "Exz", " ", "Eyw", " ", "Ezy"}], "+", 
  RowBox[{"Eww", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "+", 
  RowBox[{"Exx", " ", "Exz", " ", "Eyx", " ", "Ezy"}], "-", 
  RowBox[{"Exx", " ", "Eyw", " ", "Eyx", " ", "Ezy"}], "+", 
  RowBox[{"Exw", " ", 
   SuperscriptBox["Eyx", "2"], " ", "Ezy"}], "+", 
  RowBox[{"Exz", " ", "Eyx", " ", "Eyy", " ", "Ezy"}], "-", 
  RowBox[{"Ewx", " ", "Exw", " ", "Eyz", " ", "Ezy"}], "+", 
  RowBox[{
   SuperscriptBox["Exw", "2"], " ", "Eyz", " ", "Ezy"}], "-", 
  RowBox[{"Eww", " ", "Exx", " ", "Eyz", " ", "Ezy"}], "-", 
  RowBox[{
   SuperscriptBox["Exx", "2"], " ", "Eyz", " ", "Ezy"}], "-", 
  RowBox[{"Exz", " ", "Eyw", " ", "Eyz", " ", "Ezy"}], "-", 
  RowBox[{"Exx", " ", "Eyy", " ", "Eyz", " ", "Ezy"}], "+", 
  RowBox[{"Exw", " ", 
   SuperscriptBox["Eyz", "2"], " ", "Ezy"}], "+", 
  RowBox[{"Exx", " ", "Eyw", " ", "Ezw", " ", "Ezy"}], "-", 
  RowBox[{"Exw", " ", "Eyx", " ", "Ezw", " ", "Ezy"}], "-", 
  RowBox[{"Exz", " ", "Eyy", " ", "Ezw", " ", "Ezy"}], "+", 
  RowBox[{"Exz", " ", "Eyw", " ", 
   SuperscriptBox["Ezy", "2"]}], "-", 
  RowBox[{"Exw", " ", "Eyz", " ", 
   SuperscriptBox["Ezy", "2"]}], "+", 
  RowBox[{"Ewz", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Exy"}], " ", "Eyx", " ", "Ezw"}], "+", 
     RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "+", 
     RowBox[{"Exy", " ", "Eyw", " ", "Ezx"}], "-", 
     RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "-", 
     RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "+", 
     RowBox[{"Exw", " ", "Eyx", " ", "Ezy"}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Exw"}], " ", "Exz", " ", "Eyx"}], "+", 
     RowBox[{"Exw", " ", "Eyw", " ", "Eyx"}], "+", 
     RowBox[{"Ewy", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exx", " ", "Eyw"}], "-", 
        RowBox[{"Exw", " ", "Eyx"}]}], ")"}]}], "+", 
     RowBox[{"Ewx", " ", "Exw", " ", "Eyy"}], "-", 
     RowBox[{
      SuperscriptBox["Exw", "2"], " ", "Eyy"}], "+", 
     RowBox[{
      SuperscriptBox["Exx", "2"], " ", "Eyy"}], "-", 
     RowBox[{"Exw", " ", "Eyy", " ", "Eyz"}], "+", 
     RowBox[{"Exw", " ", "Eyx", " ", "Ezx"}], "-", 
     RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "+", 
     RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "+", 
     RowBox[{"Exw", " ", "Eyy", " ", "Ezy"}], "+", 
     RowBox[{"Exx", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exz", " ", "Eyw"}], "+", 
        RowBox[{"Eyy", " ", 
         RowBox[{"(", 
          RowBox[{"Eww", "+", "Eyy"}], ")"}]}], "-", 
        RowBox[{"Eyw", " ", 
         RowBox[{"(", 
          RowBox[{"Eyw", "+", "Ezx"}], ")"}]}], "-", 
        RowBox[{"Eyz", " ", "Ezy"}]}], ")"}]}]}], ")"}], " ", "Ezz"}], "+", 
  RowBox[{"Exx", " ", "Eyy", " ", 
   SuperscriptBox["Ezz", "2"]}], "+", 
  RowBox[{"Exy", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["Eyx", "2"]}], " ", "Ezw"}], "-", 
     RowBox[{"Exx", " ", "Eyy", " ", "Ezw"}], "+", 
     RowBox[{"Ewx", " ", "Eyz", " ", "Ezw"}], "-", 
     RowBox[{"Exw", " ", "Eyz", " ", "Ezw"}], "-", 
     RowBox[{
      SuperscriptBox["Eyz", "2"], " ", "Ezw"}], "+", 
     RowBox[{"Exw", " ", "Eyy", " ", "Ezx"}], "+", 
     RowBox[{"Eww", " ", "Eyz", " ", "Ezx"}], "+", 
     RowBox[{"Exx", " ", "Eyz", " ", "Ezx"}], "+", 
     RowBox[{"Eyy", " ", "Eyz", " ", "Ezx"}], "-", 
     RowBox[{"Eyw", " ", "Ezw", " ", "Ezx"}], "+", 
     RowBox[{"Exx", " ", "Eyw", " ", "Ezy"}], "+", 
     RowBox[{"Eyz", " ", "Ezw", " ", "Ezy"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "Ewx"}], " ", "Eyw"}], "+", 
        RowBox[{"Exw", " ", "Eyw"}], "+", 
        RowBox[{"Eyz", " ", 
         RowBox[{"(", 
          RowBox[{"Eyw", "+", "Ezx"}], ")"}]}], "-", 
        RowBox[{"Eyw", " ", "Ezy"}]}], ")"}], " ", "Ezz"}], "+", 
     RowBox[{"Eyx", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["Ezw", "2"], "+", 
        RowBox[{"Eyw", " ", "Ezx"}], "-", 
        RowBox[{"Exw", " ", "Ezy"}], "-", 
        RowBox[{"Ezz", " ", 
         RowBox[{"(", 
          RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ")"}]}]}], 
       ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.747103308200547*^9, 3.7471033464517*^9}},
 CellLabel->"Out[86]=",ExpressionUUID->"a69f17f8-7a48-47d5-a4b5-25f2ead752d0"]
}, Closed]],

Cell[TextData[{
 StyleBox["Old makeMww had   wx, xw    switched...derivation is ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["here:",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}]
}], "Text",
 CellChangeTimes->{{3.7429961172057953`*^9, 3.742996130125395*^9}, {
  3.742998175348331*^9, 3.742998186955695*^9}, {3.7429983233307858`*^9, 
  3.742998331050405*^9}},ExpressionUUID->"7674dc3c-c67f-4486-9046-\
3731f258db88"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"matrixFromLRCoeff", "[", 
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{
      RowBox[{"PQbTo4DRot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], ".",
       "hornE4mat"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.742081605600173*^9, 3.742081657610359*^9}, {
   3.742081884654695*^9, 3.742081927119203*^9}, {3.742082014798903*^9, 
   3.742082095826495*^9}, 3.742168519458087*^9, 3.7429981693389273`*^9},
 CellLabel->"In[90]:=",ExpressionUUID->"47f0e5d5-9aad-4e81-abed-a2b45d65510a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742996036117112*^9, 3.74299819469788*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"2fbbb8a8-2dc1-4947-97cd-0165c758d0e6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Output", " ", "=", " ", 
    RowBox[{
    "4", "x4", " ", "numerical", " ", "Horn", " ", "4", "D", " ", "matrix", 
     " ", 
     RowBox[{"M4", "[", "ab", "]"}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{
   RowBox[{"makeMwwmat", "[", "Ewwmat_", "]"}], " ", ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eww", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ewx", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", " ", 
       RowBox[{"Ewy", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", " ", 
       RowBox[{"Ewz", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "4"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Exw", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exx", " ", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exy", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exz", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "4"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Eyw", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyx", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyy", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyz", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "4"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ezw", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ezx", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ezy", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "3"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ezz", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "4"}], "]"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
         RowBox[{
          RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
         RowBox[{
          RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
         RowBox[{
          RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
         RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
         RowBox[{
          RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
         RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
         RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
         RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
         RowBox[{
          RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
         RowBox[{
          RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
         RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
         RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
      "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725625081905693*^9, 3.725625177255262*^9}, {
   3.72562537895212*^9, 3.725625480685306*^9}, {3.7263235825017433`*^9, 
   3.72632359349949*^9}, {3.726323738251397*^9, 3.726323777629982*^9}, {
   3.726323819738735*^9, 3.726323864347767*^9}, 3.742998257691111*^9},
 CellLabel->"In[91]:=",ExpressionUUID->"81991b07-e844-4041-bebb-a0084bf20285"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornM4mat", "-", 
  RowBox[{"makeMwwmat", "[", "hornE4mat", "]"}]}]], "Input",
 CellLabel->"In[93]:=",ExpressionUUID->"500c3252-b0d4-4bfa-aad3-7237700f963f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7429983151138077`*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"3df205d7-a87e-4332-b454-d1f12db1d2f5"]
}, Open  ]],

Cell[TextData[StyleBox["Search for makeM2Dfrm [tgt,frm] and  \
makeM3Dfrm[tgt,frm]  for the three\ntypes of 3D quaternion frame weights, \n1 \
- (Q[q].p).r = Q.E -> q.V    makeVwwvec[makeEwwmat[qtgt,qref]]\n2- (q.V)^2 = \
nonzero trace -> q.W.q  MakeWwwmat[qtgt,qref]\n3-   Tr[R[q].R[p].Rinv[r]]/2  \
= (q.V)^2 + ",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7410466844950533`*^9, 
  3.741047047086546*^9}},ExpressionUUID->"8c78b9bf-1fec-4628-9522-\
ee3e71c0bc4a"],

Cell[BoxData[
 RowBox[{"RRRQmat3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.741047094633196*^9, 3.741047134196104*^9}},
 CellLabel->
  "In[520]:=",ExpressionUUID->"95adb7b7-cf51-4150-b3cb-49580abd8b00"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vectorFromForm", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"qprod", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}]}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.741050289623382*^9, 3.74105040952899*^9}},
 CellLabel->
  "In[536]:=",ExpressionUUID->"c6146199-a807-415a-aced-31b64f928d55"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"p0", " ", "r0"}], "+", 
    RowBox[{"p1", " ", "r1"}], "+", 
    RowBox[{"p2", " ", "r2"}], "+", 
    RowBox[{"p3", " ", "r3"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "p1"}], " ", "r0"}], "+", 
    RowBox[{"p0", " ", "r1"}], "-", 
    RowBox[{"p3", " ", "r2"}], "+", 
    RowBox[{"p2", " ", "r3"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "p2"}], " ", "r0"}], "+", 
    RowBox[{"p3", " ", "r1"}], "+", 
    RowBox[{"p0", " ", "r2"}], "-", 
    RowBox[{"p1", " ", "r3"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "p3"}], " ", "r0"}], "-", 
    RowBox[{"p2", " ", "r1"}], "+", 
    RowBox[{"p1", " ", "r2"}], "+", 
    RowBox[{"p0", " ", "r3"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7410504100428047`*^9},
 CellLabel->
  "Out[536]=",ExpressionUUID->"f6a6ab34-545d-4094-9c94-46ee0718ae92"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Output", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"numerical", " ", "quaternion", " ", "4"}], "-", 
       RowBox[{"vector", ":", " ", 
        RowBox[{"V4", "[", "a", "]"}]}]}], " ", "=", " ", 
      RowBox[{"first", " ", "ROW", " ", "of", " ", "Mww"}]}]}], ",", " ", 
    RowBox[{"it", " ", "seems"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeVwVecfromEww", "[", "Ewwmat_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eww", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ewx", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", " ", 
       RowBox[{"Ewy", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", " ", 
       RowBox[{"Ewz", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "4"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Exw", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exx", " ", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exy", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ",", 
       RowBox[{"Exz", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "4"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Eyw", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyx", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyy", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ",", 
       RowBox[{"Eyz", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "4"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ezw", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ezx", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ezy", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "3"}], "]"}], "]"}]}], ",", 
       RowBox[{"Ezz", "=", 
        RowBox[{"Ewwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "4"}], "]"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"+", "Ewx"}], " ", "-", "Exw", " ", "+", "Eyz", " ", "-", 
        "Ezy"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"+", "Ewy"}], " ", "-", "Eyw", "+", "Ezx", " ", "-", "Exz"}], 
       " ", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"+", "Ewz"}], "-", "Ezw", " ", "+", "Exy", " ", "-", " ", 
        "Eyx"}]}], " ", "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725820596378134*^9, 3.725820802736498*^9}, {
   3.725821049574277*^9, 3.725821221908225*^9}, {3.725821289977553*^9, 
   3.725821348905539*^9}, {3.726323919310782*^9, 3.7263239689111557`*^9}, {
   3.7410504746004677`*^9, 3.7410504788500547`*^9}, {3.741050727648403*^9, 
   3.741050728119972*^9}, 3.7410509122882442`*^9},
 CellLabel->
  "In[266]:=",ExpressionUUID->"21a1289c-e7e3-48c7-ac5f-05019f3f5846"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Usage", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"makeVwVecfromEww", "[", 
   RowBox[{"makeEwwmat", "@@", 
    RowBox[{"testa3DFrm", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.741051016827344*^9, 3.741051038978259*^9}, {
  3.74223458784571*^9, 
  3.742234595313995*^9}},ExpressionUUID->"672206f6-6762-4772-939a-\
fbb093ab62be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "97.41199376712309`", ",", "0.36102707942129053`", ",", 
   "0.03439922085581926`", ",", 
   RowBox[{"-", "20.179044488182353`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741051039505314*^9},
 CellLabel->
  "Out[542]=",ExpressionUUID->"14ec31c4-5c8a-4a61-8662-c74d14e053be"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Build", " ", "all", " ", "the", " ", "QFrm", " ", "matrices", " ", "from",
     " ", "the", " ", "data", " ", "directly"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeV", "*", 
    RowBox[{"[", 
     RowBox[{"qTgt_", ",", "qRef_"}], "]"}]}], " ", "\[Rule]", 
   RowBox[{"{", " ", 
    RowBox[{"Vec", ",", " ", 
     RowBox[{"V", "*", "V"}], ",", " ", "RRRmat"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.7410504937675543`*^9, 3.74105056195148*^9}, {
  3.741050749157158*^9, 
  3.741050784261392*^9}},ExpressionUUID->"3e994c3f-5863-4f9f-8c7a-\
fedb9628f5ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"single", " ", "term", " ", "in", " ", 
    RowBox[{"q", ".", "V"}], " ", "sum"}], " ", "*)"}], 
  RowBox[{"vectorFromForm", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"qprod", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}]}], "]"}], ".", 
      RowBox[{"{", 
       RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], ")"}], ",", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.742233160275324*^9, 3.742233224779245*^9}, {
  3.742233293152372*^9, 3.742233299782145*^9}, {3.742233556819442*^9, 
  3.742233567139324*^9}, {3.7422336078662577`*^9, 3.742233609611293*^9}},
 CellLabel->
  "In[272]:=",ExpressionUUID->"86be3751-8045-49ef-a795-58a9ac3d77e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"p0", " ", "r0"}], "+", 
    RowBox[{"p1", " ", "r1"}], "+", 
    RowBox[{"p2", " ", "r2"}], "+", 
    RowBox[{"p3", " ", "r3"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "p1"}], " ", "r0"}], "+", 
    RowBox[{"p0", " ", "r1"}], "-", 
    RowBox[{"p3", " ", "r2"}], "+", 
    RowBox[{"p2", " ", "r3"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "p2"}], " ", "r0"}], "+", 
    RowBox[{"p3", " ", "r1"}], "+", 
    RowBox[{"p0", " ", "r2"}], "-", 
    RowBox[{"p1", " ", "r3"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "p3"}], " ", "r0"}], "-", 
    RowBox[{"p2", " ", "r1"}], "+", 
    RowBox[{"p1", " ", "r2"}], "+", 
    RowBox[{"p0", " ", "r3"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.742235316923737*^9},
 CellLabel->
  "Out[272]=",ExpressionUUID->"d91f16cb-7ab9-4c0d-8e95-809b6ffea840"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"MUCH", " ", 
      RowBox[{"cleaner", ":", " ", "\[IndentingNewLine]", "Output"}]}], " ", 
     "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"numerical", " ", "quaternion", " ", "4"}], "-", 
       RowBox[{"vector", ":", " ", 
        RowBox[{"V4", "[", "a", "]"}]}]}], " ", "=", " ", 
      RowBox[{"first", " ", "ROW", " ", "of", " ", "Mww"}]}]}], ",", " ", 
    RowBox[{"it", " ", "seems"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeVwVec", "[", 
    RowBox[{"qTgt_", ",", "qRef_"}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "qRef", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "p0", ",", "p1", ",", "p2", ",", "p3", ",", "r0", ",", "r1", ",", 
         "r2", ",", "r3"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "=", 
           RowBox[{"qTgt", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], ";", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}], "=", " ", 
           
           RowBox[{"qRef", "[", 
            RowBox[{"[", "k", " ", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"p0", " ", "r0"}], "+", 
             RowBox[{"p1", " ", "r1"}], "+", 
             RowBox[{"p2", " ", "r2"}], "+", 
             RowBox[{"p3", " ", "r3"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "p1"}], " ", "r0"}], "+", 
             RowBox[{"p0", " ", "r1"}], "-", 
             RowBox[{"p3", " ", "r2"}], "+", 
             RowBox[{"p2", " ", "r3"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "p2"}], " ", "r0"}], "+", 
             RowBox[{"p3", " ", "r1"}], "+", 
             RowBox[{"p0", " ", "r2"}], "-", 
             RowBox[{"p1", " ", "r3"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "p3"}], " ", "r0"}], "-", 
             RowBox[{"p2", " ", "r1"}], "+", 
             RowBox[{"p1", " ", "r2"}], "+", 
             RowBox[{"p0", " ", "r3"}]}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7422353438434343`*^9, 3.742235466204496*^9}, {
  3.742235506537178*^9, 3.742235529618928*^9}},
 CellLabel->
  "In[275]:=",ExpressionUUID->"8a4f62bf-026b-46d0-b1a6-94650a07d21c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Old", " ", "clunky", " ", "version", "\[IndentingNewLine]", "Output"}], 
     " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"numerical", " ", "quaternion", " ", "4"}], "-", 
       RowBox[{"vector", ":", " ", 
        RowBox[{"V4", "[", "a", "]"}]}]}], " ", "=", " ", 
      RowBox[{"first", " ", "ROW", " ", "of", " ", "Mww"}]}]}], ",", " ", 
    RowBox[{"it", " ", "seems"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeVwVecX", "[", 
    RowBox[{"qTgt_", ",", "qRef_"}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "qRef", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz", ",", "Exw", ",", "Exx", 
         ",", "Exy", ",", "Exz", ",", "Eyw", ",", "Eyx", ",", "Eyy", ",", 
         "Eyz", ",", "Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz", ",", "Vw", 
         ",", "k", ",", "i", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Eww", ",", "Ewx", ",", "Ewy", ",", "Ewz"}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Exw", ",", "Exx", ",", "Exy", ",", "Exz"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Eyw", ",", "Eyx", ",", "Eyy", ",", "Eyz"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Ezw", ",", "Ezx", ",", "Ezy", ",", "Ezz"}], "}"}]}], 
          "}"}], "=", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", " ", 
          RowBox[{
           RowBox[{"Sum", " ", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"qTgt", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "i"}], "]"}], "]"}], " ", 
              RowBox[{"qRef", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "j"}], "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1", ",", "len"}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Vw", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"+", "Ewx"}], " ", "-", "Exw", " ", "+", "Eyz", " ", "-", 
            "Ezy"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"+", "Ewy"}], " ", "-", "Eyw", "+", "Ezx", " ", "-", 
            "Exz"}], " ", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"+", "Ewz"}], "-", "Ezw", " ", "+", "Exy", " ", "-", " ", 
            "Eyx"}]}], " ", "}"}]}]}]}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.725820596378134*^9, 3.725820802736498*^9}, {
   3.725821049574277*^9, 3.725821221908225*^9}, {3.725821289977553*^9, 
   3.725821348905539*^9}, {3.726323919310782*^9, 3.7263239689111557`*^9}, {
   3.7410471737654676`*^9, 3.741047196549954*^9}, {3.741050601120345*^9, 
   3.74105071124063*^9}, {3.741050897623658*^9, 3.741050935638528*^9}, 
   3.741050992988381*^9, {3.7422355410050592`*^9, 3.742235549155201*^9}, 
   3.74223586932084*^9},ExpressionUUID->"8606ac3b-bdb9-428d-a6f3-\
95bd33dbe53e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeVwVec", "@@", 
  RowBox[{"testa3DFrm", "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.741050960576001*^9, 3.741050967795865*^9}},
 CellLabel->
  "In[540]:=",ExpressionUUID->"94198237-8a3e-4125-8345-70d976952f4b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "97.41199376712309`", ",", "0.36102707942129053`", ",", 
   "0.03439922085581926`", ",", 
   RowBox[{"-", "20.179044488182353`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.741050969857209*^9, 3.741050997608577*^9}},
 CellLabel->
  "Out[540]=",ExpressionUUID->"74c7e466-a531-4b96-a3c7-c21958336836"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Tr", "[", 
   RowBox[{"RRRQmat3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}], "]"}], 
  "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.741052317213524*^9, 3.7410523411926928`*^9}},
 CellLabel->
  "In[547]:=",ExpressionUUID->"a8b7c446-59d4-43e0-b428-0b678c933515"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.741052341642502*^9},
 CellLabel->
  "Out[547]=",ExpressionUUID->"c8a37ecb-be0f-4a10-bbbe-dde2c086590d"]
}, Open  ]],

Cell[TextData[StyleBox["Build the  U 4x4 mat for qframes directly from the \
quaternions,\n   without and intermediate Sxx 3x3 matrix.",
 FontSize->18,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.741710788151724*^9, 
  3.741710835930291*^9}},ExpressionUUID->"e74315e9-3351-40eb-8eae-\
0159c5121f1a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"metricFromForm", "[", 
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{"QuatToRot", "[", 
      RowBox[{"qprod", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"s0", ",", "s1", ",", "s2", ",", "s3"}], "}"}]}], "]"}], 
      "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.741711212603341*^9, 3.741711240319911*^9}, {
   3.741711323205818*^9, 3.741711325479669*^9}, {3.741711374070117*^9, 
   3.741711376846591*^9}, {3.7417114303096647`*^9, 3.7417114618540993`*^9}, 
   3.7417114959710007`*^9},
 CellLabel->
  "In[158]:=",ExpressionUUID->"1b567ba0-b69f-4b7f-9182-10cb484bb8b0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["s0", "2"]}], "-", 
      SuperscriptBox["s1", "2"], "-", 
      SuperscriptBox["s2", "2"], "-", 
      SuperscriptBox["s3", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "s0", " ", "s1"}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "s0", " ", "s2"}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "s0", " ", "s3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "s0", " ", "s1"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["s0", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["s1", "2"]}], "-", 
      SuperscriptBox["s2", "2"], "-", 
      SuperscriptBox["s3", "2"]}], ",", 
     RowBox[{"4", " ", "s1", " ", "s2"}], ",", 
     RowBox[{"4", " ", "s1", " ", "s3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "s0", " ", "s2"}], ",", 
     RowBox[{"4", " ", "s1", " ", "s2"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["s0", "2"]}], "-", 
      SuperscriptBox["s1", "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["s2", "2"]}], "-", 
      SuperscriptBox["s3", "2"]}], ",", 
     RowBox[{"4", " ", "s2", " ", "s3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "s0", " ", "s3"}], ",", 
     RowBox[{"4", " ", "s1", " ", "s3"}], ",", 
     RowBox[{"4", " ", "s2", " ", "s3"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["s0", "2"]}], "-", 
      SuperscriptBox["s1", "2"], "-", 
      SuperscriptBox["s2", "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["s3", "2"]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741711462323187*^9, 3.7417114983409843`*^9},
 CellLabel->
  "Out[158]=",ExpressionUUID->"7c38b373-6b1b-469c-b647-f4cd3d901d1a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Output", " ", "=", " ", 
    RowBox[{
     RowBox[{"4", "x4", " ", "numerical", " ", "matrix", " ", "U"}], " ", "=",
      " ", 
     RowBox[{"metricFromForm", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"R", "[", "q", "]"}], ".", 
        RowBox[{"S", "[", "ij", "]"}]}], "=", 
       RowBox[{"R", "[", 
        RowBox[{
         RowBox[{"p", "[", "k", "]"}], "*", 
         RowBox[{"rbar", "[", "k", "]"}]}], "]"}]}], " "}]}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeUwwmat", "[", 
    RowBox[{"qtargetListP_", ",", "qrefListR_"}], "]"}], ":=", " ", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "qrefListR", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"s0", ",", "s1", ",", "s2", ",", "s3", ",", "k"}], "}"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"s0", ",", "s1", ",", "s2", ",", "s3"}], "}"}], " ", "=", 
           " ", 
           RowBox[{"qprod", "[", 
            RowBox[{
             RowBox[{"qtargetListP", "[", 
              RowBox[{"[", "k", "]"}], "]"}], ",", 
             RowBox[{"qinverse", "[", 
              RowBox[{"qrefListR", "[", 
               RowBox[{"[", "k", "]"}], "]"}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["s0", "2"]}], "-", 
               SuperscriptBox["s1", "2"], "-", 
               SuperscriptBox["s2", "2"], "-", 
               SuperscriptBox["s3", "2"]}], ",", 
              RowBox[{
               RowBox[{"-", "4"}], " ", "s0", " ", "s1"}], ",", 
              RowBox[{
               RowBox[{"-", "4"}], " ", "s0", " ", "s2"}], ",", 
              RowBox[{
               RowBox[{"-", "4"}], " ", "s0", " ", "s3"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", "s0", " ", "s1"}], ",", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["s0", "2"]}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["s1", "2"]}], "-", 
               SuperscriptBox["s2", "2"], "-", 
               SuperscriptBox["s3", "2"]}], ",", 
              RowBox[{"4", " ", "s1", " ", "s2"}], ",", 
              RowBox[{"4", " ", "s1", " ", "s3"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", "s0", " ", "s2"}], ",", 
              RowBox[{"4", " ", "s1", " ", "s2"}], ",", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["s0", "2"]}], "-", 
               SuperscriptBox["s1", "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["s2", "2"]}], "-", 
               SuperscriptBox["s3", "2"]}], ",", 
              RowBox[{"4", " ", "s2", " ", "s3"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", "s0", " ", "s3"}], ",", 
              RowBox[{"4", " ", "s1", " ", "s3"}], ",", 
              RowBox[{"4", " ", "s2", " ", "s3"}], ",", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["s0", "2"]}], "-", 
               SuperscriptBox["s1", "2"], "-", 
               SuperscriptBox["s2", "2"], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["s3", "2"]}]}]}], "}"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741707216490459*^9, 3.741707355353816*^9}, {
  3.74170743370501*^9, 3.741707495680418*^9}, {3.741708165762628*^9, 
  3.741708220520344*^9}, {3.7417108437408257`*^9, 3.741710846714478*^9}, {
  3.7417109156501923`*^9, 3.741710947016481*^9}, {3.741710989225396*^9, 
  3.741711169993058*^9}, {3.741711511461454*^9, 3.7417115472153378`*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"507117fc-c9dc-4626-807b-24fa9e919d30"],

Cell[TextData[{
 StyleBox["Proof:  in 2D,  2(q.V)^2-q^2 p^2 r^2 = (1/2)Tr[RRRinv],\n    in 3D \
it\[CloseCurlyQuote]s  2(q.V)^2- ",
  FontSize->24,
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   FractionBox["1", "2"], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontSize->24,
  FontWeight->"Bold",ExpressionUUID->"f8283235-0b66-4490-8ce8-ec5297c7cefa"],
 StyleBox["q^2 p^2 r^2",
  FontSize->24,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.741052483975*^9, 
  3.741052569209203*^9}},ExpressionUUID->"5aceff53-fd28-46e2-a985-\
12c0383e4f1a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Tr", "[", 
   RowBox[{"RRRQmat3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}], "]"}], 
  "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.741052317213524*^9, 3.7410523411926928`*^9}},
 CellLabel->
  "In[547]:=",ExpressionUUID->"1071c746-c54f-4ef0-a4d0-d8e7c3d487ca"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.741052341642502*^9},
 CellLabel->
  "Out[547]=",ExpressionUUID->"88ff9db9-8d87-4575-88a4-ba4b85fe6f80"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qVec", "=", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], ",", 
      RowBox[{"pVec", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}]}], ",", " ", 
      RowBox[{"rVec", " ", "=", 
       RowBox[{"{", 
        RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"qprod", "[", 
            RowBox[{"qVec", ",", "pVec"}], "]"}], ".", "rVec"}], ")"}], 
         "2"]}], " ", "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"qVec", ".", "qVec"}], " ", 
        RowBox[{"pVec", ".", "pVec"}], " ", 
        RowBox[{"rVec", ".", "rVec"}]}]}], ")"}], " ", "-", 
     RowBox[{"qVec", ".", " ", 
      RowBox[{"RRRQmat3D", "[", " ", 
       RowBox[{"pVec", ",", "rVec"}], "]"}], ".", "qVec"}]}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.741051963412197*^9, 3.741052080795312*^9}, {
  3.741052133283003*^9, 3.741052207689828*^9}, {3.741052244793439*^9, 
  3.7410522579631243`*^9}, {3.7410523588210697`*^9, 3.741052360145733*^9}},
 CellLabel->
  "In[548]:=",ExpressionUUID->"848c5655-3cd4-46ef-9c0f-36d89b472776"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.7410522084821997`*^9, 3.741052259061892*^9, 
  3.741052362030262*^9},
 CellLabel->
  "Out[548]=",ExpressionUUID->"c710cd32-d93b-4215-926a-9add663d3e32"]
}, Open  ]],

Cell[TextData[StyleBox[" --- Do we have a problem with Det =0 here?",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.741052947374939*^9, 
  3.741052960067505*^9}},ExpressionUUID->"31439d02-e183-4d61-b6f2-\
70b1ed21b2f6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Tr", "[", 
    RowBox[{"Outer", "[", 
     RowBox[{"Times", ",", 
      RowBox[{"{", 
       RowBox[{"a0", ",", "a1", ",", "a2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b0", ",", "b1", ",", "b2"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"Det", "[", 
    RowBox[{"Outer", "[", 
     RowBox[{"Times", ",", 
      RowBox[{"{", 
       RowBox[{"a0", ",", "a1", ",", "a2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b0", ",", "b1", ",", "b2"}], "}"}]}], "]"}], " ", "]"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.741052837241428*^9, 3.74105290672755*^9}},
 CellLabel->
  "In[553]:=",ExpressionUUID->"357bd0c8-2303-4356-8af6-d4c9bf91fbd2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a0", " ", "b0"}], "+", 
    RowBox[{"a1", " ", "b1"}], "+", 
    RowBox[{"a2", " ", "b2"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7410528660963583`*^9, 3.741052911018839*^9},
 CellLabel->
  "Out[553]=",ExpressionUUID->"482ce49d-11ec-40ed-8015-0a311a3a2a70"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vSqTemplate", " ", "=", 
  RowBox[{
   RowBox[{"metricFromForm", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"qprod", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}]}], "]"}], 
        ".", 
        RowBox[{"{", 
         RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], ")"}], 
      "2"], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7410518394512157`*^9, 3.741051904750671*^9}, {
  3.7410526504699907`*^9, 3.741052672187896*^9}},
 CellLabel->
  "In[550]:=",ExpressionUUID->"b83831c4-8f59-4e16-82b8-2732aed67283"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}], "2"], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], "2"], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], "2"], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}]}], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], "2"]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.741052665492218*^9, 3.7410526732813263`*^9}},
 CellLabel->
  "Out[550]=",ExpressionUUID->"3e12a57c-a343-4d17-913b-4d2d1006304b"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"#", "[", "vSqTemplate", "]"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{"Tr", ",", "Det", ",", "Eigenvalues"}], "}"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.741052705740945*^9, 3.741052758908916*^9}},
 CellLabel->
  "In[551]:=",ExpressionUUID->"9ce812aa-1227-470a-9ba9-fc6f7a9ce70d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p0", "2"], "+", 
      SuperscriptBox["p1", "2"], "+", 
      SuperscriptBox["p2", "2"], "+", 
      SuperscriptBox["p3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r0", "2"], "+", 
      SuperscriptBox["r1", "2"], "+", 
      SuperscriptBox["r2", "2"], "+", 
      SuperscriptBox["r3", "2"]}], ")"}]}], ",", "0", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741052759791601*^9},
 CellLabel->
  "Out[551]=",ExpressionUUID->"a3df1748-0db6-4233-b9fe-568890625853"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "just", " ", "the", " ", "product", " ", "terms", " ", "for", " ", "the", 
     " ", "tgt"}], ",", 
    RowBox[{"ref", " ", "summation"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"VVQmat3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0_", ",", "p1_", ",", "p2_", ",", "p3_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r0_", ",", "r1_", ",", "r2_", ",", "r3_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p0", " ", "r0"}], "+", 
          RowBox[{"p1", " ", "r1"}], "+", 
          RowBox[{"p2", " ", "r2"}], "+", 
          RowBox[{"p3", " ", "r3"}]}], ")"}], "2"], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], " ", "r0"}], "+", 
          RowBox[{"p0", " ", "r1"}], "-", 
          RowBox[{"p3", " ", "r2"}], "+", 
          RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p0", " ", "r0"}], "+", 
          RowBox[{"p1", " ", "r1"}], "+", 
          RowBox[{"p2", " ", "r2"}], "+", 
          RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p2"}], " ", "r0"}], "+", 
          RowBox[{"p3", " ", "r1"}], "+", 
          RowBox[{"p0", " ", "r2"}], "-", 
          RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p0", " ", "r0"}], "+", 
          RowBox[{"p1", " ", "r1"}], "+", 
          RowBox[{"p2", " ", "r2"}], "+", 
          RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p3"}], " ", "r0"}], "-", 
          RowBox[{"p2", " ", "r1"}], "+", 
          RowBox[{"p1", " ", "r2"}], "+", 
          RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p0", " ", "r0"}], "+", 
          RowBox[{"p1", " ", "r1"}], "+", 
          RowBox[{"p2", " ", "r2"}], "+", 
          RowBox[{"p3", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], " ", "r0"}], "+", 
          RowBox[{"p0", " ", "r1"}], "-", 
          RowBox[{"p3", " ", "r2"}], "+", 
          RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p0", " ", "r0"}], "+", 
          RowBox[{"p1", " ", "r1"}], "+", 
          RowBox[{"p2", " ", "r2"}], "+", 
          RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "r0"}], "-", 
          RowBox[{"p0", " ", "r1"}], "+", 
          RowBox[{"p3", " ", "r2"}], "-", 
          RowBox[{"p2", " ", "r3"}]}], ")"}], "2"], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p2"}], " ", "r0"}], "+", 
          RowBox[{"p3", " ", "r1"}], "+", 
          RowBox[{"p0", " ", "r2"}], "-", 
          RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], " ", "r0"}], "+", 
          RowBox[{"p0", " ", "r1"}], "-", 
          RowBox[{"p3", " ", "r2"}], "+", 
          RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p3", " ", "r0"}], "+", 
          RowBox[{"p2", " ", "r1"}], "-", 
          RowBox[{"p1", " ", "r2"}], "-", 
          RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "r0"}], "-", 
          RowBox[{"p0", " ", "r1"}], "+", 
          RowBox[{"p3", " ", "r2"}], "-", 
          RowBox[{"p2", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p2"}], " ", "r0"}], "+", 
          RowBox[{"p3", " ", "r1"}], "+", 
          RowBox[{"p0", " ", "r2"}], "-", 
          RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p0", " ", "r0"}], "+", 
          RowBox[{"p1", " ", "r1"}], "+", 
          RowBox[{"p2", " ", "r2"}], "+", 
          RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p2"}], " ", "r0"}], "+", 
          RowBox[{"p3", " ", "r1"}], "+", 
          RowBox[{"p0", " ", "r2"}], "-", 
          RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p1"}], " ", "r0"}], "+", 
          RowBox[{"p0", " ", "r1"}], "-", 
          RowBox[{"p3", " ", "r2"}], "+", 
          RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p2", " ", "r0"}], "-", 
          RowBox[{"p3", " ", "r1"}], "-", 
          RowBox[{"p0", " ", "r2"}], "+", 
          RowBox[{"p1", " ", "r3"}]}], ")"}], "2"], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p3"}], " ", "r0"}], "-", 
          RowBox[{"p2", " ", "r1"}], "+", 
          RowBox[{"p1", " ", "r2"}], "+", 
          RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p2"}], " ", "r0"}], "+", 
          RowBox[{"p3", " ", "r1"}], "+", 
          RowBox[{"p0", " ", "r2"}], "-", 
          RowBox[{"p1", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p3"}], " ", "r0"}], "-", 
          RowBox[{"p2", " ", "r1"}], "+", 
          RowBox[{"p1", " ", "r2"}], "+", 
          RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p0", " ", "r0"}], "+", 
          RowBox[{"p1", " ", "r1"}], "+", 
          RowBox[{"p2", " ", "r2"}], "+", 
          RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p3", " ", "r0"}], "+", 
          RowBox[{"p2", " ", "r1"}], "-", 
          RowBox[{"p1", " ", "r2"}], "-", 
          RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "r0"}], "-", 
          RowBox[{"p0", " ", "r1"}], "+", 
          RowBox[{"p3", " ", "r2"}], "-", 
          RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p3"}], " ", "r0"}], "-", 
          RowBox[{"p2", " ", "r1"}], "+", 
          RowBox[{"p1", " ", "r2"}], "+", 
          RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "p2"}], " ", "r0"}], "+", 
          RowBox[{"p3", " ", "r1"}], "+", 
          RowBox[{"p0", " ", "r2"}], "-", 
          RowBox[{"p1", " ", "r3"}]}], ")"}]}], ",", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p3", " ", "r0"}], "+", 
          RowBox[{"p2", " ", "r1"}], "-", 
          RowBox[{"p1", " ", "r2"}], "-", 
          RowBox[{"p0", " ", "r3"}]}], ")"}], "2"]}], "}"}]}], 
    "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741053023138236*^9, 3.7410531678919163`*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"909055a9-3adb-44a7-9889-639d89efdd06"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Output", " ", "=", " ", 
    RowBox[{"Traceful", "   ", "V_a", " ", "*", " ", "V_b", " ", "matrix"}]}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"makeWwwMat", "[", 
     RowBox[{"qTgt_", ",", "qRef_"}], "]"}], " ", ":=", " ", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "qRef", "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", "k", "}"}], ",", "\[IndentingNewLine]", " ", 
        RowBox[{"Sum", " ", "[", 
         RowBox[{
          RowBox[{"VVQmat3D", "[", 
           RowBox[{
            RowBox[{"qTgt", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", " ", 
            RowBox[{"qRef", "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], 
     "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725820596378134*^9, 3.725820802736498*^9}, {
   3.725821049574277*^9, 3.725821221908225*^9}, {3.725821289977553*^9, 
   3.725821348905539*^9}, {3.726323919310782*^9, 3.7263239689111557`*^9}, {
   3.7410471737654676`*^9, 3.741047196549954*^9}, {3.741050601120345*^9, 
   3.74105071124063*^9}, {3.7410508520136538`*^9, 3.741050874556641*^9}, {
   3.741051818680387*^9, 3.741051819076727*^9}, 3.7410532108286543`*^9, {
   3.7410532581075277`*^9, 3.741053265795912*^9}, {3.74105329968641*^9, 
   3.741053320658473*^9}, {3.741053385040496*^9, 3.741053475696439*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"0a6d182d-3335-474f-9e65-fc09bf1646f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeVwVec", "@@", 
  RowBox[{"testa3DFrm", "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[565]:=",ExpressionUUID->"fdc7018b-5a8a-4b14-8743-97212a20d025"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "97.41199376712309`", ",", "0.36102707942129053`", ",", 
   "0.03439922085581926`", ",", 
   RowBox[{"-", "20.179044488182353`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741054014150195*^9},
 CellLabel->
  "Out[565]=",ExpressionUUID->"80220554-d9c5-4ff1-bd3b-f7f2d5b8f8be"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.74105447550027*^9},ExpressionUUID->"352b2145-af9d-4988-9984-4751340f7800"]
}, Open  ]],

Cell[CellGroupData[{

Cell["List of the three answers --  RRR is  agreeing?", "Subsubsection",
 CellChangeTimes->{{3.741054479813736*^9, 3.741054500062374*^9}, {
  3.7410545501899776`*^9, 
  3.741054557629644*^9}},ExpressionUUID->"963d0e94-8155-411e-bd6b-\
ea597de20b8d"],

Cell[TextData[StyleBox["Try to find out why  Vw = (q*p[k]).r[k]  gives a \
different answer for qOpt:",
 FontSlant->"Italic",
 FontVariations->{"Underline"->True}]], "Text",
 CellChangeTimes->{{3.741078107163394*^9, 
  3.7410781449717503`*^9}},ExpressionUUID->"53ad1d05-d3b8-4ae0-bd65-\
272909327ce2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testVwec", " ", "=", " ", 
  RowBox[{"makeVwVec", "@@", 
   RowBox[{"testa3DFrm", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.741077039894039*^9, 3.741077083592908*^9}},
 CellLabel->
  "In[578]:=",ExpressionUUID->"afaa8b24-d226-41e0-afef-7722e47ee1af"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "97.41199376712309`", ",", "0.36102707942129053`", ",", 
   "0.03439922085581926`", ",", 
   RowBox[{"-", "20.179044488182353`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741077086411536*^9},
 CellLabel->
  "Out[578]=",ExpressionUUID->"3ce7f506-20fe-4613-963e-b5926b13e045"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tgtFrms", " ", "=", " ", 
   RowBox[{"testa3DFrm", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
  RowBox[{"refFrms", " ", "=", " ", 
   RowBox[{"testa3DFrm", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.741077271920677*^9, 3.7410773265954933`*^9}},
 CellLabel->
  "In[582]:=",ExpressionUUID->"11c0472a-759c-4dec-a0d5-a16e399c5470"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeVwVec", "[", 
  RowBox[{"tgtFrms", ",", "refFrms"}], "]"}]], "Input",
 CellChangeTimes->{{3.741077341498363*^9, 3.7410773510505333`*^9}},
 CellLabel->
  "In[592]:=",ExpressionUUID->"a3339dbe-16d6-4d9b-ac81-d83e34cd1813"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "97.41199376712309`", ",", "0.36102707942129053`", ",", 
   "0.03439922085581926`", ",", 
   RowBox[{"-", "20.179044488182353`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741077352498725*^9, 3.7410780161615353`*^9},
 CellLabel->
  "Out[592]=",ExpressionUUID->"74d6abd5-1621-4467-ac08-501972004213"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normalize", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.7410780192824297`*^9, 3.741078023477077*^9}},
 CellLabel->
  "In[593]:=",ExpressionUUID->"ce0220ae-6317-4cad-b053-add5bf9797ae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9792043445381104`", ",", "0.003629114557601296`", ",", 
   "0.00034578767160099564`", ",", 
   RowBox[{"-", "0.20284368759244967`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7410780240127277`*^9},
 CellLabel->
  "Out[593]=",ExpressionUUID->"74acf894-8294-4ab3-95f4-7122ed2a638d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"closerTgtFrms", " ", "=", " ", 
   RowBox[{"forceCloseFramePairs", "[", 
    RowBox[{"tgtFrms", ",", "refFrms"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7410771176024*^9, 3.741077128660604*^9}, {
   3.741077240595376*^9, 3.741077266611725*^9}, 3.7410773806867733`*^9, {
   3.7410774652826653`*^9, 3.7410774673066797`*^9}},
 CellLabel->
  "In[584]:=",ExpressionUUID->"242a620f-f803-4f5f-836e-ebfdfa8e155e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Union", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"closerTgtFrms", "-", "tgtFrms"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7410774792093678`*^9, 3.7410775004174747`*^9}},
 CellLabel->
  "In[585]:=",ExpressionUUID->"99dabda8-c7dd-4d1e-af44-29611ac1931c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7410775011998253`*^9},
 CellLabel->
  "Out[585]=",ExpressionUUID->"615342ee-9ca1-40a4-af3e-432f84683654"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeVwVec", "[", 
  RowBox[{"closerTgtFrms", ",", "refFrms"}], "]"}]], "Input",
 CellChangeTimes->{3.741077367155467*^9},
 CellLabel->
  "In[586]:=",ExpressionUUID->"494b455e-6b6d-43bc-bde6-be9c84ca5921"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "97.41199376712309`", ",", "0.36102707942129053`", ",", 
   "0.03439922085581926`", ",", 
   RowBox[{"-", "20.179044488182353`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7410775144956827`*^9},
 CellLabel->
  "Out[586]=",ExpressionUUID->"42058337-fc2f-4083-b5b6-6d80a086050f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"forcePlusq0", "[", "quatList_", "]"}], ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"quatList", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "1"}], "]"}], "]"}], "<", "0"}], ",", 
      RowBox[{"-", 
       RowBox[{"quatList", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ",", 
      RowBox[{"quatList", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"Length", "[", "quatList", "]"}]}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741077640941609*^9, 3.7410777394639177`*^9}},
 CellLabel->
  "In[587]:=",ExpressionUUID->"19313102-62e4-44c8-917f-2c74d25f1f8e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tgtFrmsP", " ", "=", 
   RowBox[{"forcePlusq0", "[", " ", 
    RowBox[{"testa3DFrm", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", 
  RowBox[{"refFrmsP", " ", "=", " ", 
   RowBox[{"forcePlusq0", "[", 
    RowBox[{"testa3DFrm", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "]"}]}], " ", ";"}]], "Input",
 CellChangeTimes->{
  3.741077632408071*^9, {3.741077768955263*^9, 3.741077798271109*^9}},
 CellLabel->
  "In[588]:=",ExpressionUUID->"19f42711-7e30-4b90-8872-719a392b0a89"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeVwVec", "[", 
  RowBox[{"tgtFrmsP", ",", "refFrmsP"}], "]"}]], "Input",
 CellChangeTimes->{
  3.741077367155467*^9, {3.741077804869926*^9, 3.7410778077822847`*^9}},
 CellLabel->
  "In[589]:=",ExpressionUUID->"51144aec-f00e-468d-acd4-e8c98023313e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "89.56991374525553`", ",", "0.6141085006922674`", ",", 
   "0.1676410152419645`", ",", 
   RowBox[{"-", "18.72126680594364`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7410778152596807`*^9},
 CellLabel->
  "Out[589]=",ExpressionUUID->"2f5f3c71-6faf-42b4-8ade-6d8020cf2fde"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normalize", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.741077838278414*^9, 3.74107784439876*^9}},
 CellLabel->
  "In[590]:=",ExpressionUUID->"9cfde19b-5bee-4cb9-b365-6f3f7145aac1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9788237111303972`", ",", "0.0067110030204329575`", ",", 
   "0.0018319879278157617`", ",", 
   RowBox[{"-", "0.20458677569092476`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.74107784571628*^9},
 CellLabel->
  "Out[590]=",ExpressionUUID->"3736d703-b065-4da5-b128-d701f07eac1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"makeVwVec", "[", 
   RowBox[{
    RowBox[{"forceCloseFramePairs", "[", 
     RowBox[{"tgtFrmsP", ",", "refFrmsP"}], "]"}], ",", "refFrmsP"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.741077887890792*^9, 3.741077964141645*^9}},
 CellLabel->
  "In[591]:=",ExpressionUUID->"740fe786-df26-4aae-bb49-be4164ee1895"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9792043445381104`", ",", "0.003629114557601296`", ",", 
   "0.00034578767160099564`", ",", 
   RowBox[{"-", "0.20284368759244967`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741077964923078*^9},
 CellLabel->
  "Out[591]=",ExpressionUUID->"14015dd8-bffd-40bd-874a-55adc14eb8bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"V", " ", "ONLY", " ", "eigenvector", " ", 
      RowBox[{"q", ".", "V"}]}], " ", "\[Rule]", " ", "q"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"Vhat", "--"}], " ", "possible", " ", "sign", " ", "swaps", " ", 
     "could", " ", "jitter", " ", "answer"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"qVopt", " ", "=", " ", 
   RowBox[{"Normalize", "[", 
    RowBox[{"makeVwVec", "@@", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7410540692590637`*^9, 3.741054099373746*^9}, {
  3.741054332385312*^9, 3.741054357352798*^9}, {3.74105440603111*^9, 
  3.741054413223483*^9}},ExpressionUUID->"8adfb90e-9f8a-4e1e-afd1-\
6e96926dc2d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9792043445381104`", ",", "0.003629114557601296`", ",", 
   "0.00034578767160099564`", ",", 
   RowBox[{"-", "0.20284368759244967`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741054100598959*^9},
 CellLabel->
  "Out[566]=",ExpressionUUID->"74eb019a-4f9a-41cd-8af1-3a0b90c8d95d"]
}, Open  ]],

Cell[TextData[{
 "-------------------------------\n",
 StyleBox["V squared  profile:",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.741078203242758*^9, 3.7410782179477158`*^9}, {
  3.741078598295166*^9, 
  3.741078601663903*^9}},ExpressionUUID->"00e3b058-aff9-4034-beec-\
bba1caf8474d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Get", " ", "List", " ", "of", " ", "eigenvectors", " ", "for", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", ".", "V"}], ")"}], "^", "2"}], " ", "profile", " ", 
    "matrix"}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"testWVVmat", " ", "=", " ", 
   RowBox[{"makeWwwMat", "@@", 
    RowBox[{"testa3DFrm", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.7410518244972677`*^9, {3.741053360239764*^9, 3.741053376183817*^9}, 
   3.7410534903472652`*^9, {3.7410543687563133`*^9, 3.741054393983831*^9}, {
   3.741078275053093*^9, 
   3.741078295434753*^9}},ExpressionUUID->"d7dc7cb4-31e9-4ffc-ac11-\
a6e06555cf12"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "94.91392747121395`", ",", "0.34118622192893366`", ",", 
     "0.029575509719519374`", ",", 
     RowBox[{"-", "19.586304216678684`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.34118622192893366`", ",", "0.25629124387935465`", ",", 
     RowBox[{"-", "0.07458507345670914`"}], ",", 
     RowBox[{"-", "0.10134594187284154`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.029575509719519374`", ",", 
     RowBox[{"-", "0.07458507345670914`"}], ",", "0.4408153919834813`", ",", 
     RowBox[{"-", "0.050382308561357655`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.586304216678684`"}], ",", 
     RowBox[{"-", "0.10134594187284154`"}], ",", 
     RowBox[{"-", "0.050382308561357655`"}], ",", "4.388965892923208`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741053497601646*^9, 3.7410535791503887`*^9, 
  3.741078257695224*^9},
 CellLabel->
  "Out[594]=",ExpressionUUID->"cf182fa2-b999-4b7c-9d0f-efe6d56f6169"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigenvalues", "[", "testWVVmat", "]"}]], "Input",
 CellChangeTimes->{{3.7410783377862043`*^9, 3.7410783387461557`*^9}},
 CellLabel->
  "In[595]:=",ExpressionUUID->"a2bb902b-60b1-45fd-81b3-3eea0ab1c65f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "98.97124670044478`", ",", "0.47425280289074373`", ",", 
   "0.3415321443368089`", ",", "0.21296835232767017`"}], "}"}]], "Output",
 CellChangeTimes->{3.741078342110588*^9},
 CellLabel->
  "Out[595]=",ExpressionUUID->"8ba09cab-4f16-4bb0-bbb4-c299375b81c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigenvectors", "[", "testWVVmat", "]"}]], "Input",
 CellLabel->
  "In[597]:=",ExpressionUUID->"8819026c-80b4-447b-848d-063aa25dd6bc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9792171403627874`"}], ",", 
     RowBox[{"-", "0.0035923343332143194`"}], ",", 
     RowBox[{"-", "0.00039489891724497905`"}], ",", "0.20278247263658805`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.044907954371185`", ",", "0.28664068261897635`", ",", 
     RowBox[{"-", "0.9313256057267879`"}], ",", "0.22012044616426335`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.18617808036235028`", ",", 
     RowBox[{"-", "0.40010051416324455`"}], ",", "0.09669366819724973`", ",", 
     "0.8921365565256575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.06674421358073557`"}], ",", 
     RowBox[{"-", "0.8704848032953088`"}], ",", 
     RowBox[{"-", "0.3511164973381864`"}], ",", 
     RowBox[{"-", "0.3384060024325506`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741078385230537*^9},
 CellLabel->
  "Out[597]=",ExpressionUUID->"7cc8de70-a158-41e7-9281-4161f47e25a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Some", " ", "slight", " ", "numerical", " ", "problems", " ", "in", " ", 
    "V", " ", "vs", " ", 
    RowBox[{"VV", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"qVVoptList", " ", "=", 
   RowBox[{"Normalize", "/@", 
    RowBox[{"Eigenvectors", "[", "testWVVmat", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.741054149217683*^9, 3.741054156281431*^9}, {
  3.741054187052187*^9, 3.741054192241108*^9}, {3.7410544410448027`*^9, 
  3.741054448319803*^9}, {3.741054609991631*^9, 3.741054628973756*^9}},
 CellLabel->
  "In[596]:=",ExpressionUUID->"759d20db-557a-4275-a9ad-92a62d248da1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9792171403627876`"}], ",", 
     RowBox[{"-", "0.0035923343332143203`"}], ",", 
     RowBox[{"-", "0.00039489891724497916`"}], ",", "0.2027824726365881`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.044907954371185006`", ",", "0.2866406826189764`", ",", 
     RowBox[{"-", "0.9313256057267881`"}], ",", "0.2201204461642634`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.18617808036235028`", ",", 
     RowBox[{"-", "0.40010051416324455`"}], ",", "0.09669366819724973`", ",", 
     "0.8921365565256575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.06674421358073558`"}], ",", 
     RowBox[{"-", "0.870484803295309`"}], ",", 
     RowBox[{"-", "0.35111649733818645`"}], ",", 
     RowBox[{"-", "0.33840600243255065`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741054156939434*^9, 3.741054192844993*^9, 
  3.741054450051944*^9, 3.7410783634900227`*^9},
 CellLabel->
  "Out[596]=",ExpressionUUID->"4071f15c-8dae-42a9-ae2e-d8be68189c04"]
}, Open  ]],

Cell[TextData[{
 "-------------------------------\n",
 StyleBox["RRRinv profile: Eigenvalues DIFFER, EigenVECTORS are identical!!",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.741078203242758*^9, 3.7410782179477158`*^9}, {
  3.741078586943841*^9, 3.741078593903315*^9}, {3.741080400207266*^9, 
  3.741080414495906*^9}},ExpressionUUID->"60cf9f94-3b31-4e5a-a0d6-\
662c3f8a2afc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testMMmat", " ", "=", 
  RowBox[{"makeM3Dfrm", "@@", 
   RowBox[{"testa3DFrm", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.741078424746154*^9, 3.741078430249445*^9}},
 CellLabel->
  "In[598]:=",ExpressionUUID->"def766d6-e300-4653-9b36-48f4c21354e9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "139.82785494242788`", ",", "0.6823724438578672`", ",", 
     "0.059151019439038784`", ",", 
     RowBox[{"-", "39.17260843335736`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6823724438578672`", ",", 
     RowBox[{"-", "49.487417512241315`"}], ",", 
     RowBox[{"-", "0.1491701469134183`"}], ",", 
     RowBox[{"-", "0.20269188374568303`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.059151019439038784`", ",", 
     RowBox[{"-", "0.1491701469134183`"}], ",", 
     RowBox[{"-", "49.11836921603305`"}], ",", 
     RowBox[{"-", "0.10076461712271537`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "39.17260843335736`"}], ",", 
     RowBox[{"-", "0.20269188374568303`"}], ",", 
     RowBox[{"-", "0.10076461712271537`"}], ",", 
     RowBox[{"-", "41.22206821415357`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741078463390359*^9},
 CellLabel->
  "Out[598]=",ExpressionUUID->"b795a1b1-0984-4fa8-9a16-dfc1eb4a0986"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigenvalues", "[", "testMMmat", "]"}]], "Input",
 CellChangeTimes->{{3.741055092729463*^9, 3.74105509493754*^9}},
 CellLabel->
  "In[599]:=",ExpressionUUID->"d8a236a5-7481-4918-b023-2af591332851"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"147.94249340088948`", ",", 
   RowBox[{"-", "49.57406329534467`"}], ",", 
   RowBox[{"-", "49.31693571132638`"}], ",", 
   RowBox[{"-", "49.05149439421854`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741055095352227*^9, 3.741078497997334*^9},
 CellLabel->
  "Out[599]=",ExpressionUUID->"6cff6773-05b5-40a2-bb4a-36e0bf0acc87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RRR", " ", "eigenvectors", " ", "agree", " ", "with", " ", "VV"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"qRRRoptList", " ", "=", " ", 
   RowBox[{"Eigenvectors", "[", "testMMmat", "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.741054302676015*^9, {3.741054460939024*^9, 3.741054466903344*^9}, {
   3.741054591746934*^9, 3.741054605045867*^9}, {3.741078477946929*^9, 
   3.741078509208274*^9}},
 CellLabel->
  "In[600]:=",ExpressionUUID->"e4d2787a-6873-4dd3-8d04-65b6beddf953"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9792171403627874`"}], ",", 
     RowBox[{"-", "0.003592334333214319`"}], ",", 
     RowBox[{"-", "0.00039489891724497905`"}], ",", "0.2027824726365881`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.06674421358072874`"}], ",", 
     RowBox[{"-", "0.8704848032953204`"}], ",", 
     RowBox[{"-", "0.35111649733819145`"}], ",", 
     RowBox[{"-", "0.3384060024325178`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.18617808036235078`", ",", 
     RowBox[{"-", "0.400100514163226`"}], ",", "0.09669366819729827`", ",", 
     "0.8921365565256605`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.04490795437119299`", ",", "0.28664068261896836`", ",", 
     RowBox[{"-", "0.9313256057267808`"}], ",", "0.22012044616430132`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7410543045018997`*^9, 3.7410544681393127`*^9, 
  3.741078511437963*^9},
 CellLabel->
  "Out[600]=",ExpressionUUID->"4c9d0002-e996-4411-8dfb-fe5bbd51607b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
------------------------------  Agrees??  -------------------------\
\>", "Subsubsection",
 CellChangeTimes->{{3.7410545358374662`*^9, 
  3.741054543043152*^9}},ExpressionUUID->"4dd362ea-0fda-401c-bc6c-\
7031f37a0c96"],

Cell[BoxData["  "], "Input",
 CellChangeTimes->{{3.741054473251863*^9, 
  3.741054473662765*^9}},ExpressionUUID->"c7aa03f8-76b1-4295-be67-\
686da7ff1816"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Tr", "[", "testWVVmat", "]"}], ",", 
    RowBox[{"Det", "[", "testWVVmat", "]"}], ",", 
    RowBox[{"testWVVmat", "-", 
     RowBox[{"Transpose", "[", "testWVVmat", "]"}]}], ",", 
    RowBox[{"Eigenvalues", "[", "testWVVmat", "]"}]}], "}"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7410535054432077`*^9, 3.741053535318554*^9}, 
   3.741053583860838*^9},
 CellLabel->
  "In[559]:=",ExpressionUUID->"5189b946-fa66-4526-9753-d78bae6a0479"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"100.`", ",", "3.4140164000254223`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "98.97124670044478`", ",", "0.47425280289074373`", ",", 
     "0.3415321443368089`", ",", "0.21296835232767017`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.741053536314899*^9, 3.741053584546085*^9},
 CellLabel->
  "Out[559]=",ExpressionUUID->"0a8b8550-5ea9-418f-9b5e-370a9fc9f8ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testqqRule", " ", "=", 
  RowBox[{"makeWXYZnumRule", "[", "testWVVmat", "]"}]}]], "Input",
 CellChangeTimes->{{3.741053755340493*^9, 3.741053767472752*^9}},
 CellLabel->
  "In[562]:=",ExpressionUUID->"1530873f-5e69-4afb-bd01-f3d7f9e1f39b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", "\[Rule]", "25.`"}], ",", 
   RowBox[{"x", "\[Rule]", "22.585109357546656`"}], ",", 
   RowBox[{"y", "\[Rule]", "22.677371431598715`"}], ",", 
   RowBox[{"z", "\[Rule]", "24.65144668206858`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.34118622192893366`"}], ",", 
   RowBox[{"aw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"b", "\[Rule]", "0.029575509719519374`"}], ",", 
   RowBox[{"bw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"-", "19.586304216678684`"}]}], ",", 
   RowBox[{"cw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"aa", "\[Rule]", 
    RowBox[{"-", "0.050382308561357655`"}]}], ",", 
   RowBox[{"aaw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"bb", "\[Rule]", 
    RowBox[{"-", "0.10134594187284154`"}]}], ",", 
   RowBox[{"bbw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"cc", "\[Rule]", 
    RowBox[{"-", "0.07458507345670914`"}]}], ",", 
   RowBox[{"ccw", "\[Rule]", "0.`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741053770781211*^9},
 CellLabel->
  "Out[562]=",ExpressionUUID->"4eae0198-e318-4ae7-ae07-d45cf859c300"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigenvectors", "[", "testWVVmat", "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.74110709526422*^9, 3.741107100847741*^9}},
 CellLabel->
  "In[622]:=",ExpressionUUID->"35051284-039d-4f2f-b411-ea7ad436b333"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9792171403627874`"}], ",", 
   RowBox[{"-", "0.0035923343332143194`"}], ",", 
   RowBox[{"-", "0.00039489891724497905`"}], ",", "0.20278247263658805`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.741107101331461*^9},
 CellLabel->
  "Out[622]=",ExpressionUUID->"61475354-00f5-4a2e-9cf5-b6e97e4b7195"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "NEW", " ", "TRACEFUL", " ", "eigenvector", " ", "is", " ", "RIGHT"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{"wVVeigvec", " ", "=", " ", 
   RowBox[{
    RowBox[{"eigenvecRMSDp1", "[", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"xyzEps0", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
        "subVVRule"}], ")"}], ",", "w", ",", "\[IndentingNewLine]", "x", ",", 
      "y", ",", "z", ",", "a", ",", "b", ",", "c", ",", "aa", ",", "bb", ",", 
      "cc"}], "]"}], " ", "/.", "testqqRule"}]}]}]], "Input",
 CellChangeTimes->{{3.741106926815502*^9, 3.741106939361031*^9}, {
  3.741106982430081*^9, 3.7411070743918*^9}, {3.7411071117972183`*^9, 
  3.74110712677597*^9}},ExpressionUUID->"3e0af743-c73f-4041-a8e1-\
8433204f1a37"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9792171403627875`"}], ",", 
   RowBox[{"-", "0.003592334333214316`"}], ",", 
   RowBox[{"-", "0.0003948989172451336`"}], ",", "0.20278247263658802`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.741107063522792*^9, 3.741107075870273*^9}},
 CellLabel->
  "Out[621]=",ExpressionUUID->"08433c74-ae75-474a-bfaf-3ccf1e08d78a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testMRule", " ", "=", 
  RowBox[{"makeXYZnumRule", "[", "testMMmat", "]"}]}]], "Input",
 CellChangeTimes->{{3.741054921690961*^9, 3.74105493724219*^9}},
 CellLabel->
  "In[572]:=",ExpressionUUID->"efe34b3a-93cd-418d-bef4-bea3aebc3183"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "45.170218715093284`"}], ",", 
   RowBox[{"y", "\[Rule]", "45.354742863197416`"}], ",", 
   RowBox[{"z", "\[Rule]", "49.30289336413715`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.6823724438578672`"}], ",", 
   RowBox[{"b", "\[Rule]", "0.059151019439038784`"}], ",", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"-", "39.17260843335736`"}]}], ",", 
   RowBox[{"aa", "\[Rule]", 
    RowBox[{"-", "0.10076461712271537`"}]}], ",", 
   RowBox[{"bb", "\[Rule]", 
    RowBox[{"-", "0.20269188374568303`"}]}], ",", 
   RowBox[{"cc", "\[Rule]", 
    RowBox[{"-", "0.1491701469134183`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.74105494034095*^9},
 CellLabel->
  "Out[572]=",ExpressionUUID->"19d72660-6b39-4c01-8b76-bcd7336a5380"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subMRule", " ", "=", " ", 
  RowBox[{"makePnNumRule", "[", "testMRule", "]"}]}]], "Input",
 CellChangeTimes->{
  3.74105490503513*^9, {3.741054947925377*^9, 3.741054955578472*^9}},
 CellLabel->
  "In[573]:=",ExpressionUUID->"e992a06c-e768-4ab3-b631-cf41f52333e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "14591.389177772106`"}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "959404.9980061649`"}]}], ",", 
   RowBox[{"p4", "\[Rule]", 
    RowBox[{"-", "1.7741722331615582`*^7"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.741054956696632*^9},
 CellLabel->
  "Out[573]=",ExpressionUUID->"869392f7-e10c-4460-90a6-c29302a57c7d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subVVRule", " ", "=", " ", 
  RowBox[{"makePn4NumRule", "[", "testqqRule", "]"}]}]], "Input",
 CellChangeTimes->{{3.741053865681738*^9, 3.741053888236103*^9}},
 CellLabel->
  "In[563]:=",ExpressionUUID->"b086d7b4-599c-4d9e-b688-e063e281d446"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", 
    RowBox[{"-", "100.`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", "102.15270555697018`"}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "33.26002861926827`"}]}], ",", 
   RowBox[{"p4", "\[Rule]", "3.4140164000254742`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741053888841251*^9},
 CellLabel->
  "Out[563]=",ExpressionUUID->"74b58dfe-de04-464f-b7ea-d025fe8b1014"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"xyzEps0", "[", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
   "subVVRule"}]}]], "Input",
 CellChangeTimes->{{3.741053913530987*^9, 3.741053920639344*^9}},
 CellLabel->
  "In[564]:=",ExpressionUUID->"1193df1d-004f-4813-8aa2-75eb6411f81b"],

Cell[BoxData["98.9712467004448`"], "Output",
 CellChangeTimes->{3.741053921854197*^9},
 CellLabel->
  "Out[564]=",ExpressionUUID->"13502213-c5cb-4b07-bbd7-549a7722d386"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xyzEps0", "[", 
   RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
  "subMRule"}]], "Input",
 CellChangeTimes->{3.741054972942473*^9},
 CellLabel->
  "In[574]:=",ExpressionUUID->"302c3f1f-194e-4b81-a6ad-bc6bf12b19d3"],

Cell[BoxData["147.94249340088953`"], "Output",
 CellChangeTimes->{3.741054974493823*^9},
 CellLabel->
  "Out[574]=",ExpressionUUID->"3703fc22-4082-4551-b2b1-c481049dca15"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigvecTestM", " ", "=", " ", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"eigenvecRMSD", "[", 
     RowBox[{
     "147.94249340088953`", ",", "x", ",", "y", ",", "z", ",", "a", ",", "b", 
      ",", "c", ",", "aa", ",", "bb", ",", "cc"}], "]"}]}], " ", "/.", 
   "testMRule"}]}]], "Input",
 CellChangeTimes->{{3.741055031057543*^9, 3.7410550605254993`*^9}, {
  3.741112936646667*^9, 3.741112951145294*^9}, {3.741113275828403*^9, 
  3.741113277200843*^9}},
 CellLabel->
  "In[659]:=",ExpressionUUID->"be16d0b3-5477-4abe-845a-53216980720d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9792171403627875`", ",", "0.003592334333214316`", ",", 
   "0.00039489891724513404`", ",", 
   RowBox[{"-", "0.20278247263658808`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741055062454958*^9, 3.741112952691483*^9, 
  3.741113280507535*^9},
 CellLabel->
  "Out[659]=",ExpressionUUID->"85f42547-8eae-4852-9d52-41e4c7c4b854"]
}, Open  ]],

Cell[TextData[StyleBox["** Need a traceful p1  eigenvecRMSDW routine **\n\n\
*** xxxxx  Look here in the morning, does W make a difference... EXACTLY THE \
SAME!!",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.741055192751833*^9, 3.741055222696074*^9}, {
  3.741055275991503*^9, 3.7410552994473877`*^9}, {3.7411074084124527`*^9, 
  3.741107416117083*^9}},ExpressionUUID->"3ee53b94-3bd5-448e-bcbc-\
46214ba100c5"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"eigenvecRMSDp1", "[", 
    RowBox[{
    "98.9712467004448`", ",", "w", ",", "x", ",", "y", ",", "z", ",", "a", 
     ",", "b", ",", "c", ",", "aa", ",", "bb", ",", "cc"}], "]"}], " ", "/.", 
   "testqqRule"}]}]], "Input",
 CellChangeTimes->{{3.741055031057543*^9, 3.7410550605254993`*^9}, {
  3.74105523925893*^9, 3.741055269211606*^9}, {3.741107365540019*^9, 
  3.74110739341429*^9}},
 CellLabel->
  "In[624]:=",ExpressionUUID->"32607901-204d-4690-ab46-1c2e7d419495"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "0.9792171403627875`"}], ",", 
    RowBox[{"-", "0.003592334333214316`"}], ",", 
    RowBox[{"-", "0.0003948989172451336`"}], ",", "0.20278247263658802`"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.741107605803856*^9, 3.741107611495099*^9}},
 CellLabel->
  "In[627]:=",ExpressionUUID->"d00e9d7c-a8cc-449f-953b-e195f0ee9291"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9792171403627875`", ",", "0.003592334333214316`", ",", 
   "0.0003948989172451336`", ",", 
   RowBox[{"-", "0.20278247263658802`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741107612968758*^9},
 CellLabel->
  "Out[627]=",ExpressionUUID->"6905571f-809a-4293-9915-30e4bfe6ffa7"]
}, Open  ]],

Cell[TextData[StyleBox[" Now do EXACT arclength measure numerically:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.741107432092038*^9, 
  3.741107445421093*^9}},ExpressionUUID->"089bce06-c2d5-475d-bd02-\
5f110d2a4104"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";", 
    RowBox[{"Sum", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"quatmat4", "[", 
              RowBox[{"{", 
               RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], 
             ".", " ", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "k"}], "]"}], "]"}]}], " ", ")"}], ".", 
           RowBox[{"testa3DFrm", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "k"}], "]"}], "]"}]}], "]"}], "]"}], ")"}], 
       "2"], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"testa3DFrm", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}]}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{{3.741110871977293*^9, 3.741110920514071*^9}},
 CellLabel->
  "In[642]:=",ExpressionUUID->"de17dc08-9fd2-416d-836d-30b0581c4000"],

Cell[BoxData["5.206378233803604`"], "Output",
 CellChangeTimes->{3.741110922419981*^9},
 CellLabel->
  "Out[642]=",ExpressionUUID->"086a6873-4cec-406a-80d6-149bb77f5efc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3", ",", 
       RowBox[{"qsol", "=", 
        RowBox[{"{", 
         RowBox[{
         "0.9792171403627875`", ",", "0.003592334333214316`", ",", 
          "0.0003948989172451336`", ",", 
          RowBox[{"-", "0.20278247263658802`"}]}], "}"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "=", 
       RowBox[{"slerp", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "qsol", 
         ",", "t"}], "]"}]}], ";", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"Line", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"u", ",", 
               RowBox[{"Sum", "[", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"ArcCos", "[", 
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"quatmat4", "[", 
                    RowBox[{"slerp", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
                    "qsol", ",", "u"}], "]"}], "]"}], ".", " ", 
                    RowBox[{"testa3DFrm", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "k"}], "]"}], "]"}]}], " ", ")"}], ".", 
                    
                    RowBox[{"testa3DFrm", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "k"}], "]"}], "]"}]}], "]"}], "]"}], 
                   ")"}], "2"], ",", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", "1", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"testa3DFrm", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}],
               "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"u", ",", "0", ",", "2", ",", ".1"}], "}"}]}], "]"}], 
           "]"}], ",", " ", "Red", ",", "Thick", ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"t", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", 
               RowBox[{"Sum", "[", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"ArcCos", "[", 
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"quatmat4", "[", 
                    RowBox[{"{", 
                    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], 
                    "]"}], ".", " ", 
                    RowBox[{"testa3DFrm", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "k"}], "]"}], "]"}]}], " ", ")"}], ".", 
                    
                    RowBox[{"testa3DFrm", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "k"}], "]"}], "]"}]}], "]"}], "]"}], 
                   ")"}], "2"], ",", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", "1", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"testa3DFrm", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}],
               " ", "}"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "10"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.74111097279935*^9, 3.741111195666458*^9}, {
  3.741111227842135*^9, 3.7411114251611347`*^9}, {3.7411114633230057`*^9, 
  3.741111480936898*^9}},
 CellLabel->
  "In[647]:=",ExpressionUUID->"b7fa96ec-2102-47ba-a4f9-f9874429a716"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], 0, 2}}, Typeset`size$$ = {360., {176., 183.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`t$453702$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`t$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$453702$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`q0$, $CellContext`q1$, $CellContext`q2$, \
$CellContext`q3$, $CellContext`qsol$ = {0.9792171403627875, 
          0.003592334333214316, 
          0.0003948989172451336, -0.20278247263658802`}}, {$CellContext`q0$, \
$CellContext`q1$, $CellContext`q2$, $CellContext`q3$} = $CellContext`slerp[{1,
            0, 0, 0}, $CellContext`qsol$, $CellContext`t$$]; Graphics[{Blue, 
           Line[
            Table[{$CellContext`u, 
              Sum[ArcCos[
                 Abs[
                  Dot[
                   Dot[
                    $CellContext`quatmat4[
                    $CellContext`slerp[{1, 0, 0, 
                    0}, $CellContext`qsol$, $CellContext`u]], 
                    Part[$CellContext`testa3DFrm, 1, $CellContext`k]], 
                   
                   Part[$CellContext`testa3DFrm, 
                    2, $CellContext`k]]]]^2, {$CellContext`k, 1, 
                Length[
                 Part[$CellContext`testa3DFrm, 2]]}]}, {$CellContext`u, 0, 2, 
              0.1}]], Red, Thick, 
           Line[{{$CellContext`t$$, 0}, {$CellContext`t$$, 
              Sum[ArcCos[
                 Abs[
                  Dot[
                   Dot[
                    $CellContext`quatmat4[{$CellContext`q0$, \
$CellContext`q1$, $CellContext`q2$, $CellContext`q3$}], 
                    Part[$CellContext`testa3DFrm, 1, $CellContext`k]], 
                   
                   Part[$CellContext`testa3DFrm, 
                    2, $CellContext`k]]]]^2, {$CellContext`k, 1, 
                Length[
                 Part[$CellContext`testa3DFrm, 2]]}]}}]}, Axes -> True, 
          PlotRange -> {{0, 2}, {0, 10}}, AspectRatio -> 1]], 
      "Specifications" :> {{$CellContext`t$$, 0, 2, Appearance -> "Labeled"}},
       "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{407., {221., 228.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.741111184733095*^9, 3.741111196621683*^9}, 
   3.741111429740464*^9, {3.741111469589911*^9, 3.74111148171023*^9}},
 CellLabel->
  "Out[647]=",ExpressionUUID->"ea412e96-9dba-4962-88c8-91b70997a911"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,126,15,27328294211596885504,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.741707702090411*^9},
 CellLabel->"",ExpressionUUID->"11c7e6e7-c29d-4844-8d95-41d32accdafe"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,126,16,
   27328294211596885504,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7417077021707478`*^9},
 CellLabel->"",ExpressionUUID->"0cfa20bf-1c90-4586-9f9f-fe88449cae34"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,126,17,
   27328294211596885504,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.741707702220821*^9},
 CellLabel->"",ExpressionUUID->"dd4b48e2-683d-4f1a-88e3-f3577267f448"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,126,18,27328294211596885504,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.741707702271871*^9},
 CellLabel->"",ExpressionUUID->"beab6507-b10d-42cb-8897-976bbeca91e7"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,51,25,27330770613124539526,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.742082610334787*^9},
 CellLabel->"",ExpressionUUID->"4eb4fd06-339d-4bbd-b3ce-6343351342ab"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,51,26,
   27330770613124539526,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.742082610394107*^9},
 CellLabel->"",ExpressionUUID->"1aff7bd6-a499-4543-aea1-b48f2e4d7f68"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,51,27,
   27330770613124539526,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.742082610444537*^9},
 CellLabel->"",ExpressionUUID->"bc88cfb0-f77a-436f-841d-3291f79b9dfa"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,51,28,27330770613124539526,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.742082610475024*^9},
 CellLabel->"",ExpressionUUID->"a69058d3-568c-4fa3-9fbd-6c6a771428b0"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,48,4,27336476473265712915,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.742993829241722*^9},
 CellLabel->"",ExpressionUUID->"609721e3-f753-4ac5-b50a-4b3cea125cf8"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,48,5,
   27336476473265712915,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.74299382926684*^9},
 CellLabel->"",ExpressionUUID->"736542bc-abe6-4c6e-90bf-a3d2b6a15d2f"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,48,6,
   27336476473265712915,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.74299382933178*^9},
 CellLabel->"",ExpressionUUID->"0584e417-03ee-40e4-a496-cc31637fda5e"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,48,7,27336476473265712915,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.74299382938876*^9},
 CellLabel->"",ExpressionUUID->"c4aad8e8-7889-422f-bbb2-03cbfab70b40"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,11,1,27337377797248259160,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.743088263670505*^9},
 CellLabel->"",ExpressionUUID->"e58324f4-920f-4f9e-aea8-0ba8c1da8b3b"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,11,2,
   27337377797248259160,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.743088263697796*^9},
 CellLabel->"",ExpressionUUID->"80963834-a7a4-43f9-a91d-65d3c9910b06"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,11,3,
   27337377797248259160,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7430882637446127`*^9},
 CellLabel->"",ExpressionUUID->"a71c9a57-c9b7-4c23-8c0d-65cf375d2e3f"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,11,4,27337377797248259160,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.743088263810195*^9},
 CellLabel->"",ExpressionUUID->"bcd231b5-06dc-41ec-89bf-760f1ee35c65"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,189,25,27344378750003428142,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.744217730457458*^9},
 CellLabel->"",ExpressionUUID->"e489a821-fdbf-48b3-bfef-ba539ccbd429"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,189,26,
   27344378750003428142,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.744217730489255*^9},
 CellLabel->"",ExpressionUUID->"f3bf51c9-b4e7-4274-aff0-f78e5d5417d3"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"testa3DFrm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"",2,189,27,
   27344378750003428142,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7442177305068197`*^9},
 CellLabel->"",ExpressionUUID->"ecc7106b-864e-4af8-bd6c-481b8e644496"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,189,28,27344378750003428142,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.744217730568445*^9},
 CellLabel->"",ExpressionUUID->"42afeed0-135c-480e-b0c1-010333e54176"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Module", " ", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sumSqrArcCos", "=", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"ArcCos", "[", 
           RowBox[{"Abs", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"quatmat4", "[", 
                RowBox[{"{", 
                 RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], 
                "]"}], ".", " ", 
               RowBox[{"testa3DFrm", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "k"}], "]"}], "]"}]}], " ", ")"}], ".", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "k"}], "]"}], "]"}]}], "]"}], "]"}], ")"}], 
         "2"], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"testa3DFrm", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], "}"}], 
    ",", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{"sumSqrArcCos", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"q0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"q1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"q2", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"q3", ",", "0"}], "}"}]}], "}"}]}], "]"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.741105735825656*^9, 3.7411059422979116`*^9}, {
  3.741106098622035*^9, 3.741106109457465*^9}, {3.741106198792799*^9, 
  3.7411063036073*^9}, {3.741106340975155*^9, 3.741106463982195*^9}, {
  3.741106496992937*^9, 3.741106517230455*^9}, {3.741106553157732*^9, 
  3.7411066026533546`*^9}, {3.741107460895794*^9, 3.741107462638029*^9}},
 CellLabel->
  "In[625]:=",ExpressionUUID->"593fdd4b-1b46-4583-8265-07ba2edb9f23"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.2063782338036075`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q0", "\[Rule]", "0.983838857597438`"}], ",", 
     RowBox[{"q1", "\[Rule]", "0.0026958804682577367`"}], ",", 
     RowBox[{"q2", "\[Rule]", "0.013005086797480062`"}], ",", 
     RowBox[{"q3", "\[Rule]", 
      RowBox[{"-", "0.31492073763500855`"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741107471430521*^9},
 CellLabel->
  "Out[625]=",ExpressionUUID->"a954fcbf-8461-4b9e-8efd-e9588272b485"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/.", 
  RowBox[{"%", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.741107476739976*^9, 3.7411074955721483`*^9}},
 CellLabel->
  "In[626]:=",ExpressionUUID->"ed26c67f-b4a6-4512-92f9-bd7b41f5a2b6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.983838857597438`", ",", "0.0026958804682577367`", ",", 
   "0.013005086797480062`", ",", 
   RowBox[{"-", "0.31492073763500855`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741107497107072*^9},
 CellLabel->
  "Out[626]=",ExpressionUUID->"23d0f95d-3710-471a-b4c5-08223da3edea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"qsol", "=", 
       RowBox[{"{", 
        RowBox[{
        "0.9792171403627875`", ",", "0.003592334333214316`", ",", 
         "0.0003948989172451336`", ",", 
         RowBox[{"-", "0.20278247263658802`"}]}], "}"}]}], ",", "rule"}], 
     "}"}], ",", 
    RowBox[{"Module", " ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sumSqrArcCos", "=", " ", 
        RowBox[{"Sum", "[", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"ArcCos", "[", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"quatmat4", "[", 
                  RowBox[{"{", 
                   RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], 
                  "]"}], ".", " ", 
                 RowBox[{"testa3DFrm", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "k"}], "]"}], "]"}]}], " ", ")"}], ".", 
               RowBox[{"testa3DFrm", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "k"}], "]"}], "]"}]}], "]"}], "]"}], ")"}],
            "2"], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
       "}"}], ",", 
      RowBox[{
       RowBox[{"rule", "=", 
        RowBox[{"FindMinimum", "[", 
         RowBox[{"sumSqrArcCos", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"q0", ",", 
              RowBox[{"qsol", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"q1", ",", 
              RowBox[{"qsol", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"q2", ",", 
              RowBox[{"qsol", "[", 
               RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"q3", ",", 
              RowBox[{"qsol", "[", 
               RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rule", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ".", 
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "/.", 
          RowBox[{"rule", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"qsol", ".", 
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "/.", 
          RowBox[{"rule", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ",", 
         RowBox[{"qsol", ".", 
          RowBox[{"Normalize", "[", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/.", 
            RowBox[{"rule", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "]"}]}]}], "}"}]}]}], 
     "]"}]}], "]"}], "//", "Quiet"}]], "Input",
 CellChangeTimes->{{3.741111554891727*^9, 3.741111555781749*^9}, {
  3.7411115868649607`*^9, 3.7411116783875303`*^9}, {3.7411117168926992`*^9, 
  3.741111780500136*^9}, {3.741111821322297*^9, 3.741111839264779*^9}, {
  3.74111189082183*^9, 3.741111920254116*^9}},
 CellLabel->
  "In[652]:=",ExpressionUUID->"1da10d78-e228-4c3f-85ce-3151434361ec"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.0417456500919178`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q0", "\[Rule]", "0.9769235158227592`"}], ",", 
       RowBox[{"q1", "\[Rule]", "0.003210054426322758`"}], ",", 
       RowBox[{"q2", "\[Rule]", 
        RowBox[{"-", "0.0005591232947929885`"}]}], ",", 
       RowBox[{"q3", "\[Rule]", 
        RowBox[{"-", "0.2159826234523286`"}]}]}], "}"}]}], "}"}], ",", 
   "1.00103866646913`", ",", "1.0004290527388664`", ",", 
   "0.9999099010670437`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.741111680552894*^9, 3.741111782892969*^9, {3.741111830372617*^9, 
   3.741111852163363*^9}, 3.7411119228792686`*^9},
 CellLabel->
  "Out[652]=",ExpressionUUID->"cf37a831-2818-4007-9ae1-f7608f017fd1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MEASURE the cost metrics", "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741107800977324*^9, 3.741107806417831*^9}, 
   3.741187240647439*^9, {3.742232209886836*^9, 
   3.7422322133658943`*^9}},ExpressionUUID->"36e96544-5f77-4799-9a51-\
4280dc6e0e5f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"qCost", " ", "[", 
   RowBox[{"q_", ",", "tgt_", ",", "ref_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"len", " ", "=", " ", 
      RowBox[{"Length", "[", "ref", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"ArcCos", "[", 
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{"q", ",", 
           RowBox[{"tgt", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ".", 
         RowBox[{"ref", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.7288717992498083`*^9, 3.7288719178300943`*^9}, {
   3.7288721628677197`*^9, 3.728872173195294*^9}, {3.7288722409213057`*^9, 
   3.7288722416189137`*^9}, 3.7411872406488113`*^9},
 CellLabel->
  "In[653]:=",ExpressionUUID->"f6d99348-5c96-4a32-b286-e4178e595aac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"use", " ", "the", " ", "square"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"qCost2", " ", "[", 
    RowBox[{"q_", ",", "tgt_", ",", "ref_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", " ", "=", " ", 
       RowBox[{"Length", "[", "ref", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"ArcCos", "[", 
           RowBox[{"Abs", "[", 
            RowBox[{
             RowBox[{"qprod", "[", 
              RowBox[{"q", ",", 
               RowBox[{"tgt", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ".", 
             RowBox[{"ref", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], ")"}], "2"], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.7288717992498083`*^9, 3.7288719178300943`*^9}, {
   3.7288721628677197`*^9, 3.728872173195294*^9}, {3.7288722409213057`*^9, 
   3.7288722416189137`*^9}, {3.741114087649971*^9, 3.741114098441477*^9}, {
   3.741114131752232*^9, 3.741114163231966*^9}, 3.741187240650002*^9},
 CellLabel->
  "In[666]:=",ExpressionUUID->"93ecf169-bcfb-4df9-8d74-02111007e41b"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.742177386839074*^9},ExpressionUUID->"26455cb9-5463-4eb4-a17b-\
ca967d0e7053"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Squared", " ", "pure", " ", "arc", " ", "angles"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"qCostArcN2", " ", "[", 
    RowBox[{"q_", ",", "tgt_", ",", "ref_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", " ", "=", " ", 
       RowBox[{"Length", "[", "ref", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"ArcCos", "[", 
           RowBox[{"Abs", "[", 
            RowBox[{
             RowBox[{"qprod", "[", 
              RowBox[{"q", ",", 
               RowBox[{"tgt", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ".", 
             RowBox[{"ref", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], ")"}], "2"], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741898033128202*^9, 3.741898059352174*^9}},
 CellLabel->
  "In[244]:=",ExpressionUUID->"df1531cf-68cd-4d80-a321-a68e601dbcf9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Squared", " ", "pure", " ", "chord", " ", 
     RowBox[{"dist", "^", "2"}]}], ",", " ", 
    RowBox[{"must", " ", "agree", " ", "with", " ", 
     RowBox[{"q", ".", "V"}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"qCostChordN2", "[", 
    RowBox[{"q_", ",", "tgt_", ",", "ref_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"len", " ", "=", " ", 
        RowBox[{"Length", "[", "ref", "]"}]}], ",", "vi"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"vi", "=", 
         RowBox[{"(", " ", 
          RowBox[{
           RowBox[{"qprod", "[", 
            RowBox[{"q", ",", 
             RowBox[{"tgt", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "-", 
           RowBox[{"ref", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}], ";", 
        RowBox[{"vi", ".", "vi"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7418979965972757`*^9, 3.741898137829907*^9}, {
  3.7418987814773493`*^9, 3.741898826537202*^9}, {3.741898922521928*^9, 
  3.741898931615453*^9}, {3.7422307852882013`*^9, 3.7422307961157846`*^9}},
 CellLabel->
  "In[247]:=",ExpressionUUID->"54bc6bab-bc00-4705-8b3d-c1b62853cb9f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"chord", " ", "Cross", " ", "term"}], ",", " ", 
    RowBox[{"must", " ", "agree", " ", "with", " ", 
     RowBox[{"chord", "^", "2"}], " ", "AND", " ", 
     RowBox[{"q", ".", "V"}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"qCostCrossChordN2", "[", 
    RowBox[{"q_", ",", "tgt_", ",", "ref_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", " ", "=", " ", 
       RowBox[{"Length", "[", "ref", "]"}]}], " ", "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Sum", "[", " ", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{"q", ",", 
           RowBox[{"tgt", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ".", 
         RowBox[{"ref", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7418979965972757`*^9, 3.741898137829907*^9}, {
   3.7418987814773493`*^9, 3.741898826537202*^9}, {3.741898879835294*^9, 
   3.741898901792457*^9}, {3.74189893779919*^9, 3.7418989689275007`*^9}, 
   3.7418991283939543`*^9, {3.7418991833185263`*^9, 3.741899184029912*^9}, 
   3.742177401960452*^9},
 CellLabel->
  "In[246]:=",ExpressionUUID->"b6ba970c-5415-42d7-802a-382c34cb32e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qCost", "[", 
  RowBox[{"eigvecTestM", ",", 
   RowBox[{"testa3DFrm", "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
   RowBox[{"testa3DFrm", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411128974719057`*^9, 3.741112900351396*^9}, {
   3.7411129734560204`*^9, 3.7411129903120213`*^9}, 3.741113289154502*^9, 
   3.7411872406505537`*^9},
 CellLabel->
  "In[660]:=",ExpressionUUID->"634c540f-c0a7-4adc-85d7-fc14f4026ad5"],

Cell[BoxData["15.390906981438379`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741112991043199*^9, 3.741113291151963*^9, 
  3.741187240651002*^9},
 CellLabel->
  "Out[660]=",ExpressionUUID->"a607a15b-fc3a-4fd9-a4af-80e23a21eb65"],

Cell[BoxData[
 RowBox[{"trueCost", "=", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"qCost", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox["q0", "2"], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], "]"}]}], ",", 
      RowBox[{"testa3DFrm", "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
      RowBox[{"testa3DFrm", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411130149983883`*^9, 3.741113042809252*^9}, {
   3.741113119377616*^9, 3.741113193431044*^9}, 3.741187240651495*^9},
 CellLabel->
  "In[657]:=",ExpressionUUID->"2b6dccc5-0bcd-4054-9927-41d5325c4fe9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15.323903010485274`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q0", "\[Rule]", "5.4167042764579465`"}], ",", 
     RowBox[{"q1", "\[Rule]", "0.0178125796772299`"}], ",", 
     RowBox[{"q2", "\[Rule]", 
      RowBox[{"-", "0.0033786059790813718`"}]}], ",", 
     RowBox[{"q3", "\[Rule]", 
      RowBox[{"-", "1.092864684206138`"}]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741113200761426*^9, 3.741187240651929*^9},
 CellLabel->
  "Out[657]=",ExpressionUUID->"a85ce8c4-d0e0-47f4-8ef4-2caa9c000099"],

Cell[BoxData[
 RowBox[{"trueQuat", " ", "=", " ", 
  RowBox[{"Normalize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/.", 
    RowBox[{"trueCost", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741113219431884*^9, 3.7411132561115513`*^9}, 
   3.7411872406524*^9},
 CellLabel->
  "In[658]:=",ExpressionUUID->"d8eab257-e912-4819-bce5-b9baebcd082f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9802425561621191`", ",", "0.003223481981568873`", ",", 
   RowBox[{"-", "0.0006114148368027591`"}], ",", 
   RowBox[{"-", "0.1977720061701524`"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741113257542575*^9, 3.741187240652833*^9},
 CellLabel->
  "Out[658]=",ExpressionUUID->"dfafc066-1c28-4b89-b280-32e2c7f2e1f0"],

Cell[BoxData[
 RowBox[{"trueCost2", "=", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"qCost2", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox["q0", "2"], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], "]"}]}], ",", 
      RowBox[{"testa3DFrm", "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
      RowBox[{"testa3DFrm", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411130149983883`*^9, 3.741113042809252*^9}, {
   3.741113119377616*^9, 3.741113193431044*^9}, {3.741114566828012*^9, 
   3.741114568716299*^9}, 3.741187240653323*^9},
 CellLabel->
  "In[674]:=",ExpressionUUID->"d45ed26b-968d-480c-99a9-9b9aabe1c983"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.166977121483573`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q0", "\[Rule]", "163.41529282929415`"}], ",", 
     RowBox[{"q1", "\[Rule]", "0.6077074497834659`"}], ",", 
     RowBox[{"q2", "\[Rule]", "0.054849798076261176`"}], ",", 
     RowBox[{"q3", "\[Rule]", 
      RowBox[{"-", "33.855339945749236`"}]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741114588644024*^9, 3.741187240653965*^9},
 CellLabel->
  "Out[674]=",ExpressionUUID->"e4e04728-ba07-4287-9b1f-5381b178fa88"],

Cell[BoxData[
 RowBox[{"trueQuat2", " ", "=", " ", 
  RowBox[{"Normalize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/.", 
    RowBox[{"trueCost2", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741113219431884*^9, 3.7411132561115513`*^9}, {
   3.7411145794385147`*^9, 3.7411145821073713`*^9}, 3.741187240654582*^9},
 CellLabel->
  "In[675]:=",ExpressionUUID->"8f15f8e8-8589-40fb-909a-80dadac4e953"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9792000089597551`", ",", "0.003641440956780557`", ",", 
   "0.0003286652175437508`", ",", 
   RowBox[{"-", "0.2028644235447618`"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741114593380394*^9, 3.741187240655156*^9},
 CellLabel->
  "Out[675]=",ExpressionUUID->"a6cbad46-3413-4892-861e-aec4fdb1d26b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"qCost2", "[", " ", 
    RowBox[{"trueQuat", " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"qCost2", "[", " ", 
    RowBox[{"trueQuat2", " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"qCost2", "[", " ", 
    RowBox[{"eigvecTestM", " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741114306293315*^9, 3.741114309535933*^9}, {
   3.741114373321447*^9, 3.741114379636636*^9}, {3.741114615429323*^9, 
   3.7411146202033253`*^9}, 3.741187240655879*^9},
 CellLabel->
  "In[676]:=",ExpressionUUID->"cd9cac67-1829-4e70-863d-e61510aae97e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4.178181451927997`", ",", "4.166977121483677`", ",", 
   "4.166982600367653`"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741114621140821*^9, 3.741187240656467*^9},
 CellLabel->
  "Out[676]=",ExpressionUUID->"5eb57308-1d14-4e2f-84e4-a814d12703df"],

Cell[TextData[StyleBox["Compare  forceCloseSign cost and   |ArcCos|^2  cost",
 FontSize->18,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741114176334379*^9, 3.7411142118951063`*^9}, 
   3.741187240656825*^9},ExpressionUUID->"e5298d57-ed96-4de6-9518-\
2eb90551090a"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qCost", "[", 
      RowBox[{
       RowBox[{"slerp", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         "eigvecTestM", ",", "t"}], "]"}], ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"qCost", "[", 
      RowBox[{
       RowBox[{"slerp", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "trueQuat",
          ",", "t"}], "]"}], ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", ".95", ",", "1.05"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"15.3", ",", "15.7"}], "}"}]}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"qCost", "[", 
            RowBox[{"eigvecTestM", ",", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", ",", " ", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}], "}"}], 
       "]"}], ",", "\[IndentingNewLine]", "Blue", ",", "Thick", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"qCost", "[", 
            RowBox[{"trueQuat", ",", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", ",", " ", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}], "}"}], 
       "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741113476945685*^9, 3.741113601251175*^9}, {
   3.741113634161338*^9, 3.741113636276922*^9}, {3.7411137847285757`*^9, 
   3.741113980826928*^9}, {3.741114014251748*^9, 3.741114040955113*^9}, 
   3.741187240657501*^9},
 CellLabel->
  "In[665]:=",ExpressionUUID->"387e1031-e76d-4b4d-8620-163faf598030"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd1wk0VP3/B3C0GD2RJVuLNUSZQbLG99Zje6TIFkKTsqdIKEm2JPws4SGU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       "]]},
     Annotation[#, "Charting`Private`Tag$609050#1"]& ], 
    TagBox[
     {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k8ldkfB3BEliyFsrbZmsy4l6mkxHlSmSiFlO1HlC1RSpsypUQ1kbVi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       "]]},
     Annotation[#, "Charting`Private`Tag$609050#2"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9500000020408162, 15.3},
  DisplayFunction->Identity,
  Epilog->{
    RGBColor[1, 0, 0], 
    LineBox[{{1, 0}, {1, 15.390906981438379`}}], 
    RGBColor[0, 0, 1], 
    Thickness[Large], 
    LineBox[{{1, 0}, {1, 15.323903010485342`}}]},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9500000020408162, 1.0499999979591836`}, {15.3, 15.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.741113612920267*^9, 3.7411136494528027`*^9, 3.74111399189845*^9, {
   3.7411140258228283`*^9, 3.7411140550238733`*^9}, 3.7411872406580677`*^9},
 CellLabel->
  "Out[665]=",ExpressionUUID->"1f0635da-f772-465e-a24d-0aef84b35be0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"qCost2", "[", " ", 
    RowBox[{"trueQuat", " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"qCost2", "[", " ", 
    RowBox[{"eigvecTestM", " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741114306293315*^9, 3.741114309535933*^9}, {
   3.741114373321447*^9, 3.741114379636636*^9}, 3.741187240658679*^9},
 CellLabel->
  "In[671]:=",ExpressionUUID->"6ee86164-df0f-41da-a46f-cc30cc1ea55f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.178181451927997`", ",", "4.166982600367653`"}], "}"}]], "Output",\

 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.74111431269838*^9, 3.741114379956793*^9, 
  3.741187240659252*^9},
 CellLabel->
  "Out[671]=",ExpressionUUID->"6c186f01-a527-4910-8a53-227a5ca69036"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qCost2", "[", 
      RowBox[{
       RowBox[{"slerp", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         "eigvecTestM", ",", "t"}], "]"}], ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"qCost2", "[", 
      RowBox[{
       RowBox[{"slerp", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "trueQuat",
          ",", "t"}], "]"}], ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", ".9", ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"4", ",", "4.3"}], "}"}]}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"qCost2", "[", 
            RowBox[{"eigvecTestM", ",", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", ",", " ", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}], "}"}], 
       "]"}], ",", "\[IndentingNewLine]", "Blue", ",", "Thick", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"qCost2", "[", 
            RowBox[{"trueQuat", ",", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", ",", " ", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}], "}"}], 
       "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741110763041937*^9, 3.7411107937258873`*^9}, {
   3.741114223353126*^9, 3.7411142325360327`*^9}, {3.74111427500249*^9, 
   3.74111428644973*^9}, {3.741114321728458*^9, 3.741114338154016*^9}, {
   3.741114396712062*^9, 3.7411144564639*^9}, 3.7411872406599617`*^9},
 CellLabel->
  "In[673]:=",ExpressionUUID->"3477b900-045b-4594-886b-f39e7e7b2770"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJw913k0ldv7AHAa3BJ6j6lQpnCUWyQZMjxvEkJyGyRDRcgUJbmJ3G7oq4iE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       "]]},
     Annotation[#, "Charting`Private`Tag$614755#1"]& ], 
    TagBox[
     {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd13k0Vd0bB3CSBlFHhpKIMtQrJRWh7CsaRFQqKRXKVIbMcwOhMlQyZJak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       "]]},
     Annotation[#, "Charting`Private`Tag$614755#2"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000040816327, 4},
  DisplayFunction->Identity,
  Epilog->{
    RGBColor[1, 0, 0], 
    LineBox[{{1, 0}, {1, 4.166982600367653}}], 
    RGBColor[0, 0, 1], 
    Thickness[Large], 
    LineBox[{{1, 0}, {1, 4.178181451927997}}]},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000040816327, 1.0999999959183675`}, {4, 4.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.741110794177268*^9, 3.741114248982663*^9, {3.741114335041156*^9, 
   3.741114349023985*^9}, 3.741114422398481*^9, 3.741114467490288*^9, 
   3.741187240660561*^9},
 CellLabel->
  "Out[673]=",ExpressionUUID->"c182d96a-6a0e-4b55-88e4-e18b66e2e05a"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qCost2", "[", 
      RowBox[{
       RowBox[{"slerp", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         "eigvecTestM", ",", "t"}], "]"}], ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"qCost2", "[", 
      RowBox[{
       RowBox[{"slerp", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         "trueQuat2", ",", "t"}], "]"}], ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
       RowBox[{"testa3DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", ".9", ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"4", ",", "4.3"}], "}"}]}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"qCost2", "[", 
            RowBox[{"eigvecTestM", ",", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", ",", " ", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}], "}"}], 
       "]"}], ",", "\[IndentingNewLine]", "Blue", ",", "Thick", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"qCost2", "[", 
            RowBox[{"trueQuat2", ",", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", ",", " ", 
             RowBox[{"testa3DFrm", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}], "}"}], 
       "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741110763041937*^9, 3.7411107937258873`*^9}, {
   3.741114223353126*^9, 3.7411142325360327`*^9}, {3.74111427500249*^9, 
   3.74111428644973*^9}, {3.741114321728458*^9, 3.741114338154016*^9}, {
   3.741114396712062*^9, 3.7411144564639*^9}, {3.741114678967041*^9, 
   3.7411146808110723`*^9}, 3.741187240661295*^9},
 CellLabel->
  "In[677]:=",ExpressionUUID->"e49eea1b-15eb-475c-a6e4-ac61634e8271"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJw913k0ldv7AHAa3BJ6j6lQpnCUWyQZMjxvEkJyGyRDRcgUJbmJ3G7oq4iE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       "]]},
     Annotation[#, "Charting`Private`Tag$616275#1"]& ], 
    TagBox[
     {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJw913k4VWsXAHBlSCH7iAbzTGTMZ4i8m4TMNzSYiiKVKbfrSoauuKVryCyU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       "]]},
     Annotation[#, "Charting`Private`Tag$616275#2"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000040816327, 4},
  DisplayFunction->Identity,
  Epilog->{
    RGBColor[1, 0, 0], 
    LineBox[{{1, 0}, {1, 4.166982600367653}}], 
    RGBColor[0, 0, 1], 
    Thickness[Large], 
    LineBox[{{1, 0}, {1, 4.166977121483677}}]},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000040816327, 1.0999999959183675`}, {4, 4.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741114693589786*^9, 3.74118724066187*^9},
 CellLabel->
  "Out[677]=",ExpressionUUID->"432357ba-9d9f-4bd6-a62b-556b36930bc2"],

Cell["\<\
THIS IS AMAZING. If true, we have a closed form arclength measure.\
\>", "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411234228573227`*^9, 3.7411234464029512`*^9}, 
   3.74118724066224*^9},ExpressionUUID->"accc498e-71ed-4c86-b46e-\
c58846cf9934"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"QuatToRot", "[", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], ".", 
    RowBox[{"QuatToRot", "[", 
     RowBox[{"{", 
      RowBox[{"p0", ",", 
       RowBox[{"-", "p1"}], ",", 
       RowBox[{"-", "p2"}], ",", 
       RowBox[{"-", "p3"}]}], "}"}], "]"}]}], "//", "Simplify"}], "//", 
  "Dimensions"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741123627733773*^9, 3.741123641216775*^9}, 
   3.741187240662846*^9},
 CellLabel->
  "In[683]:=",ExpressionUUID->"b27f67ff-6730-4d45-8fe7-7570663bb53b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "3"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741123617805595*^9, 3.7411236420172853`*^9}, 
   3.7411872406633587`*^9},
 CellLabel->
  "Out[683]=",ExpressionUUID->"057278a7-478b-48c6-93b9-434d5b2d1f67"],

Cell[BoxData[
 RowBox[{"bussForm", " ", "=", " ", 
  RowBox[{
   RowBox[{"metricFromForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}], 
      RowBox[{"Tr", "[", 
       RowBox[{
        RowBox[{"QuatToRot", "[", 
         RowBox[{"{", 
          RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], ".", 
        
        RowBox[{"QuatToRot", "[", 
         RowBox[{"{", 
          RowBox[{"p0", ",", 
           RowBox[{"-", "p1"}], ",", 
           RowBox[{"-", "p2"}], ",", 
           RowBox[{"-", "p3"}]}], "}"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741123460306321*^9, 3.741123539190877*^9}, {
   3.741123582252882*^9, 3.741123592477504*^9}, {3.741123668980468*^9, 
   3.74112368020851*^9}, 3.741187240663842*^9},
 CellLabel->
  "In[684]:=",ExpressionUUID->"a9334ba8-752e-4469-af07-1fbcb0209494"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["p0", "2"]}], "-", 
        SuperscriptBox["p1", "2"], "-", 
        SuperscriptBox["p2", "2"], "-", 
        SuperscriptBox["p3", "2"]}], ")"}]}], ",", 
     RowBox[{"2", " ", "p0", " ", "p1"}], ",", 
     RowBox[{"2", " ", "p0", " ", "p2"}], ",", 
     RowBox[{"2", " ", "p0", " ", "p3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "p0", " ", "p1"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p0", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p1", "2"]}], "-", 
        SuperscriptBox["p2", "2"], "-", 
        SuperscriptBox["p3", "2"]}], ")"}]}], ",", 
     RowBox[{"2", " ", "p1", " ", "p2"}], ",", 
     RowBox[{"2", " ", "p1", " ", "p3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "p0", " ", "p2"}], ",", 
     RowBox[{"2", " ", "p1", " ", "p2"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p0", "2"]}], "-", 
        SuperscriptBox["p1", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p2", "2"]}], "-", 
        SuperscriptBox["p3", "2"]}], ")"}]}], ",", 
     RowBox[{"2", " ", "p2", " ", "p3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "p0", " ", "p3"}], ",", 
     RowBox[{"2", " ", "p1", " ", "p3"}], ",", 
     RowBox[{"2", " ", "p2", " ", "p3"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p0", "2"]}], "-", 
        SuperscriptBox["p1", "2"], "-", 
        SuperscriptBox["p2", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p3", "2"]}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741123593393025*^9, 3.741123682289455*^9, 
  3.741187240664377*^9},
 CellLabel->
  "Out[684]=",ExpressionUUID->"470c5687-4c16-45f7-b765-ea147c5c823a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Tr", "[", "bussForm", "]"}], ",", 
      RowBox[{"Det", "[", "bussForm", "]"}], ",", 
      RowBox[{"Eigenvalues", "[", "bussForm", "]"}], ",", 
      RowBox[{"Eigenvectors", "[", "bussForm", "]"}]}], "}"}], "//", 
    "Simplify"}], ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["p0", "2"], "+", 
      SuperscriptBox["p1", "2"], "+", 
      SuperscriptBox["p2", "2"], "+", 
      SuperscriptBox["p3", "2"]}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["p0", "2"]}], "-", 
      SuperscriptBox["p1", "2"], "-", 
      SuperscriptBox["p2", "2"], "-", 
      SuperscriptBox["p3", "2"]}], "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "}"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.74112369509348*^9, 3.7411237213835297`*^9}, {
   3.7411237893567743`*^9, 3.741123826718522*^9}, 3.741187240665019*^9},
 CellLabel->
  "In[686]:=",ExpressionUUID->"0bd72bef-b924-4b5a-ae59-60e90386e48f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox["3", "16"]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["3", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p3", "p0"]}], ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "p0"]}], ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p1", "p0"]}], ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["p0", "p3"], ",", 
       FractionBox["p1", "p3"], ",", 
       FractionBox["p2", "p3"], ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",\

 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741123722143216*^9, 3.7411238278665743`*^9, 
  3.741187240665474*^9},
 CellLabel->
  "Out[686]=",ExpressionUUID->"9c136397-ebe0-405f-b56f-eb5e6348d8e5"],

Cell["Try a data form:", "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741123868181622*^9, 3.7411238749020452`*^9}, 
   3.7411872406658373`*^9},ExpressionUUID->"3fb5127f-bf44-47ce-a94b-\
04c6b82d841d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeQuatCMdata", "[", "qList_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "=", 
        RowBox[{"qList", "[", 
         RowBox[{"[", "k", "]"}], "]"}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["p0", "2"]}], "-", 
              SuperscriptBox["p1", "2"], "-", 
              SuperscriptBox["p2", "2"], "-", 
              SuperscriptBox["p3", "2"]}], ")"}]}], ",", 
           RowBox[{"2", " ", "p0", " ", "p1"}], ",", 
           RowBox[{"2", " ", "p0", " ", "p2"}], ",", 
           RowBox[{"2", " ", "p0", " ", "p3"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"2", " ", "p0", " ", "p1"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["p0", "2"]}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["p1", "2"]}], "-", 
              SuperscriptBox["p2", "2"], "-", 
              SuperscriptBox["p3", "2"]}], ")"}]}], ",", 
           RowBox[{"2", " ", "p1", " ", "p2"}], ",", 
           RowBox[{"2", " ", "p1", " ", "p3"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"2", " ", "p0", " ", "p2"}], ",", 
           RowBox[{"2", " ", "p1", " ", "p2"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["p0", "2"]}], "-", 
              SuperscriptBox["p1", "2"], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["p2", "2"]}], "-", 
              SuperscriptBox["p3", "2"]}], ")"}]}], ",", 
           RowBox[{"2", " ", "p2", " ", "p3"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"2", " ", "p0", " ", "p3"}], ",", 
           RowBox[{"2", " ", "p1", " ", "p3"}], ",", 
           RowBox[{"2", " ", "p2", " ", "p3"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["p0", "2"]}], "-", 
              SuperscriptBox["p1", "2"], "-", 
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["p3", "2"]}]}], ")"}]}]}], "}"}]}], "}"}]}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", 
        RowBox[{"Length", "[", "qList", "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.741123879693169*^9, 3.741124049344475*^9}, 
   3.7411872406663923`*^9},
 CellLabel->
  "In[687]:=",ExpressionUUID->"86c17a47-664e-461c-9329-2bd48e84f895"],

Cell[BoxData[
 RowBox[{"quatCMdata", " ", "=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"randomSphere3", "[", "100", "]"}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], "&"}], ")"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.74112406818089*^9, 3.741124139908189*^9}, {
   3.741138803111368*^9, 3.7411388335645742`*^9}, 3.741187240666802*^9},
 CellLabel->
  "In[702]:=",ExpressionUUID->"55864a24-f7d2-4ef7-b176-f8b46ac112d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.6087111673405788`", ",", 
     RowBox[{"-", "0.5119889120652877`"}], ",", 
     RowBox[{"-", "0.5934975861912901`"}], ",", 
     RowBox[{"-", "0.12287670186892609`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4459240077285204`", ",", "0.7900957137406945`", ",", 
     RowBox[{"-", "0.26419990956430317`"}], ",", 
     RowBox[{"-", "0.32725975958881826`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.07092702756220667`", ",", 
     RowBox[{"-", "0.2705069488098392`"}], ",", "0.5463841948213318`", ",", 
     "0.7894679594867836`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.26045159179712346`", ",", 
     RowBox[{"-", "0.3938790493917382`"}], ",", 
     RowBox[{"-", "0.2832787681773079`"}], ",", 
     RowBox[{"-", "0.8347319343840585`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4694548441967641`", ",", 
     RowBox[{"-", "0.7679656450542576`"}], ",", "0.23287937604503517`", ",", 
     "0.3682500692321256`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.18933832536763587`", ",", 
     RowBox[{"-", "0.6069748221225701`"}], ",", 
     RowBox[{"-", "0.6971445098564213`"}], ",", 
     RowBox[{"-", "0.33124325839676144`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5725660382245754`", ",", "0.10132168968980525`", ",", 
     "0.7538751834879394`", ",", "0.30589909249823277`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5768163037696414`", ",", "0.5961133193080653`", ",", 
     "0.5506439194449763`", ",", "0.09339773138210536`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.45722733115992964`", ",", 
     RowBox[{"-", "0.19755133215055481`"}], ",", 
     RowBox[{"-", "0.7558658088814182`"}], ",", "0.4249511945740932`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.06661585830148503`", ",", "0.03631002936563534`", ",", 
     RowBox[{"-", "0.1628982535895368`"}], ",", 
     RowBox[{"-", "0.9837215399531019`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.17746941891905418`", ",", 
     RowBox[{"-", "0.36739544189672974`"}], ",", 
     RowBox[{"-", "0.9059845608424852`"}], ",", 
     RowBox[{"-", "0.11277043112930447`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.1089988689873211`", ",", 
     RowBox[{"-", "0.4271070281472191`"}], ",", "0.46368381362732636`", ",", 
     RowBox[{"-", "0.7685675988790798`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7975059249395727`", ",", 
     RowBox[{"-", "0.08050376531806565`"}], ",", 
     RowBox[{"-", "0.570144709384939`"}], ",", "0.18010678448146772`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8423820927031553`", ",", 
     RowBox[{"-", "0.0953992888924041`"}], ",", "0.032243051494248665`", ",", 
     
     RowBox[{"-", "0.5293881101821385`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.474522567626505`", ",", 
     RowBox[{"-", "0.8057524468426105`"}], ",", "0.010328421007741749`", ",", 
     "0.35423812745070493`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.8423774401055225`", ",", "0.3530035374299287`", ",", 
     "0.3967034246991735`", ",", 
     RowBox[{"-", "0.09173409287266723`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.09012664893756096`", ",", 
     RowBox[{"-", "0.6057866811261589`"}], ",", 
     RowBox[{"-", "0.7900476047848777`"}], ",", 
     RowBox[{"-", "0.026915911560206344`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7886261619728588`", ",", 
     RowBox[{"-", "0.5476723335633904`"}], ",", 
     RowBox[{"-", "0.2673722305443926`"}], ",", "0.0814609233614808`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5638403511828858`", ",", "0.6101789362426735`", ",", 
     RowBox[{"-", "0.06364891723241516`"}], ",", 
     RowBox[{"-", "0.5529145860608677`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.47416354233109514`", ",", 
     RowBox[{"-", "0.3927353794376445`"}], ",", "0.7789743995288396`", ",", 
     "0.11885597057228804`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.791091835420169`", ",", "0.29564849917198677`", ",", 
     "0.5131374129840374`", ",", 
     RowBox[{"-", "0.15315243473399126`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7962554832457202`", ",", 
     RowBox[{"-", "0.5925530248073785`"}], ",", "0.12007853360195046`", ",", 
     RowBox[{"-", "0.02095862497293519`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.3080130086547766`", ",", "0.45182620685150165`", ",", 
     "0.50933552277513`", ",", 
     RowBox[{"-", "0.6644986008570684`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8183213650149268`", ",", 
     RowBox[{"-", "0.5235947519745557`"}], ",", 
     RowBox[{"-", "0.05504758948989832`"}], ",", 
     RowBox[{"-", "0.23058283144276365`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.3130465126858373`", ",", "0.6116842145740641`", ",", 
     "0.5923565508202647`", ",", "0.4206637840799529`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5663665767908156`", ",", "0.33748155092588494`", ",", 
     RowBox[{"-", "0.33980364235702043`"}], ",", "0.6707224374656141`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9493509858743653`", ",", 
     RowBox[{"-", "0.29345492488384967`"}], ",", 
     RowBox[{"-", "0.0019324342399308196`"}], ",", "0.11230840742657383`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.16821110323223648`", ",", 
     RowBox[{"-", "0.5512785357083598`"}], ",", "0.5594302387688963`", ",", 
     RowBox[{"-", "0.5956801228575754`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5481244984214884`", ",", "0.14247991375062127`", ",", 
     "0.3973282244856772`", ",", "0.722072912132055`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5155665241789601`", ",", "0.017841047567507658`", ",", 
     "0.576071142861019`", ",", "0.634046445089411`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.16876193162676278`", ",", "0.2872450106863088`", ",", 
     RowBox[{"-", "0.7899411478917412`"}], ",", 
     RowBox[{"-", "0.5147841267336287`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.9094223015559875`", ",", "0.35163085206168865`", ",", 
     "0.20483257331841886`", ",", 
     RowBox[{"-", "0.08573469670288525`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.06573285039727637`", ",", "0.05207989063082519`", ",", 
     "0.5749006895863117`", ",", 
     RowBox[{"-", "0.8139140461275464`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.20431041448392684`", ",", "0.8263250083585026`", ",", 
     RowBox[{"-", "0.17278168519039877`"}], ",", "0.4955711092845227`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.18998211119617628`", ",", 
     RowBox[{"-", "0.9109191319385356`"}], ",", "0.3402810847897584`", ",", 
     RowBox[{"-", "0.1354323293312713`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5683302728503323`", ",", 
     RowBox[{"-", "0.32127462317058103`"}], ",", "0.7555169909670496`", ",", 
     RowBox[{"-", "0.0545655003510744`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5208229689771938`", ",", "0.27049073175673266`", ",", 
     "0.8055597201230101`", ",", "0.08155817760853717`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.07379950304841046`", ",", "0.2509924178909106`", ",", 
     RowBox[{"-", "0.6759191871025062`"}], ",", 
     RowBox[{"-", "0.6889772797543976`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6101048087647022`", ",", 
     RowBox[{"-", "0.022330066569677273`"}], ",", 
     RowBox[{"-", "0.6658661822722098`"}], ",", "0.42883063994473636`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5797296293126256`", ",", "0.08401477700621897`", ",", 
     RowBox[{"-", "0.8048024821850772`"}], ",", "0.09564538049681012`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9885907757686154`", ",", 
     RowBox[{"-", "0.07585341881110381`"}], ",", "0.08224339190151642`", ",", 
     "0.10084920132756718`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.656791848205698`", ",", "0.036863887993527085`", ",", 
     RowBox[{"-", "0.7458448761395257`"}], ",", 
     RowBox[{"-", "0.10478999298100868`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.6234903617922284`", ",", "0.05439392144143199`", ",", 
     "0.7769707757128266`", ",", "0.06795206950952883`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.08591399394072259`", ",", 
     RowBox[{"-", "0.41293743670399113`"}], ",", "0.11828928383899887`", ",", 
     "0.8989488886151134`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.751090886018088`", ",", 
     RowBox[{"-", "0.6124125390917283`"}], ",", 
     RowBox[{"-", "0.01415901732595474`"}], ",", 
     RowBox[{"-", "0.2461968422465022`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.608934045558937`", ",", "0.20820935540098726`", ",", 
     RowBox[{"-", "0.16029763839972322`"}], ",", 
     RowBox[{"-", "0.7484336040065301`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5850093415490443`", ",", "0.4285539577591738`", ",", 
     RowBox[{"-", "0.5630258075062721`"}], ",", "0.39636790444133124`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3135372247462908`", ",", 
     RowBox[{"-", "0.6334715476225338`"}], ",", 
     RowBox[{"-", "0.5649305402394726`"}], ",", 
     RowBox[{"-", "0.42574839019759503`"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741138834513728*^9, 3.741187240667199*^9},
 CellLabel->
  "Out[702]=",ExpressionUUID->"f98c8aee-6a1c-4cda-b718-5f4e58331c38"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"Point", "[", 
   RowBox[{"Rest", "/@", "quatCMdata"}], "]"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741124183673059*^9, 3.741124207671225*^9}, 
   3.741187240667603*^9},
 CellLabel->
  "In[703]:=",ExpressionUUID->"3dd3a9e4-5963-4f89-8a06-ac9917228fd6"],

Cell[BoxData[
 Graphics3DBox[Point3DBox[CompressedData["
1:eJwNwwk0lAkcAHCP0r5KQkqnZS1RCm3u5p9OItQ+8iQkt+ysfTUSKTQmrbKU
I8n1arLYdtRMRjF/95lrBs3QZOb7DDOOojy2HG2/9356AdTTQcpKSkpm36t8
70c3yrAMkOCyky/zwxKB5sz5eeElxBG7kC6aowLC+zqqmfIe9G/aM8Gf6cNV
Jfn+i269+Ij4wv4aK4WZlBC304cVwBmZuuK+X4SNBylHD+jx0TKE5Om+HEeC
TWHtvidHM1+VN0tdnZCQqFoTmv4WfjzvTvO8SGJ1eKeSstsopoVdnty4rx9h
MHvYaroKduo4i3i6cuAupLSJ7gmgIiLwgI8WCVJ762/D+VKwTO5SKOSVQNlI
/dfHqQ07pozj1czkqC1tig+2GAKyyzHMNrsY2GuHs0WiRqxd4Zbz5OpH7PBU
7ApNeovrFqgegqVJfLTwVEp/X41Ke/6o5HoM4Ryrc3i5XAxVkTytrTlyfDJH
UZc9ZOMz2uYdhRQC9X3SLWvUWiCrfjBm40UuHuw5f9w4sRBmPyd54LQE7e8s
eFe1KrC84P4+DSM6BIZtDhooG4BN6TsN87IHwFPAr8+6IAKThR4WEVuJQQ5f
MDeAxMKKLeMajgosSs0AYdpDpNAt9G4lS7FhKTG8cFsvnjlVk1AwyIZJ0cKX
zGQSGIHTRc7OLNTJ0/oQUyHFsH9KM+7pi3B3lQv37JQczPtvn/CK5IGQ0fBs
bIIPqkOkYUGEBGy3U2qu5zYg23yg3nyOwNfFTfHRNTywqXNLMqVlYn5bTDR3
/B1M/1qofNVFAt4h4vSMwzKM6VFudaqTYMM5kwcWe8sxMfyHxeqkThQE6zeP
Z5BwamVZVeYsAc6ru9uNJgeB4K6zdnnQD7lrsPkM9iOd9mL0Lk0GNrGuJvMt
fOSITKOt/vbDavpcKKW2GgI97AjNx1L8uhhHGRyVgk5+b323Oon7Sj8ZtNrX
g2ZwnI8gUgRcuZhpvXUMnle6UyePZEC7vRB3UwlQfW3TtPXECNimcWTWAXzY
9DK+xOK4AqOO5KZti5HgIjOatSNhAIS/txjPWrVDa9mVZM4nDq5v1zK0Ki0F
mSZDLyuIgHMf7K5krhnHpltCA4eocXjeli/gbG9GXNNFUCuHwclBVwqGU3jj
8VN3k5Z+4B1icoUedbjSm6Q2pPVhsOC/eXNTOUy8XfZVni7DktUVZ7luvXB2
LM/05xYFpHalGn+TsEFQmnPj0PoeoKpEHNMrkqHqb4wNW9aOov21lOAKcRbS
yD9zml1lqBNN15iLGoIorwL15QQOeO3N1p+pVSDtJOy3iuOCtp+2uV7EC2Rd
YhiOqXHALpPRf7C3ClL6yvj84WIgNcSac+IxtNnb6XVT8Aqf+Af8RBeVQbLL
bM/MOzkk7DqQ6hpUATEqcQbpkYMYcOyu+BdHHhhsKL9s1jgJPNn5PUQOidpG
7/VDvqVikVTxxj+pGzv+0i7NZbZDYcMxteKbjXjy451Vuz6P4atQp/uRkUPQ
cqHuuesKArvzWHGbfEVwjXFdN/joCMYR3pYKLQIHTqwzpcEQ/g8CynxM
   "]],
  ImageSize->{303.0437820566285, 327.6373321962694},
  ImageSizeRaw->Automatic,
  ViewPoint->{0.55842156734127, -3.3078514728258552`, 0.443039486786378},
  ViewVertical->{0.007346145502237841, -0.5045173339931914, 
   0.8736716360159225}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741124202589683*^9, 3.741124208198083*^9}, 
   3.741138847249777*^9, 3.741187240667989*^9},
 CellLabel->"Out[703]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"d5a618ae-cecf-4cbb-a78e-daf4917956e2"],

Cell[BoxData[
 RowBox[{"qCMMatrix4", "=", 
  RowBox[{"makeQuatCMdata", "[", "quatCMdata", " ", "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741124226971149*^9, 3.741124270747219*^9}, {
   3.741133099389814*^9, 3.7411331077739277`*^9}, {3.741138854649282*^9, 
   3.741138857530841*^9}, 3.741187240668399*^9},
 CellLabel->
  "In[704]:=",ExpressionUUID->"3e40daa9-4235-48cd-a230-4e5ff48cd945"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5.268076672457812`", ",", 
     RowBox[{"-", "2.590656792802759`"}], ",", "0.8795973836261006`", ",", 
     "0.05894478800856051`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.590656792802759`"}], ",", 
     RowBox[{"-", "4.505988868981172`"}], ",", "2.0274495981337757`", ",", 
     "0.7886843652088218`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.8795973836261006`", ",", "2.0274495981337757`", ",", 
     "2.396358450384567`", ",", "2.4442750742834645`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.05894478800856051`", ",", "0.7886843652088218`", ",", 
     "2.4442750742834645`", ",", 
     RowBox[{"-", "3.158446253861208`"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741124232836935*^9, 3.741124271730268*^9, 
  3.74113310873552*^9, 3.741138858262184*^9, 3.741187240668787*^9},
 CellLabel->
  "Out[704]=",ExpressionUUID->"9a51d2d6-4edc-4566-a178-52306ac3e5ac"],

Cell[BoxData[
 RowBox[{"Eigenvalues", "[", "qCMMatrix4", "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411243010345488`*^9, 3.741124301914769*^9}, 
   3.741187240669199*^9},
 CellLabel->
  "In[705]:=",ExpressionUUID->"167021a7-c3c3-4337-9b7b-1f4cd53600dc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.95875141907519`", ",", 
   RowBox[{"-", "5.7429750476155785`"}], ",", 
   RowBox[{"-", "4.086240350167537`"}], ",", "3.870463978707929`"}], 
  "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741124302600534*^9, 3.7411331126012*^9, 
  3.741138864920928*^9, 3.741187240669587*^9},
 CellLabel->
  "Out[705]=",ExpressionUUID->"217c2f7e-b43f-44e6-b494-dbe0c739a378"],

Cell[BoxData[
 RowBox[{"Eigenvectors", "[", "qCMMatrix4", "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741124279346409*^9, 3.741124288266494*^9}, 
   3.7411872406699877`*^9},
 CellLabel->
  "In[706]:=",ExpressionUUID->"b3857005-e286-4cd3-a218-387f5dd183b1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9676782846181645`", ",", 
     RowBox[{"-", "0.21155861159131692`"}], ",", "0.1351185431164041`", ",", 
     "0.02417996373241602`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.24029546051222106`"}], ",", 
     RowBox[{"-", "0.9382682781538484`"}], ",", "0.24030385795325282`", ",", 
     "0.06453515104355856`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.018638088621589576`", ",", 
     RowBox[{"-", "0.029132209129402287`"}], ",", 
     RowBox[{"-", "0.3468252914915151`"}], ",", "0.9372919252962761`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.07422567472377517`", ",", 
     RowBox[{"-", "0.27211561231029624`"}], ",", 
     RowBox[{"-", "0.8964983281304596`"}], ",", 
     RowBox[{"-", "0.3416641485553964`"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7411242888009357`*^9, 3.741133117098501*^9, 
  3.741138871262786*^9, 3.741187240670415*^9},
 CellLabel->
  "Out[706]=",ExpressionUUID->"d98a107d-6c95-4e63-bdc7-7df6cff9118c"],

Cell[BoxData[
 RowBox[{"evec", " ", "=", " ", 
  RowBox[{"%", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.74113887999257*^9, 3.741138886010494*^9}, 
   3.741187240670874*^9},
 CellLabel->
  "In[707]:=",ExpressionUUID->"0db90163-6aef-4a8c-9d4b-5a6e36809fe1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9676782846181645`", ",", 
   RowBox[{"-", "0.21155861159131692`"}], ",", "0.1351185431164041`", ",", 
   "0.02417996373241602`"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741138887121163*^9, 3.7411872406712713`*^9},
 CellLabel->
  "Out[707]=",ExpressionUUID->"5c1fb435-575f-454b-b499-b5f3fc8a96d3"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Point", "[", 
     RowBox[{"Rest", "/@", "quatCMdata"}], " ", "]"}], ",", "Red", ",", 
    RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
    RowBox[{"Point", "[", 
     RowBox[{"Rest", "[", "evec", "]"}], "]"}]}], "}"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741124321641571*^9, 3.741124385626594*^9}, {
   3.7411331274494867`*^9, 3.741133135885776*^9}, {3.741138893402524*^9, 
   3.7411389063071127`*^9}, 3.741187240671685*^9},
 CellLabel->
  "In[708]:=",ExpressionUUID->"d0c86b0c-cf85-4829-ba9b-222076e4e820"],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[CompressedData["
1:eJwNwwk0lAkcAHCP0r5KQkqnZS1RCm3u5p9OItQ+8iQkt+ysfTUSKTQmrbKU
I8n1arLYdtRMRjF/95lrBs3QZOb7DDOOojy2HG2/9356AdTTQcpKSkpm36t8
70c3yrAMkOCyky/zwxKB5sz5eeElxBG7kC6aowLC+zqqmfIe9G/aM8Gf6cNV
Jfn+i269+Ij4wv4aK4WZlBC304cVwBmZuuK+X4SNBylHD+jx0TKE5Om+HEeC
TWHtvidHM1+VN0tdnZCQqFoTmv4WfjzvTvO8SGJ1eKeSstsopoVdnty4rx9h
MHvYaroKduo4i3i6cuAupLSJ7gmgIiLwgI8WCVJ762/D+VKwTO5SKOSVQNlI
/dfHqQ07pozj1czkqC1tig+2GAKyyzHMNrsY2GuHs0WiRqxd4Zbz5OpH7PBU
7ApNeovrFqgegqVJfLTwVEp/X41Ke/6o5HoM4Ryrc3i5XAxVkTytrTlyfDJH
UZc9ZOMz2uYdhRQC9X3SLWvUWiCrfjBm40UuHuw5f9w4sRBmPyd54LQE7e8s
eFe1KrC84P4+DSM6BIZtDhooG4BN6TsN87IHwFPAr8+6IAKThR4WEVuJQQ5f
MDeAxMKKLeMajgosSs0AYdpDpNAt9G4lS7FhKTG8cFsvnjlVk1AwyIZJ0cKX
zGQSGIHTRc7OLNTJ0/oQUyHFsH9KM+7pi3B3lQv37JQczPtvn/CK5IGQ0fBs
bIIPqkOkYUGEBGy3U2qu5zYg23yg3nyOwNfFTfHRNTywqXNLMqVlYn5bTDR3
/B1M/1qofNVFAt4h4vSMwzKM6VFudaqTYMM5kwcWe8sxMfyHxeqkThQE6zeP
Z5BwamVZVeYsAc6ru9uNJgeB4K6zdnnQD7lrsPkM9iOd9mL0Lk0GNrGuJvMt
fOSITKOt/vbDavpcKKW2GgI97AjNx1L8uhhHGRyVgk5+b323Oon7Sj8ZtNrX
g2ZwnI8gUgRcuZhpvXUMnle6UyePZEC7vRB3UwlQfW3TtPXECNimcWTWAXzY
9DK+xOK4AqOO5KZti5HgIjOatSNhAIS/txjPWrVDa9mVZM4nDq5v1zK0Ki0F
mSZDLyuIgHMf7K5krhnHpltCA4eocXjeli/gbG9GXNNFUCuHwclBVwqGU3jj
8VN3k5Z+4B1icoUedbjSm6Q2pPVhsOC/eXNTOUy8XfZVni7DktUVZ7luvXB2
LM/05xYFpHalGn+TsEFQmnPj0PoeoKpEHNMrkqHqb4wNW9aOov21lOAKcRbS
yD9zml1lqBNN15iLGoIorwL15QQOeO3N1p+pVSDtJOy3iuOCtp+2uV7EC2Rd
YhiOqXHALpPRf7C3ClL6yvj84WIgNcSac+IxtNnb6XVT8Aqf+Af8RBeVQbLL
bM/MOzkk7DqQ6hpUATEqcQbpkYMYcOyu+BdHHhhsKL9s1jgJPNn5PUQOidpG
7/VDvqVikVTxxj+pGzv+0i7NZbZDYcMxteKbjXjy451Vuz6P4atQp/uRkUPQ
cqHuuesKArvzWHGbfEVwjXFdN/joCMYR3pYKLQIHTqwzpcEQ/g8CynxM
    "]], 
   {RGBColor[1, 0, 0], PointSize[0.02], 
    Point3DBox[{-0.21155861159131692`, 0.1351185431164041, 
     0.02417996373241602}]}},
  ImageSize->{301.73097563605603`, 312.32266171579},
  ImageSizeRaw->Automatic,
  ViewPoint->{3.1345607767387214`, -1.097436380231506, 0.6481991424520026},
  ViewVertical->{0.4434260595264393, -0.1266401231378525, 
   0.9051641439764749}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411243817329597`*^9, 3.741124386029572*^9}, 
   3.741133143790368*^9, 3.741138908903152*^9, 3.74118724067208*^9},
 CellLabel->
  "Out[708]=",ExpressionUUID->"6cca2a41-df60-4f6b-bed2-516dce91453a"],

Cell[BoxData[
 RowBox[{"distlist", " ", "=", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"ArcCos", "[", 
     RowBox[{"evec", ".", 
      RowBox[{"quatCMdata", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"Length", "[", "quatCMdata", "]"}]}], "}"}]}], "]"}]}]], "Input",\

 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741138928734488*^9, 3.741138963146742*^9}, {
   3.741138993626429*^9, 3.741139037970051*^9}, 3.7411872406725197`*^9},
 CellLabel->
  "In[709]:=",ExpressionUUID->"a8ab30c8-8646-4bc1-8f47-df43004a44e7"],

Cell[BoxData["49.30608221411928`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741139038881831*^9, 3.7411872406729097`*^9},
 CellLabel->
  "Out[709]=",ExpressionUUID->"856450b2-027a-4e7c-8174-154ec16b14b3"],

Cell[BoxData["evec"], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139226523775*^9, 3.741139227376505*^9}, 
   3.741187240673463*^9},
 CellLabel->
  "In[710]:=",ExpressionUUID->"fdb0c79b-5f6d-4046-b864-4870b3f3442c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9676782846181645`", ",", 
   RowBox[{"-", "0.21155861159131692`"}], ",", "0.1351185431164041`", ",", 
   "0.02417996373241602`"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741139228313262*^9, 3.7411872406740227`*^9},
 CellLabel->
  "Out[710]=",ExpressionUUID->"82c852f1-47f9-4eaa-953e-1ec81e900a4d"],

Cell[BoxData[
 RowBox[{"quatCMdata", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139365566299*^9, 3.741139366390675*^9}, 
   3.741187240674432*^9},
 CellLabel->
  "In[712]:=",ExpressionUUID->"068b90ea-e0f6-4043-8ddd-c1a8fdc2c0c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.4459240077285204`", ",", "0.7900957137406945`", ",", 
   RowBox[{"-", "0.26419990956430317`"}], ",", 
   RowBox[{"-", "0.32725975958881826`"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741139366821703*^9, 3.741187240674856*^9},
 CellLabel->
  "Out[712]=",ExpressionUUID->"c98f09e3-b9d8-43e8-b040-0e9a9ec4c466"],

Cell[BoxData[
 RowBox[{
  RowBox[{"minRuleE", "=", 
   RowBox[{"FindMinimum", "[", 
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"ArcCos", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             SuperscriptBox["q0", "2"], "+", 
             SuperscriptBox["q1", "2"], "+", 
             SuperscriptBox["q2", "2"], "+", 
             SuperscriptBox["q3", "2"]}], "]"}]}], ")"}], ".", 
         RowBox[{"quatCMdata", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", 
         RowBox[{"Length", "[", "quatCMdata", "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139046402824*^9, 3.7411390869034653`*^9}, {
   3.741139121728376*^9, 3.741139124336134*^9}, {3.7411391630174713`*^9, 
   3.741139221208755*^9}, {3.7411392800385103`*^9, 3.741139287656581*^9}, {
   3.7411393763464823`*^9, 3.7411393820705433`*^9}, 3.741187240675318*^9},
 CellLabel->
  "In[713]:=",ExpressionUUID->"b9ff3da9-a3ba-4f70-a50c-4664ca21e146"],

Cell[BoxData[
 TemplateBox[{
  "FindMinimum","lstol",
   "\"The line search decreased the step size to within the tolerance \
specified by AccuracyGoal and PrecisionGoal but was unable to find a \
sufficient decrease in the function. You may need more than \\!\\(\\*RowBox[{\
\\\"MachinePrecision\\\"}]\\) digits of working precision to meet these \
tolerances.\"",2,713,138,27320936865651559573,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741139328621847*^9, 3.74113943190967*^9, 
  3.741187240675561*^9},
 CellLabel->
  "During evaluation of \
In[713]:=",ExpressionUUID->"7929fe3b-5f09-48f9-92f3-8faf1eac02c2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"48.91288672339179`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q0", "\[Rule]", "2.8450080662647905`"}], ",", 
     RowBox[{"q1", "\[Rule]", 
      RowBox[{"-", "0.6000576714708266`"}]}], ",", 
     RowBox[{"q2", "\[Rule]", 
      RowBox[{"-", "0.0022382752713001907`"}]}], ",", 
     RowBox[{"q3", "\[Rule]", 
      RowBox[{"-", "0.1859002793875777`"}]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741139328680331*^9, 3.741139431937641*^9, 
  3.7411872406761*^9},
 CellLabel->
  "Out[713]=",ExpressionUUID->"b31da96a-3f8c-448c-8dc0-d0bb3986618a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Normalize", "@", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "/.", 
  RowBox[{"minRuleE", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139498210258*^9, 3.7411395070060053`*^9}, 
   3.741187240676515*^9},
 CellLabel->
  "In[717]:=",ExpressionUUID->"0ccae733-5729-4946-8454-d5ea87914d00"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9764787715802297`", ",", 
   RowBox[{"-", "0.20595497948250485`"}], ",", 
   RowBox[{"-", "0.0007682327207764742`"}], ",", 
   RowBox[{"-", "0.06380568076600603`"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139481202753*^9, 3.7411395081446753`*^9}, 
   3.741187240676903*^9},
 CellLabel->
  "Out[717]=",ExpressionUUID->"1389bc41-91e4-4496-941a-8a0582e11248"],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"svec", " ", "=", 
     RowBox[{
      RowBox[{"Normalize", "@", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "/.", 
      RowBox[{"minRuleE", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"ArcCos", "[", 
      RowBox[{"svec", ".", 
       RowBox[{"quatCMdata", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"Length", "[", "quatCMdata", "]"}]}], "}"}]}], "]"}]}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139247398758*^9, 3.741139318126988*^9}, {
   3.741139458389653*^9, 3.741139459254807*^9}, {3.741139513706451*^9, 
   3.741139520421929*^9}, 3.741187240677471*^9},
 CellLabel->
  "In[718]:=",ExpressionUUID->"d6539c4d-5f53-400f-847f-1e76aaf15ac8"],

Cell[BoxData["48.91288672339181`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411394490415993`*^9, 3.7411394599023027`*^9}, 
   3.741139521304597*^9, 3.741187240677869*^9},
 CellLabel->
  "Out[718]=",ExpressionUUID->"7b20b040-353f-4db3-bb9b-39ad69916f7a"],

Cell[TextData[StyleBox["Try again with square:",
 FontSize->16]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741186377370928*^9, 3.741186380982183*^9}, 
   3.7411872406781273`*^9},ExpressionUUID->"1b50adad-2f1d-46ac-8120-\
d2413bf9e127"],

Cell[BoxData[
 RowBox[{"minRuleE2", "=", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"ArcCos", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              SuperscriptBox["q0", "2"], "+", 
              SuperscriptBox["q1", "2"], "+", 
              SuperscriptBox["q2", "2"], "+", 
              SuperscriptBox["q3", "2"]}], "]"}]}], ")"}], ".", 
          RowBox[{"quatCMdata", "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ")"}], "2"], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", 
        RowBox[{"Length", "[", "quatCMdata", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139046402824*^9, 3.7411390869034653`*^9}, {
   3.741139121728376*^9, 3.741139124336134*^9}, {3.7411391630174713`*^9, 
   3.741139221208755*^9}, {3.7411392800385103`*^9, 3.741139287656581*^9}, {
   3.7411393763464823`*^9, 3.7411393820705433`*^9}, {3.7411863872716293`*^9, 
   3.7411864225342073`*^9}, 3.741187240678536*^9},
 CellLabel->
  "In[720]:=",ExpressionUUID->"f5f0a952-c8f6-41c2-8e0f-3a8a3d0bdf32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"55.41340635611865`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q0", "\[Rule]", "637.5135739109783`"}], ",", 
     RowBox[{"q1", "\[Rule]", 
      RowBox[{"-", "99.89514194499031`"}]}], ",", 
     RowBox[{"q2", "\[Rule]", 
      RowBox[{"-", "7.605518447344281`"}]}], ",", 
     RowBox[{"q3", "\[Rule]", 
      RowBox[{"-", "67.365335437053`"}]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741186443668182*^9, 3.741187240678931*^9},
 CellLabel->
  "Out[720]=",ExpressionUUID->"c1f0072f-17b8-412e-aba8-2116eb38a59e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Normalize", "@", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "/.", 
  RowBox[{"minRuleE2", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139498210258*^9, 3.7411395070060053`*^9}, 
   3.741186429754983*^9, 3.741187240679352*^9},
 CellLabel->
  "In[721]:=",ExpressionUUID->"70eabe11-ee9a-4115-830b-7f5762c51d57"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9825375278837989`", ",", 
   RowBox[{"-", "0.15395864469536397`"}], ",", 
   RowBox[{"-", "0.011721644211722712`"}], ",", 
   RowBox[{"-", "0.1038236248670487`"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741186450171611*^9, 3.741187240679739*^9},
 CellLabel->
  "Out[721]=",ExpressionUUID->"f2d6c94c-34b1-4137-9e74-e18174657ba9"],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"svec", " ", "=", 
     RowBox[{
      RowBox[{"Normalize", "@", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "/.", 
      RowBox[{"minRuleE2", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"ArcCos", "[", 
      RowBox[{"svec", ".", 
       RowBox[{"quatCMdata", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"Length", "[", "quatCMdata", "]"}]}], "}"}]}], "]"}]}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139247398758*^9, 3.741139318126988*^9}, {
   3.741139458389653*^9, 3.741139459254807*^9}, {3.741139513706451*^9, 
   3.741139520421929*^9}, 3.7411864655126657`*^9, 3.741187240680193*^9},
 CellLabel->
  "In[723]:=",ExpressionUUID->"9bb0ef62-903b-4510-aaac-7da358a751c3"],

Cell[BoxData["48.9713072406812`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741186458241005*^9, 3.741186470454233*^9}, 
   3.741187240680604*^9},
 CellLabel->
  "Out[723]=",ExpressionUUID->"bf868468-c473-464a-9b98-36b7bce4449c"],

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{"ArcCos", "[", 
    RowBox[{"evec", ".", 
     RowBox[{"quatCMdata", "[", 
      RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "quatCMdata", "]"}]}], "}"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741186535980299*^9, 3.741186536420742*^9}, 
   3.741187240681027*^9},
 CellLabel->
  "In[724]:=",ExpressionUUID->"70934af3-2f83-473f-b11f-6a98e0cc0a17"],

Cell[BoxData["49.30608221411928`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741186538697694*^9, 3.7411872406814213`*^9},
 CellLabel->
  "Out[724]=",ExpressionUUID->"87887f14-ef6e-4106-9dfb-54f73f819e53"],

Cell["\<\
The FindMinimum  gets a quaternion with a smaller cost by   0.8 %.
To solve Buss Fillmore, we need 0.0%.  Can this be done?\
\>", "Subsubsection",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411396607957897`*^9, 3.7411396786839952`*^9}, {
   3.741139724010335*^9, 3.741139761203497*^9}, 
   3.7411872406816673`*^9},ExpressionUUID->"10ab4eae-4529-4436-b760-\
554553358ef2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"49.30608221411928`", " ", "-", "48.91288672339181`"}], ")"}], "*", 
  RowBox[{"100", "/", "48.91288672339181`"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741187240682078*^9},
 CellLabel->
  "In[726]:=",ExpressionUUID->"990ba5f9-0720-4aca-bada-bb467337d5ee"],

Cell[BoxData["0.8038689128103167`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741186623493238*^9, 3.741187240682477*^9},
 CellLabel->
  "Out[726]=",ExpressionUUID->"43ff589f-34f0-4690-8e83-99bb612101f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"49.30608221411928`", " ", "-", "48.9713072406812`"}], ")"}], "*", 
  
  RowBox[{"100", "/", "48.9713072406812`"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741139702026909*^9, 3.7411397188346167`*^9}, {
   3.741186590727572*^9, 3.741186620456587*^9}, 3.741187240682899*^9},
 CellLabel->
  "In[727]:=",ExpressionUUID->"e5d1ba4a-442e-4fcb-8a4e-63d8aaec4b84"],

Cell[BoxData["0.6836145332873148`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7411397197009373`*^9, 3.7411865945831842`*^9, 
  3.7411866270262833`*^9, 3.741187240683313*^9},
 CellLabel->
  "Out[727]=",ExpressionUUID->"45eb4c31-0c1b-4747-b510-2f0277840125"],

Cell[BoxData[" "], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741139320812686*^9, 
  3.741187240683722*^9},ExpressionUUID->"17399dac-047f-4793-a4d2-\
158316e61fbe"],

Cell[BoxData[" "], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741139322270054*^9, 
  3.741187240684102*^9},ExpressionUUID->"ff4b30bf-a48c-4a09-9cc0-\
992a9df62cd2"],

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
     RowBox[{"testa3DFrm", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", "4"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741107988672085*^9, 3.7411080248764544`*^9}, 
   3.7411872406845007`*^9},
 CellLabel->
  "In[630]:=",ExpressionUUID->"7d67ce46-f748-4c22-af89-09cb518b1362"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.8136313725568916`"}], ",", "0.10424700981981341`", 
        ",", 
        RowBox[{"-", "0.4465056815293834`"}], ",", 
        RowBox[{"-", "0.3574482156855694`"}]}], "}"}], ",", 
      RowBox[{"\[LeftSkeleton]", "98", "\[RightSkeleton]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5746097858850512`"}], ",", 
        RowBox[{"-", "0.02293209650944948`"}], ",", "0.31334135655856116`", 
        ",", "0.7557214481439953`"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.871631337751526`"}], ",", 
        RowBox[{"-", "0.0019814692798710834`"}], ",", 
        RowBox[{"-", 
         RowBox[{"\[LeftSkeleton]", "20", "\[RightSkeleton]"}]}], ",", 
        RowBox[{"-", "0.1650541834892486`"}]}], "}"}], ",", 
      RowBox[{"\[LeftSkeleton]", "98", "\[RightSkeleton]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}]}], "}"}]}],
    "}"}],
  Short[#, 4]& ]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741108014086141*^9, 3.741108026081756*^9}, 
   3.7411872406848927`*^9},
 CellLabel->
  "Out[630]//Short=",ExpressionUUID->"bcb08ad1-4bf4-43e9-b65e-96b08a2fc987"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quickqFrmMeasure", "[", 
   RowBox[{"q_", ",", "testData_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FrmTgt", " ", "=", " ", 
       RowBox[{"testData", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"FrmRef", "=", 
       RowBox[{"testData", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", "rot"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Sum", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"quatmat4", "[", "q", "]"}], ".", " ", 
             RowBox[{"FrmTgt", "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], " ", ")"}], ".", 
           RowBox[{"FrmRef", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], "]"}], "]"}], ")"}], "2"], ",", 
      
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", 
        RowBox[{"Length", "[", "FrmRef", "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.741107815527973*^9, 3.7411079269480953`*^9}, {
   3.741107967776965*^9, 3.741107975512994*^9}, {3.7411080355358963`*^9, 
   3.741108142287888*^9}, {3.741108230438682*^9, 3.741108262990878*^9}, {
   3.741108313500093*^9, 3.7411083304879837`*^9}, {3.7411084087422333`*^9, 
   3.741108418739448*^9}, {3.74110848559028*^9, 3.741108487426611*^9}, 
   3.7411872406853657`*^9},
 CellLabel->
  "In[632]:=",ExpressionUUID->"9a7328b6-d332-4895-99a5-03dff0d1c29f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.983838857597438`", ",", "0.0026958804682577367`", ",", 
   "0.013005086797480062`", ",", 
   RowBox[{
    RowBox[{"-", "0.31492073763500855`."}], "testMMmat"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.983838857597438`", ",", "0.0026958804682577367`", ",", 
     "0.013005086797480062`", ",", 
     RowBox[{"-", "0.31492073763500855`"}]}]}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.74111071875429*^9, 3.7411107284552717`*^9}, 
   3.741187240685758*^9},ExpressionUUID->"85b13877-8052-4695-b268-\
a7676c263c9f"],

Cell[BoxData[
 RowBox[{"quickqFrmMeasure", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.983838857597438`", ",", "0.0026958804682577367`", ",", 
     "0.013005086797480062`", ",", 
     RowBox[{"-", "0.31492073763500855`"}]}], "}"}], ",", "testa3DFrm"}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741108439020482*^9, 3.7411084795403547`*^9}, 
   3.741187240686318*^9},
 CellLabel->
  "In[633]:=",ExpressionUUID->"0ab03119-8da4-44b2-ace1-298921ce5d3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4.3684990788442315`"}], "+", 
  RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741108492199864*^9, 3.741187240686713*^9},
 CellLabel->
  "Out[633]=",ExpressionUUID->"f4548690-3d03-42ab-9d0c-0965f5fb7ca4"],

Cell[BoxData[
 RowBox[{"quickqFrmMeasure", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.983838857597438`", ",", 
     RowBox[{"-", "0.0026958804682577367`"}], ",", 
     RowBox[{"-", "0.013005086797480062`"}], ",", "0.31492073763500855`"}], 
    "}"}], ",", "testa3DFrm"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741108439020482*^9, 3.7411084795403547`*^9}, {
   3.7411086014776297`*^9, 3.741108607235547*^9}, 3.7411872406871347`*^9},
 CellLabel->
  "In[634]:=",ExpressionUUID->"8f488b73-e911-432e-98ce-29a2909c098f"],

Cell[BoxData["21.452579957086297`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741108609373989*^9, 3.7411872406875277`*^9},
 CellLabel->
  "Out[634]=",ExpressionUUID->"b33cef65-6f12-4e7d-9894-3fdbaeff6f84"],

Cell[BoxData[
 RowBox[{"quickqFrmMeasure", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.9792171403627875`", ",", "0.003592334333214316`", ",", 
     "0.0003948989172451336`", ",", 
     RowBox[{"-", "0.20278247263658802`"}]}], "}"}], ",", "testa3DFrm"}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741108439020482*^9, 3.7411084795403547`*^9}, {
   3.7411086014776297`*^9, 3.741108607235547*^9}, 3.7411087495304823`*^9, 
   3.7411872406879387`*^9},
 CellLabel->
  "In[635]:=",ExpressionUUID->"635c8f76-965a-4a4c-a099-96a3996809e2"],

Cell[BoxData["1.0417456500919164`"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741108755192769*^9, 3.741187240688341*^9},
 CellLabel->
  "Out[635]=",ExpressionUUID->"459764e0-4716-4057-ad98-69c95366811c"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Module", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q0exact", "=", 
       RowBox[{"{", 
        RowBox[{
        "0.983838857597438`", ",", "0.0026958804682577367`", ",", 
         "0.013005086797480062`", ",", 
         RowBox[{"-", "0.31492073763500855`"}]}], "}"}]}], ",", " ", 
      RowBox[{"q0RRR", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
        "0.9792171403627875`", ",", "0.003592334333214316`", ",", 
         "0.0003948989172451336`", ",", 
         RowBox[{"-", "0.20278247263658802`"}]}], "}"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ParametricPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"Chop", "@", 
           RowBox[{"quickqFrmMeasure", "[", 
            RowBox[{
             RowBox[{"slerp", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
               "q0exact", ",", "t"}], "]"}], ",", "testa3DFrm"}], "]"}]}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"Chop", "@", 
           RowBox[{"quickqFrmMeasure", "[", 
            RowBox[{
             RowBox[{"slerp", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
               "q0RRR", ",", "t"}], "]"}], ",", "testa3DFrm"}], "]"}]}]}], 
         "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "3"}], "}"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Epilog", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"quickqFrmMeasure", "[", " ", 
               RowBox[{"q0exact", ",", " ", "testa3DFrm"}], "]"}]}], "}"}]}], 
           "}"}], "]"}], ",", "\[IndentingNewLine]", "Blue", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"quickqFrmMeasure", "[", " ", 
               RowBox[{"q0RRR", ",", " ", "testa3DFrm"}], "]"}]}], "}"}]}], 
           "}"}], "]"}]}], "}"}]}]}], "]"}]}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411087925921307`*^9, 3.741109089715542*^9}, {
   3.741109127635919*^9, 3.741109166560622*^9}, {3.74110922197093*^9, 
   3.741109327223987*^9}, 3.741187240688837*^9},
 CellLabel->
  "In[640]:=",ExpressionUUID->"004f4e01-2402-4966-a62d-87569983ca1c"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      LineBox[{{0., 5.206378233803604}, {0.0009200925371890843, 
       5.194503942899878}, {0.0018401850743781686`, 5.182635299305456}, {
       0.003680370148756337, 5.158914954008587}, {0.007360740297512674, 
       5.111542030731872}, {0.014721480595025349`, 5.0170672514437795`}, {
       0.029442961190050698`, 4.829201945960111}, {0.058885922380101395`, 
       4.4578082205414225`}, {0.12272501003188614`, 3.6724016450177586`}, {
       0.18233358948596648`, 2.963581407748523}, {0.18651068370632465`, 
       2.914798997734778}}], 
      LineBox[{{0.241568971455552, 2.2826724288578446`}, {0.262843963285638, 
       2.0438279788769242`}}], 
      LineBox[{{0.301549913896607, 1.6170344601337614`}, {0.3035765699246061, 
       1.594962628171065}}], 
      LineBox[{{0.3438954601199191, 1.1615508923410582`}, {0.3438954601199191,
        1.1615508923410582`}}], 
      LineBox[{{0.39801388073881455`, 0.5968370576832966}, {
       0.3995148861816361, 0.5814526872028722}}], 
      LineBox[{{0.4712465480623561, -0.13624232430404823`}, {
       0.4747094828671445, -0.1700220150859952}}], 
      LineBox[{{0.47662274817326694`, -0.1886509503928127}, {
       0.4866676161328762, -0.28605470157057306`}}], 
      LineBox[{{0.5779365330363561, -1.1402592108271454`}, {
       0.5783398675839831, -1.1439108766703912`}}], 
      LineBox[{{0.6265133876935848, -1.5722605394845475`}, {
       0.6399460650192477, -1.6889436250346779`}}], 
      LineBox[{{0.6418593303253701, -1.705465383103373}, {
       0.6514814661500183, -1.788186238419145}}], 
      LineBox[{{0.7610414104871407, -2.686555999156152}, {
       0.8252251284426202, -3.175693836804029}}], 
      LineBox[{{0.8271383937487427, -3.189853313896038}, {
       0.8429783931583863, -3.3061432996533897`}}], 
      LineBox[{{0.8448916584645088, -3.3200764500280395`}, {
       0.9794117335407672, -4.2385629753834255`}, {
       1.0379564635331082`, -4.600646777748915}, {
       1.1014543587971328`, -4.967551575302503}, {
       1.160721745863453, -5.285776887525904}, {
       1.1763942827133713`, -5.366015835392325}}], 
      LineBox[{{1.1783075480194938`, -5.375699149641352}, {
       1.2879935668315514`, -5.8900680157520915`}, {
       1.3468143272639421`, -6.132896580017611}, {
       1.410588252968016, -6.37013674169057}, {
       1.4245099027176038`, -6.418323548068712}}], LineBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAAqLKOGaHS9j/+RIiSCrMZwKGRkYDC
dPg/RQoWjCXzGsByLoMO0Hj4P2woddXm9RrARMt0nN18+D8ntkBppvgawOYE
WLj4hPg/XlsdcCD+GsAseB7wLpX4P4Ra7vr/CBvAuF6rX5u1+D9Fl/sEbR4b
wM4rxT509vg/DU0l6/5HG8D7xfj8JXj5PzmStgIClhvAGszgOu57+T+deGcm
LpgbwDrSyHi2f/k/E4sKzViaG8B63pj0Rof5P+lfJ6OpnhvA+PY47GeW+T+Y
7rxyOacbwPYneduptPk/x8pgnxG4G8Dwifm5LfH5P44D1C6k2BvA5E36djVq
+j/mmJ8oUhUcwKQK99tObvo/jUStmEUXHMBlx/NAaHL6P7ChIkk3GRzA5kDt
Cpt6+j/tn0RrFR0cwOgz4J4Ai/o/RQNntLwkHMDrGcbGy6v6Px7yL1q3MxzA
8uWRFmLt+j9gwyX0XFAcwLKijnt78fo/tM1AcRhSHMBzX4vglPX6P7IExS7S
UxzA9NiEqsf9+j+8JglrQFccwPXLdz4tDvs/qX6B6AdeHMD4sV1m+C77P0hw
PPdCaxzAXrVePy8z+z+oE/8d7mwcwBHs6fk=
       "]], LineBox[CompressedData["
1:eJwV1Xk0lVsfB/CTqXLMRaXnqfQehwyXV3HvzavfQclcCAuNCodQyWyJXGPX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       "]], LineBox[CompressedData["
1:eJwVj20sFHAcgP//s5iXNBGr+x+Xyk1SMxfK8Ku2VuuIrKE2hwnjwimdDzSK
IkVqLSI6511oiDrjfjvubG0dW/QyK3R0y0tcRkMlfXj27Pn47I5JOXeJQwgR
bPLfNpNdfXNBBCoPaKO3WPAweOMRMcQSkPP5eh8ODyOb30TPxRHoarnpKaM8
lIRtqI0JBJ704HAH4WFBW0LebwmBpMRBo2CDoVrsa7E9nYDmmplufZ2hECds
/fIISC6cXwhZZrgzx03wsJaAKQaMdn9jqIu+OJFeT2DZIVcyPM0w93hhWXgj
gRjxWr5hiuEPk1lLxxYCDf2ZITZ6hgO3mhYbOgl4uH/ih44zTL3rquzrJ5BT
8PNV8QeG2seCwJlJAim/unRzWoaZGWGmb/UE3lX4Wb3XMPSIuK1qmyawTbai
6x1gWLHL4JH+ncDZkb/6fDVD6dM6e2IkoIhJFG3tY8gU+yZ2EArrqa32Q50M
01r3XDnmSOFe7sp9LznDjJnPKhGfwniP3dpIFcPrLqVW4c4URovN66SVDAsq
reqSXSiArUxbW87wWdHyx/KDFDS90a6rjzb/kwf9V/wpqAQymegOQ7dDSRbN
YgrdUS3CWinDqbZ2uZ2cgqSwyNPJl2EJP+Hkn2oK0qwO18tHGPqX8Ganayi0
mrSXv/ZmWJqWL+xuoOCt810KFDI8czhyMOIFhZq4G6mx7gzblebzlSoKC0tj
ilNODLM1UT6uXzb/rNTz85Qhb8x6yI/LgcasCOvnai42fS0bZzwOVJ1QxiuQ
i14zexfXHTlgcDYVlfVxMWj1qI3SmQNX3cQvs5VczHaID/Xav9nB9pb+7Vw0
kurTMk8OmCUFPDDUc/Efg2cczQ==
       "]], 
      LineBox[{{2.277043132150738, -6.909653557068373}, {
       2.292541268741464, -6.87379601449214}, {
       2.321781052763779, -6.801789782300757}, {
       2.380083767135618, -6.641220436845557}}], 
      LineBox[{{2.38199703244174, -6.635567622184773}, {
       2.43450931795268, -6.470902984073528}}], 
      LineBox[{{2.436422583258802, -6.464556810008565}, {
       2.5085714015889944`, -6.207453850508379}, {
       2.571557508271378, -5.954664265858273}, {
       2.612313775343553, -5.777015218170688}}], 
      LineBox[{{2.614227040649675, -5.768403841370096}, {
       2.694021870512421, -5.387549340844951}, {
       2.7535001260710796`, -5.07608368772411}, {
       2.8072061613771497`, -4.774605653177029}}], 
      LineBox[{{2.8091194266832717`, -4.763511247411701}, {
       2.875071235044263, -4.366175049007135}, {
       2.8855579900485706`, -4.300327007947249}}], 
      LineBox[{{2.8874712553546926`, -4.288234307031955}, {
       2.899796763340496, -4.209747155728814}}], 
      LineBox[{{2.9524439225410375`, -3.863107240997997}, {
       2.9579973417660375`, -3.8254661224291633`}}], 
      LineBox[{{2.9599106070721595`, -3.812450425640783}, {
       2.969110717485465, -3.749522801324204}, {
       2.971170002986434, -3.7353603337911507`}, {
       2.975288573988372, -3.706950672995992}, {
       2.983525715992248, -3.649792447618632}, {
       2.9845553587427327`, -3.642615897140085}, {
       2.985585001493217, -3.6354322861358495`}, {
       2.987644286994186, -3.621043882534766}, {
       2.991762857996124, -3.592182348850444}, {
       2.9927925007466083`, -3.5849493140559523`}, {
       2.993822143497093, -3.5777092187040687`}, {
       2.9958814289980618`, -3.5632078463121917`}, {
       2.9969110717485465`, -3.5559465692640053`}, {
       2.997940714499031, -3.5486782316426053`}, {
       2.998970357249515, -3.5414028334437084`}, {3., -3.534120374663488}}], 
      LineBox[{{2.9212348006856645`, -4.070822486028808}, {
       2.936162149469961, -3.9722814085406375`}, {
       2.93822143497093, -3.9585708072462604`}, {
       2.9423400059728677`, -3.931064880383986}, {
       2.9505306572349155`, -3.8760277984481877`}}]},
     Annotation[#, "Charting`Private`Tag$283330#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw1mHk8Fd/7wO3Xkp3SR4kSSspViOg5bSpSKtnJvlWISClLaLGEoo+QtWQP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       "]]},
     Annotation[#, "Charting`Private`Tag$283330#2"]& ], {}}, {{}, {}, {}, {}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    RGBColor[1, 0, 0], 
    LineBox[
     NCache[{{1, 0}, {1, 
        Complex[-4.3684990788442315`, 0.]}}, {{1, 0}, {
       1, -4.3684990788442315`}}]], 
    RGBColor[0, 0, 1], 
    LineBox[{{1, 0}, {1, 1.0417456500919164`}}]},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{0., 3.}, {-7.293895912581157, 17.679425621990998`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411090744609823`*^9, 3.741109095284111*^9}, {
   3.741109145080967*^9, 3.741109171744013*^9}, 3.741109335730897*^9, 
   3.741187240689241*^9},
 CellLabel->
  "Out[640]=",ExpressionUUID->"3865fe13-21c3-40b0-a823-dfcb0289979f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "MEASURE", "  ", "cost", " ", "of", " ", "exact", " ", "vs", " ", "MM"}], 
   " ", "*)"}], 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q0exact", "=", 
       RowBox[{"{", 
        RowBox[{
        "0.983838857597438`", ",", "0.0026958804682577367`", ",", 
         "0.013005086797480062`", ",", 
         RowBox[{"-", "0.31492073763500855`"}]}], "}"}]}], ",", " ", 
      RowBox[{"q0RRR", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
        "0.9792171403627875`", ",", "0.003592334333214316`", ",", 
         "0.0003948989172451336`", ",", 
         RowBox[{"-", "0.20278247263658802`"}]}], "}"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q0exact", ".", "testMMmat", ".", "q0exact"}], ",", 
      RowBox[{"q0RRR", ".", "testMMmat", ".", "q0RRR"}], ",", 
      RowBox[{"q0RRR", ".", "testWVVmat", ".", "q0RRR"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7411075567482758`*^9, 3.7411075792521133`*^9}, {
   3.741107619552306*^9, 3.741107716579328*^9}, 3.74118724068969*^9},
 CellLabel->
  "In[628]:=",ExpressionUUID->"7fcd1526-9ab3-421b-a3c7-6f6bd7426ab4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "155.5280407121892`", ",", "147.94249340088953`", ",", 
   "98.97124670044478`"}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741107717373115*^9, 3.741187240690096*^9},
 CellLabel->
  "Out[628]=",ExpressionUUID->"75e4e3ce-55d7-4f89-99d5-fb74ff675a00"],

Cell[BoxData[" "], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741053854970722*^9, 
  3.74118724069051*^9},ExpressionUUID->"225ea84a-fba5-4b8a-a5be-df76249335a1"],

Cell[BoxData["makeM3Dfrm"], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.741187240690878*^9},ExpressionUUID->"6b66a389-9390-49ef-bf14-\
9e94e56195fe"],

Cell[BoxData[
 RowBox[{"testMMmat", " ", "=", 
  RowBox[{"makeM3Dfrm", "@@", 
   RowBox[{"testa3DFrm", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.74105176928235*^9, 3.741051787129174*^9}, {
   3.741053649450664*^9, 3.741053654214435*^9}, 3.7411872406912813`*^9},
 CellLabel->
  "In[560]:=",ExpressionUUID->"8882ff76-4b8d-44e2-9c19-0bd68acb2f8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "139.82785494242788`", ",", "0.6823724438578672`", ",", 
     "0.059151019439038784`", ",", 
     RowBox[{"-", "39.17260843335736`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6823724438578672`", ",", 
     RowBox[{"-", "49.487417512241315`"}], ",", 
     RowBox[{"-", "0.1491701469134183`"}], ",", 
     RowBox[{"-", "0.20269188374568303`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.059151019439038784`", ",", 
     RowBox[{"-", "0.1491701469134183`"}], ",", 
     RowBox[{"-", "49.11836921603305`"}], ",", 
     RowBox[{"-", "0.10076461712271537`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "39.17260843335736`"}], ",", 
     RowBox[{"-", "0.20269188374568303`"}], ",", 
     RowBox[{"-", "0.10076461712271537`"}], ",", 
     RowBox[{"-", "41.22206821415357`"}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.741051788890777*^9, 3.7410536552412367`*^9, 
  3.741187240691676*^9},
 CellLabel->
  "Out[560]=",ExpressionUUID->"9858d2f1-64e2-4ccc-8a33-d107bf90888b"],

Cell[BoxData[
 RowBox[{"testMMmat", "//", "Eigenvalues"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.741053666228951*^9, 3.741053668466522*^9}, 
   3.741187240692092*^9},
 CellLabel->
  "In[561]:=",ExpressionUUID->"7b1be2df-dc23-4fe4-9f27-89f520d71d3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"147.94249340088948`", ",", 
   RowBox[{"-", "49.57406329534467`"}], ",", 
   RowBox[{"-", "49.31693571132638`"}], ",", 
   RowBox[{"-", "49.05149439421854`"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.74105366919676*^9, 3.741187240692487*^9},
 CellLabel->
  "Out[561]=",ExpressionUUID->"a5024dfe-023b-472e-b55b-814c5ca7470a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EXAMPLE data sets:", "Subsubsection",
 CellChangeTimes->{{3.726421617292644*^9, 
  3.726421621460836*^9}},ExpressionUUID->"76bc5cf7-e0b3-49be-baca-\
d224d88ec7af"],

Cell[BoxData[
 RowBox[{"makePnNumRule", "[", 
  RowBox[{"makeXYZnumRule", "[", 
   RowBox[{"makeMxxmat", "[", 
    RowBox[{"makeExxmat", "[", 
     RowBox[{"target", ",", "reference"}], "]"}], "]"}], "]"}], 
  "]"}]], "Input",ExpressionUUID->"a4d789f4-5707-4ac8-bbab-79555dd2ac26"],

Cell[BoxData[
 RowBox[{"makePn4NumRule", "[", 
  RowBox[{"makeWXYZnumRule", "[", 
   RowBox[{"makeMxxmat", "[", 
    RowBox[{"makeExxmat", "[", 
     RowBox[{"target", ",", "reference"}], "]"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.741050828324768*^9, 
  3.7410508306453648`*^9}},ExpressionUUID->"543841a3-3d21-448e-a55f-\
9abe75a3cd3e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["II. Build the rules  needed for the eigenvector.", "Subsubsection",
 CellChangeTimes->{{3.725625566067275*^9, 
  3.725625587603285*^9}},ExpressionUUID->"a9ba0a59-3191-444b-b571-\
8c7e08d33039"],

Cell[CellGroupData[{

Cell[BoxData["hornAmat"], "Input",
 CellChangeTimes->{{3.725625789283584*^9, 
  3.725625790739485*^9}},ExpressionUUID->"5d841571-01ae-4e16-8434-\
ac512a62bb2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "+", "y", "+", "z"}], ",", "a", ",", "b", ",", "c"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"x", "-", "y", "-", "z"}], ",", "cc", ",", "bb"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "cc", ",", 
     RowBox[{
      RowBox[{"-", "x"}], "+", "y", "-", "z"}], ",", "aa"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "bb", ",", "aa", ",", 
     RowBox[{
      RowBox[{"-", "x"}], "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.725625791367035*^9},ExpressionUUID->"e5f04057-e88a-4a13-b746-\
657185b78e02"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeXYZnumRule", "[", "Mxxmat_", "]"}], " ", ":=", 
  "\[IndentingNewLine]", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mxxmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
        RowBox[{"Mxxmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mxxmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
        RowBox[{"Mxxmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"z", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mxxmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
        RowBox[{"Mxxmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "4"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"a", "\[Rule]", " ", 
     RowBox[{"Mxxmat", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", " ", 
    RowBox[{"b", "\[Rule]", " ", 
     RowBox[{"Mxxmat", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", " ", 
    RowBox[{"c", "\[Rule]", " ", 
     RowBox[{"Mxxmat", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "4"}], "]"}], "]"}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"aa", "\[Rule]", " ", 
     RowBox[{"Mxxmat", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "4"}], "]"}], "]"}]}], ",", " ", 
    RowBox[{"bb", "\[Rule]", " ", 
     RowBox[{"Mxxmat", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "4"}], "]"}], "]"}]}], ",", 
    RowBox[{"cc", "\[Rule]", " ", 
     RowBox[{"Mxxmat", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "3"}], "]"}], "]"}]}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7256256138690443`*^9, 3.725625680722851*^9}, {
  3.725625724466792*^9, 3.725625912731062*^9}, {3.725625953025879*^9, 
  3.72562599017822*^9}},
 CellLabel->
  "In[292]:=",ExpressionUUID->"6a9b6a13-71a3-47c1-bcdb-3688acb3cc83"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeXYZnumRule", "[", "hornAmat", "]"}]], "Input",
 CellChangeTimes->{{3.726422555156721*^9, 
  3.7264225576611147`*^9}},ExpressionUUID->"48714568-6525-4bde-b566-\
14f6873a2e1f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "x"}], ",", 
   RowBox[{"y", "\[Rule]", "y"}], ",", 
   RowBox[{"z", "\[Rule]", "z"}], ",", 
   RowBox[{"a", "\[Rule]", "a"}], ",", 
   RowBox[{"b", "\[Rule]", "b"}], ",", 
   RowBox[{"c", "\[Rule]", "c"}], ",", 
   RowBox[{"aa", "\[Rule]", "aa"}], ",", 
   RowBox[{"bb", "\[Rule]", "bb"}], ",", 
   RowBox[{"cc", "\[Rule]", "cc"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726422558030171*^9},ExpressionUUID->"91c248fd-8005-4348-a60e-\
dc2cbdc73f4b"]
}, Open  ]],

Cell["\<\
xxxx  here is the cross check **THIS HAS BEEN WRONG FROM BEGINNING\
\>", "Text",
 CellChangeTimes->{{3.742151597997388*^9, 3.742151605548654*^9}, {
  3.742152596069042*^9, 
  3.7421526056758823`*^9}},ExpressionUUID->"847cb2a5-47f1-4a29-9036-\
178ce7ae1b50"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"OLD", ",", " ", 
    RowBox[{
    "wrong", " ", "convention", " ", "for", " ", "*", "w", " ", "signs"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"hornA4mat", "//", "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.726421751831749*^9, 3.726421755535685*^9}, {
  3.7264218359325857`*^9, 3.726421839064354*^9}, {3.742152619957384*^9, 
  3.7421526330367327`*^9}},ExpressionUUID->"c97c0365-fe77-4a9e-b1b8-\
f41a9dc36928"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"w", "+", "x", "+", "y", "+", "z"}], 
      RowBox[{"a", "+", "aw"}], 
      RowBox[{"b", "+", "bw"}], 
      RowBox[{"c", "+", "cw"}]},
     {
      RowBox[{"a", "-", "aw"}], 
      RowBox[{"w", "+", "x", "-", "y", "-", "z"}], 
      RowBox[{"cc", "+", "ccw"}], 
      RowBox[{"bb", "-", "bbw"}]},
     {
      RowBox[{"b", "-", "bw"}], 
      RowBox[{"cc", "-", "ccw"}], 
      RowBox[{"w", "-", "x", "+", "y", "-", "z"}], 
      RowBox[{"aa", "+", "aaw"}]},
     {
      RowBox[{"c", "-", "cw"}], 
      RowBox[{"bb", "+", "bbw"}], 
      RowBox[{"aa", "-", "aaw"}], 
      RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7264217563710833`*^9, 
  3.726421839574407*^9},ExpressionUUID->"d5589b8c-cf25-40c0-a326-\
d74a0bce169b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornA4mat", "//", "MatrixForm"}]], "Input",
 CellLabel->
  "In[132]:=",ExpressionUUID->"8e480af6-484f-4266-b92a-ededf66f9f05"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"w", "+", "x", "+", "y", "+", "z"}], 
      RowBox[{"a", "-", "aw"}], 
      RowBox[{"b", "-", "bw"}], 
      RowBox[{"c", "-", "cw"}]},
     {
      RowBox[{"a", "+", "aw"}], 
      RowBox[{"w", "+", "x", "-", "y", "-", "z"}], 
      RowBox[{"cc", "-", "ccw"}], 
      RowBox[{"bb", "+", "bbw"}]},
     {
      RowBox[{"b", "+", "bw"}], 
      RowBox[{"cc", "+", "ccw"}], 
      RowBox[{"w", "-", "x", "+", "y", "-", "z"}], 
      RowBox[{"aa", "-", "aaw"}]},
     {
      RowBox[{"c", "+", "cw"}], 
      RowBox[{"bb", "-", "bbw"}], 
      RowBox[{"aa", "+", "aaw"}], 
      RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.742152616090702*^9},
 CellLabel->
  "Out[132]//MatrixForm=",ExpressionUUID->"48517134-cfa1-406d-b3fd-\
e265c9f2e551"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeWXYZnumRule", "[", "Mwwmat_", "]"}], " ", ":=", 
  "\[IndentingNewLine]", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"w", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "4"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"4", ",", "4"}], "]"}], "]"}]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"4", ",", "4"}], "]"}], "]"}]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"z", "\[Rule]", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"4", ",", "4"}], "]"}], "]"}]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}], "+", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"4", ",", "4"}], "]"}], "]"}]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"a", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{"aw", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"b", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{"bw", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "4"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "1"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{"cw", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "4"}], "]"}], "]"}], "-", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "1"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"aa", "\[Rule]", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "4"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{"aaw", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "4"}], "]"}], "]"}], "-", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"bb", "\[Rule]", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "4"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{"bbw", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", " ", 
         RowBox[{"Mwwmat", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "4"}], "]"}], "]"}]}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"cc", "\[Rule]", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{"ccw", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"Mwwmat", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "2"}], "]"}], "]"}]}], ")"}]}]}]}], 
   "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7256256138690443`*^9, 3.725625680722851*^9}, {
   3.725625724466792*^9, 3.725625912731062*^9}, {3.725625953025879*^9, 
   3.72562599017822*^9}, 3.726421768542171*^9, {3.7264218181816196`*^9, 
   3.7264218224295473`*^9}, {3.726421855141548*^9, 3.726421982460834*^9}, {
   3.726422032582138*^9, 3.7264222775386467`*^9}, {3.726422338125238*^9, 
   3.726422375956893*^9}, {3.7264224782677727`*^9, 3.726422481400729*^9}, {
   3.726422517463337*^9, 3.726422520734817*^9}, {3.7421527191207952`*^9, 
   3.742152744293633*^9}, {3.742173178134438*^9, 3.7421731996910877`*^9}},
 CellLabel->
  "In[291]:=",ExpressionUUID->"a69c8452-2fee-4344-bad1-f5d602243e92"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"old", " ", "wrong", " ", "signs"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"makeWXYZnumRule", "[", "hornA4mat", "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.726422398694474*^9, 3.7264224099656477`*^9}, {
  3.742152681441078*^9, 
  3.742152690636422*^9}},ExpressionUUID->"a360f094-f880-4cfa-a54e-\
ecddf0fdf79b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", "\[Rule]", "w"}], ",", 
   RowBox[{"x", "\[Rule]", "x"}], ",", 
   RowBox[{"y", "\[Rule]", "y"}], ",", 
   RowBox[{"z", "\[Rule]", "z"}], ",", 
   RowBox[{"a", "\[Rule]", "a"}], ",", 
   RowBox[{"aw", "\[Rule]", 
    RowBox[{"-", "aw"}]}], ",", 
   RowBox[{"b", "\[Rule]", "b"}], ",", 
   RowBox[{"bw", "\[Rule]", 
    RowBox[{"-", "bw"}]}], ",", 
   RowBox[{"c", "\[Rule]", "c"}], ",", 
   RowBox[{"cw", "\[Rule]", 
    RowBox[{"-", "cw"}]}], ",", 
   RowBox[{"aa", "\[Rule]", "aa"}], ",", 
   RowBox[{"aaw", "\[Rule]", 
    RowBox[{"-", "aaw"}]}], ",", 
   RowBox[{"bb", "\[Rule]", "bb"}], ",", 
   RowBox[{"bbw", "\[Rule]", 
    RowBox[{"-", "bbw"}]}], ",", 
   RowBox[{"cc", "\[Rule]", "cc"}], ",", 
   RowBox[{"ccw", "\[Rule]", 
    RowBox[{"-", "ccw"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.726422403672956*^9, 3.7264224103530493`*^9}, 
   3.726422526799074*^9, 3.742152675970243*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"8fe07238-7e72-4689-be9d-033c7bf45a28"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makeWXYZnumRule", "[", "hornA4mat", "]"}], "//", 
  "Simplify"}]], "Input",
 CellLabel->
  "In[135]:=",ExpressionUUID->"cfd564e6-5cd1-4fd2-bd8a-611cfed9be0d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", "\[Rule]", "w"}], ",", 
   RowBox[{"x", "\[Rule]", "x"}], ",", 
   RowBox[{"y", "\[Rule]", "y"}], ",", 
   RowBox[{"z", "\[Rule]", "z"}], ",", 
   RowBox[{"a", "\[Rule]", "a"}], ",", 
   RowBox[{"aw", "\[Rule]", "aw"}], ",", 
   RowBox[{"b", "\[Rule]", "b"}], ",", 
   RowBox[{"bw", "\[Rule]", "bw"}], ",", 
   RowBox[{"c", "\[Rule]", "c"}], ",", 
   RowBox[{"cw", "\[Rule]", "cw"}], ",", 
   RowBox[{"aa", "\[Rule]", "aa"}], ",", 
   RowBox[{"aaw", "\[Rule]", "aaw"}], ",", 
   RowBox[{"bb", "\[Rule]", "bb"}], ",", 
   RowBox[{"bbw", "\[Rule]", "bbw"}], ",", 
   RowBox[{"cc", "\[Rule]", "cc"}], ",", 
   RowBox[{"ccw", "\[Rule]", "ccw"}]}], "}"}]], "Output",
 CellChangeTimes->{3.742152751880045*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"5fecd9d9-0057-4a00-b9bc-6623ab08f00b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["thePRule"], "Input",
 CellChangeTimes->{{3.72562615196045*^9, 
  3.725626155050383*^9}},ExpressionUUID->"acace04f-f11f-499b-a903-\
d16d17ba06b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["aa", "2"]}], "-", 
     RowBox[{"2", " ", "a", " ", "aa", " ", "b", " ", "bb"}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["bb", "2"]}], "-", 
     RowBox[{"2", " ", "a", " ", "aa", " ", "c", " ", "cc"}], "-", 
     RowBox[{"2", " ", "b", " ", "bb", " ", "c", " ", "cc"}], "+", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox["cc", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["cc", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["bb", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["aa", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "b", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], "+", 
        RowBox[{"a", " ", "bb", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}], "+", 
        RowBox[{"a", " ", "b", " ", "cc", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "+", 
        RowBox[{"aa", " ", "bb", " ", "cc", " ", 
         RowBox[{"(", 
          RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", "x", " ", "y", " ", "z"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", "bb", " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "cc"}], "+", 
        RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["aa", "2"]}], ")"}], " ", "x"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["bb", "2"]}], ")"}], " ", "y"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["c", "2"], "-", 
           SuperscriptBox["cc", "2"]}], ")"}], " ", "z"}]}], ")"}]}]}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "-", 
     SuperscriptBox["aa", "2"], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["bb", "2"], "-", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox["cc", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.72562615575877*^9},ExpressionUUID->"89f377ec-6550-480d-a8a2-aca923777dbe"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"makePnNumRule", "[", "XYZnumRule_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "\[Rule]", "0"}], ",", 
     RowBox[{"p2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "-", 
       SuperscriptBox["aa", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["bb", "2"], "-", 
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["cc", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "x", " ", "y", " ", "z"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "b", " ", "c"}], "+", 
          RowBox[{"a", " ", "bb", " ", "c"}], "+", 
          RowBox[{"a", " ", "b", " ", "cc"}], "+", 
          RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["aa", "2"]}], ")"}], " ", "x"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["bb", "2"]}], ")"}], " ", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["c", "2"], "-", 
             SuperscriptBox["cc", "2"]}], ")"}], " ", "z"}]}], ")"}]}]}]}], 
     ",", "\[IndentingNewLine]", " ", 
     RowBox[{"p4", "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["aa", "2"]}], "-", 
       RowBox[{"2", " ", "a", " ", "aa", " ", "b", " ", "bb"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["bb", "2"]}], "-", 
       RowBox[{"2", " ", "a", " ", "aa", " ", "c", " ", "cc"}], "-", 
       RowBox[{"2", " ", "b", " ", "bb", " ", "c", " ", "cc"}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox["cc", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["cc", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "b", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], "+", 
          RowBox[{"a", " ", "bb", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}], "+", 
          RowBox[{"a", " ", "b", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "+", 
          RowBox[{"aa", " ", "bb", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}]}]}], 
    "}"}], "/.", "XYZnumRule"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7256260874815893`*^9, 3.7256260955844107`*^9}, {
  3.725626138096204*^9, 3.7256261456393633`*^9}, {3.725626197895269*^9, 
  3.72562629168946*^9}},
 CellLabel->
  "In[290]:=",ExpressionUUID->"d74b5efd-770a-4d59-bf52-40cccc9371e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Usage", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"makePnNumRule", "[", 
   RowBox[{"makeXYZnumRule", "[", 
    RowBox[{"makeMwwmat", "[", 
     RowBox[{"makeEwwmat", "[", 
      RowBox[{"target", ",", "reference"}], "]"}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.726156517993895*^9, 3.726156577118228*^9}, {
   3.726426667763685*^9, 3.726426676323326*^9}, 
   3.726427142943823*^9},ExpressionUUID->"8f0ef87a-3e6b-4935-9fdc-\
65de8223dcd3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Generates", " ", "Target"}], ",", " ", 
    RowBox[{"Reference", " ", "in", " ", "that", " ", "order"}]}], " ", 
   "*)"}], "  ", 
  RowBox[{
   RowBox[{"buildXRMSDdataset", "[", "3", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.726426725490617*^9, 3.7264267260104*^9}, {
  3.726426816570394*^9, 
  3.726426863769395*^9}},ExpressionUUID->"970f7621-c77c-447a-a426-\
6bcbb34fb259"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.02516357310795034`"}], ",", "0.540599432995742`", ",", 
       
       RowBox[{"-", "0.28054858954276674`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8667517188169345`", ",", "0.02001603508238181`", ",", 
       RowBox[{"-", "0.6200054869420025`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.8415881457089842`"}], ",", 
       RowBox[{"-", "0.5606154680781237`"}], ",", "0.9005540764847694`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.16743837412574758`", ",", "0.3702086091964418`", ",", 
       RowBox[{"-", "0.4084315955088404`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5212723596300469`", ",", 
       RowBox[{"-", "0.737059049589839`"}], ",", 
       RowBox[{"-", "0.5588815540180125`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6887107337557946`"}], ",", "0.36685044039339737`", ",",
        "0.9673131495268528`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.726426820317466*^9, 
  3.726426825582334*^9}},ExpressionUUID->"3b90c94f-eb14-4821-bb5f-\
93f1294aaa8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox[" ",
  FontSize->16],
 StyleBox["Various Checks are",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" here",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox[", including  pn-> Exx + Eyy....",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["\n_______________________________",
  FontSize->16]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725627017425425*^9, 
  3.725627073697352*^9}},ExpressionUUID->"8c7679a7-b637-4569-b8f2-\
a300e3c75b3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Checks", " ", "*)"}], " ", 
  RowBox[{"makeXYZnumRule", "[", "hornAmat", "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725625978352518*^9, 3.725625979168605*^9}, {
   3.7256260436333427`*^9, 3.725626050743932*^9}, 
   3.7256270468441*^9},ExpressionUUID->"822a9c4a-3a9b-4d77-9548-508a155ed8ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "x"}], ",", 
   RowBox[{"y", "\[Rule]", "y"}], ",", 
   RowBox[{"z", "\[Rule]", "z"}], ",", 
   RowBox[{"a", "\[Rule]", "a"}], ",", 
   RowBox[{"b", "\[Rule]", "b"}], ",", 
   RowBox[{"c", "\[Rule]", "c"}], ",", 
   RowBox[{"aa", "\[Rule]", "aa"}], ",", 
   RowBox[{"bb", "\[Rule]", "bb"}], ",", 
   RowBox[{"cc", "\[Rule]", "cc"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725625979932054*^9, 3.725625993812469*^9}, 
   3.725627046844389*^9},ExpressionUUID->"2fbeeb40-ea2d-4ce6-8495-\
e159630da827"],

Cell[BoxData[
 RowBox[{"makeXYZnumRule", "[", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Exx", "+", "Eyy", "+", "Ezz"}], ",", 
      RowBox[{"Eyz", " ", "-", "Ezy"}], ",", " ", 
      RowBox[{"Ezx", " ", "-", " ", "Exz"}], ",", 
      RowBox[{"Exy", "-", "Eyx"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"Eyz", " ", "-", "Ezy"}], ",", 
      RowBox[{"Exx", "-", "Eyy", "-", "Ezz"}], ",", 
      RowBox[{"Exy", " ", "+", " ", "Eyx"}], ",", " ", 
      RowBox[{"Ezx", "+", "Exz"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Ezx", " ", "-", " ", "Exz"}], ",", 
      RowBox[{"Exy", " ", "+", " ", "Eyx"}], " ", ",", 
      RowBox[{
       RowBox[{"-", "Exx"}], "+", "Eyy", "-", "Ezz"}], ",", 
      RowBox[{"Eyz", "+", "Ezy"}]}], " ", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"Exy", "-", "Eyx"}], ",", " ", 
      RowBox[{"Ezx", "+", "Exz"}], " ", ",", 
      RowBox[{"Eyz", "+", "Ezy"}], " ", ",", 
      RowBox[{
       RowBox[{"-", "Exx"}], "-", "Eyy", "+", "Ezz"}]}], " ", "}"}]}], "}"}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.725626023348897*^9, 
  3.725627046844799*^9},ExpressionUUID->"ed85d8e2-8723-4499-a433-\
24397c6849e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "Exx"}], ",", 
   RowBox[{"y", "\[Rule]", "Eyy"}], ",", 
   RowBox[{"z", "\[Rule]", "Ezz"}], ",", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"Eyz", "-", "Ezy"}]}], ",", 
   RowBox[{"b", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "Exz"}], "+", "Ezx"}]}], ",", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"Exy", "-", "Eyx"}]}], ",", 
   RowBox[{"aa", "\[Rule]", 
    RowBox[{"Eyz", "+", "Ezy"}]}], ",", 
   RowBox[{"bb", "\[Rule]", 
    RowBox[{"Exz", "+", "Ezx"}]}], ",", 
   RowBox[{"cc", "\[Rule]", 
    RowBox[{"Exy", "+", "Eyx"}]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.725626026553957*^9, 
  3.7256270468450727`*^9},ExpressionUUID->"a7511c4a-8b4d-4d8a-ab77-\
6cf57addd2db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Look", " ", "at", " ", "the", " ", "pn"}], "\[Rule]", 
    RowBox[{"Exx", " ", "form"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"makePnNumRule", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "Exx"}], ",", 
       RowBox[{"y", "\[Rule]", "Eyy"}], ",", 
       RowBox[{"z", "\[Rule]", "Ezz"}], ",", 
       RowBox[{"a", "\[Rule]", 
        RowBox[{"Eyz", "-", "Ezy"}]}], ",", 
       RowBox[{"b", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "Exz"}], "+", "Ezx"}]}], ",", 
       RowBox[{"c", "\[Rule]", 
        RowBox[{"Exy", "-", "Eyx"}]}], ",", 
       RowBox[{"aa", "\[Rule]", 
        RowBox[{"Eyz", "+", "Ezy"}]}], ",", 
       RowBox[{"bb", "\[Rule]", 
        RowBox[{"Exz", "+", "Ezx"}]}], ",", 
       RowBox[{"cc", "\[Rule]", 
        RowBox[{"Exy", "+", "Eyx"}]}]}], "}"}], "]"}], "//", "Expand"}], "//",
    "FullSimplify"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725626344645329*^9, 3.725626377774149*^9}, {
   3.725626417653977*^9, 3.7256264182376223`*^9}, {3.725626448911089*^9, 
   3.725626461184647*^9}, 
   3.725627046845416*^9},ExpressionUUID->"961ea8cb-eddb-4631-a821-\
fc6750ee2666"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["Exx", "2"], "+", 
       SuperscriptBox["Exy", "2"], "+", 
       SuperscriptBox["Exz", "2"], "+", 
       SuperscriptBox["Eyx", "2"], "+", 
       SuperscriptBox["Eyy", "2"], "+", 
       SuperscriptBox["Eyz", "2"], "+", 
       SuperscriptBox["Ezx", "2"], "+", 
       SuperscriptBox["Ezy", "2"], "+", 
       SuperscriptBox["Ezz", "2"]}], ")"}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "-", 
       RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "-", 
       RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "+", 
       RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "+", 
       RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "-", 
       RowBox[{"Exx", " ", "Eyy", " ", "Ezz"}]}], ")"}]}]}], ",", 
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     SuperscriptBox["Exx", "4"], "+", 
     SuperscriptBox["Exy", "4"], "+", 
     SuperscriptBox["Exz", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["Exz", "2"], " ", 
      SuperscriptBox["Eyx", "2"]}], "+", 
     SuperscriptBox["Eyx", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["Exz", "2"], " ", 
      SuperscriptBox["Eyy", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyx", "2"], " ", 
      SuperscriptBox["Eyy", "2"]}], "+", 
     SuperscriptBox["Eyy", "4"], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Exz", "2"], " ", 
      SuperscriptBox["Eyz", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyx", "2"], " ", 
      SuperscriptBox["Eyz", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyy", "2"], " ", 
      SuperscriptBox["Eyz", "2"]}], "+", 
     SuperscriptBox["Eyz", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["Exz", "2"], " ", 
      SuperscriptBox["Ezx", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyx", "2"], " ", 
      SuperscriptBox["Ezx", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyy", "2"], " ", 
      SuperscriptBox["Ezx", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyz", "2"], " ", 
      SuperscriptBox["Ezx", "2"]}], "+", 
     SuperscriptBox["Ezx", "4"], "+", 
     RowBox[{"8", " ", "Eyx", " ", "Eyy", " ", "Ezx", " ", "Ezy"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["Exz", "2"], " ", 
      SuperscriptBox["Ezy", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyx", "2"], " ", 
      SuperscriptBox["Ezy", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyy", "2"], " ", 
      SuperscriptBox["Ezy", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["Eyz", "2"], " ", 
      SuperscriptBox["Ezy", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Ezx", "2"], " ", 
      SuperscriptBox["Ezy", "2"]}], "+", 
     SuperscriptBox["Ezy", "4"], "+", 
     RowBox[{"8", " ", "Eyz", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Eyx", " ", "Ezx"}], "+", 
        RowBox[{"Eyy", " ", "Ezy"}]}], ")"}], " ", "Ezz"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["Exz", "2"], "-", 
        SuperscriptBox["Eyx", "2"], "-", 
        SuperscriptBox["Eyy", "2"], "+", 
        SuperscriptBox["Eyz", "2"], "+", 
        SuperscriptBox["Ezx", "2"], "+", 
        SuperscriptBox["Ezy", "2"]}], ")"}], " ", 
      SuperscriptBox["Ezz", "2"]}], "+", 
     SuperscriptBox["Ezz", "4"], "+", 
     RowBox[{"8", " ", "Exx", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exy", " ", "Eyx", " ", "Eyy"}], "+", 
        RowBox[{"Exz", " ", "Eyx", " ", "Eyz"}], "+", 
        RowBox[{"Exy", " ", "Ezx", " ", "Ezy"}], "+", 
        RowBox[{"Exz", " ", "Ezx", " ", "Ezz"}]}], ")"}]}], "+", 
     RowBox[{"8", " ", "Exy", " ", "Exz", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Eyy", " ", "Eyz"}], "+", 
        RowBox[{"Ezy", " ", "Ezz"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Exx", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["Exy", "2"], "+", 
        SuperscriptBox["Exz", "2"], "+", 
        SuperscriptBox["Eyx", "2"], "-", 
        SuperscriptBox["Eyy", "2"], "-", 
        SuperscriptBox["Eyz", "2"], "+", 
        SuperscriptBox["Ezx", "2"], "-", 
        SuperscriptBox["Ezy", "2"], "-", 
        SuperscriptBox["Ezz", "2"]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["Exy", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["Exz", "2"], "-", 
        SuperscriptBox["Eyx", "2"], "+", 
        SuperscriptBox["Eyy", "2"], "-", 
        SuperscriptBox["Eyz", "2"], "-", 
        SuperscriptBox["Ezx", "2"], "+", 
        SuperscriptBox["Ezy", "2"], "-", 
        SuperscriptBox["Ezz", "2"]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.72562637858043*^9, 3.725626419834827*^9, 
  3.725627046845702*^9},ExpressionUUID->"be8f512b-1fe3-4597-a470-\
09eadeac0c54"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.7264265368888903`*^9},ExpressionUUID->"97857eed-fc13-412b-b10f-\
f0146404ffbf"],

Cell[TextData[StyleBox[" Now do 4D rules:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726426510988583*^9, 
  3.7264265155325413`*^9}},ExpressionUUID->"466e97d7-6c09-43f4-9fdd-\
a8a26d771403"],

Cell[CellGroupData[{

Cell[BoxData["hornA4mat"], "Input",
 CellChangeTimes->{{3.726426272164384*^9, 
  3.726426275882852*^9}},ExpressionUUID->"36d779af-56c6-4c7e-a363-\
90c176edfed5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", 
     RowBox[{"a", "+", "aw"}], ",", 
     RowBox[{"b", "+", "bw"}], ",", 
     RowBox[{"c", "+", "cw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", "aw"}], ",", 
     RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", 
     RowBox[{"cc", "+", "ccw"}], ",", 
     RowBox[{"bb", "-", "bbw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", "-", "bw"}], ",", 
     RowBox[{"cc", "-", "ccw"}], ",", 
     RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", 
     RowBox[{"aa", "+", "aaw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "-", "cw"}], ",", 
     RowBox[{"bb", "+", "bbw"}], ",", 
     RowBox[{"aa", "-", "aaw"}], ",", 
     RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.726426276661916*^9},ExpressionUUID->"9d873097-13e9-42c2-8b37-\
09faee97278b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"makeDetHornA4", "//", "Clear"}]], "Input",
 CellChangeTimes->{{3.7407453815869102`*^9, 3.740745382875259*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"f7dbcd92-973a-4a31-a166-f472848befa2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeDetHornA4", " ", "[", 
   RowBox[{
   "w_", ",", "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", "c_", 
    ",", "aw_", ",", "bw_", ",", "cw_", ",", "aa_", ",", "bb_", ",", "cc_", 
    ",", "aaw_", ",", "bbw_", ",", "ccw_"}], "]"}], " ", ":=", 
  RowBox[{"Det", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", 
       RowBox[{"a", "+", "aw"}], ",", 
       RowBox[{"b", "+", "bw"}], ",", 
       RowBox[{"c", "+", "cw"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "aw"}], ",", 
       RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", 
       RowBox[{"cc", "+", "ccw"}], ",", 
       RowBox[{"bb", "-", "bbw"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b", "-", "bw"}], ",", 
       RowBox[{"cc", "-", "ccw"}], ",", 
       RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", 
       RowBox[{"aa", "+", "aaw"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c", "-", "cw"}], ",", 
       RowBox[{"bb", "+", "bbw"}], ",", 
       RowBox[{"aa", "-", "aaw"}], ",", 
       RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], "}"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726426288615272*^9, 3.7264263412243443`*^9}, {
  3.740745197653067*^9, 3.740745240199299*^9}, {3.740745401945326*^9, 
  3.740745402725689*^9}, {3.74074656734798*^9, 3.740746607450664*^9}},
 CellLabel->
  "In[288]:=",ExpressionUUID->"da471091-7977-463c-bd32-2007d71b35e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeDetHornA4", "[", 
    RowBox[{
    "w", ",", "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c", ",", 
     "aw", ",", "bw", ",", "cw", ",", "aa", ",", "bb", ",", "cc", ",", "aaw", 
     ",", "bbw", ",", "ccw"}], "]"}], " ", "-", 
   RowBox[{"Det", "[", "hornA4mat", "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.740745410490871*^9, 3.740745416523176*^9}, {
  3.740746617482132*^9, 3.7407466420569773`*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"1ff4bfed-03bd-4a94-8295-025fd1197868"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.7407466436120787`*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"eb7b7ae2-d056-4731-b642-64d4ff795923"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Derive", " ", "4", "D"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"the4DPRuleArg", " ", "=", " ", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Det", "[", 
         RowBox[{"hornA4mat", "-", 
          RowBox[{"e", " ", 
           RowBox[{"IdentityMatrix", "[", "4", "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"e", ",", 
          SuperscriptBox["e", "2"], ",", 
          SuperscriptBox["e", "3"], ",", 
          SuperscriptBox["e", "4"]}], "}"}]}], "]"}], "//", 
      "FullSimplify"}]}], ";"}], "\n", 
   RowBox[{"the4DPRule0", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p3", ",", "p2", ",", "p1"}], "}"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}], "->", 
       RowBox[{"the4DPRuleArg", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "3", ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.726426218442524*^9, 3.726426224879921*^9}, {
  3.7264263682262363`*^9, 
  3.726426423046234*^9}},ExpressionUUID->"dea62121-94c1-444b-96e4-\
c37e1ebe9bc2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "4"}], " ", "w"}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "-", 
     SuperscriptBox["aa", "2"], "+", 
     SuperscriptBox["aaw", "2"], "+", 
     SuperscriptBox["aw", "2"], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["bb", "2"], "+", 
     SuperscriptBox["bbw", "2"], "+", 
     SuperscriptBox["bw", "2"], "-", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox["cc", "2"], "+", 
     SuperscriptBox["ccw", "2"], "+", 
     SuperscriptBox["cw", "2"], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["w", "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}]}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aw", " ", "bbw", " ", "c"}], "-", 
       RowBox[{"aaw", " ", "bw", " ", "c"}], "-", 
       RowBox[{"aaw", " ", "bbw", " ", "cc"}], "+", 
       RowBox[{"aw", " ", "bw", " ", "cc"}], "-", 
       RowBox[{"aw", " ", "b", " ", "ccw"}], "-", 
       RowBox[{"aaw", " ", "bb", " ", "ccw"}], "+", 
       RowBox[{"aaw", " ", "b", " ", "cw"}], "+", 
       RowBox[{"aw", " ", "bb", " ", "cw"}], "-", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bb", " ", "c"}], "+", 
          RowBox[{"b", " ", "cc"}], "-", 
          RowBox[{"bw", " ", "ccw"}], "+", 
          RowBox[{"bbw", " ", "cw"}]}], ")"}]}], "-", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", "c"}], "+", 
          RowBox[{"bb", " ", "cc"}], "+", 
          RowBox[{"bbw", " ", "ccw"}], "-", 
          RowBox[{"bw", " ", "cw"}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["aaw", "2"], " ", "w"}], "-", 
       RowBox[{
        SuperscriptBox["aw", "2"], " ", "w"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "w"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", "w"}], "-", 
       RowBox[{
        SuperscriptBox["bbw", "2"], " ", "w"}], "-", 
       RowBox[{
        SuperscriptBox["bw", "2"], " ", "w"}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", "w"}], "+", 
       RowBox[{
        SuperscriptBox["cc", "2"], " ", "w"}], "-", 
       RowBox[{
        SuperscriptBox["ccw", "2"], " ", "w"}], "-", 
       RowBox[{
        SuperscriptBox["cw", "2"], " ", "w"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["w", "3"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"w", "-", "x"}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["aaw", "2"], " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["aw", "2"], " ", "x"}], "+", 
       RowBox[{"2", " ", "w", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"w", "+", "x"}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "y"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", "y"}], "-", 
       RowBox[{
        SuperscriptBox["bbw", "2"], " ", "y"}], "+", 
       RowBox[{
        SuperscriptBox["bw", "2"], " ", "y"}], "+", 
       RowBox[{"2", " ", "w", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c", "2"]}], "+", 
          SuperscriptBox["cc", "2"], "-", 
          SuperscriptBox["ccw", "2"], "+", 
          SuperscriptBox["cw", "2"], "-", 
          RowBox[{"4", " ", "x", " ", "y"}]}], ")"}], " ", "z"}], "+", 
       RowBox[{"2", " ", "w", " ", 
        SuperscriptBox["z", "2"]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.726426391948181*^9, 
  3.726426423990787*^9},ExpressionUUID->"7027db94-5d4a-4ccf-bc9f-\
d3adfdec61ed"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"makePn4NumRule", "[", "WXYZnumRule_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "4"}], " ", "w"}]}], ",", 
     RowBox[{"p2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "-", 
       SuperscriptBox["aa", "2"], "+", 
       SuperscriptBox["aaw", "2"], "+", 
       SuperscriptBox["aw", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["bb", "2"], "+", 
       SuperscriptBox["bbw", "2"], "+", 
       SuperscriptBox["bw", "2"], "-", 
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["cc", "2"], "+", 
       SuperscriptBox["ccw", "2"], "+", 
       SuperscriptBox["cw", "2"], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["w", "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}]}]}]}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"aw", " ", "bbw", " ", "c"}], "-", 
         RowBox[{"aaw", " ", "bw", " ", "c"}], "-", 
         RowBox[{"aaw", " ", "bbw", " ", "cc"}], "+", 
         RowBox[{"aw", " ", "bw", " ", "cc"}], "-", 
         RowBox[{"aw", " ", "b", " ", "ccw"}], "-", 
         RowBox[{"aaw", " ", "bb", " ", "ccw"}], "+", 
         RowBox[{"aaw", " ", "b", " ", "cw"}], "+", 
         RowBox[{"aw", " ", "bb", " ", "cw"}], "-", 
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"bb", " ", "c"}], "+", 
            RowBox[{"b", " ", "cc"}], "-", 
            RowBox[{"bw", " ", "ccw"}], "+", 
            RowBox[{"bbw", " ", "cw"}]}], ")"}]}], "-", 
         RowBox[{"aa", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", " ", "c"}], "+", 
            RowBox[{"bb", " ", "cc"}], "+", 
            RowBox[{"bbw", " ", "ccw"}], "-", 
            RowBox[{"bw", " ", "cw"}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["aaw", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["aw", "2"], " ", "w"}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "w"}], "+", 
         RowBox[{
          SuperscriptBox["bb", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["bbw", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["bw", "2"], " ", "w"}], "+", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", "w"}], "+", 
         RowBox[{
          SuperscriptBox["cc", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["ccw", "2"], " ", "w"}], "-", 
         RowBox[{
          SuperscriptBox["cw", "2"], " ", "w"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["w", "3"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"w", "-", "x"}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["aaw", "2"], " ", "x"}], "+", 
         RowBox[{
          SuperscriptBox["aw", "2"], " ", "x"}], "+", 
         RowBox[{"2", " ", "w", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["aa", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"w", "+", "x"}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "y"}], "+", 
         RowBox[{
          SuperscriptBox["bb", "2"], " ", "y"}], "-", 
         RowBox[{
          SuperscriptBox["bbw", "2"], " ", "y"}], "+", 
         RowBox[{
          SuperscriptBox["bw", "2"], " ", "y"}], "+", 
         RowBox[{"2", " ", "w", " ", 
          SuperscriptBox["y", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["cc", "2"], "-", 
            SuperscriptBox["ccw", "2"], "+", 
            SuperscriptBox["cw", "2"], "-", 
            RowBox[{"4", " ", "x", " ", "y"}]}], ")"}], " ", "z"}], "+", 
         RowBox[{"2", " ", "w", " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"p4", "\[Rule]", 
      RowBox[{"makeDetHornA4", "[", 
       RowBox[{
       "w", ",", "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c", ",", 
        "aw", ",", "bw", ",", "cw", ",", "aa", ",", "bb", ",", "cc", ",", 
        "aaw", ",", "bbw", ",", "ccw"}], "]"}]}]}], "}"}], "/.", 
   "WXYZnumRule"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7256260874815893`*^9, 3.7256260955844107`*^9}, {
   3.725626138096204*^9, 3.7256261456393633`*^9}, {3.725626197895269*^9, 
   3.72562629168946*^9}, {3.72642263942775*^9, 3.726422656371035*^9}, {
   3.726426445023254*^9, 3.7264264605288677`*^9}, {3.740745365160905*^9, 
   3.740745367328061*^9}, 3.740746688993763*^9},
 CellLabel->
  "In[289]:=",ExpressionUUID->"9fa2a61d-7357-43bf-8336-490200fb90c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Usage", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"makePn4NumRule", "[", 
   RowBox[{"makeWXYZnumRule", "[", 
    RowBox[{"makeMwwmat", "[", 
     RowBox[{"makeEwwmat", "[", 
      RowBox[{"target", ",", "reference"}], "]"}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.726156517993895*^9, 3.726156577118228*^9}, {
  3.72642664715567*^9, 3.7264266513801327`*^9}, {3.726427017512917*^9, 
  3.726427022807732*^9}},ExpressionUUID->"faf53a21-9d57-431b-ae83-\
1a345b055da3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Generates", " ", "Target"}], ",", " ", 
    RowBox[{"Reference", " ", "in", " ", "that", " ", "order"}]}], " ", 
   "*)"}], 
  RowBox[{
   RowBox[{"buildX4DRMSDdataset", "[", "2", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.726323087375875*^9, 3.726323088287725*^9}, 
   3.7264267327175283`*^9, {3.726426882105949*^9, 3.726426883936908*^9}, 
   3.726426914509418*^9},ExpressionUUID->"bebab335-ee0c-4050-b155-\
fc6eaa92706e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6396361722596501`"}], ",", "0.8346915980293992`", ",", 
       
       RowBox[{"-", "0.044551991770031094`"}], ",", "0.03144379874657042`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6396361722596501`", ",", 
       RowBox[{"-", "0.8346915980293992`"}], ",", "0.044551991770031094`", 
       ",", 
       RowBox[{"-", "0.03144379874657042`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6525259165502733`"}], ",", "0.6576649949771292`", ",", 
       "0.4021631812767281`", ",", 
       RowBox[{"-", "0.09385875651944797`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6525259165502733`", ",", 
       RowBox[{"-", "0.6576649949771292`"}], ",", 
       RowBox[{"-", "0.4021631812767281`"}], ",", "0.09385875651944797`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726426884628551*^9},ExpressionUUID->"7ac3ce8e-b6e3-4783-b59f-\
9adcdef2f541"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dateset1", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"makePn4NumRule", "[", 
     RowBox[{"makeWXYZnumRule", "[", 
      RowBox[{"makeMwwmat", "[", 
       RowBox[{"makeEwwmat", "@@", 
        RowBox[{
         RowBox[{"buildX4DRMSDdataset", "[", "10", "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], "]"}], ",", 
    
    RowBox[{"{", "2", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.72642692849697*^9, 3.7264269826657248`*^9}, {
  3.72642702809079*^9, 
  3.726427032047853*^9}},ExpressionUUID->"2218073f-32bc-40f5-8490-\
e9be178a8360"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "\[Rule]", 
      RowBox[{"-", "5.058365509132539`"}]}], ",", 
     RowBox[{"p2", "\[Rule]", 
      RowBox[{"-", "25.09792661243937`"}]}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{"-", "6.363087664814115`"}]}], ",", 
     RowBox[{"p4", "\[Rule]", "125.78880117706849`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "\[Rule]", 
      RowBox[{"-", "16.37468815512529`"}]}], ",", 
     RowBox[{"p2", "\[Rule]", "56.41864072866737`"}], ",", 
     RowBox[{"p3", "\[Rule]", 
      RowBox[{"-", "163.7339500836398`"}]}], ",", 
     RowBox[{"p4", "\[Rule]", "426.9084009470973`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7264269833950377`*^9, 
  3.72642703406664*^9},ExpressionUUID->"dd429c25-c011-4389-9e7a-4237724d24f6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["THIS IS THE 4D RMSD:",
 FontSize->24,
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.742174430709656*^9, 
  3.742174440789915*^9}},ExpressionUUID->"1dd6488f-139e-44aa-a2a6-\
a1e7cc15235c"],

Cell[CellGroupData[{

Cell[BoxData["hornM4mat"], "Input",
 CellLabel->
  "In[206]:=",ExpressionUUID->"b0fff4ab-47a7-44e1-9669-3c4c3ee82099"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742174832696076*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"27d88df5-33c6-4045-9e0b-3dbc4718cf47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pn4toEwwRule", "//", "Short"}]], "Input",
 CellChangeTimes->{{3.742174754371368*^9, 3.7421747733947163`*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"ea9694b1-75bc-4b8c-a510-f1ba4da8a96a"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p1", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "Eww"}]}], ",", 
    RowBox[{"\[LeftSkeleton]", "2", "\[RightSkeleton]"}], ",", 
    RowBox[{"p4", "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Ewz", "-", "Exy", "+", "Eyx", "-", "Ezw"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}]}], "+", 
      RowBox[{"\[LeftSkeleton]", "3", "\[RightSkeleton]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "+", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], ")"}]}], 
         "+", 
         RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "-", 
         RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
        ")"}]}]}]}]}], "}"}],
  Short]], "Output",
 CellChangeTimes->{{3.7421747628796797`*^9, 3.7421747739506397`*^9}},
 CellLabel->
  "Out[205]//Short=",ExpressionUUID->"3f90521e-058c-4fe7-8734-435249516e64"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Derive", " ", "pn4toEwwRule", " ", "from", " ", "this"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"pn4NumRule", "//", "Short"}]}]], "Input",
 CellChangeTimes->{{3.742175192823538*^9, 3.7421752317034082`*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"b3a866b2-7e6d-41ec-8462-2042f6b546d1"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p1", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "w"}]}], ",", 
    RowBox[{"p2", "\[Rule]", 
     RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], ",", 
    RowBox[{"p3", "\[Rule]", 
     RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], ",", 
    RowBox[{"p4", "\[Rule]", 
     RowBox[{
      RowBox[{"\[LeftSkeleton]", "4", "\[RightSkeleton]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "-", "x", "-", "y", "+", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "bw"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"a", "+", "aw"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"cc", "+", "ccw"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"b", "+", "bw"}], ")"}], " ", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "-", 
         RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
        ")"}]}]}]}]}], "}"}],
  Short]], "Output",
 CellChangeTimes->{3.7421751952001953`*^9, 3.742175233283182*^9},
 CellLabel->
  "Out[208]//Short=",ExpressionUUID->"72266491-b4cd-4e8b-b2cc-3d01e81fc22f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Identical", " ", "ways"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], "/.", 
         "pn4NumRule"}], "/.", "wxyz2EwwRule"}], "//", "Simplify"}], ")"}], 
     "-", 
     RowBox[{"{", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}]}], "/.", 
    "pn4toEwwRule"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.742175291774764*^9, 
  3.7421753430226107`*^9}},ExpressionUUID->"5bc13e1e-630d-4f6c-8b5f-\
c0c6399e6049"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.7421753065942583`*^9, 3.742175320717864*^9}},
 CellLabel->
  "Out[211]=",ExpressionUUID->"b5800002-1644-4ef5-a31e-510f2c4307b2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"the4DpNs", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], "/.", 
     "pn4NumRule"}], "/.", "wxyz2EwwRule"}], "//", "Simplify"}]}]], "Input",Ex\
pressionUUID->"1be82c95-4bb9-4971-83fe-a7c13574d783"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"the4DpNs", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.742175260551166*^9, 3.742175261351283*^9}},
 CellLabel->
  "In[209]:=",ExpressionUUID->"2c1191ea-b978-4b12-a6ec-92ef501967d6"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["Eww", "2"]}], "+", 
    SuperscriptBox["Ewx", "2"], "+", 
    SuperscriptBox["Ewy", "2"], "+", 
    SuperscriptBox["Ewz", "2"], "+", 
    SuperscriptBox["Exw", "2"], "-", 
    SuperscriptBox["Exx", "2"], "-", 
    SuperscriptBox["Exy", "2"], "-", 
    SuperscriptBox["Exz", "2"], "+", 
    SuperscriptBox["Eyw", "2"], "-", 
    SuperscriptBox["Eyx", "2"], "-", 
    SuperscriptBox["Eyy", "2"], "-", 
    SuperscriptBox["Eyz", "2"], "+", 
    SuperscriptBox["Ezw", "2"], "-", 
    SuperscriptBox["Ezx", "2"], "-", 
    SuperscriptBox["Ezy", "2"], "-", 
    SuperscriptBox["Ezz", "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.742175262040555*^9},
 CellLabel->
  "Out[209]=",ExpressionUUID->"82cef49c-4ca8-44bb-bde4-cfc1edcbba8d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], "[", 
        RowBox[{"[", "k", "]"}], "]"}], "\[Rule]", " ", 
       RowBox[{"the4DpNs", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}], "//", "Expand"}], "//",
    "Factor"}]}]], "Input",
 CellChangeTimes->{
  3.742175085344677*^9},ExpressionUUID->"f18696c0-e9fb-4d08-aaa6-\
83443271a14a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"(*", " ", 
   RowBox[{"Transpose", " ", "admits", " ", "no", " ", 
    RowBox[{"solution", " ", "--"}], " ", "strange", " ", "but", " ", 
    RowBox[{"true", " ", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"Tr", "[", "hornM4mat", "]"}], " ", ")"}], "2"]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"Tr", "[", 
        RowBox[{"hornM4mat", ".", " ", 
         RowBox[{"Transpose", "[", "hornM4mat", "]"}]}], "]"}]}]}], ")"}], 
    "-", 
    RowBox[{"(", 
     RowBox[{"p2", "/.", "pn4toEwwRule"}], ")"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.74217547907576*^9, 3.742175507600637*^9}, {
  3.7421760197588387`*^9, 
  3.742176045545156*^9}},ExpressionUUID->"cab463a4-2614-4b33-9c7a-\
b972f8c276c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["Ewx", "2"], "+", 
    SuperscriptBox["Ewy", "2"], "+", 
    SuperscriptBox["Ewz", "2"], "+", 
    SuperscriptBox["Exw", "2"], "+", 
    SuperscriptBox["Eyw", "2"], "+", 
    SuperscriptBox["Ezw", "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.742175503015806*^9, 3.7421755087479897`*^9}},
 CellLabel->
  "Out[213]=",ExpressionUUID->"a2b33715-bdb3-4a02-85a6-22c630c80436"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve p2", "Subsubsection",
 CellChangeTimes->{{3.742176781266982*^9, 
  3.742176783394877*^9}},ExpressionUUID->"75c1db07-edd2-4980-be80-\
3cef5723beaf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"check2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"the4DpNs", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"Tr", "[", "hornM4mat", "]"}], ")"}], "2"]}], " ", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Tr", "[", 
        RowBox[{"hornM4mat", ".", "hornM4mat"}], "]"}]}]}], ")"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.742000466356325*^9, 3.742000485292639*^9}, {
   3.742000576911707*^9, 3.7420005950994997`*^9}, {3.742000740551119*^9, 
   3.742000742898608*^9}, 3.7420010361506166`*^9, {3.742001100365363*^9, 
   3.742001135022172*^9}, {3.74200337519132*^9, 3.742003481341872*^9}, {
   3.7420035878418427`*^9, 3.7420035896334267`*^9}, {3.742175901726103*^9, 
   3.7421759274105387`*^9}},
 CellLabel->
  "In[219]:=",ExpressionUUID->"c2579004-87fb-4431-a9ec-3b9b82574df8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"8", " ", "a"}], "+", 
     RowBox[{"2", " ", "b"}]}], ")"}], " ", 
   SuperscriptBox["Eww", "2"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", "b"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Ewx", "2"], "+", 
     SuperscriptBox["Ewy", "2"], "+", 
     SuperscriptBox["Ewz", "2"], "+", 
     SuperscriptBox["Exw", "2"], "-", 
     SuperscriptBox["Exx", "2"], "-", 
     SuperscriptBox["Exy", "2"], "-", 
     SuperscriptBox["Exz", "2"], "+", 
     SuperscriptBox["Eyw", "2"], "-", 
     SuperscriptBox["Eyx", "2"], "-", 
     SuperscriptBox["Eyy", "2"], "-", 
     SuperscriptBox["Eyz", "2"], "+", 
     SuperscriptBox["Ezw", "2"], "-", 
     SuperscriptBox["Ezx", "2"], "-", 
     SuperscriptBox["Ezy", "2"], "-", 
     SuperscriptBox["Ezz", "2"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.742000468983795*^9, 3.742000492451717*^9}, 
   3.7420005957566357`*^9, 3.742000744451749*^9, 3.742001037247075*^9, {
   3.742001130596034*^9, 3.742001136339373*^9}, {3.742003420143887*^9, 
   3.742003482129079*^9}, 3.74200359283057*^9, {3.742175919320499*^9, 
   3.7421759295911293`*^9}},
 CellLabel->
  "Out[219]=",ExpressionUUID->"6ace9591-7ab5-4789-b798-7cf38ef8d43e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"8", " ", "a"}], "+", 
        RowBox[{"2", " ", "b"}]}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "b"}]}], "\[Equal]", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.742003620165824*^9, 3.742003654840784*^9}},
 CellLabel->
  "In[1201]:=",ExpressionUUID->"0e1f01c3-77ff-4202-ba05-3c70e40c5398"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", 
    FractionBox["1", "2"]}], ",", 
   RowBox[{"b", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.742003647680653*^9, 3.7420036557054987`*^9}},
 CellLabel->
  "Out[1201]=",ExpressionUUID->"21695b5c-90ce-42d3-a130-5775d248fdc3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Tr", "[", "hornM4mat", "]"}], " ", ")"}], "2"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Tr", "[", 
       RowBox[{"hornM4mat", ".", " ", "hornM4mat"}], "]"}]}]}], ")"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.742172090709877*^9, 3.7421720932959633`*^9}},
 FontWeight->"Plain",
 CellLabel->
  "In[173]:=",ExpressionUUID->"5ebf1278-faca-4199-8169-95897ee7920a"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["Eww", "2"]}], "+", 
    SuperscriptBox["Ewx", "2"], "+", 
    SuperscriptBox["Ewy", "2"], "+", 
    SuperscriptBox["Ewz", "2"], "+", 
    SuperscriptBox["Exw", "2"], "-", 
    SuperscriptBox["Exx", "2"], "-", 
    SuperscriptBox["Exy", "2"], "-", 
    SuperscriptBox["Exz", "2"], "+", 
    SuperscriptBox["Eyw", "2"], "-", 
    SuperscriptBox["Eyx", "2"], "-", 
    SuperscriptBox["Eyy", "2"], "-", 
    SuperscriptBox["Eyz", "2"], "+", 
    SuperscriptBox["Ezw", "2"], "-", 
    SuperscriptBox["Ezx", "2"], "-", 
    SuperscriptBox["Ezy", "2"], "-", 
    SuperscriptBox["Ezz", "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.742172086960574*^9, 3.7421720937059298`*^9}},
 CellLabel->
  "Out[173]=",ExpressionUUID->"ef7eab37-bc59-48d8-8917-ed382a9b41cb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve p3", "Subsubsection",
 CellChangeTimes->{{3.742176850754377*^9, 
  3.7421768526665154`*^9}},ExpressionUUID->"49edc810-1df7-4b22-9f51-\
68a40bf35e9a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"the4DpNs", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", " ", 
   RowBox[{"a", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Tr", "[", "hornE4mat", "]"}], " ", ")"}], "3"]}], "+", 
   RowBox[{"b", " ", 
    RowBox[{"Tr", "[", 
     RowBox[{"hornE4mat", ".", "hornE4mat"}], "]"}], 
    RowBox[{"Tr", "[", "hornE4mat", "]"}]}], " ", "+", " ", 
   RowBox[{"c", " ", 
    RowBox[{"Tr", "[", 
     RowBox[{"hornE4mat", ".", "hornE4mat", ".", "hornE4mat"}], "]"}]}]}], "//",
   "Simplify"}]], "Input",
 CellChangeTimes->{{3.7420026048695183`*^9, 3.7420026188162823`*^9}, 
   3.7420027115574903`*^9},
 CellLabel->
  "In[1178]:=",ExpressionUUID->"37999a61-ef7d-4ced-9f79-210b67b27ab2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"16", " ", "a"}], "+", 
     RowBox[{"4", " ", "b"}], "+", "c"}], ")"}], " ", 
   SuperscriptBox["Eww", "3"]}], "+", 
  RowBox[{"8", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"3", " ", "c"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Ewz", " ", "Exw", " ", "Exz"}], "+", 
     RowBox[{"Ewz", " ", "Eyw", " ", "Eyz"}], "-", 
     RowBox[{"Exz", " ", "Eyy", " ", "Ezx"}], "+", 
     RowBox[{"Exy", " ", "Eyz", " ", "Ezx"}], "+", 
     RowBox[{"Ewx", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exw", " ", "Exx"}], "+", 
        RowBox[{"Eyw", " ", "Eyx"}], "+", 
        RowBox[{"Ezw", " ", "Ezx"}]}], ")"}]}], "+", 
     RowBox[{"Exz", " ", "Eyx", " ", "Ezy"}], "-", 
     RowBox[{"Exx", " ", "Eyz", " ", "Ezy"}], "+", 
     RowBox[{"Ewy", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exw", " ", "Exy"}], "+", 
        RowBox[{"Eyw", " ", "Eyy"}], "+", 
        RowBox[{"Ezw", " ", "Ezy"}]}], ")"}]}], "-", 
     RowBox[{"Exy", " ", "Eyx", " ", "Ezz"}], "+", 
     RowBox[{"Exx", " ", "Eyy", " ", "Ezz"}], "+", 
     RowBox[{"Ewz", " ", "Ezw", " ", "Ezz"}]}], ")"}]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"4", " ", "b"}], "+", 
     RowBox[{"3", " ", "c"}]}], ")"}], " ", "Eww", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Ewx", "2"], "+", 
     SuperscriptBox["Ewy", "2"], "+", 
     SuperscriptBox["Ewz", "2"], "+", 
     SuperscriptBox["Exw", "2"], "-", 
     SuperscriptBox["Exx", "2"], "-", 
     SuperscriptBox["Exy", "2"], "-", 
     SuperscriptBox["Exz", "2"], "+", 
     SuperscriptBox["Eyw", "2"], "-", 
     SuperscriptBox["Eyx", "2"], "-", 
     SuperscriptBox["Eyy", "2"], "-", 
     SuperscriptBox["Eyz", "2"], "+", 
     SuperscriptBox["Ezw", "2"], "-", 
     SuperscriptBox["Ezx", "2"], "-", 
     SuperscriptBox["Ezy", "2"], "-", 
     SuperscriptBox["Ezz", "2"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7420026133421097`*^9, 3.742002619440751*^9}, 
   3.742002712961231*^9},
 CellLabel->
  "Out[1178]=",ExpressionUUID->"dc60a00d-4668-4dcb-8959-5e6cf64fca85"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"16", " ", "a"}], "+", 
         RowBox[{"4", " ", "b"}], "+", "c"}], ")"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"3", " ", "c"}]}], ")"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"4", " ", "b"}], "+", 
         RowBox[{"3", " ", "c"}]}], ")"}], "\[Equal]", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.742002383671001*^9, 3.742002397812316*^9}, {
  3.742002458451269*^9, 3.742002506271576*^9}, {3.742002638216896*^9, 
  3.742002675314321*^9}, {3.742002724460679*^9, 3.742002742334003*^9}},
 CellLabel->
  "In[1179]:=",ExpressionUUID->"983fdc82-5a58-4044-8afc-85b5bc1ee873"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["1", "6"]}]}], ",", 
    RowBox[{"b", "\[Rule]", 
     FractionBox["1", "2"]}], ",", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["1", "3"]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.742002498479817*^9, 3.742002507244934*^9}, 
   3.742002677971261*^9, 3.742002743601966*^9},
 CellLabel->
  "Out[1179]=",ExpressionUUID->"c0eced75-ae4d-4ff1-8e64-576522367911"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.742176005280984*^9},ExpressionUUID->"04df9630-dbe5-4948-b738-\
d9fab06c2bf4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["All 4D Mww solutions for Pn:", "Subsubsection",
 CellChangeTimes->{{3.742176793738963*^9, 
  3.742176805658972*^9}},ExpressionUUID->"dfd236e7-b2a6-4cf1-8a04-\
37dc0a148ddc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Tr", "[", "hornM4mat", "]"}]}], " ", "-", 
    RowBox[{"(", 
     RowBox[{"p1", "/.", "pn4toEwwRule"}], ")"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"Tr", "[", "hornM4mat", "]"}], " ", ")"}], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"Tr", "[", 
         RowBox[{"hornM4mat", ".", " ", "hornM4mat"}], "]"}]}]}], ")"}], "-", 
     
     RowBox[{"(", 
      RowBox[{"p2", "/.", "pn4toEwwRule"}], ")"}]}], "//", "Simplify"}], ",", 
   " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"-", "1"}], "6"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"Tr", "[", "hornM4mat", "]"}], " ", ")"}], "3"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}], 
        RowBox[{"Tr", "[", 
         RowBox[{"hornM4mat", ".", "hornM4mat"}], "]"}], 
        RowBox[{"Tr", "[", "hornM4mat", "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}], 
        RowBox[{"Tr", "[", 
         RowBox[{"hornM4mat", ".", "hornM4mat", ".", "hornM4mat"}], "]"}]}]}],
       ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"p3", "/.", "pn4toEwwRule"}], ")"}]}], "//", "Simplify"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.74217189723024*^9, 3.742172040651692*^9}, {
  3.742173740377308*^9, 3.742173751947322*^9}, {3.742174322961913*^9, 
  3.74217441684933*^9}, {3.742174491105938*^9, 3.7421745035418577`*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"056c49ef-681d-4f72-bc1a-28791c1ae97a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.742174417517365*^9, 3.74217450494936*^9},
 CellLabel->
  "Out[201]=",ExpressionUUID->"e5c312c6-79ca-426c-b6b7-8f3dbac6a541"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["TEST these against the sign of the Square Root arg:",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.7264270809910927`*^9, 
  3.726427098214464*^9}},ExpressionUUID->"321395e8-e5c0-44bb-aa85-\
df100d9685fe"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"argSqrt", "[", 
    RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["p3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p1", "2"]}], " ", 
           SuperscriptBox["p2", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["p1", "3"], " ", "p3"}], "-", 
          RowBox[{"18", " ", "p1", " ", "p2", " ", "p3"}], "+", 
          RowBox[{"27", " ", 
           SuperscriptBox["p3", "2"]}]}], ")"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p1", "2"], "-", 
             RowBox[{"4", " ", "p2"}]}], ")"}], " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"p1", " ", "p2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p1", "2"]}], "+", 
             RowBox[{"40", " ", "p2"}]}], ")"}], " ", "p3"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p1", "2"], "-", 
             RowBox[{"24", " ", "p2"}]}], ")"}], " ", 
           SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"27", " ", 
           SuperscriptBox["p1", "4"]}], "-", 
          RowBox[{"144", " ", 
           SuperscriptBox["p1", "2"], " ", "p2"}], "+", 
          RowBox[{"128", " ", 
           SuperscriptBox["p2", "2"]}], "+", 
          RowBox[{"192", " ", "p1", " ", "p3"}]}], ")"}], " ", 
        SuperscriptBox["p4", "2"]}], "-", 
       RowBox[{"768", " ", 
        SuperscriptBox["p4", "3"]}]}], ")"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"argSqrt", "[", 
    RowBox[{"0", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"12", " ", 
       SuperscriptBox["p2", "3"], " ", 
       SuperscriptBox["p3", "2"]}], "+", 
      RowBox[{"81", " ", 
       SuperscriptBox["p3", "4"]}], "-", 
      RowBox[{"48", " ", "p2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "3"], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
      RowBox[{"384", " ", 
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["p4", "2"]}], "-", 
      RowBox[{"768", " ", 
       SuperscriptBox["p4", "3"]}]}], ")"}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7264229333233843`*^9, 3.726422986150238*^9}, {
  3.726425544192577*^9, 3.7264255589768867`*^9}, {3.726425608192306*^9, 
  3.7264256305354156`*^9}, {3.726425883261074*^9, 
  3.726425901812311*^9}},ExpressionUUID->"9b6ec4fb-aed3-4306-bd8d-\
ff0c28a201a8"],

Cell[TextData[StyleBox["  3D spectrum  - Signs of argSqrt always positive",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726427118446517*^9, 3.726427127334607*^9}, {
  3.72642779374446*^9, 
  3.726427804071228*^9}},ExpressionUUID->"51eac93e-8f42-4dd7-b7ce-\
10a2425deaca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makePnNumRule", "[", 
  RowBox[{"makeXYZnumRule", "[", 
   RowBox[{"makeMxxmat", "[", 
    RowBox[{"makeExxmat", "@@", 
     RowBox[{
      RowBox[{"buildXRMSDdataset", "[", "10", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.7264271611294127`*^9, 
  3.7264271900095587`*^9}},ExpressionUUID->"d102d7a8-0cfe-4ea8-8034-\
602f1cc3fe15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "47.608321090660496`"}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "122.48424077088704`"}]}], ",", 
   RowBox[{"p4", "\[Rule]", 
    RowBox[{"-", "50.21483977344642`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7264271744259653`*^9, 
  3.726427214536788*^9},ExpressionUUID->"d02dfd5b-5d8b-49b5-bd36-\
e1b851983830"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"argSqrt", "[", 
  RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellChangeTimes->{{3.726427231501376*^9, 
  3.726427249189563*^9}},ExpressionUUID->"86e7143e-165e-47cd-89ae-\
5b35953b5ab7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "12"}], " ", 
   SuperscriptBox["p2", "3"], " ", 
   SuperscriptBox["p3", "2"]}], "-", 
  RowBox[{"81", " ", 
   SuperscriptBox["p3", "4"]}], "+", 
  RowBox[{"48", " ", "p2", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "3"], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "-", 
  RowBox[{"384", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["p4", "2"]}], "+", 
  RowBox[{"768", " ", 
   SuperscriptBox["p4", "3"]}]}]], "Output",
 CellChangeTimes->{
  3.726427252382608*^9},ExpressionUUID->"5f07f53e-f0c6-43c8-9e8f-\
37212e63f417"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"ArgSqrt", " ", "always", " ", "POSITIVE"}], " ", "*)"}], 
  RowBox[{"Sign", "/@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"argSqrt", "[", 
       RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", " ", 
      RowBox[{"makePnNumRule", "[", 
       RowBox[{"makeXYZnumRule", "[", 
        RowBox[{"makeMxxmat", "[", 
         RowBox[{"makeExxmat", "@@", 
          RowBox[{
           RowBox[{"buildXRMSDdataset", "[", "100", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], "]"}]}], 
     ",", 
     RowBox[{"{", "100", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7264272627382383`*^9, 3.726427294305183*^9}, {
  3.726427357644812*^9, 3.726427400493045*^9}, {3.7264277548905277`*^9, 
  3.726427763753323*^9}},ExpressionUUID->"6887ca06-537f-4845-80f6-\
ebf1ea5dbc12"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.726427401468175*^9},ExpressionUUID->"02f3c188-27bd-4a15-8a67-\
ff6910c38432"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Parts", " ", "always", " ", "NEGATIVE"}], " ", "*)"}], 
  RowBox[{"Sign", "/@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p2", ",", "p3", ",", "p4"}], "}"}], "/.", " ", 
      RowBox[{"makePnNumRule", "[", 
       RowBox[{"makeXYZnumRule", "[", 
        RowBox[{"makeMxxmat", "[", 
         RowBox[{"makeExxmat", "@@", 
          RowBox[{
           RowBox[{"buildXRMSDdataset", "[", "100", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], "]"}]}], 
     ",", 
     RowBox[{"{", "20", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7264272627382383`*^9, 3.726427294305183*^9}, {
  3.726427357644812*^9, 3.726427400493045*^9}, {3.726427605187331*^9, 
  3.726427609971038*^9}, {3.7264277363383923`*^9, 
  3.726427771944706*^9}},ExpressionUUID->"a6c787a8-0bfd-4180-8a97-\
e30a45ccc565"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.726427612770608*^9, 
  3.726427772768365*^9},ExpressionUUID->"7cda377f-621a-44cb-9b76-\
7d48d21ccf00"]
}, Open  ]],

Cell[TextData[StyleBox[" 4D spectrum  - Signs seem to be MIXED, unlike 3D",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7264272071094847`*^9, 3.7264272102220078`*^9}, {
  3.726427778440761*^9, 
  3.726427789184245*^9}},ExpressionUUID->"ea6a1c5b-36ba-4c2a-b6e7-\
a1aeb9514d60"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makePn4NumRule", "[", 
  RowBox[{"makeWXYZnumRule", "[", 
   RowBox[{"makeMwwmat", "[", 
    RowBox[{"makeEwwmat", "@@", 
     RowBox[{
      RowBox[{"buildX4DRMSDdataset", "[", "10", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.726427315381184*^9, 
  3.7264273170779057`*^9}},ExpressionUUID->"90799a22-a964-4b62-a400-\
84e6db93e156"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", 
    RowBox[{"-", "16.565421277996606`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", "59.1147413270866`"}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "184.1739314683317`"}]}], ",", 
   RowBox[{"p4", "\[Rule]", "217.42399651097253`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726427317620111*^9},ExpressionUUID->"34e8df9e-5664-4591-bbbb-\
649a85edc20a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Sign", " ", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"argSqrt", "[", 
       RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", "  ", 
      RowBox[{"makePn4NumRule", "[", 
       RowBox[{"makeWXYZnumRule", "[", 
        RowBox[{"makeMwwmat", "[", 
         RowBox[{"makeEwwmat", "@@", 
          RowBox[{
           RowBox[{"buildX4DRMSDdataset", "[", "100", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], "]"}]}], 
     ")"}]}], ",", 
   RowBox[{"{", "100", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.72642692849697*^9, 3.7264269826657248`*^9}, {
  3.72642702809079*^9, 3.726427032047853*^9}, {3.7264274297275543`*^9, 
  3.726427507203341*^9}, {3.726427842036381*^9, 
  3.726427904306175*^9}},ExpressionUUID->"d132a9a8-92b3-47c3-a79f-\
ec42488edd5b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7264274764942102`*^9, 3.726427509976411*^9, 3.7264278471984386`*^9, {
   3.7264278803619633`*^9, 
   3.726427906958324*^9}},ExpressionUUID->"4346fab0-64c9-4e1d-931e-\
1b10f8a49b74"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.726427543877983*^9, 
  3.726427547810573*^9}},ExpressionUUID->"f1d1cb09-1d77-46c4-aadb-\
b7619475c0d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "21"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "79"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726427548376298*^9},ExpressionUUID->"7af5222c-578a-4a0a-b284-\
7d88cdfe42c0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "[", 
  RowBox[{"Sign", "/@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], "/.", "  ", 
      RowBox[{"makePn4NumRule", "[", 
       RowBox[{"makeWXYZnumRule", "[", 
        RowBox[{"makeMwwmat", "[", 
         RowBox[{"makeEwwmat", "@@", 
          RowBox[{
           RowBox[{"buildX4DRMSDdataset", "[", "10", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], "]"}]}], 
     ",", 
     RowBox[{"{", "1000", "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.726427824072425*^9, 3.72642783643226*^9}, {
  3.72642792042346*^9, 3.726427920607266*^9}, {3.726428031792079*^9, 
  3.7264280556867027`*^9}, {3.726428099104556*^9, 
  3.726428117965493*^9}},ExpressionUUID->"02320950-f2fc-489d-8048-\
ff07570423db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", "284"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", "54"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", "65"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "280"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1"}], "}"}], ",", "71"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "145"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", "56"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", "45"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7264279215159597`*^9, {3.726428033817645*^9, 3.726428057802672*^9}, {
   3.726428101147423*^9, 
   3.726428121087851*^9}},ExpressionUUID->"9041694c-6b79-4c7a-8a94-\
2e6ea106b19c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Do one more type of test: do a whole mass of 3D and \
4D eigenvalues",
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Subsubsection",
 CellChangeTimes->{{3.726429840963744*^9, 
  3.726429862115827*^9}},ExpressionUUID->"a125393e-5818-4ced-b444-\
fb65ef9346e0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"theEigValN", "[", 
    RowBox[{"1", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "-", 
   RowBox[{"optEigVal", "[", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.726430135065439*^9, 
  3.726430204056229*^9}},ExpressionUUID->"230bf0e7-9976-47ce-867a-\
3c2feb6628a5"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7264301421558228`*^9, 
  3.726430204799036*^9}},ExpressionUUID->"fcbf3c51-7e1c-4e84-9fe4-\
e054c2cec592"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"datasetPrule3", ",", "theMxxmat"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"theMxxmat", " ", "=", 
       RowBox[{"makeMxxmat", "[", 
        RowBox[{"makeExxmat", "@@", 
         RowBox[{
          RowBox[{"buildXRMSDdataset", "[", "100", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}]}], ";", 
      RowBox[{"datasetPrule3", "=", 
       RowBox[{"makePnNumRule", "[", 
        RowBox[{"makeXYZnumRule", "[", "theMxxmat", "]"}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"theEigValN", "[", 
             RowBox[{"i", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
          "datasetPrule3"}], ",", " ", 
         RowBox[{"Sort", "[", 
          RowBox[{
           RowBox[{"Eigenvalues", "[", "theMxxmat", "]"}], ",", 
           RowBox[{
            RowBox[{"#1", ">", "#2"}], "&"}]}], "]"}]}], "}"}], "//", 
       "Chop"}]}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.726430217492955*^9, 3.726430321655702*^9}, {
  3.726430358178335*^9, 3.7264305563175297`*^9}, {3.726430650142371*^9, 
  3.726430696756957*^9}},ExpressionUUID->"a1cd676d-c82e-4766-b806-\
ccde70f3de3b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100.94456385917533`", ",", 
       RowBox[{"-", "22.021827630422294`"}], ",", 
       RowBox[{"-", "31.014855137234335`"}], ",", 
       RowBox[{"-", "47.9078810915187`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"100.94456385917528`", ",", 
       RowBox[{"-", "22.021827630422102`"}], ",", 
       RowBox[{"-", "31.01485513723457`"}], ",", 
       RowBox[{"-", "47.907881091518675`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100.35100829228375`", ",", 
       RowBox[{"-", "27.114780640914354`"}], ",", 
       RowBox[{"-", "33.77909286884437`"}], ",", 
       RowBox[{"-", "39.45713478252503`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"100.3510082922837`", ",", 
       RowBox[{"-", "27.114780640918422`"}], ",", 
       RowBox[{"-", "33.77909286883588`"}], ",", 
       RowBox[{"-", "39.45713478252946`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.726430557585249*^9, {3.726430652473729*^9, 
   3.72643069840486*^9}},ExpressionUUID->"51e2236d-5819-42ea-bb8b-\
dd4654f93fe3"]
}, Open  ]],

Cell[TextData[StyleBox["  Hmm 4D data have imaginary eigenvalues, both \
analytic and numeric,\n   and the phases disagree...",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726430881145071*^9, 
  3.7264309119771023`*^9}},ExpressionUUID->"6af59048-7641-4dbe-9db8-\
795933c41aad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"datasetPrule4", ",", "theMwwmat"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"theMwwmat", " ", "=", 
       RowBox[{"makeMwwmat", "[", 
        RowBox[{"makeEwwmat", "@@", 
         RowBox[{
          RowBox[{"buildX4DRMSDdataset", "[", "100", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}]}], ";", 
      RowBox[{"datasetPrule4", "=", 
       RowBox[{"makePn4NumRule", "[", 
        RowBox[{"makeWXYZnumRule", "[", "theMwwmat", "]"}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"theEigValN", "[", 
             RowBox[{"i", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}],
             ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
          "datasetPrule4"}], ",", " ", 
         RowBox[{"Sort", "[", 
          RowBox[{
           RowBox[{"Eigenvalues", "[", "theMwwmat", "]"}], ",", 
           RowBox[{
            RowBox[{"#1", ">", "#2"}], "&"}]}], "]"}]}], "}"}], "//", 
       "Chop"}]}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.726430217492955*^9, 3.726430338327672*^9}, {
  3.726430722036252*^9, 
  3.726430811051353*^9}},ExpressionUUID->"1c88d72e-a8f9-4b4d-904c-\
f1f944ad47f3"],

Cell[BoxData[
 TemplateBox[{
  "Greater","nord",
   "\"Invalid comparison with \\!\\(\\*RowBox[{RowBox[{\\\"3.228527813585968`\
\\\", \\\"\[VeryThinSpace]\\\"}], \\\"+\\\", RowBox[{\\\"9.335694823762438`\\\
\", \\\" \\\", \\\"\[ImaginaryI]\\\"}]}]\\) attempted.\"",2,447,19,
   27227075904496510320,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.726430815441276*^9},ExpressionUUID->"af437db0-eeb2-4c6c-b332-\
19a09d632ecf"],

Cell[BoxData[
 TemplateBox[{
  "Greater","nord",
   "\"Invalid comparison with \\!\\(\\*RowBox[{RowBox[{\\\"3.228527813585968`\
\\\", \\\"\[VeryThinSpace]\\\"}], \\\"-\\\", RowBox[{\\\"9.335694823762438`\\\
\", \\\" \\\", \\\"\[ImaginaryI]\\\"}]}]\\) attempted.\"",2,447,20,
   27227075904496510320,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.726430815466604*^9},ExpressionUUID->"9cafc88e-16d3-427e-9e27-\
49332cfce561"],

Cell[BoxData[
 TemplateBox[{
  "Greater","nord",
   "\"Invalid comparison with \\!\\(\\*RowBox[{RowBox[{\\\"3.228527813585968`\
\\\", \\\"\[VeryThinSpace]\\\"}], \\\"+\\\", RowBox[{\\\"9.335694823762438`\\\
\", \\\" \\\", \\\"\[ImaginaryI]\\\"}]}]\\) attempted.\"",2,447,21,
   27227075904496510320,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.726430815479991*^9},ExpressionUUID->"e3cec28d-1063-4f5d-b7a7-\
58bab10be95c"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Greater\\\", \
\\\"::\\\", \\\"nord\\\"}], \\\"MessageName\\\"]\\) will be suppressed during \
this calculation.\"",2,447,22,27227075904496510320,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.726430815493587*^9},ExpressionUUID->"4d38fd9b-fcd0-4d0d-a6f0-\
d3862b34b3b5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"133.5807174332257`", ",", 
       RowBox[{"-", "8.78621188537128`"}], ",", 
       RowBox[{"3.228527813585977`", "\[VeryThinSpace]", "+", 
        RowBox[{"9.335694823762433`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"3.228527813585977`", "\[VeryThinSpace]", "-", 
        RowBox[{"9.335694823762433`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"133.58071743322563`", ",", 
       RowBox[{"3.228527813585968`", "\[VeryThinSpace]", "+", 
        RowBox[{"9.335694823762438`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"3.228527813585968`", "\[VeryThinSpace]", "-", 
        RowBox[{"9.335694823762438`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"-", "8.786211885371282`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"96.78707006129676`", ",", "17.832528758191614`", ",", 
       RowBox[{"-", "4.957296059044724`"}], ",", 
       RowBox[{"-", "18.732940044394525`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"96.78707006129676`", ",", "17.832528758191632`", ",", 
       RowBox[{"-", "4.957296059044727`"}], ",", 
       RowBox[{"-", "18.732940044394514`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7264308154964037`*^9},ExpressionUUID->"121161bb-9243-4cc5-87eb-\
b46f28c7d373"]
}, Open  ]],

Cell[BoxData["optEigVal"], "Input",
 CellChangeTimes->{{3.7264299446069517`*^9, 
  3.7264299561787567`*^9}},ExpressionUUID->"056ceca7-3020-4cf5-b12e-\
6218b408c682"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.726429939989843*^9},ExpressionUUID->"d0de3bfa-5ac6-4714-95a8-\
d9bd569c77b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
III. Get the eigenvalue: remember to CHOP to get rid of small imaginary \
rounding errors.\
\>", "Subsubsection",
 CellChangeTimes->{{3.725626507556843*^9, 3.725626513845685*^9}, {
  3.7256267379626513`*^9, 
  3.725626753002713*^9}},ExpressionUUID->"a197fc58-ec01-4c90-b17a-\
c271f7a91730"],

Cell[TextData[StyleBox[" Need to define optEigVal from below, remember to \
Chop.",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726080718493637*^9, 
  3.7260807523494453`*^9}},ExpressionUUID->"f2e6e107-7f5f-47d6-8442-\
51adff2307cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeEigvalNumRule", "[", "PnNumRule_", "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"eigval", "\[Rule]", " ", 
      RowBox[{"optEigval", "[", 
       RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], "/.", 
     "PnNumRule"}], "//", "Chop"}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725626525757311*^9, 3.7256265336288137`*^9}, {
  3.725626903242159*^9, 3.725626924218074*^9}, {3.725626980985113*^9, 
  3.725626993641101*^9}, {3.72562776703498*^9, 3.72562776853891*^9}},
 CellLabel->
  "In[427]:=",ExpressionUUID->"e3fd09f0-a77f-430a-8d16-336693e72fa0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Build the eigenvectors from the eigenvalues:",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.726073125942054*^9, 3.7260731341658707`*^9}, {
  3.7260747973918056`*^9, 
  3.7260748086474237`*^9}},ExpressionUUID->"9292fb44-f54d-488e-89ab-\
7703dde55878"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optSolve", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"hornAmat", "[", 
            RowBox[{"[", 
             RowBox[{"i", "+", "1"}], "]"}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{"1", ",", "vx", ",", "vy", ",", "vz"}], "}"}]}], " ", "-",
           " ", 
          RowBox[{"e", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"vx", ",", "vy", ",", "vz"}], "}"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"vx", ",", "vy", ",", "vz"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.725305187567337*^9, 3.725305291481596*^9}, {
  3.725305341705224*^9, 3.7253054026085243`*^9}, {3.725305527708928*^9, 
  3.725305548367922*^9}},
 CellLabel->
  "In[608]:=",ExpressionUUID->"7c34e1c1-1e39-48d6-aafb-b2cc39f35383"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"vx", "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", 
          SuperscriptBox["aa", "2"]}], "+", 
         RowBox[{"aa", " ", "b", " ", "bb"}], "+", 
         RowBox[{"aa", " ", "c", " ", "cc"}], "+", 
         RowBox[{"bb", " ", "c", " ", "e"}], "+", 
         RowBox[{"b", " ", "cc", " ", "e"}], "+", 
         RowBox[{"bb", " ", "c", " ", "x"}], "+", 
         RowBox[{"b", " ", "cc", " ", "x"}], "-", 
         RowBox[{"bb", " ", "c", " ", "y"}], "+", 
         RowBox[{"b", " ", "cc", " ", "y"}], "+", 
         RowBox[{"bb", " ", "c", " ", "z"}], "-", 
         RowBox[{"b", " ", "cc", " ", "z"}], "+", 
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
         RowBox[{
          SuperscriptBox["bb", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["aa", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["cc", "2"], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], ")"}]}]}], ",", 
   RowBox[{"vy", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"aa", " ", "bb"}], "+", 
         RowBox[{"cc", " ", 
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
      "-", 
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"bb", " ", "cc"}], "+", 
         RowBox[{"aa", " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["bb", "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
     
     RowBox[{
      RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
      RowBox[{
       SuperscriptBox["bb", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["aa", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["cc", "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
        ")"}]}]}]]}], ",", 
   RowBox[{"vz", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"aa", " ", "cc"}], "+", 
         RowBox[{"bb", " ", 
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], 
      "-", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"bb", " ", "cc"}], "+", 
         RowBox[{"aa", " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["cc", "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
     
     RowBox[{
      RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
      RowBox[{
       SuperscriptBox["bb", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["aa", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["cc", "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
        ")"}]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.741104747215932*^9},
 CellLabel->
  "Out[608]=",ExpressionUUID->"ff936dd0-ffb3-471a-aaad-d0192135fd69"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Factor", " ", "out", " ", "denominator"}], " ", "*)"}], 
  RowBox[{"optQuatBare", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
        SuperscriptBox["cc", "2"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", "+", "x", "+", "y", "-", "z"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"e", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}], 
     RowBox[{"{", 
      RowBox[{"1", ",", "vx", ",", "vy", ",", "vz"}], "}"}]}], "/.", 
    "optSolve"}]}]}]], "Input",
 CellChangeTimes->{{3.725305617235581*^9, 3.725305668680132*^9}, {
  3.725584365937842*^9, 3.725584373803894*^9}, {3.726074846897582*^9, 
  3.7260748600242662`*^9}},ExpressionUUID->"d71c990e-fcf1-4fbf-a785-\
0ea0cb18e194"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvecRMSD", "[", 
   RowBox[{
   "eigval_", ",", "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", 
    "c_", ",", "aa_", ",", "bb_", ",", "cc_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qbare", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
          RowBox[{
           SuperscriptBox["cc", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["bb", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["aa", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ",", 
         
         RowBox[{
          RowBox[{"a", " ", 
           SuperscriptBox["aa", "2"]}], "-", 
          RowBox[{"aa", " ", "b", " ", "bb"}], "-", 
          RowBox[{"aa", " ", "c", " ", "cc"}], "-", 
          RowBox[{"b", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
          RowBox[{"bb", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ",", 
         
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "aa", " ", "bb"}], "+", 
          RowBox[{"b", " ", 
           SuperscriptBox["bb", "2"]}], "-", 
          RowBox[{"bb", " ", "c", " ", "cc"}], "-", 
          RowBox[{"a", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
          RowBox[{"aa", "  ", "c", 
           RowBox[{"(", " ", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ",", 
         
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "aa", " ", "cc"}], "-", 
          RowBox[{"b", " ", "bb", " ", "cc"}], "+", 
          RowBox[{"c", " ", 
           SuperscriptBox["cc", "2"]}], "-", 
          RowBox[{"a", " ", "bb", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{"aa", " ", "b", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}]}]}], 
        "}"}]}], ",", "norm"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"norm", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"qbare", ".", "qbare"}], "]"}]}], ";", " ", 
     RowBox[{"qbare", "/", "norm"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725575612366349*^9, 3.72557570949866*^9}, {
  3.7255842445435457`*^9, 3.725584257559821*^9}, {3.72558430173621*^9, 
  3.725584313739051*^9}, {3.7255849796150427`*^9, 3.7255850062316008`*^9}, {
  3.725585037682225*^9, 3.725585073930138*^9}, {3.725585120799941*^9, 
  3.725585123871475*^9}, {3.725585158541409*^9, 3.72558516776853*^9}},
 CellLabel->
  "In[283]:=",ExpressionUUID->"281c209a-f5ec-4827-a31f-c9f887b04808"],

Cell[CellGroupData[{

Cell["Get the whole optimal system:", "Subsubsection",
 CellChangeTimes->{{3.7417181269813232`*^9, 
  3.741718133124854*^9}},ExpressionUUID->"bee69428-b163-4ea7-b198-\
071591c8eac9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"optimalEigvalEigvec", "[", 
   RowBox[{"testData_", ",", "refData_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"profile", " ", "=", " ", 
       RowBox[{"makeMxxmat", "[", 
        RowBox[{"makeExxmat", "[", 
         RowBox[{"testData", ",", "refData"}], "]"}], "]"}]}], ",", 
      "\[IndentingNewLine]", "eigval", ",", "eigvec", ",", "xyzRules", ",", 
      "PnRules"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xyzRules", "=", 
      RowBox[{"makeXYZnumRule", "[", "profile", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"PnRules", "=", 
      RowBox[{"makePnNumRule", "[", "xyzRules", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eigval", " ", "=", " ", 
      RowBox[{
       RowBox[{"xyzEpsN", "[", 
        RowBox[{"1", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.",
        "PnRules"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"eigvec", " ", "=", " ", 
      RowBox[{
       RowBox[{"eigenvecRMSD", "[", 
        RowBox[{
        "eigval", ",", "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c", 
         ",", "aa", ",", "bb", ",", "cc"}], "]"}], "/.", "xyzRules"}]}], ";", 
     
     RowBox[{"{", 
      RowBox[{"eigval", ",", "eigvec"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741718143334503*^9, 3.741718181326496*^9}, {
  3.7417182167932167`*^9, 3.741718221993175*^9}},
 CellLabel->
  "In[284]:=",ExpressionUUID->"363a5cd6-f032-477f-838a-3d48bb9ab7dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"optimalEigvalEigvecFromProfile", "[", "profileMat_", "]"}], ":=", 
  " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"eigval", ",", "eigvec", ",", "xyzRules", ",", "PnRules"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xyzRules", "=", 
      RowBox[{"makeXYZnumRule", "[", "profileMat", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"PnRules", "=", 
      RowBox[{"makePnNumRule", "[", "xyzRules", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eigval", " ", "=", " ", 
      RowBox[{
       RowBox[{"xyzEpsN", "[", 
        RowBox[{"1", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.",
        "PnRules"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"eigvec", " ", "=", " ", 
      RowBox[{
       RowBox[{"eigenvecRMSD", "[", 
        RowBox[{
        "eigval", ",", "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c", 
         ",", "aa", ",", "bb", ",", "cc"}], "]"}], "/.", "xyzRules"}]}], ";", 
     
     RowBox[{"{", 
      RowBox[{"eigval", ",", "eigvec"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741718143334503*^9, 3.741718181326496*^9}, {
  3.7417182167932167`*^9, 3.741718221993175*^9}, {3.74171833039048*^9, 
  3.741718382127851*^9}},
 CellLabel->
  "In[285]:=",ExpressionUUID->"8254cc8f-1538-43f6-bdba-ee72e1a656c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optimalEigvalEigvec", "[", 
  RowBox[{
   RowBox[{"test3DPnt", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"test3DPnt", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.74171820180072*^9, 3.741718205485021*^9}, 
   3.741718308180668*^9},
 CellLabel->
  "In[240]:=",ExpressionUUID->"fefafc70-f989-41b4-ae81-096d46831720"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"240.99613042076453`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7762612391097554`"}], ",", "0.15462228985485835`", ",", 
     "0.39145999428129435`", ",", "0.4693287856216752`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.741718308870669*^9},
 CellLabel->
  "Out[240]=",ExpressionUUID->"9792afcc-3c1f-42af-acd1-4e61c76e18f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optimalEigvalEigvecFromProfile", "[", " ", 
  RowBox[{"makeMxxmat", "[", 
   RowBox[{"makeExxmat", "[", 
    RowBox[{
     RowBox[{"test3DPnt", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"test3DPnt", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7417184011870317`*^9, 3.74171842574734*^9}},
 CellLabel->
  "In[242]:=",ExpressionUUID->"25b7e61f-c395-4cdb-af91-fc40fc65293e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"240.99613042076453`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7762612391097554`"}], ",", "0.15462228985485835`", ",", 
     "0.39145999428129435`", ",", "0.4693287856216752`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.741718426900816*^9},
 CellLabel->
  "Out[242]=",ExpressionUUID->"53d863df-2257-440f-b27b-5a7e160fc3b0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get the whole Eigensystem:", "Subsubsection",
 CellChangeTimes->{{3.7417181269813232`*^9, 3.741718133124854*^9}, {
  3.7417961329002333`*^9, 
  3.7417961337631598`*^9}},ExpressionUUID->"0c38f3f8-f0ae-406c-bbb8-\
63f36f235d4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"test3DPnt", " ", "=", " ", 
   RowBox[{"build3DPntdataset", "[", 
    RowBox[{"400", ",", " ", 
     RowBox[{"Normalize", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", ".2", ",", ".5", ",", ".6"}], "}"}], "]"}]}], 
    "]"}]}], ";"}]], "Input",ExpressionUUID->"b218700e-3b68-4dd2-9d78-\
229b6f8c6157"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "/@", "test3DPnt"}]], "Input",
 CellChangeTimes->{{3.741796301386586*^9, 3.741796328451096*^9}, {
  3.741796460657798*^9, 3.74179647480171*^9}},
 CellLabel->
  "In[501]:=",ExpressionUUID->"e73debe0-df24-41d0-b647-314b35a8967e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"400", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "3"}], "}"}], ",", 
   RowBox[{"{", "4", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.741796304520197*^9, {3.741796462657062*^9, 3.741796475208733*^9}},
 CellLabel->
  "Out[501]=",ExpressionUUID->"8985eb51-5297-4ec3-a68f-421c5213abb4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"test3DpntProfile", " ", "=", " ", 
  RowBox[{"makeMxxmat", "[", 
   RowBox[{"makeExxmat", "[", 
    RowBox[{
     RowBox[{"test3DPnt", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"test3DPnt", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7417963818540993`*^9, 3.7417964380898867`*^9}},
 CellLabel->
  "In[499]:=",ExpressionUUID->"66cb68c9-6481-4c98-bd24-91b0dddb5e3f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"116.0340210512125`", ",", 
     RowBox[{"-", "37.85342899603464`"}], ",", 
     RowBox[{"-", "92.50886253101696`"}], ",", 
     RowBox[{"-", "117.05384556930932`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "37.85342899603464`"}], ",", 
     RowBox[{"-", "70.37127165642524`"}], ",", "11.454356325233341`", ",", 
     "30.41848097562628`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "92.50886253101696`"}], ",", "11.454356325233341`", ",", 
     RowBox[{"-", "27.21079244241182`"}], ",", "66.92565721881785`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "117.05384556930932`"}], ",", "30.41848097562628`", ",", 
     "66.92565721881785`", ",", 
     RowBox[{"-", "18.45195695237546`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741796439000301*^9},
 CellLabel->
  "Out[499]=",ExpressionUUID->"f7b7c3c7-aeb7-4db4-9a20-9800e7f023de"]
}, Open  ]],

Cell[TextData[StyleBox["Curious: note that the LARGEST eigenvector in the \
ALGEBRAIC solution\n    comes out with the OPPOSITE sign to the built-in \
Eigenvectors[ ] routine:\n    in fact we noticed that we had to change OUR \
sign when using this in a SLERP.\n    We wonder if there is some content to \
this difference...",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.741796740086473*^9, 
  3.741796830278458*^9}},ExpressionUUID->"3bb79ead-8bfd-4ea7-9431-\
40ef843a450b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"optimalEigSystem", "[", 
   RowBox[{"testData_", ",", "refData_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"profile", " ", "=", " ", 
       RowBox[{"makeMxxmat", "[", 
        RowBox[{"makeExxmat", "[", 
         RowBox[{"testData", ",", "refData"}], "]"}], "]"}]}], ",", 
      "\[IndentingNewLine]", "eigvals", ",", "eigvecs", ",", "xyzRules", ",", 
      "PnRules"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xyzRules", "=", 
      RowBox[{"makeXYZnumRule", "[", "profile", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"PnRules", "=", 
      RowBox[{"makePnNumRule", "[", "xyzRules", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eigvals", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"xyzEpsN", "[", 
          RowBox[{"k", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.",
          "PnRules"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eigvecs", " ", "=", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"eigenvecRMSD", "[", 
          RowBox[{
           RowBox[{"eigvals", "[", 
            RowBox[{"[", "k", "]"}], "]"}], ",", "x", ",", "y", ",", "z", ",",
            "a", ",", "b", ",", "c", ",", "aa", ",", "bb", ",", "cc"}], "]"}],
          "/.", "xyzRules"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"{", 
      RowBox[{"eigvals", ",", "eigvecs"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741718143334503*^9, 3.741718181326496*^9}, {
  3.7417182167932167`*^9, 3.741718221993175*^9}, {3.741796154368937*^9, 
  3.741796241188735*^9}},
 CellLabel->
  "In[286]:=",ExpressionUUID->"6aa86839-afed-48ad-aafe-befa9edea0d9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigensystem", "[", "test3DpntProfile", "]"}], 
  RowBox[{"(*", " ", "Unsorted", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.741796254990947*^9, 3.7417962879266233`*^9}, {
  3.741796490076642*^9, 3.7417965108690453`*^9}, {3.7417965573314447`*^9, 
  3.741796560256982*^9}},ExpressionUUID->"7fac0e6c-b56a-47a6-995e-\
015050593c6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"240.99613042076422`", ",", 
     RowBox[{"-", "98.36842547133334`"}], ",", 
     RowBox[{"-", "74.91298066353974`"}], ",", 
     RowBox[{"-", "67.71472428589148`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.7762612391097553`", ",", 
       RowBox[{"-", "0.15462228985485843`"}], ",", 
       RowBox[{"-", "0.39145999428129474`"}], ",", 
       RowBox[{"-", "0.46932878562167546`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.12995531313398645`", ",", 
       RowBox[{"-", "0.45012944206588734`"}], ",", 
       RowBox[{"-", "0.465061258687297`"}], ",", "0.7511412168440018`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.4940538377605845`"}], ",", 
       RowBox[{"-", "0.7290788934878696`"}], ",", 
       RowBox[{"-", "0.15519017232926452`"}], ",", 
       RowBox[{"-", "0.44751623755675585`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3693790879815383`", ",", 
       RowBox[{"-", "0.4918530267630737`"}], ",", "0.7787124687314881`", ",", 
       "0.1234770442958571`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.741796496444345*^9, 3.741796513573724*^9}},
 CellLabel->
  "Out[503]=",ExpressionUUID->"75704603-a133-40e3-81d9-431411206b73"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optimalEigSystem", "[", 
  RowBox[{
   RowBox[{"test3DPnt", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"test3DPnt", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.741796525808318*^9, 3.741796535832777*^9}},
 CellLabel->
  "In[504]:=",ExpressionUUID->"70fdcc5f-e6a6-4ea4-96c8-8572bb0a1362"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"240.99613042076453`", ",", 
     RowBox[{"-", "67.71472428589145`"}], ",", 
     RowBox[{"-", "74.91298066353993`"}], ",", 
     RowBox[{"-", "98.36842547133314`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7762612391097554`"}], ",", "0.15462228985485835`", ",",
        "0.39145999428129435`", ",", "0.4693287856216752`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3693790879815418`", ",", 
       RowBox[{"-", "0.4918530267630692`"}], ",", "0.7787124687314888`", ",", 
       "0.12347704429586037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.49405383776059336`"}], ",", 
       RowBox[{"-", "0.729078893487859`"}], ",", 
       RowBox[{"-", "0.15519017232928392`"}], ",", 
       RowBox[{"-", "0.4475162375567563`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.12995531313396264`", ",", 
       RowBox[{"-", "0.4501294420659006`"}], ",", 
       RowBox[{"-", "0.465061258687314`"}], ",", "0.7511412168439872`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741796537059647*^9},
 CellLabel->
  "Out[504]=",ExpressionUUID->"0134546a-d34d-4c99-a44e-a0fc9dbc7ff9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"optimalEigSystemFromProfile", "[", "profileMat_", "]"}], ":=", " ",
   "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"eigvals", ",", "eigvecs", ",", "xyzRules", ",", "PnRules"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xyzRules", "=", 
      RowBox[{"makeXYZnumRule", "[", "profileMat", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"PnRules", "=", 
      RowBox[{"makePnNumRule", "[", "xyzRules", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eigvals", " ", "=", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"xyzEpsN", "[", 
          RowBox[{"k", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.",
          "PnRules"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eigvecs", " ", "=", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"eigenvecRMSD", "[", 
          RowBox[{
           RowBox[{"eigvals", "[", 
            RowBox[{"[", "k", "]"}], "]"}], ",", "x", ",", "y", ",", "z", ",",
            "a", ",", "b", ",", "c", ",", "aa", ",", "bb", ",", "cc"}], "]"}],
          "/.", "xyzRules"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"{", 
      RowBox[{"eigvals", ",", "eigvecs"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741718143334503*^9, 3.741718181326496*^9}, {
  3.7417182167932167`*^9, 3.741718221993175*^9}, {3.74171833039048*^9, 
  3.741718382127851*^9}, {3.741796576500453*^9, 3.7417966519048967`*^9}},
 CellLabel->
  "In[505]:=",ExpressionUUID->"719d53ab-2159-4c4d-8f8f-a4826cead0d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optimalEigSystemFromProfile", "[", "test3DpntProfile", 
  "]"}]], "Input",
 CellChangeTimes->{{3.741796668967978*^9, 3.741796669623343*^9}},
 CellLabel->
  "In[506]:=",ExpressionUUID->"e8d71445-3ecc-4f0d-87e0-324bbe79348f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"240.99613042076453`", ",", 
     RowBox[{"-", "67.71472428589145`"}], ",", 
     RowBox[{"-", "74.91298066353993`"}], ",", 
     RowBox[{"-", "98.36842547133314`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.7762612391097554`"}], ",", "0.15462228985485835`", ",",
        "0.39145999428129435`", ",", "0.4693287856216752`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3693790879815418`", ",", 
       RowBox[{"-", "0.4918530267630692`"}], ",", "0.7787124687314888`", ",", 
       "0.12347704429586037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.49405383776059336`"}], ",", 
       RowBox[{"-", "0.729078893487859`"}], ",", 
       RowBox[{"-", "0.15519017232928392`"}], ",", 
       RowBox[{"-", "0.4475162375567563`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.12995531313396264`", ",", 
       RowBox[{"-", "0.4501294420659006`"}], ",", 
       RowBox[{"-", "0.465061258687314`"}], ",", "0.7511412168439872`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7417966702002707`*^9},
 CellLabel->
  "Out[506]=",ExpressionUUID->"84aedfe2-4814-48d2-9d57-4cd1ad97a660"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Build the traceful eigenvectors from the eigenvalues:",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.726073125942054*^9, 3.7260731341658707`*^9}, {
  3.7260747973918056`*^9, 3.7260748086474237`*^9}, {3.741104355022315*^9, 
  3.741104357079178*^9}},ExpressionUUID->"6d62e101-2a7a-45bc-b020-\
d9b8e23778ab"],

Cell[CellGroupData[{

Cell[BoxData["hornA4mat"], "Input",
 CellChangeTimes->{{3.741104380982201*^9, 3.741104383770585*^9}},
 CellLabel->
  "In[603]:=",ExpressionUUID->"999a8688-8518-4d0b-a507-cc2e713ffbc5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", 
     RowBox[{"a", "+", "aw"}], ",", 
     RowBox[{"b", "+", "bw"}], ",", 
     RowBox[{"c", "+", "cw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", "aw"}], ",", 
     RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", 
     RowBox[{"cc", "+", "ccw"}], ",", 
     RowBox[{"bb", "-", "bbw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", "-", "bw"}], ",", 
     RowBox[{"cc", "-", "ccw"}], ",", 
     RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", 
     RowBox[{"aa", "+", "aaw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "-", "cw"}], ",", 
     RowBox[{"bb", "+", "bbw"}], ",", 
     RowBox[{"aa", "-", "aaw"}], ",", 
     RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.741104384461095*^9},
 CellLabel->
  "Out[603]=",ExpressionUUID->"ee5bd601-7ce5-4622-9972-9b3ec2b101a5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornA4SymMat", "=", 
  RowBox[{"hornA4mat", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"aw", "\[Rule]", "0"}], ",", 
     RowBox[{"bw", "\[Rule]", "0"}], ",", 
     RowBox[{"cw", "\[Rule]", "0"}], ",", 
     RowBox[{"aaw", "\[Rule]", "0"}], ",", 
     RowBox[{"bbw", "\[Rule]", "0"}], ",", 
     RowBox[{"ccw", "\[Rule]", "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.7411043947981453`*^9, 3.741104453249879*^9}},
 CellLabel->
  "In[604]:=",ExpressionUUID->"0643396e-465a-4903-81e8-ef5a3514a2ae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", "a", ",", "b", ",", 
     "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", "cc", ",", "bb"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "cc", ",", 
     RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", "aa"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "bb", ",", "aa", ",", 
     RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.741104457798039*^9},
 CellLabel->
  "Out[604]=",ExpressionUUID->"c76d07c6-867c-4f7e-9a3b-7682ef0eb907"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optSolvep1", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"hornA4SymMat", "[", 
            RowBox[{"[", 
             RowBox[{"i", "+", "1"}], "]"}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{"1", ",", "vx", ",", "vy", ",", "vz"}], "}"}]}], " ", "-",
           " ", 
          RowBox[{"e", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"vx", ",", "vy", ",", "vz"}], "}"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"vx", ",", "vy", ",", "vz"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.725305187567337*^9, 3.725305291481596*^9}, {
  3.725305341705224*^9, 3.7253054026085243`*^9}, {3.725305527708928*^9, 
  3.725305548367922*^9}, {3.7411046468447*^9, 3.741104658202479*^9}},
 CellLabel->
  "In[607]:=",ExpressionUUID->"01894aab-aba1-47a7-96dd-de984d540d21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"vx", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", "aa"}], "-", 
          RowBox[{"b", " ", "bb"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "bb"}], "+", 
          RowBox[{"cc", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bb", " ", "c"}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "aa"}], " ", "cc"}], "-", 
          RowBox[{"bb", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"bb", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
         RowBox[{
          SuperscriptBox["bb", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox["aa", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
          
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["cc", "2"], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], 
              ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], ",", 
   RowBox[{"vy", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "bb"}], "+", 
          RowBox[{"cc", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bb", " ", "cc"}], "+", 
          RowBox[{"aa", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["bb", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
       
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
       
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["cc", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{"vz", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "cc"}], "+", 
          RowBox[{"bb", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bb", " ", "cc"}], "+", 
          RowBox[{"aa", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["cc", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
       
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
       
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["cc", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.741104669641706*^9},
 CellLabel->
  "Out[607]=",ExpressionUUID->"346cf623-1f00-45a9-b4f5-e0029dd06ffa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Factor", " ", "out", " ", "denominator"}], " ", "*)"}], 
  RowBox[{"optQuatBarep1", " ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
           RowBox[{
            SuperscriptBox["bb", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["aa", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["cc", "2"], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], 
               " ", 
               RowBox[{"(", 
                RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], 
                ")"}]}]}], ")"}]}]}], ")"}], 
         RowBox[{"{", 
          RowBox[{"1", ",", "vx", ",", "vy", ",", "vz"}], "}"}]}], "/.", 
        "optSolvep1"}], "//", "Expand"}], "//", "FullSimplify"}], ")"}], "/.", 
    RowBox[{"e", "\[Rule]", "eigval"}]}]}]}]], "Input",
 CellChangeTimes->{{3.725305617235581*^9, 3.725305668680132*^9}, {
  3.725584365937842*^9, 3.725584373803894*^9}, {3.726074846897582*^9, 
  3.7260748600242662`*^9}, {3.7411046855899143`*^9, 3.741104687559293*^9}, {
  3.741104829148344*^9, 3.741104882236814*^9}, {3.741105006542178*^9, 
  3.741105029603405*^9}},
 CellLabel->
  "In[614]:=",ExpressionUUID->"f6dd9ff7-7e7f-4f0b-b44d-06063b8d8a03"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], 
    "+", 
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
     
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["cc", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "aa"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "bb"}], "+", 
       RowBox[{"c", " ", "cc"}]}], ")"}]}], "-", 
    RowBox[{"bb", " ", "c", " ", "eigval"}], "-", 
    RowBox[{"b", " ", "cc", " ", "eigval"}], "+", 
    RowBox[{"bb", " ", "c", " ", "w"}], "+", 
    RowBox[{"b", " ", "cc", " ", "w"}], "-", 
    RowBox[{"bb", " ", "c", " ", "x"}], "-", 
    RowBox[{"b", " ", "cc", " ", "x"}], "+", 
    RowBox[{"bb", " ", "c", " ", "y"}], "-", 
    RowBox[{"b", " ", "cc", " ", "y"}], "-", 
    RowBox[{"bb", " ", "c", " ", "z"}], "+", 
    RowBox[{"b", " ", "cc", " ", "z"}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["aa", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", "bb"}], "+", 
       RowBox[{"cc", " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
         ")"}]}]}], ")"}]}], "-", 
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bb", " ", "cc"}], "+", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["bb", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", "cc"}], "+", 
       RowBox[{"bb", " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}], "-", 
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bb", " ", "cc"}], "+", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["cc", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7411048322839403`*^9, 3.7411048837435102`*^9}, {
  3.74110500850177*^9, 3.741105031722686*^9}},
 CellLabel->
  "Out[614]=",ExpressionUUID->"106e6712-85fa-46ab-805d-a1ec8a5fca06"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvecRMSDp1", "[", 
   RowBox[{
   "eigval_", ",", "w_", ",", "x_", ",", "y_", ",", "z_", ",", "a_", ",", 
    "b_", ",", "c_", ",", "aa_", ",", "bb_", ",", "cc_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qbare", " ", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
          RowBox[{
           SuperscriptBox["bb", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
            ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["aa", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
            ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}],
            " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["cc", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "aa"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"b", " ", "bb"}], "+", 
             RowBox[{"c", " ", "cc"}]}], ")"}]}], "-", 
          RowBox[{"bb", " ", "c", " ", "eigval"}], "-", 
          RowBox[{"b", " ", "cc", " ", "eigval"}], "+", 
          RowBox[{"bb", " ", "c", " ", "w"}], "+", 
          RowBox[{"b", " ", "cc", " ", "w"}], "-", 
          RowBox[{"bb", " ", "c", " ", "x"}], "-", 
          RowBox[{"b", " ", "cc", " ", "x"}], "+", 
          RowBox[{"bb", " ", "c", " ", "y"}], "-", 
          RowBox[{"b", " ", "cc", " ", "y"}], "-", 
          RowBox[{"bb", " ", "c", " ", "z"}], "+", 
          RowBox[{"b", " ", "cc", " ", "z"}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["aa", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"aa", " ", "bb"}], "+", 
             RowBox[{"cc", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}]}]}], ")"}]}], "-", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"bb", " ", "cc"}], "+", 
             RowBox[{"aa", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["bb", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"aa", " ", "cc"}], "+", 
             RowBox[{"bb", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "-", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"bb", " ", "cc"}], "+", 
             RowBox[{"aa", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["cc", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}]}], "}"}]}], ",", "norm"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"norm", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"qbare", ".", "qbare"}], "]"}]}], ";", " ", 
     RowBox[{"qbare", "/", "norm"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725575612366349*^9, 3.72557570949866*^9}, {
   3.7255842445435457`*^9, 3.725584257559821*^9}, {3.72558430173621*^9, 
   3.725584313739051*^9}, {3.7255849796150427`*^9, 3.7255850062316008`*^9}, {
   3.725585037682225*^9, 3.725585073930138*^9}, {3.725585120799941*^9, 
   3.725585123871475*^9}, {3.725585158541409*^9, 3.72558516776853*^9}, {
   3.741104614930942*^9, 3.741104623066741*^9}, {3.7411049544875793`*^9, 
   3.7411049628311777`*^9}, 3.741105089140779*^9},
 CellLabel->
  "In[615]:=",ExpressionUUID->"daf62a1c-556f-47f1-be2e-e58e84cc0129"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Need to check again which formulas are ",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SqrtBox["xx"], "+", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}]}]], "Input",
  CellChangeTimes->{{3.725287853806384*^9, 3.725287860647037*^9}, {
   3.725288009026163*^9, 3.725288064860168*^9}},ExpressionUUID->
  "c1a76abf-2935-409b-b5e3-895ed244833c"],
 StyleBox[" vs  ",
  FontWeight->"Bold"],
 StyleBox["x + y + z \n           ",
  FontSize->24],
 StyleBox["vs",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["  {a + b,  a -b,  -a + c, -a -c}  ",
  FontSize->24],
 StyleBox["v and then pick out the ",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["utility functions\n           ",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox["in the same format for the main text.",
  FontSize->24]
}], "Section",
 CellChangeTimes->{{3.7260739072598457`*^9, 
  3.726074080335722*^9}},ExpressionUUID->"f3034191-ac83-45ca-bd0d-\
8c177663ca87"],

Cell[CellGroupData[{

Cell[BoxData["pnRandom"], "Input",
 CellChangeTimes->{{3.7260746765167027`*^9, 
  3.726074677907629*^9}},ExpressionUUID->"879e4241-85dd-4b0d-98d5-\
681a3efad84d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{"-", "0.20625855909879243`"}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "3.236097015970737`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "4.023123533571914`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726074678647809*^9},ExpressionUUID->"d74fc34a-a0ff-4e75-a7c4-\
f1172df1651f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pnRandom0", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p4", "\[Rule]", "0.2621670574518047`"}], ",", 
    RowBox[{"p3", "\[Rule]", 
     RowBox[{"-", "2.347438927680793`"}]}], ",", 
    RowBox[{"p2", "\[Rule]", 
     RowBox[{"-", "3.589172779025842`"}]}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726074685227532*^9, 
  3.726074710638618*^9}},ExpressionUUID->"6357e4ec-cf08-4f26-ab1c-\
d4893293bae9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", "0.2621670574518047`"}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "2.347438927680793`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "3.589172779025842`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.726074719214986*^9, 3.7262567642552547`*^9, 
  3.7290086285924177`*^9},ExpressionUUID->"8e9bec1f-d09c-4fce-8053-\
34a828c8806b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"eig4D1", "[", 
      RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
     RowBox[{"eig4D2", "[", 
      RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
     RowBox[{"eig4D3", "[", 
      RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
     RowBox[{"eig4D4", "[", 
      RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], "}"}], "/.", 
   "pnRandom0"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.7260747086100883`*^9, 
  3.726074726573073*^9}},ExpressionUUID->"d7319550-6baf-4ad3-8c34-\
4afb22e50694"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"xyzRoot", "[", 
       RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "+", 
      RowBox[{"xyzRoot", "[", 
       RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xyzRoot", "[", 
       RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "-", 
      RowBox[{"xyzRoot", "[", 
       RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
    "}"}], "/.", "pnRandom0"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{
  3.726074729098908*^9},ExpressionUUID->"a89565f0-6bb2-4a30-9389-\
9f1bdeff023c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       SqrtBox["xx"], "+", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}], ",", " ", 
      RowBox[{
       SqrtBox["xx"], "-", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", " ", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "+", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", " ", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "-", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "\[Rule]", 
       RowBox[{"fxx0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], ",", " ", 
      RowBox[{"yy", "\[Rule]", 
       RowBox[{"fyy0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], " ", ",", " ", 
      RowBox[{"zz", "\[Rule]", 
       RowBox[{"fzz0", "[", 
        RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}]}], " ", "}"}]}], "/.", 
   "pnRandom0"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{
  3.726074737067807*^9},ExpressionUUID->"3b68db44-25fb-404a-8143-\
853441c36577"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"x", "+", "y", "+", "z"}], ",", " ", 
      RowBox[{"x", "-", "y", "-", "z"}], ",", " ", 
      RowBox[{
       RowBox[{"-", "x"}], "+", "y", "-", "z"}], ",", " ", 
      RowBox[{
       RowBox[{"-", "x"}], "-", "y", "+", "z"}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", " ", 
       RowBox[{"xyzRoot", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"y", "\[Rule]", " ", 
       RowBox[{"xyzRoot", "[", 
        RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"zz", "\[Rule]", " ", 
       RowBox[{"xyzRoot", "[", 
        RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
     "}"}]}], "/.", "pnRandom0"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.7260742073311443`*^9, 3.7260742609340887`*^9}, 
   3.72607474039548*^9},ExpressionUUID->"cf432475-d057-405d-8041-\
c94831204f3b"],

Cell[CellGroupData[{

Cell["\<\
Work on defining the optimum eigenvalues and their pieces in a structured way.\
\>", "Subsection",
 CellChangeTimes->{{3.726076667925991*^9, 
  3.726076687429936*^9}},ExpressionUUID->"7b182b51-19ae-4117-9f55-\
465049fc7667"],

Cell[CellGroupData[{

Cell[TextData[{
 " ",
 StyleBox["Defining  optEigval[p1,p2,p3,p4]  for BOTH 3D and 4D cases HERE",
  FontWeight->"Bold"],
 "\n__________________________________________________________"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725626774018581*^9, 3.725626797992423*^9}, 
   3.725626868609404*^9},ExpressionUUID->"b56c26ad-e3ae-44bd-939c-\
71bd22576276"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Get", " ", "the", " ", "arg", " ", "list", " ", "for", " ", "the", " ", 
    "maximal", " ", 
    RowBox[{"eigenvalue", ":"}]}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{"eig4D4", "[", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.725626551909781*^9, 3.725626590940324*^9}, {
   3.725626662779428*^9, 3.72562668419657*^9}, 
   3.725626868609706*^9},ExpressionUUID->"860cc18b-43da-4d8f-92c5-\
98eda12aca34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"optEigvalFull", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", "p1"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
      RowBox[{
       SqrtBox["6"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["2", 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "-", 
               RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "-", 
              RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                   RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                  ")"}], "2"]}]]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["p1", "2"]}], "-", 
               RowBox[{"8", " ", "p2"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["2", 
                   RowBox[{"1", "/", "3"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "-", 
                    RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                    RowBox[{"9", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", " ", "p3"}], "+", 
                    RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
                    RowBox[{"27", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], 
                    ")"}], "2"]}], ")"}]}]}], ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], 
         ")"}]}]}]}], ")"}]}], "//", "Chop"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.7256266367075043`*^9, 3.725626653066493*^9}, {
   3.725626730089731*^9, 3.725626731553133*^9}, 3.725626868610442*^9, {
   3.726078673488364*^9, 
   3.726078674368053*^9}},ExpressionUUID->"da40dacf-05e6-4168-9bc2-\
b202625d331d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Basic 3D versions of solving the eigenvalue eqns:",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.727629622307069*^9, 
  3.727629634723748*^9}},ExpressionUUID->"2caae632-3ee0-439d-b108-\
d918a02fbfca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqLinear", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["xE", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["xE", "2"], " ", 
       SuperscriptBox["yE", "2"]}], "+", 
      SuperscriptBox["yE", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["xE", "2"], " ", 
       SuperscriptBox["zE", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["yE", "2"], " ", 
       SuperscriptBox["zE", "2"]}], "+", 
      SuperscriptBox["zE", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["xE", "2"], "+", 
        SuperscriptBox["yE", "2"], "+", 
        SuperscriptBox["zE", "2"]}], ")"}]}], ",", "0", ",", "1"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.718813602313676*^9, 3.718813603950697*^9}, 
   3.718814172495448*^9},ExpressionUUID->"35b1a766-79a0-46f4-9222-\
e758c3064e22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqQuadratic", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["xx", "2"], "-", 
      RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
      SuperscriptBox["yy", "2"], "-", 
      RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
      RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
      SuperscriptBox["zz", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SqrtBox["xx"], " ", 
      SqrtBox["yy"], " ", 
      SqrtBox["zz"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], ",", "0", ",", "1"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7188140010293827`*^9, 3.718814019187117*^9}, {
   3.7188141186197433`*^9, 3.7188141459069347`*^9}, 
   3.71881419506844*^9},ExpressionUUID->"8646f4de-12a6-41e9-be4c-\
722bed29d39e"],

Cell[BoxData[
 RowBox[{"hornEigValEqn", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p2", "\[Equal]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}]}], ",", 
    RowBox[{"p3", "\[Equal]", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SqrtBox["xx"], " ", 
      SqrtBox["yy"], " ", 
      SqrtBox["zz"]}]}], ",", 
    RowBox[{"p4", "\[Equal]", 
     RowBox[{
      SuperscriptBox["xx", "2"], "-", 
      RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
      SuperscriptBox["yy", "2"], "-", 
      RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
      RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
      SuperscriptBox["zz", "2"]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{
  3.7196792634934893`*^9},ExpressionUUID->"db37f37c-85f3-49c0-b893-\
78edaee33bb7"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Square Form:",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.727629692498064*^9, 
  3.727629695211143*^9}},ExpressionUUID->"a36fd601-b0a4-41e6-b27a-\
e415ecd5486b"],

Cell[BoxData[
 RowBox[{"eqnsq", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p4", "\[Equal]", "  ", 
     RowBox[{
      SuperscriptBox["xE", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["xE", "2"], " ", 
       SuperscriptBox["yE", "2"]}], "+", 
      SuperscriptBox["yE", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["xE", "2"], " ", 
       SuperscriptBox["zE", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["yE", "2"], " ", 
       SuperscriptBox["zE", "2"]}], "+", 
      SuperscriptBox["zE", "4"]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"p3", "\[Equal]", " ", 
     RowBox[{
      RowBox[{"-", "8"}], " ", "xE", " ", "yE", " ", "zE"}]}], ",", "  ", 
    RowBox[{"p2", "\[Equal]", "  ", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["xE", "2"], "+", 
        SuperscriptBox["yE", "2"], "+", 
        SuperscriptBox["zE", "2"]}], ")"}]}]}], ",", " ", 
    RowBox[{"p1", " ", "\[Equal]", "0"}]}], " ", "}"}]}]], "Input",
 CellChangeTimes->{{3.7276314674552107`*^9, 
  3.727631536328618*^9}},ExpressionUUID->"0487b397-640f-47f8-9dc1-\
e78274fb4ec8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Sqrt form:",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.727629680634264*^9, 
  3.727629685795315*^9}},ExpressionUUID->"f16b87e5-5c79-4b0d-9a8f-\
b027a465f7f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqnsxyz", "=", "  ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["xx", "2"], "-", 
       RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
       SuperscriptBox["yy", "2"], "-", 
       RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
       RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
       SuperscriptBox["zz", "2"]}], "\[Equal]", "p4"}], ",", 
     RowBox[{
      RowBox[{"64", " ", "xx", " ", "yy", " ", "zz"}], "\[Equal]", 
      SuperscriptBox["p3", "2"]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], "\[Equal]", "p2"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.718239887083992*^9, 3.7182399901036453`*^9}, {
   3.718240791303701*^9, 3.718240799621731*^9}, {3.7182408955467787`*^9, 
   3.718240914318993*^9}, 3.718240984413211*^9, {3.71830239090114*^9, 
   3.718302396188451*^9}, {3.718965969710548*^9, 3.71896597823615*^9}, {
   3.727629710571928*^9, 3.727629717684119*^9}, {3.727629778674391*^9, 
   3.727629783113453*^9}},ExpressionUUID->"ebba0f84-d7e3-4596-9af8-\
5900022dc61b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"convert", " ", "to", " ", "p3sq"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqnsxxyyzz", "=", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["xx", "2"], "-", 
        RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
        SuperscriptBox["yy", "2"], "-", 
        RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
        RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
        SuperscriptBox["zz", "2"]}], "\[Equal]", "p4"}], ",", 
      RowBox[{
       RowBox[{"64", " ", "xx", " ", "yy", " ", "zz"}], "\[Equal]", 
       SuperscriptBox["p3", "2"]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], "\[Equal]", "p2"}]}], 
     "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.718239887083992*^9, 3.7182399901036453`*^9}, {
   3.718240791303701*^9, 3.718240799621731*^9}, {3.7182408955467787`*^9, 
   3.718240914318993*^9}, 3.718240984413211*^9, {3.71830239090114*^9, 
   3.718302396188451*^9}, {3.718965969710548*^9, 
   3.71896597823615*^9}},ExpressionUUID->"f902dcd8-309d-49f8-8e4f-\
84a7a2f3eb86"],

Cell[TextData[StyleBox["  the set of equations in {xx,yy,zz}  runs for 1 \
minute and gets an answer:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.718268135077319*^9, 3.7182682029245033`*^9}, {
  3.718566109874337*^9, 3.718566135309482*^9}, {3.718566499759536*^9, 
  3.7185665194930973`*^9}},ExpressionUUID->"4f07eab1-7203-49bf-84db-\
c45dd830eef7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"solnxxyyzz", " ", "=", " ", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"eqnsxxyyzz", ",", 
       RowBox[{"{", 
        RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}]}], "]"}], "//", 
     "Simplify"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7182409772892*^9, 3.718240991567073*^9}, {
   3.718242410990157*^9, 3.718242413268931*^9}, 
   3.718242612270728*^9},ExpressionUUID->"30640830-db03-459e-9a38-\
f745f64ee550"],

Cell[BoxData["75.621503`"], "Output",
 CellChangeTimes->{3.718242699464625*^9, 3.7182796602963037`*^9, 
  3.71856660705029*^9, 3.718995670959694*^9, 
  3.719170972747797*^9},ExpressionUUID->"046271aa-d562-4e81-b6ed-\
ae7dec2845d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"ByteCount", ",", "solnxxyyzz", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.718566621440036*^9, 
  3.718566631973278*^9}},ExpressionUUID->"30d1f437-8ec6-42a7-8bd1-\
4eb772f0401e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4584", ",", "19544", ",", "21552"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4584", ",", "19448", ",", "21552"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22232", ",", "28640"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22400", ",", "28736"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22256", ",", "28632"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22392", ",", "28728"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.718566632372364*^9, 3.718995741308429*^9, 
  3.719171018166819*^9},ExpressionUUID->"1f0f637e-2f38-453c-887d-\
b2853e09d204"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Example", " ", "solution"}], " ", "*)"}], "  ", 
  RowBox[{"solnxxyyzz", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.718566729644546*^9, 3.718566732652195*^9}, {
  3.7185667698797073`*^9, 3.7185667977156057`*^9}, {3.718566883276229*^9, 
  3.718566890506445*^9}},ExpressionUUID->"99641aae-ed4e-404a-b3bf-\
d3f67856d190"],

Cell[BoxData[
 RowBox[{"xx", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["p2", "6"]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], 
    RowBox[{"12", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", 
              SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
             RowBox[{"432", " ", "p2", " ", 
              SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]], "-", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", 
           SuperscriptBox["p3", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"81", " ", 
             SuperscriptBox["p3", "4"]}], "-", 
            RowBox[{"48", " ", 
             SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
            RowBox[{"432", " ", "p2", " ", 
             SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["p2", "2"], " ", 
             SuperscriptBox["p4", "2"]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]}]}]], "Output",
 CellChangeTimes->{
  3.719170982846155*^9},ExpressionUUID->"296ef6f1-e59d-4759-bae5-\
c8cd6cbefe75"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Working on simplification of eigval:",
  FontWeight->"Bold"],
 "\n   NOTHING useful here except  theEigValN[n,p]  and  \
theEIgValNSym[n,p,Fsym]\n   \
------------------------------------------------------------------------------\
--------------"
}], "Subsection",
 CellChangeTimes->{{3.727629401909391*^9, 3.727629410278167*^9}, {
  3.727629455126568*^9, 
  3.7276295257936707`*^9}},ExpressionUUID->"6e65e322-5cfd-4e5f-95b3-\
6c732a17d6cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Try", " ", "some", " ", "reductions"}], " ", "-", " ", 
    RowBox[{"first", " ", "the", " ", "cube", " ", "root"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["p2", "3"]}], "-", 
    RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
    RowBox[{"27", " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    RowBox[{"27", " ", 
     SuperscriptBox["p1", "2"], " ", "p4"}], "-", 
    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "-", 
          RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"9", " ", "p2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", " ", "p3"}], "+", 
            RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
         RowBox[{"27", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p3", "2"], "+", 
            RowBox[{
             SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
       "2"]}]]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.726076760265213*^9, 
  3.7260768007304583`*^9}},ExpressionUUID->"f5755d51-2a11-40bd-b4da-\
9c5b3bc26408"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "-", 
        RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
        RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"9", " ", "p2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "p3"}], "+", 
          RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
       RowBox[{"27", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p3", "2"], "+", 
          RowBox[{
           SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], "2"]}],
    "//", "Expand"}], "//", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{"#", ",", "p1"}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.726077614979741*^9, 
  3.726077639955467*^9}},ExpressionUUID->"d32f7ccd-a6ee-4d9a-a839-\
0b051a6ed994"],

Cell[BoxData[
 RowBox[{
  RowBox[{"108", " ", 
   SuperscriptBox["p2", "3"], " ", 
   SuperscriptBox["p3", "2"]}], "+", 
  RowBox[{"729", " ", 
   SuperscriptBox["p3", "4"]}], "-", 
  RowBox[{"432", " ", 
   SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
  RowBox[{"3888", " ", "p2", " ", 
   SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
  RowBox[{"729", " ", 
   SuperscriptBox["p1", "4"], " ", 
   SuperscriptBox["p4", "2"]}], "+", 
  RowBox[{"3456", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["p4", "2"]}], "-", 
  RowBox[{"6912", " ", 
   SuperscriptBox["p4", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["p1", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"108", " ", 
      SuperscriptBox["p3", "3"]}], "-", 
     RowBox[{"486", " ", "p2", " ", "p3", " ", "p4"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["p1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "27"}], " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     RowBox[{"108", " ", 
      SuperscriptBox["p2", "3"], " ", "p4"}], "+", 
     RowBox[{"162", " ", 
      SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
     RowBox[{"3888", " ", "p2", " ", 
      SuperscriptBox["p4", "2"]}]}], ")"}]}], "+", 
  RowBox[{"p1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "486"}], " ", "p2", " ", 
      SuperscriptBox["p3", "3"]}], "+", 
     RowBox[{"2160", " ", 
      SuperscriptBox["p2", "2"], " ", "p3", " ", "p4"}], "+", 
     RowBox[{"5184", " ", "p3", " ", 
      SuperscriptBox["p4", "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.726077640321906*^9},ExpressionUUID->"e36b3197-2ddb-475c-85bb-\
b8caefda37b9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"108", " ", 
    SuperscriptBox["p2", "3"], " ", 
    SuperscriptBox["p3", "2"]}], "+", 
   RowBox[{"729", " ", 
    SuperscriptBox["p3", "4"]}], "-", 
   RowBox[{"432", " ", 
    SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
   RowBox[{"3888", " ", "p2", " ", 
    SuperscriptBox["p3", "2"], " ", "p4"}], " ", "+", 
   RowBox[{"3456", " ", 
    SuperscriptBox["p2", "2"], " ", 
    SuperscriptBox["p4", "2"]}], "-", 
   RowBox[{"6912", " ", 
    SuperscriptBox["p4", "3"]}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7260778774492064`*^9, 
  3.726077914163587*^9}},ExpressionUUID->"20a1c202-0902-4637-b2de-\
590344de0a61"],

Cell[BoxData[
 RowBox[{"27", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox["p2", "3"], " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    RowBox[{"27", " ", 
     SuperscriptBox["p3", "4"]}], "-", 
    RowBox[{"16", " ", "p2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "3"], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
    RowBox[{"128", " ", 
     SuperscriptBox["p2", "2"], " ", 
     SuperscriptBox["p4", "2"]}], "-", 
    RowBox[{"256", " ", 
     SuperscriptBox["p4", "3"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.7260778827889433`*^9, 
  3.726077914840707*^9}},ExpressionUUID->"f6d5b112-9512-430b-8b07-\
264209c89187"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "p1", " ", "*)"}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "486"}], " ", "p2", " ", 
      SuperscriptBox["p3", "3"]}], "+", 
     RowBox[{"2160", " ", 
      SuperscriptBox["p2", "2"], " ", "p3", " ", "p4"}], "+", 
     RowBox[{"5184", " ", "p3", " ", 
      SuperscriptBox["p4", "2"]}]}], ")"}], "//", "FullSimplify"}]}]], "Input",\

 CellChangeTimes->{{3.726077720298473*^9, 
  3.726077765394333*^9}},ExpressionUUID->"a6d0af5f-bf0d-464e-8ec0-\
25fa72df9620"],

Cell[BoxData[
 RowBox[{"54", " ", "p3", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "9"}], " ", "p2", " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    RowBox[{"40", " ", 
     SuperscriptBox["p2", "2"], " ", "p4"}], "+", 
    RowBox[{"96", " ", 
     SuperscriptBox["p4", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.72607775915238*^9, 
  3.7260777658126383`*^9}},ExpressionUUID->"96511ada-8f91-4a8b-bda4-\
5a9d64ba16cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SuperscriptBox["p1", "2"], " ", "*)"}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "27"}], " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     RowBox[{"108", " ", 
      SuperscriptBox["p2", "3"], " ", "p4"}], "+", 
     RowBox[{"162", " ", 
      SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
     RowBox[{"3888", " ", "p2", " ", 
      SuperscriptBox["p4", "2"]}]}], ")"}], "//", "FullSimplify"}]}]], "Input",\

 CellChangeTimes->{{3.726077733213238*^9, 3.726077735418233*^9}, {
  3.7260777698027487`*^9, 
  3.726077779913735*^9}},ExpressionUUID->"2c2b6bf1-3667-4a08-ad83-\
f642a84926e9"],

Cell[BoxData[
 RowBox[{"27", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["p2", "2"]}], " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["p2", "3"], " ", "p4"}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
    RowBox[{"144", " ", "p2", " ", 
     SuperscriptBox["p4", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.726077771438452*^9, 
  3.726077780431041*^9}},ExpressionUUID->"b51170a6-7c37-4fc1-bfaf-\
b62b34a36202"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   SuperscriptBox["p1", "3"], "*)"}], " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"108", " ", 
      SuperscriptBox["p3", "3"]}], "-", 
     RowBox[{"486", " ", "p2", " ", "p3", " ", "p4"}]}], ")"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{
  3.726077752500997*^9, {3.72607778405088*^9, 
   3.726077789697687*^9}},ExpressionUUID->"157d62f8-77a2-4e87-a2c9-\
a5a773c6f125"],

Cell[BoxData[
 RowBox[{"54", " ", "p3", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["p3", "2"]}], "-", 
    RowBox[{"9", " ", "p2", " ", "p4"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.726077785852803*^9, 
  3.726077790475931*^9}},ExpressionUUID->"41bd86f0-3969-4f0f-9184-\
634e8906b608"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"729", " ", 
  SuperscriptBox["p1", "4"], " ", 
  SuperscriptBox["p4", "2"]}]], "Input",ExpressionUUID->"537d3fb1-6761-46b7-\
be7f-09556751979b"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.726078028728403*^9},ExpressionUUID->"e2b79411-27a6-4f97-bbd7-\
315f746494eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["p2", "3"]}], "+", 
   RowBox[{"27", " ", 
    SuperscriptBox["p3", "2"]}], "-", 
   RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
   RowBox[{"9", " ", "p1", " ", "p2", " ", "p3"}], "+", 
   RowBox[{"27", " ", 
    SuperscriptBox["p1", "2"], " ", "p4"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.72607803307901*^9, 
  3.726078038462536*^9}},ExpressionUUID->"36f74659-9506-4d65-ab86-\
c4d4e0d6113c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "3"]}], "-", 
  RowBox[{"9", " ", "p2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p1", " ", "p3"}], "+", 
     RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
  RowBox[{"27", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p3", "2"], "+", 
     RowBox[{
      SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7260780388536987`*^9},ExpressionUUID->"511ca021-6489-475d-a47b-\
6c01b27db02d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"argGrt", " ", "=", 
  RowBox[{
   RowBox[{"+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"9", " ", "p2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p1", " ", "p3"}], "+", 
          RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
       RowBox[{"27", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p3", "2"], "+", 
          RowBox[{
           SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], "2"]}],
    " ", "-", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "-", 
       RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}]}]}]], "Input",
 CellChangeTimes->{{3.7260776668065453`*^9, 3.726077707363688*^9}, {
  3.726077968864609*^9, 3.726078009515583*^9}, {3.72607810406415*^9, 
  3.726078106291654*^9}},ExpressionUUID->"ce85d041-a08a-4d3a-8f9a-\
27f2a6180775"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theGfun", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["p2", "3"]}], "-", 
    RowBox[{"9", " ", "p2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"p1", " ", "p3"}], "+", 
       RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
    RowBox[{"27", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p3", "2"], "+", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"9", " ", "p2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", " ", "p3"}], "+", 
            RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
         RowBox[{"27", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p3", "2"], "+", 
            RowBox[{
             SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], "2"],
       "-", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "-", 
          RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}]}]]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.7260775312314167`*^9, 3.726077546784399*^9}, {
  3.7260783128118563`*^9, 3.72607832589255*^9}, {3.7260783855416527`*^9, 
  3.7260783964845552`*^9}, {3.7260785439554358`*^9, 
  3.726078587163566*^9}},ExpressionUUID->"e2912d93-dc96-4e74-89ef-\
1f474a1c7b51"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theFfun", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox["Gfun", 
     RowBox[{"1", "/", "3"}]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["2", 
      RowBox[{"1", "/", "3"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "-", 
       RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}]}], 
    SuperscriptBox["Gfun", 
     RowBox[{"1", "/", "3"}]]]}]}]], "Input",
 CellChangeTimes->{{3.726079275700633*^9, 3.7260793219973373`*^9}, {
  3.7260793595079813`*^9, 
  3.726079382051634*^9}},ExpressionUUID->"6a027c63-843e-45f0-a6c3-\
76910e63cea3"],

Cell[BoxData[
 RowBox[{"optEigvalFull", "[", 
  RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellChangeTimes->{{3.726078915237157*^9, 
  3.72607893445686*^9}},ExpressionUUID->"880c515e-40db-492d-8f9e-\
cdb31e391e32"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", "p1"}], "+", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
          SuperscriptBox[
           RowBox[{"(", "Gfun", ")"}], 
           RowBox[{"1", "/", "3"}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", "Gfun", ")"}], 
           RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SqrtBox["6"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
          SuperscriptBox[
           RowBox[{"(", "Gfun", ")"}], 
           RowBox[{"1", "/", "3"}]]}], "-", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", "Gfun", ")"}], 
           RowBox[{"1", "/", "3"}]]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SqrtBox["3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p1", "3"], "-", 
              RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
              RowBox[{"8", " ", "p3"}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"\[Sqrt]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["p1", "2"]}], "-", 
              RowBox[{"8", " ", "p2"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "-", 
                   RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
               SuperscriptBox[
                RowBox[{"(", "Gfun", ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", "Gfun", ")"}], 
                RowBox[{"1", "/", "3"}]]}]}], ")"}]}], ")"}]}]}], ")"}]}]}]}],
     ")"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.726078949231245*^9, 
  3.726079007310481*^9}},ExpressionUUID->"a2df0327-dcb7-4302-ab3d-\
fcfc8802b452"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", "p1"}], "+", " ", 
    RowBox[{
     FractionBox[
      SqrtBox["3"], "12"], 
     SqrtBox[
      RowBox[{" ", 
       RowBox[{
        RowBox[{
         RowBox[{"+", "3"}], " ", 
         SuperscriptBox["p1", "2"]}], "-", 
        RowBox[{"8", " ", "p2"}], "+", 
        RowBox[{"2", " ", "Ffun", "  "}]}]}]]}], "+", 
    RowBox[{
     FractionBox[
      SqrtBox["6"], "12"], " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"+", "3"}], " ", 
         SuperscriptBox["p1", "2"]}], "-", 
        RowBox[{"8", " ", "p2"}], "-", "Ffun", "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SqrtBox["3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p1", "3"], "-", 
            RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
            RowBox[{"8", " ", "p3"}]}], ")"}]}], 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"+", "3"}], " ", 
            SuperscriptBox["p1", "2"]}], "-", 
           RowBox[{"8", " ", "p2"}], "+", 
           RowBox[{"2", " ", "Ffun"}]}]]]}], ")"}]}]}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.726079409018358*^9, 3.7260794740268593`*^9}, {
   3.726079511066338*^9, 3.7260795281775503`*^9}, {3.72607956389765*^9, 
   3.7260795672016497`*^9}, 
   3.7260796286636133`*^9},ExpressionUUID->"8f31ffa5-30d2-4bf0-a97f-\
d67bbbe442b2"],

Cell[CellGroupData[{

Cell["Work on adding the p1->0 special case:", "Subsubsection",
 CellChangeTimes->{{3.726169827118003*^9, 
  3.726169840517568*^9}},ExpressionUUID->"66ab8d0e-6bf2-4086-8104-\
ff553c5d0729"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"9", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "p3"}], "+", 
           RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
        RowBox[{"27", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p3", "2"], "+", 
           RowBox[{
            SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], "2"], 
     "-", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "-", 
         RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}]}], "/.", 
    RowBox[{"p1", "\[Rule]", "0"}]}], "//", "Expand"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7261691394693813`*^9, 3.72616914348455*^9}, 
   3.726169175885353*^9, {3.726169275861903*^9, 
   3.72616927928413*^9}},ExpressionUUID->"52e72da5-abb2-432d-a755-\
267db6e04054"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "27"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     SuperscriptBox["p2", "3"], " ", 
     SuperscriptBox["p3", "2"]}], "-", 
    RowBox[{"27", " ", 
     SuperscriptBox["p3", "4"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
    RowBox[{"144", " ", "p2", " ", 
     SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
    RowBox[{"128", " ", 
     SuperscriptBox["p2", "2"], " ", 
     SuperscriptBox["p4", "2"]}], "+", 
    RowBox[{"256", " ", 
     SuperscriptBox["p4", "3"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.726169143837047*^9, 3.726169177499539*^9, 
  3.726169281173115*^9},ExpressionUUID->"b7bc4075-607b-4ceb-894e-\
378369ee8e62"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["p2", "3"], " ", 
      SuperscriptBox["p3", "2"]}], "-", 
     RowBox[{"27", " ", 
      SuperscriptBox["p3", "4"]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
     RowBox[{"144", " ", "p2", " ", 
      SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
     RowBox[{"128", " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p4", "2"]}], "+", 
     RowBox[{"256", " ", 
      SuperscriptBox["p4", "3"]}]}], ")"}]}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.726169358962907*^9, 
  3.726169366642405*^9}},ExpressionUUID->"d0d10b31-4055-4a46-92bc-\
06774b049399"],

Cell[BoxData[
 RowBox[{
  RowBox[{"12", " ", 
   SuperscriptBox["p2", "3"], " ", 
   SuperscriptBox["p3", "2"]}], "+", 
  RowBox[{"81", " ", 
   SuperscriptBox["p3", "4"]}], "-", 
  RowBox[{"48", " ", 
   SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
  RowBox[{"432", " ", "p2", " ", 
   SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
  RowBox[{"384", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["p4", "2"]}], "-", 
  RowBox[{"768", " ", 
   SuperscriptBox["p4", "3"]}]}]], "Output",
 CellChangeTimes->{
  3.726169367056342*^9},ExpressionUUID->"e07f96f5-6704-46a8-9357-\
a4e01757805f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"it", "'"}], "s", " ", "a", " ", "negative", " ", "number", " ", 
    "in", " ", "the", " ", "Square", " ", 
    RowBox[{"root", "!!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"%", "/.", "pnRandom0"}]}]], "Input",
 CellChangeTimes->{{3.7261693804063673`*^9, 
  3.726169413218449*^9}},ExpressionUUID->"cf73d454-f89e-414d-9029-\
af2b24208769"],

Cell[BoxData[
 RowBox[{"-", "119.99375364720117`"}]], "Output",
 CellChangeTimes->{
  3.726169387240801*^9},ExpressionUUID->"435ca909-41b8-4cad-be54-\
a7e3e469f9e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["p2", "3"]}], "-", 
   RowBox[{"9", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"p1", " ", "p3"}], "+", 
      RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
   RowBox[{"27", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p3", "2"], "+", 
      RowBox[{
       SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], "/.", 
  RowBox[{"p1", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.72616947692972*^9, 
  3.726169479409419*^9}},ExpressionUUID->"5edfb859-8170-4283-859b-\
14140058b5e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"27", " ", 
   SuperscriptBox["p3", "2"]}], "-", 
  RowBox[{"72", " ", "p2", " ", "p4"}]}]], "Output",
 CellChangeTimes->{
  3.726169480291252*^9},ExpressionUUID->"31bd5b48-9055-49bd-a810-\
7a8bdba15e65"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xxyyzzRoot", "[", 
   RowBox[{"\"\<x\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
   "]"}], "-", 
  RowBox[{
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"\"\<x\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
    "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], "-", 
  RowBox[{
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"\"\<x\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
    "]"}], "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7261706880231752`*^9, 
  3.726170728420574*^9}},ExpressionUUID->"d2d3c32d-5850-428b-bf4c-\
e51285809e71"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["p2", "6"]}]], "Output",
 CellChangeTimes->{{3.726170666661704*^9, 
  3.726170729131956*^9}},ExpressionUUID->"5ef0c086-a60c-4a59-97f6-\
6a96445bd86a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theGfun", "[", 
  RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellChangeTimes->{{3.726171003813691*^9, 
  3.726171010305767*^9}},ExpressionUUID->"16e17424-cb75-49e3-9ea6-\
fad5d5fe1203"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"27", " ", 
   SuperscriptBox["p3", "2"]}], "-", 
  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
  RowBox[{"3", " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["p2", "3"], " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     RowBox[{"81", " ", 
      SuperscriptBox["p3", "4"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
     RowBox[{"432", " ", "p2", " ", 
      SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
     RowBox[{"384", " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p4", "2"]}], "-", 
     RowBox[{"768", " ", 
      SuperscriptBox["p4", "3"]}]}]]}]}]], "Output",
 CellChangeTimes->{
  3.7261710107252398`*^9},ExpressionUUID->"ec4c3213-3dde-4d3b-acf0-\
f8b9826d9b35"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["p3", "2"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "+", 
      RowBox[{"3", " ", "I", " ", 
       SqrtBox[
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "-", 
           RowBox[{"48", " ", 
            SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
           RowBox[{"432", " ", "p2", " ", 
            SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "-", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}], "*", 
    "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["p3", "2"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "-", 
      RowBox[{"3", " ", "I", " ", 
       SqrtBox[
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "-", 
           RowBox[{"48", " ", 
            SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
           RowBox[{"432", " ", "p2", " ", 
            SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "-", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}]}], "//", 
   "Expand"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7261710501135*^9, 3.726171056729335*^9}, {
  3.7261711013287287`*^9, 
  3.7261711667922373`*^9}},ExpressionUUID->"2983eeed-423f-40f0-9848-\
7baa0d1d5838"],

Cell[BoxData[
 RowBox[{"4", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}]], "Output",
 CellChangeTimes->{{3.7261711509062223`*^9, 
  3.726171167125269*^9}},ExpressionUUID->"8e18d509-5243-4b06-a661-\
09b46d5e71a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"xxyyzzRoot", "[", 
     RowBox[{"\"\<x\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
     "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"xxyyzzRoot", "[", 
     RowBox[{"\"\<x\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
     "]"}], "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.7261707462853193`*^9, 
  3.726170753228396*^9}},ExpressionUUID->"74aba718-03c4-4865-981c-\
9c22fb749d13"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], 
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]], ",", 
   RowBox[{
    FractionBox["1", "24"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", 
           SuperscriptBox["p3", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"81", " ", 
             SuperscriptBox["p3", "4"]}], "-", 
            RowBox[{"48", " ", "p2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "3"], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["p2", "2"], " ", 
             SuperscriptBox["p4", "2"]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726170753579739*^9},ExpressionUUID->"1c1ec28c-ee3a-428c-b89b-\
c519ff05523d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"EXACTLY", " ", "OPPOSITE", " ", "imaginary", " ", "parts"}], " ",
     "-", " ", 
    RowBox[{"how", " ", "can", " ", "that", " ", 
     RowBox[{"be", "?", "  ", "Complex"}], " ", 
     RowBox[{"conjugates", "?"}]}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"xxyyzzRoot", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ",
         "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"xxyyzzRoot", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ",
         "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "/.", "pnRandom0"}], "//", 
   "Chop"}]}]], "Input",
 CellChangeTimes->{{3.7261707462853193`*^9, 
  3.7261708277488317`*^9}},ExpressionUUID->"2632f4a4-79d1-41a1-923f-\
32630766306b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.33238455566982583`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.028761345229436824`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"0.3323845556698256`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.028761345229436852`", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7261707878362083`*^9, 
  3.726170830167588*^9},ExpressionUUID->"f49e3654-e400-48ff-8b28-\
359cc0716dc2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Now you must separate the imaginary parts - cannot publish this with \
conjugate cancellations!!\
\>", "Subsubsection",
 CellChangeTimes->{{3.7261698466692123`*^9, 
  3.726169870829111*^9}},ExpressionUUID->"4338c631-6f04-4418-ae63-\
3f9abcd21813"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xxyyzzRoot", "[", 
      RowBox[{"\"\<x\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
      "]"}], ",", 
     RowBox[{"xxyyzzRoot", "[", 
      RowBox[{"\"\<y\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
      "]"}], ",", 
     RowBox[{"xxyyzzRoot", "[", 
      RowBox[{"\"\<z\>\"", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
      "]"}]}], "}"}], "/.", "pnRandom0"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.726170522478774*^9, 
  3.726170594166092*^9}},ExpressionUUID->"6f0a7345-bf41-423a-9fc5-\
6d8c4c0112e5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.262964574510625`", ",", "0.31562701873256127`", ",", 
   "0.2159947962697345`"}], "}"}]], "Output",
 CellChangeTimes->{3.726170555419511*^9, 
  3.726170596490945*^9},ExpressionUUID->"1a563cea-36b3-4e08-b790-\
fe4bb65bd03b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"theGfun", "[", 
    RowBox[{"0", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", "]"}], "/.",
    "pnRandom0"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.726169513945333*^9, 
  3.726169540856593*^9}},ExpressionUUID->"b9ca66ce-1ee4-4526-863a-\
337d9ed2ff77"],

Cell[BoxData[
 RowBox[{"124.05939848317021`", "\[VeryThinSpace]", "+", 
  RowBox[{"32.862498122096724`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.726169522802393*^9, 
  3.72616954159704*^9}},ExpressionUUID->"a75dd173-7040-4b33-a4d2-\
90a8bea253be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"theFfun", "[", 
    RowBox[{"0", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", "]"}], "/.",
    "pnRandom0"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{
  3.726169636767744*^9},ExpressionUUID->"ef3e4d5f-12b6-401d-bfd2-\
208b3fbb3116"],

Cell[BoxData["15.954458672151635`"], "Output",
 CellChangeTimes->{
  3.7261696395938473`*^9},ExpressionUUID->"b3be68e3-d212-4973-8afd-\
132263615e49"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Imag", " ", "parts", " ", "cancel", " ", "EXACTLY", " ", "for", " ", 
    "any", " ", 
    RowBox[{"p1", ":", " ", 
     RowBox[{
     "so", " ", "you", " ", "MUST", " ", "break", " ", "it", " ", "out"}]}]}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"2", "/", "3"}]], " ", 
        SuperscriptBox[
         RowBox[{"theGfun", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
         RowBox[{"1", "/", "3"}]]}], ",", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["2", 
          RowBox[{"1", "/", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "-", 
           RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
           RowBox[{"12", " ", "p4"}]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"theGfun", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
         RowBox[{"1", "/", "3"}]]]}], "}"}], "/.", 
     RowBox[{"p1", "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{"{", 
        RowBox[{".1", ",", "2"}], "}"}], "]"}]}]}], "/.", "pnRandom0"}], "//",
    "Chop"}]}]], "Input",
 CellChangeTimes->{{3.726169672627448*^9, 3.726169757422607*^9}, {
  3.726169901462131*^9, 
  3.7261699661247463`*^9}},ExpressionUUID->"ce1334d3-249d-4410-b778-\
50c2b165a5ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8.34323816130637`", "\[VeryThinSpace]", "+", 
    RowBox[{"3.084370805278715`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"8.34323816130637`", "\[VeryThinSpace]", "-", 
    RowBox[{"3.084370805278715`", " ", "\[ImaginaryI]"}]}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.7261697043977413`*^9, {3.726169737765861*^9, 3.7261697585600843`*^9}, 
   3.7261699194906054`*^9},ExpressionUUID->"efccf885-b752-4ae6-b08a-\
74a714e1cec5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theFfun", "[", 
  RowBox[{"0", ",", "p2", " ", ",", "p3", " ", ",", "p4"}], " ", 
  "]"}]], "Input",ExpressionUUID->"5e494133-43fa-4000-b0c2-5e18b62aba02"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p2", "2"], "+", 
      RowBox[{"12", " ", "p4"}]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["p3", "2"]}], "-", 
      RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
      RowBox[{"3", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["p2", "3"], " ", 
          SuperscriptBox["p3", "2"]}], "+", 
         RowBox[{"81", " ", 
          SuperscriptBox["p3", "4"]}], "-", 
         RowBox[{"48", " ", 
          SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
         RowBox[{"432", " ", "p2", " ", 
          SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
         RowBox[{"384", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["p4", "2"]}], "-", 
         RowBox[{"768", " ", 
          SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]], "+", 
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"2", "/", "3"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["p3", "2"]}], "-", 
      RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
      RowBox[{"3", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["p2", "3"], " ", 
          SuperscriptBox["p3", "2"]}], "+", 
         RowBox[{"81", " ", 
          SuperscriptBox["p3", "4"]}], "-", 
         RowBox[{"48", " ", 
          SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
         RowBox[{"432", " ", "p2", " ", 
          SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
         RowBox[{"384", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["p4", "2"]}], "-", 
         RowBox[{"768", " ", 
          SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}]}]], "Output",
 CellChangeTimes->{
  3.726174434628593*^9},ExpressionUUID->"3ebd688a-aafe-4c63-aa4f-\
9bd51e5566d4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Try", " ", "to", " ", "pull", " ", "out", " ", "real", " ", "only"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"2", "/", "3"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", "I", " ", 
          SqrtBox[
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", 
               SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
              RowBox[{"432", " ", "p2", " ", 
               SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}]]}], "+", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", 
        SuperscriptBox["2", 
         RowBox[{"1", "/", "3"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
            RowBox[{"3", " ", "I", " ", 
             SqrtBox[
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", 
                  SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                 RowBox[{"432", " ", "p2", " ", 
                  SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"27", " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
           RowBox[{"3", " ", "I", " ", 
            SqrtBox[
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", 
                 SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                RowBox[{"432", " ", "p2", " ", 
                 SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"27", " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
           RowBox[{"3", " ", "I", " ", 
            SqrtBox[
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", 
                 SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                RowBox[{"432", " ", "p2", " ", 
                 SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}]}], ")"}], 
       
       RowBox[{"1", "/", "3"}]]}]}], "//", "Expand"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7261743627994328`*^9, 3.7261743774626703`*^9}, {
   3.726174460801536*^9, 3.726174494430222*^9}, 3.726174529809395*^9, {
   3.7261745766894836`*^9, 3.72617462402849*^9}, {3.726174655314433*^9, 
   3.726174714235466*^9}, {3.726174771078179*^9, 
   3.726174774323143*^9}},ExpressionUUID->"7dd93c16-6379-492b-8a33-\
87053856b75f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["p3", "2"]}], "-", 
      RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
      RowBox[{"3", " ", "I", " ", 
       SqrtBox[
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "-", 
           RowBox[{"48", " ", 
            SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
           RowBox[{"432", " ", "p2", " ", 
            SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "-", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["p3", "2"]}], "-", 
      RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
      RowBox[{"3", " ", "I", " ", 
       SqrtBox[
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "-", 
           RowBox[{"48", " ", 
            SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
           RowBox[{"432", " ", "p2", " ", 
            SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "-", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}]}], "//", 
   "Expand"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.726174865441861*^9, 
  3.726174870937057*^9}},ExpressionUUID->"de861241-8a19-4d1a-9ea1-\
fc2784769310"],

Cell[BoxData[
 RowBox[{"4", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}]], "Output",
 CellChangeTimes->{
  3.726174871373248*^9},ExpressionUUID->"963731ec-95a0-4396-bc7f-\
276dce8e7322"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"Insert", " ", "denominator", " ", "by", " ", "hand"}], ",", " ", 
    
    RowBox[{
     RowBox[{"won", "'"}], "t", " ", "work", " ", "automatically"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"2", "/", "3"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", "I", " ", 
          SqrtBox[
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", 
               SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
              RowBox[{"432", " ", "p2", " ", 
               SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}]]}], "+", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"2", "/", "3"}]], "  ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
            RowBox[{"3", " ", "I", " ", 
             SqrtBox[
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", 
                  SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                 RowBox[{"432", " ", "p2", " ", 
                  SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}], ")"}]}]]}]}], ")"}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}], "/", 
      RowBox[{"(", "  ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], ")"}]}]}], "//", "Expand"}], "//",
    "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7261743627994328`*^9, 3.7261743774626703`*^9}, {
   3.726174460801536*^9, 3.726174494430222*^9}, 3.726174529809395*^9, {
   3.7261745766894836`*^9, 3.72617462402849*^9}, {3.726174655314433*^9, 
   3.726174714235466*^9}, {3.726174771078179*^9, 3.726174774323143*^9}, {
   3.726174839617978*^9, 3.7261748535450563`*^9}, {3.726174890646935*^9, 
   3.726174942688424*^9}},ExpressionUUID->"dea814ae-2d71-4e01-8d0a-\
fcc0e41c770c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"2", "/", "3"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["p3", "2"]}], "-", 
      RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox["p2", "3"], " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"81", " ", 
          SuperscriptBox["p3", "4"]}], "+", 
         RowBox[{"48", " ", 
          SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
         RowBox[{"432", " ", "p2", " ", 
          SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
         RowBox[{"384", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["p4", "2"]}], "+", 
         RowBox[{"768", " ", 
          SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}], "+", 
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"2", "/", "3"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["p3", "2"]}], "-", 
      RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox["p2", "3"], " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"81", " ", 
          SuperscriptBox["p3", "4"]}], "+", 
         RowBox[{"48", " ", 
          SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
         RowBox[{"432", " ", "p2", " ", 
          SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
         RowBox[{"384", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["p4", "2"]}], "+", 
         RowBox[{"768", " ", 
          SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}]}]], "Output",
 CellChangeTimes->{
  3.726174948175118*^9},ExpressionUUID->"d909ef64-0068-49e7-9e67-\
128662a4baaa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Looks promising:  (a+I b)^(1/3)  +  (a-I b)^(1/3)  is certainly a sum of \
complex conjugates, and
    therefore real --- but how do you deal with it analytically?
    
    ***  Yes, all the Q[] and G[] functions are essentially this form: one \
can get the
    cosine analytically:  any way to get Cos[th/3] analytically from that?\
\>", "Subsubsection",
 CellChangeTimes->{{3.726175005287325*^9, 3.726175073783145*^9}, {
  3.726234411301503*^9, 
  3.7262344550929127`*^9}},ExpressionUUID->"c00db58a-ca82-473d-b48d-\
b4678cd626a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", " ", "+", " ", 
       RowBox[{"I", " ", "b"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}]], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", " ", "-", " ", 
       RowBox[{"I", " ", "b"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}]]}], "//", "Re"}], "//", 
  "ComplexExpand"}]], "Input",
 CellChangeTimes->{{3.726175094098405*^9, 3.7261751237906103`*^9}, {
  3.7261752069276533`*^9, 
  3.726175211453884*^9}},ExpressionUUID->"70d449e3-dda4-4625-9b8c-\
d9757612ed86"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}], 
    RowBox[{"1", "/", "6"}]], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"Arg", "[", 
      RowBox[{"a", "-", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], "]"}]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}], 
    RowBox[{"1", "/", "6"}]], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"Arg", "[", 
      RowBox[{"a", "+", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], "]"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.726175506265276*^9},ExpressionUUID->"51796e3d-e54a-47f5-9056-\
c89c1a1d0c76"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Arg", "[", 
    RowBox[{".2", " ", "+", " ", 
     RowBox[{"I", " ", ".67"}]}], "]"}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{".2", ",", " ", ".67"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.726175335592319*^9, 3.7261753636438723`*^9}, {
  3.726175436436263*^9, 3.726175441179021*^9}, {3.726175512725143*^9, 
  3.726175538929721*^9}},ExpressionUUID->"56428cf4-f70e-45fa-8cae-\
1c151212cd7b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.2807093944738686`", ",", "1.2807093944738686`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.726175344949072*^9, 3.726175364115335*^9}, 
   3.72617544209601*^9, 
   3.726175539374181*^9},ExpressionUUID->"d51473f1-1e78-495e-9c7c-\
3a447cfa0cd4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"Arg", "[", 
      RowBox[{"a", "-", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], "]"}]}], "]"}], "+", "  ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"Arg", "[", 
      RowBox[{"a", "+", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.726175291500621*^9, 
  3.726175329476946*^9}},ExpressionUUID->"afd9a56a-5910-4ade-887e-\
b46d4d020c8c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"Arg", "[", 
     RowBox[{"a", "-", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}], "]"}]}], "]"}], "+", 
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"Arg", "[", 
     RowBox[{"a", "+", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}], "]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.7261753022031813`*^9, 
  3.726175310866723*^9}},ExpressionUUID->"4f019186-056d-4e58-b4e3-\
46a99ed9681c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{"3", " ", "x"}], "]"}], "//", "TrigExpand"}]], "Input",
 CellChangeTimes->{{3.7261910890385103`*^9, 
  3.726191160537023*^9}},ExpressionUUID->"9bf4ac57-cb98-4143-add6-\
47f9d7f9f231"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"Cos", "[", "x", "]"}], "3"], "-", 
  RowBox[{"3", " ", 
   RowBox[{"Cos", "[", "x", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "x", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.726191111741912*^9, 
  3.7261911612922907`*^9}},ExpressionUUID->"d6292501-23a3-45ce-ab7a-\
8702cf97ec1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Cos", "[", "  ", "x", "]"}], "-", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"x", "/", "3"}], "]"}], "3"], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"x", "/", "3"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"x", "/", "3"}], "]"}], "2"]}]}], ")"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.726191227840598*^9, 
  3.72619126388846*^9}},ExpressionUUID->"7ba22fc1-e24b-4489-83eb-\
2362cff63539"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7261912473588123`*^9, 
  3.726191264531749*^9}},ExpressionUUID->"2a8460f7-0d6d-4f65-96ef-\
1f7af79e30a4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cx", "-", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["cx3", "3"], "-", 
       RowBox[{"3", " ", "cx3", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["cx3", "2"]}], ")"}]}]}], ")"}]}], "\[Equal]", "0"}],
    ",", "cx3"}], "]"}]], "Input",
 CellChangeTimes->{{3.7262344791166162`*^9, 3.726234531684273*^9}, {
  3.726234579012903*^9, 
  3.7262345796434927`*^9}},ExpressionUUID->"fd649d17-7eed-4699-8f33-\
fe62ec2b33f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cx3", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "cx"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["cx", "2"]}]]}], ")"}], 
           RowBox[{"1", "/", "3"}]]]}], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "cx"}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["cx", "2"]}]]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cx3", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "cx"}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["cx", "2"]}]]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "cx"}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["cx", "2"]}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cx3", "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "cx"}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["cx", "2"]}]]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "cx"}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["cx", "2"]}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.726234532834465*^9, 
  3.726234582164598*^9},ExpressionUUID->"cad43703-84bd-4728-bf35-\
3d3ea6cf7140"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["c", "3"], "-", 
      RowBox[{"3", " ", "c", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["c", "2"]}], ")"}]}]}], "\[Equal]", "cx"}], ",", " ", 
    "c"}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.726191279244247*^9, 
  3.726191359102652*^9}},ExpressionUUID->"68d904f7-6960-43e9-ad09-\
90ffa2507a31"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"cx", "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["cx", "2"]}]]}], ")"}], 
          RowBox[{"1", "/", "3"}]]], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"cx", "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["cx", "2"]}]]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", "+", 
          SqrtBox["3"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"cx", "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["cx", "2"]}]]}], ")"}], 
         RowBox[{"2", "/", "3"}]]}]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"cx", "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["cx", "2"]}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"cx", "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["cx", "2"]}]]}], ")"}], 
         RowBox[{"2", "/", "3"}]]}]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"cx", "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["cx", "2"]}]]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.726191350346427*^9, 
  3.726191359469657*^9}},ExpressionUUID->"cb89ec29-b804-476d-b1fa-\
6a66afdba637"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"subCS3rule", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"x", "/", "3"}], "]"}], " ", "\[Rule]", " ", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "x", "]"}], "+", 
           RowBox[{"I", " ", 
            RowBox[{"Sin", "[", "x", "]"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "x", "]"}], "+", 
          RowBox[{"I", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.726191407794614*^9, 
  3.7261915080063457`*^9}},ExpressionUUID->"4745cb24-2107-4ad0-9e60-\
936499954dd2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"I", " ", "y"}]}], ")"}], "/", "3"}], ")"}]}], "+", " ", 
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"x", "+", 
           RowBox[{"I", " ", "y"}]}], ")"}]}], "/", "3"}], ")"}]}]}], ")"}]}],
   "//", "TrigReduce"}]], "Input",
 CellChangeTimes->{{3.726191526121698*^9, 
  3.726191617092326*^9}},ExpressionUUID->"f971c556-9fcd-411f-b33c-\
fedf8c070873"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]]}], ")"}]}]], "Output",\

 CellChangeTimes->{{3.7261915972310762`*^9, 
  3.726191617520545*^9}},ExpressionUUID->"b26c8d9c-6b14-42c3-98e4-\
e9236a98c558"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", " ", "=", " ", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{"27", " ", 
        SuperscriptBox["p3", "2"]}], "-", 
       RowBox[{"72", " ", "p2", " ", "p4"}]}]}], ",", " ", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{"3", "   ", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox["p2", "3"], " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"81", " ", 
          SuperscriptBox["p3", "4"]}], "+", 
         RowBox[{"48", " ", 
          SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
         RowBox[{"432", " ", "p2", " ", 
          SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
         RowBox[{"384", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["p4", "2"]}], "+", 
         RowBox[{"768", " ", 
          SuperscriptBox["p4", "3"]}]}]]}]}], ",", "tan", ",", "cos", ",", 
     "sin", ",", " ", "r", ",", "rsq", ",", "arg", ",", "argc"}], " ", "}"}], 
   ",", 
   RowBox[{
    RowBox[{"rsq", " ", "=", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]}], ";", " ", 
    RowBox[{"r", " ", "=", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}], "]"}]}], ";", " ", 
    RowBox[{"cos", " ", "=", " ", 
     RowBox[{"x", "/", "r"}]}], ";", " ", 
    RowBox[{"sin", "=", " ", 
     RowBox[{"y", "/", "r"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"arg", " ", "=", " ", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], ";", 
    RowBox[{"argc", " ", "=", " ", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"x", ",", 
       RowBox[{"-", "y"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", "rsq", ")"}], 
          RowBox[{"1", "/", "6"}]], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["1", "3"], " ", "arg"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", "rsq", ")"}], 
          RowBox[{"1", "/", "6"}]], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["1", "3"], " ", "argc"}], "]"}]}]}], "//", " ", 
       "Simplify"}], ")"}], "//", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ">", "0"}]}], "]"}], "&"}]}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.726190631125903*^9, 3.7261908405984983`*^9}, {
  3.726190871903453*^9, 
  3.726191072725987*^9}},ExpressionUUID->"fdbe4e81-1d9e-4718-80b7-\
4bb4867a31ef"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{"1", "/", "3"}]], " ", 
  SqrtBox[
   RowBox[{
    SuperscriptBox["p2", "2"], "+", 
    RowBox[{"12", " ", "p4"}]}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}]}], ",", 
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "+", 
           RowBox[{"48", " ", 
            SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
           RowBox[{"432", " ", "p2", " ", 
            SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "+", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}]]}]}], "]"}]}], "]"}], "+", 
    RowBox[{"Cos", "[", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}]}], ",", 
        RowBox[{"3", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "+", 
           RowBox[{"48", " ", 
            SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
           RowBox[{"432", " ", "p2", " ", 
            SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "+", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}]]}]}], "]"}]}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.726191073682708*^9},ExpressionUUID->"580ea0c5-5a81-4fea-be17-\
e85b8ae3e9a4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["p3", "2"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "+", 
           RowBox[{"48", " ", 
            SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
           RowBox[{"432", " ", "p2", " ", 
            SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "+", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["p3", "2"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "+", 
           RowBox[{"48", " ", 
            SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
           RowBox[{"432", " ", "p2", " ", 
            SuperscriptBox["p3", "2"], " ", "p4"}], "-", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "+", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}]]}]}], ")"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "/", "6"}], ")"}]], "//", "Simplify"}], "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.7261756143216248`*^9, 
  3.726175654769911*^9}},ExpressionUUID->"7c6e794f-c016-4b5c-aee3-\
749f36239e49"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{"1", "/", "3"}]], " ", 
  SqrtBox[
   RowBox[{
    SuperscriptBox["p2", "2"], "+", 
    RowBox[{"12", " ", "p4"}]}]]}]], "Output",
 CellChangeTimes->{{3.726175641224362*^9, 
  3.726175655280738*^9}},ExpressionUUID->"732498dd-4559-41df-ae90-\
d95ccd5e657c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox[
        RowBox[{"theGfun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
        RowBox[{"1", "/", "3"}]]}], ",", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["2", 
         RowBox[{"1", "/", "3"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "-", 
          RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"theGfun", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
        RowBox[{"1", "/", "3"}]]]}], "}"}], "/.", 
    RowBox[{"p1", "\[Rule]", "0"}]}], "/.", "pnRandom0"}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{
  3.726169926365818*^9},ExpressionUUID->"3d8f8d7a-1159-43a8-b3a5-\
c65a241bcf8a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"7.977229336075816`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.6902722855064835`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"7.977229336075819`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.6902722855064838`", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.726169927448484*^9},ExpressionUUID->"491a56d5-4a9d-482d-8365-\
843655db30bd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", " ", "+", " ", 
       RowBox[{"I", " ", "b"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}]], "+", " ", 
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"2", "/", "3"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", " ", "+", " ", 
        RowBox[{"I", " ", "b"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "3"}], ")"}]]}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7261700470676203`*^9, 3.726170131496612*^9}, {
  3.726170166044251*^9, 
  3.7261702272424603`*^9}},ExpressionUUID->"f2718423-c462-4860-bfb9-\
63c736804a3e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", 
        RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
      RowBox[{"1", "/", "3"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"2", "/", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]]}], ",", "b"}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7261702406816883`*^9, 
  3.7261702484869547`*^9}},ExpressionUUID->"4c83e247-a1bb-41c5-b0ae-\
f75568edf7e6"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", 
        RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
      RowBox[{"2", "/", "3"}]], "-", 
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"2", "/", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "+", 
        RowBox[{"12", " ", "p4"}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"3", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
    RowBox[{"4", "/", "3"}]]}]]], "Output",
 CellChangeTimes->{
  3.7261702492864*^9},ExpressionUUID->"b7544906-1002-41c0-93de-bbd1a92e8b67"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here is the better-expressed code: Do the special p1=0 case using patterns:\
\>", "Subsubsection",
 CellChangeTimes->{{3.726079809798699*^9, 3.726079818326488*^9}, {
  3.72616957332008*^9, 
  3.72616959096004*^9}},ExpressionUUID->"1e1c0099-f6e4-4562-af0d-\
b5d3316302a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theGfun", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["p2", "3"]}], "-", 
    RowBox[{"9", " ", "p2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"p1", " ", "p3"}], "+", 
       RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
    RowBox[{"27", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p3", "2"], "+", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "-", 
         RowBox[{"9", " ", "p2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", " ", "p3"}], "+", 
            RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
         RowBox[{"27", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p3", "2"], "+", 
            RowBox[{
             SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], "2"],
       "-", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "-", 
          RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}]}]]}], ")"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7260775312314167`*^9, 3.726077546784399*^9}, {
  3.7260783128118563`*^9, 3.72607832589255*^9}, {3.7260783855416527`*^9, 
  3.7260783964845552`*^9}, {3.7260785439554358`*^9, 3.726078587163566*^9}},
 CellLabel->
  "In[434]:=",ExpressionUUID->"f9f9d650-8633-4bf0-ba0d-0882bc674309"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theGfun", "[", 
   RowBox[{"0", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["p2", "3"]}], "+", 
    RowBox[{"27", " ", 
     SuperscriptBox["p3", "2"]}], "-", 
    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
    RowBox[{"3", 
     SqrtBox[
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["p2", "3"], " ", 
        SuperscriptBox["p3", "2"]}], "+", 
       RowBox[{"81", " ", 
        SuperscriptBox["p3", "4"]}], "-", 
       RowBox[{"48", " ", 
        SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
       RowBox[{"432", " ", "p2", " ", 
        SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
       RowBox[{"384", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p4", "2"]}], "-", 
       RowBox[{"768", " ", 
        SuperscriptBox["p4", "3"]}]}]]}]}], ")"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7260775312314167`*^9, 3.726077546784399*^9}, {
   3.7260783128118563`*^9, 3.72607832589255*^9}, {3.7260783855416527`*^9, 
   3.7260783964845552`*^9}, {3.7260785439554358`*^9, 3.726078587163566*^9}, 
   3.7261692664995813`*^9, {3.726169449074918*^9, 3.7261694629375563`*^9}, 
   3.7261694932312937`*^9},
 CellLabel->
  "In[433]:=",ExpressionUUID->"a08ee633-549b-4294-9e70-45ab457a2893"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theFfun", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox[
     RowBox[{"theGfun", "[", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
     RowBox[{"1", "/", "3"}]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["2", 
      RowBox[{"1", "/", "3"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "-", 
       RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"theGfun", "[", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
     RowBox[{"1", "/", "3"}]]]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726079275700633*^9, 3.7260793219973373`*^9}, {
  3.7260793595079813`*^9, 3.726079382051634*^9}, {3.726079920507094*^9, 
  3.7260799330310707`*^9}},
 CellLabel->
  "In[432]:=",ExpressionUUID->"b5136d90-2e9d-48c4-b69e-66214f0d5fd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"optEigVal", " ", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "p1"}], "+", " ", 
     RowBox[{
      FractionBox[
       SqrtBox["3"], "12"], 
      SqrtBox[
       RowBox[{" ", 
        RowBox[{
         RowBox[{
          RowBox[{"+", "3"}], " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"theFfun", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
          " "}]}]}]]}], "+", 
     RowBox[{
      FractionBox[
       SqrtBox["6"], "12"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"+", "3"}], " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "-", 
         RowBox[{"theFfun", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "-", 
         FractionBox[
          RowBox[{"3", " ", 
           SqrtBox["3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["p1", "3"], "-", 
             RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
             RowBox[{"8", " ", "p3"}]}], ")"}]}], 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"+", "3"}], " ", 
             SuperscriptBox["p1", "2"]}], "-", 
            RowBox[{"8", " ", "p2"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"theFfun", "[", 
              RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}]]]}], 
        ")"}]}]}]}], ")"}], "//", "Chop"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726079764558526*^9, 3.726079794637978*^9}, {
  3.726079864276005*^9, 3.726079892095599*^9}, {3.726080673657496*^9, 
  3.72608067485046*^9}},
 CellLabel->
  "In[431]:=",ExpressionUUID->"a1aaa429-14c9-40d5-8663-d5a0f47151d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Check", " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"optEigvalFull", "[", 
     RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], " ", "-", " ", 
    RowBox[{"optEigVal", "[", 
     RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.726079982565668*^9, 
  3.726080015788464*^9}},ExpressionUUID->"404619b1-528f-4913-873e-\
6e32f32f0bd8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.726080009750052*^9, 
  3.726080016556579*^9}},ExpressionUUID->"7f2a9b4f-e092-4728-b411-\
bbd07657d6b7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"theEigValN", " ", "[", 
   RowBox[{"n_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ",
   ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"S1", " ", "=", " ", 
       RowBox[{"Switch", "[", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"+", "1"}], ",", " ", "2", ",", " ", 
         RowBox[{"+", "1"}], ",", " ", "3", ",", 
         RowBox[{"-", "1"}], ",", "4", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"S2", " ", "=", " ", 
       RowBox[{"Switch", "[", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"+", "1"}], ",", " ", "2", ",", " ", 
         RowBox[{"-", "1"}], ",", " ", "3", ",", 
         RowBox[{"+", "1"}], ",", "4", ",", 
         RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "p1"}], "+", 
      RowBox[{"S1", " ", 
       FractionBox[
        SqrtBox["3"], "12"], 
       SqrtBox[
        RowBox[{" ", 
         RowBox[{
          RowBox[{
           RowBox[{"+", "3"}], " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"theFfun", "[", 
            RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
           " "}]}]}]]}], "+", 
      RowBox[{"S2", 
       FractionBox[
        SqrtBox["6"], "12"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"+", "3"}], " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", 
          RowBox[{"theFfun", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "-", 
          RowBox[{"S1", 
           FractionBox[
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"+", "3"}], " ", 
               SuperscriptBox["p1", "2"]}], "-", 
              RowBox[{"8", " ", "p2"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"theFfun", "[", 
                RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], 
                "]"}]}]}]]]}]}], ")"}]}]}]}], ")"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726079764558526*^9, 3.726079794637978*^9}, {
   3.726079864276005*^9, 3.726079892095599*^9}, {3.72608010291181*^9, 
   3.72608030843752*^9}, {3.726080339133754*^9, 3.726080347827962*^9}, 
   3.726080398715815*^9},ExpressionUUID->"05638ad8-4a95-468a-8b19-\
2b473d7787e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theEigValNSym", " ", "[", 
   RowBox[{"n_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ",
   ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"S1", " ", "=", " ", 
       RowBox[{"Switch", "[", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"+", "1"}], ",", " ", "2", ",", " ", 
         RowBox[{"+", "1"}], ",", " ", "3", ",", 
         RowBox[{"-", "1"}], ",", "4", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"S2", " ", "=", " ", 
       RowBox[{"Switch", "[", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"+", "1"}], ",", " ", "2", ",", " ", 
         RowBox[{"-", "1"}], ",", " ", "3", ",", 
         RowBox[{"+", "1"}], ",", "4", ",", 
         RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "p1"}], "+", 
      RowBox[{"S1", " ", 
       FractionBox[
        SqrtBox["3"], "12"], 
       SqrtBox[
        RowBox[{" ", 
         RowBox[{
          RowBox[{
           RowBox[{"+", "3"}], " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{"2", " ", "Ffun", "  "}]}]}]]}], "+", 
      RowBox[{"S2", 
       FractionBox[
        SqrtBox["6"], "12"], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"+", "3"}], " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "-", " ", "Ffun", " ", "-", 
          RowBox[{"S1", 
           FractionBox[
            RowBox[{"3", " ", 
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p1", "3"], "-", 
               RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
               RowBox[{"8", " ", "p3"}]}], ")"}]}], 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"+", "3"}], " ", 
               SuperscriptBox["p1", "2"]}], "-", 
              RowBox[{"8", " ", "p2"}], "+", 
              RowBox[{"2", " ", "Ffun", " "}]}]]]}]}], ")"}]}]}]}], ")"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726079764558526*^9, 3.726079794637978*^9}, {
   3.726079864276005*^9, 3.726079892095599*^9}, {3.72608010291181*^9, 
   3.72608030843752*^9}, {3.726080339133754*^9, 3.726080347827962*^9}, 
   3.726080398715815*^9, {3.726080460547426*^9, 
   3.726080503276083*^9}},ExpressionUUID->"19427b4b-12e0-4f1b-9ec8-\
a7b8d6435bcc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"theEigValNSym", "[", 
    RowBox[{"i", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.72608040314889*^9, 3.726080426992659*^9}, {
  3.726080522922368*^9, 
  3.726080524136559*^9}},ExpressionUUID->"ce18bd1e-5172-4902-915c-\
bb54afac04ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["p1", "4"]}], "+", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"2", " ", "Ffun"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "-", 
       RowBox[{"8", " ", "p2"}]}]], 
     RowBox[{"4", " ", 
      SqrtBox["3"]}]], "+", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"-", "Ffun"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "-", 
       RowBox[{"8", " ", "p2"}], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p1", "3"], "-", 
           RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
           RowBox[{"8", " ", "p3"}]}], ")"}]}], 
        SqrtBox[
         RowBox[{
          RowBox[{"2", " ", "Ffun"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}]}]]]}]], 
     RowBox[{"2", " ", 
      SqrtBox["6"]}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p1", "4"]}], "+", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"2", " ", "Ffun"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "-", 
       RowBox[{"8", " ", "p2"}]}]], 
     RowBox[{"4", " ", 
      SqrtBox["3"]}]], "-", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"-", "Ffun"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "-", 
       RowBox[{"8", " ", "p2"}], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p1", "3"], "-", 
           RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
           RowBox[{"8", " ", "p3"}]}], ")"}]}], 
        SqrtBox[
         RowBox[{
          RowBox[{"2", " ", "Ffun"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}]}]]]}]], 
     RowBox[{"2", " ", 
      SqrtBox["6"]}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p1", "4"]}], "-", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"2", " ", "Ffun"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "-", 
       RowBox[{"8", " ", "p2"}]}]], 
     RowBox[{"4", " ", 
      SqrtBox["3"]}]], "+", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"-", "Ffun"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "-", 
       RowBox[{"8", " ", "p2"}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p1", "3"], "-", 
           RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
           RowBox[{"8", " ", "p3"}]}], ")"}]}], 
        SqrtBox[
         RowBox[{
          RowBox[{"2", " ", "Ffun"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}]}]]]}]], 
     RowBox[{"2", " ", 
      SqrtBox["6"]}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p1", "4"]}], "-", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"2", " ", "Ffun"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "-", 
       RowBox[{"8", " ", "p2"}]}]], 
     RowBox[{"4", " ", 
      SqrtBox["3"]}]], "-", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"-", "Ffun"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["p1", "2"]}], "-", 
       RowBox[{"8", " ", "p2"}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p1", "3"], "-", 
           RowBox[{"4", " ", "p1", " ", "p2"}], "+", 
           RowBox[{"8", " ", "p3"}]}], ")"}]}], 
        SqrtBox[
         RowBox[{
          RowBox[{"2", " ", "Ffun"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}]}]]]}]], 
     RowBox[{"2", " ", 
      SqrtBox["6"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.726080415422084*^9, 3.7260804326109943`*^9}, 
   3.726080524634161*^9},ExpressionUUID->"08ac2336-064c-45db-91ed-\
e98b413f4e78"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Now look at the 3D root structure: p1 = 0", "Subsubsection",
 CellChangeTimes->{{3.726109175686058*^9, 3.726109189485978*^9}, {
  3.726161863348628*^9, 
  3.7261618651557207`*^9}},ExpressionUUID->"e873e24e-2550-4990-9a08-\
7a93b6f23a4e"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" Gfun  at p1 = 0 has to appear in the sum: compute \
matching algebra...",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7261541097012243`*^9, 3.726154130429283*^9}, 
   3.726161409976282*^9, {3.7261618566367273`*^9, 
   3.726161898667891*^9}},ExpressionUUID->"da7f0ea6-164c-4443-b6c2-\
d33e93498c87"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"theGfun", "[", 
    RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "//", "Expand"}], "//",
   "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7261543687215433`*^9, 3.726154384886849*^9}, {
   3.7261545997631063`*^9, 3.7261546247367783`*^9}, 3.726161191517775*^9, 
   3.726161409976967*^9},ExpressionUUID->"925b9d56-f933-45ad-b881-\
1f61995c664f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"27", " ", 
   SuperscriptBox["p3", "2"]}], "-", 
  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
  SqrtBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "+", 
        RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{"27", " ", 
        SuperscriptBox["p3", "2"]}], "-", 
       RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.72615438558816*^9, {3.726154605692865*^9, 3.7261546251802692`*^9}, 
   3.7261611922068644`*^9, 
   3.726161409977564*^9},ExpressionUUID->"7abfc3a8-6063-4804-8d8a-\
567a78b5038d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "9"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"27", " ", 
           SuperscriptBox["p3", "2"]}], "-", 
          RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}], ")"}]}], "//",
     "Expand"}], "//", "Factor"}], "//", "FullSimplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.72615472970393*^9, 3.726154746647724*^9}, {
   3.726161217282926*^9, 3.726161263548555*^9}, 
   3.726161409979393*^9},ExpressionUUID->"0d45098d-6531-4e8d-9574-\
f3baf86de23b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"12", " ", 
   SuperscriptBox["p2", "3"], " ", 
   SuperscriptBox["p3", "2"]}], "+", 
  RowBox[{"81", " ", 
   SuperscriptBox["p3", "4"]}], "-", 
  RowBox[{"48", " ", "p2", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "3"], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
  RowBox[{"384", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["p4", "2"]}], "-", 
  RowBox[{"768", " ", 
   SuperscriptBox["p4", "3"]}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.726154732005156*^9, 3.726154747241942*^9}, {
   3.7261612307301617`*^9, 3.726161264090886*^9}, 
   3.726161409979615*^9},ExpressionUUID->"a9a30b35-c03c-41eb-9bd7-\
8a0986a62e1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["p2", "3"], " ", 
    SuperscriptBox["p3", "2"]}], "+", 
   RowBox[{"81", " ", 
    SuperscriptBox["p3", "4"]}], "-", 
   RowBox[{"48", " ", 
    SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
   RowBox[{"432", " ", "p2", " ", 
    SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
   RowBox[{"384", " ", 
    SuperscriptBox["p2", "2"], " ", 
    SuperscriptBox["p4", "2"]}], "-", 
   RowBox[{"768", " ", 
    SuperscriptBox["p4", "3"]}]}], "//", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{"#", ",", "p3"}], "]"}], "&"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.726161102131762*^9, 3.7261611047508917`*^9}, 
   3.726161409979857*^9, {3.726161532872697*^9, 3.726161544959448*^9}, {
   3.726161576905141*^9, 
   3.7261615988868237`*^9}},ExpressionUUID->"17e43fc7-0ca9-42c0-a06e-\
f8da68c09874"],

Cell[BoxData[
 RowBox[{
  RowBox[{"81", " ", 
   SuperscriptBox["p3", "4"]}], "-", 
  RowBox[{"48", " ", 
   SuperscriptBox["p2", "4"], " ", "p4"}], "+", 
  RowBox[{"384", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["p4", "2"]}], "-", 
  RowBox[{"768", " ", 
   SuperscriptBox["p4", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["p3", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["p2", "3"]}], "-", 
     RowBox[{"432", " ", "p2", " ", "p4"}]}], ")"}]}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.726161105334832*^9, 3.726161409980061*^9, {3.726161534880327*^9, 
   3.7261615453879642`*^9}, {3.7261615815390263`*^9, 
   3.7261616009292603`*^9}},ExpressionUUID->"55f8bb42-ab79-4db6-9591-\
82fd4ac8f9be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Compare", " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["p2", "3"]}], "+", 
    RowBox[{"27", " ", 
     SuperscriptBox["p3", "2"]}], "-", 
    RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]], " ", "-", 
    "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["p3", "2"]}], "-", 
      RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
      RowBox[{"3", 
       SqrtBox[
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["p2", "3"], " ", 
          SuperscriptBox["p3", "2"]}], "+", 
         RowBox[{"81", " ", 
          SuperscriptBox["p3", "4"]}], "-", 
         RowBox[{"48", " ", "p2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "3"], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
         RowBox[{"384", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["p4", "2"]}], "-", 
         RowBox[{"768", " ", 
          SuperscriptBox["p4", "3"]}]}]]}]}], ")"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.726161293253832*^9, 3.726161350312996*^9}, 
   3.726161409980351*^9},ExpressionUUID->"5661ec59-eb94-4539-a64a-\
eb1dfc4e0dbb"],

Cell[BoxData["0"], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.726161350662462*^9, 
  3.726161409980571*^9},ExpressionUUID->"06d3bd82-a724-4b65-a4c2-\
4f96ef518d4f"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"theGfun0", "[", " ", 
   RowBox[{"p2_", ",", "p3_", ",", "p4_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["p2", "3"]}], "+", 
   RowBox[{"27", " ", 
    SuperscriptBox["p3", "2"]}], "-", 
   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
   RowBox[{"3", 
    SqrtBox[
     RowBox[{
      RowBox[{"12", " ", 
       SuperscriptBox["p2", "3"], " ", 
       SuperscriptBox["p3", "2"]}], "+", 
      RowBox[{"81", " ", 
       SuperscriptBox["p3", "4"]}], "-", 
      RowBox[{"48", " ", 
       SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
      RowBox[{"432", " ", "p2", " ", 
       SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
      RowBox[{"384", " ", 
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["p4", "2"]}], "-", 
      RowBox[{"768", " ", 
       SuperscriptBox["p4", "3"]}]}]]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726161694734591*^9, 3.726161727010848*^9}, {
  3.7261617873106194`*^9, 
  3.72616179487675*^9}},ExpressionUUID->"686c6c68-d509-4d0d-b78d-\
f8e521be3fdb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"theGfun0", "[", 
    RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], "-", 
   RowBox[{"theGfun", "[", 
    RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.726161819727129*^9, 
  3.726161848348062*^9}},ExpressionUUID->"3c75eaff-ab66-4c77-9962-\
f1bca3fff10f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.726161848639881*^9},ExpressionUUID->"72694d66-0217-428d-bad4-\
63f850bcb523"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyzRoot", "[", 
  RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellChangeTimes->{{3.726108910432061*^9, 
  3.726108924418095*^9}},ExpressionUUID->"27b76226-c8b3-4070-beb3-\
5be7e94bf730"],

Cell[BoxData[
 RowBox[{"\[Sqrt]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "2"], "+", 
       RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "24"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.726108924829439*^9},ExpressionUUID->"76d94af6-efbe-4da9-9c37-\
bf5b12b5fb56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xxyyzzRoot", "[", 
  RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellChangeTimes->{{3.726108958773189*^9, 
  3.72610900364915*^9}},ExpressionUUID->"b7520839-396e-41a9-88d7-\
50da049fde6e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["p2", "6"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "24"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "9"}], " ", 
          SuperscriptBox["p3", "2"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"12", " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "-", 
           RowBox[{"48", " ", "p2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "3"], "+", 
              RowBox[{"9", " ", 
               SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "-", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}]}]], "Output",
 CellChangeTimes->{
  3.726109004453722*^9},ExpressionUUID->"ca1168f5-937a-4420-8a1a-\
c038c09aa5c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "+", 
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "+", 
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.726109112385727*^9, 
  3.7261091176876173`*^9}},ExpressionUUID->"cbed455d-791d-42a3-84d7-\
8aa72af27977"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["p2", "2"]}]], "Output",
 CellChangeTimes->{
  3.726109159331531*^9},ExpressionUUID->"d8c32c74-0a26-44a9-a94b-\
3df0d5a7e9b4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"xxyyzzRoot", "[", 
      RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
     RowBox[{"xxyyzzRoot", "[", 
      RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
     RowBox[{"xxyyzzRoot", "[", 
      RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ")"}], 
   
   RowBox[{"(", 
    RowBox[{"1", "/", "2"}], ")"}]], "//", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"#", ",", 
     RowBox[{"p3", ">", "0"}]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.7261090844831667`*^9, 
  3.726109149606741*^9}},ExpressionUUID->"9a381dfe-bddc-413a-8617-\
66f65190483c"],

Cell[BoxData[
 FractionBox["p3", "8"]], "Output",
 CellChangeTimes->{
  3.726109100072715*^9, {3.726109131450304*^9, 
   3.726109150450218*^9}},ExpressionUUID->"e7a6dca0-b7b9-4b34-88d4-\
d11b7c3aa90d"]
}, Open  ]],

Cell[TextData[StyleBox["Check the p1->0 form...  We may have to pick a BRANCH \
of the square root that is negative?",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726162146713509*^9, 3.7261621547613573`*^9}, {
  3.7261636664353*^9, 
  3.726163686067174*^9}},ExpressionUUID->"c2d511ff-7580-405d-96a3-\
5ec248eedc89"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theGfun0", "[", 
  RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]], "Input",ExpressionUUID->\
"ae100c0c-2623-458b-8484-c0c7e1c861c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"27", " ", 
   SuperscriptBox["p3", "2"]}], "-", 
  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
  RowBox[{"3", " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["p2", "3"], " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     RowBox[{"81", " ", 
      SuperscriptBox["p3", "4"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
     RowBox[{"432", " ", "p2", " ", 
      SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
     RowBox[{"384", " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p4", "2"]}], "-", 
     RowBox[{"768", " ", 
      SuperscriptBox["p4", "3"]}]}]]}]}]], "Output",
 CellChangeTimes->{
  3.7261619415009823`*^9},ExpressionUUID->"3e413777-feb9-4902-9811-\
f5c8c22b1aa7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Bad", " ", 
    RowBox[{"sign", "?"}]}], "*)"}], 
  RowBox[{
   RowBox[{"grule2x", "=", " ", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["p2", "3"], " ", 
        SuperscriptBox["p3", "2"]}], "+", 
       RowBox[{"81", " ", 
        SuperscriptBox["p3", "4"]}], "-", 
       RowBox[{"48", " ", 
        SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
       RowBox[{"432", " ", "p2", " ", 
        SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
       RowBox[{"384", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p4", "2"]}], "-", 
       RowBox[{"768", " ", 
        SuperscriptBox["p4", "3"]}]}]], "\[Rule]", " ", 
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"(", " ", 
       RowBox[{"Gfun0", " ", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"27", " ", 
         SuperscriptBox["p3", "2"]}], "+", 
        RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}]}]}]}], ";"}]}]], "Input",\

 CellChangeTimes->{{3.7261624679990883`*^9, 3.7261625347831593`*^9}, {
  3.726163699380836*^9, 
  3.726163730682824*^9}},ExpressionUUID->"65cb3dce-6cbd-47be-9a9a-\
946f4d2b3f1b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"grule2x", "/.", " ", 
  RowBox[{"Gfun0", "\[Rule]", 
   RowBox[{"theGfun0", "[", 
    RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.726163253743299*^9, 3.726163267111347*^9}, 
   3.726163702332375*^9},ExpressionUUID->"763e2936-9444-4cfc-a8b5-\
9cc46b9d6702"],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{"12", " ", 
     SuperscriptBox["p2", "3"], " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    RowBox[{"81", " ", 
     SuperscriptBox["p3", "4"]}], "-", 
    RowBox[{"48", " ", 
     SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
    RowBox[{"432", " ", "p2", " ", 
     SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
    RowBox[{"384", " ", 
     SuperscriptBox["p2", "2"], " ", 
     SuperscriptBox["p4", "2"]}], "-", 
    RowBox[{"768", " ", 
     SuperscriptBox["p4", "3"]}]}]], "\[Rule]", 
  SqrtBox[
   RowBox[{
    RowBox[{"12", " ", 
     SuperscriptBox["p2", "3"], " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    RowBox[{"81", " ", 
     SuperscriptBox["p3", "4"]}], "-", 
    RowBox[{"48", " ", 
     SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
    RowBox[{"432", " ", "p2", " ", 
     SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
    RowBox[{"384", " ", 
     SuperscriptBox["p2", "2"], " ", 
     SuperscriptBox["p4", "2"]}], "-", 
    RowBox[{"768", " ", 
     SuperscriptBox["p4", "3"]}]}]]}]], "Output",
 CellChangeTimes->{3.726163267876936*^9, 
  3.726163719856225*^9},ExpressionUUID->"ca85eb59-eeea-46b2-ae3f-\
60c2961933c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"grule2", " ", "/.", " ", 
  RowBox[{"Gfun0", "\[Rule]", 
   RowBox[{"theGfun0", "[", 
    RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.726164632985989*^9},ExpressionUUID->"63b1faf8-f520-4e54-95b7-\
45c77ba95f91"],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{"12", " ", 
     SuperscriptBox["p2", "3"], " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    RowBox[{"81", " ", 
     SuperscriptBox["p3", "4"]}], "-", 
    RowBox[{"48", " ", 
     SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
    RowBox[{"432", " ", "p2", " ", 
     SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
    RowBox[{"384", " ", 
     SuperscriptBox["p2", "2"], " ", 
     SuperscriptBox["p4", "2"]}], "-", 
    RowBox[{"768", " ", 
     SuperscriptBox["p4", "3"]}]}]], "\[Rule]", 
  RowBox[{"-", 
   SqrtBox[
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["p2", "3"], " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     RowBox[{"81", " ", 
      SuperscriptBox["p3", "4"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
     RowBox[{"432", " ", "p2", " ", 
      SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
     RowBox[{"384", " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p4", "2"]}], "-", 
     RowBox[{"768", " ", 
      SuperscriptBox["p4", "3"]}]}]]}]}]], "Output",
 CellChangeTimes->{
  3.7261646342983932`*^9},ExpressionUUID->"0498168a-3671-412c-b4d5-\
3fb3bb093bda"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Switch", " ", 
    RowBox[{"sign", "?"}]}], "*)"}], 
  RowBox[{
   RowBox[{"grule2", " ", "=", " ", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["p2", "3"], " ", 
        SuperscriptBox["p3", "2"]}], "+", 
       RowBox[{"81", " ", 
        SuperscriptBox["p3", "4"]}], "-", 
       RowBox[{"48", " ", 
        SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
       RowBox[{"432", " ", "p2", " ", 
        SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
       RowBox[{"384", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p4", "2"]}], "-", 
       RowBox[{"768", " ", 
        SuperscriptBox["p4", "3"]}]}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", " ", 
       FractionBox["1", "3"]}], 
      RowBox[{"(", " ", 
       RowBox[{"Gfun0", " ", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"27", " ", 
         SuperscriptBox["p3", "2"]}], "+", 
        RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}]}]}]}], ";"}]}]], "Input",\

 CellChangeTimes->{{3.7261624679990883`*^9, 3.7261625347831593`*^9}, {
  3.726163699380836*^9, 3.726163751867567*^9}, {3.726164655034863*^9, 
  3.726164656193728*^9}},ExpressionUUID->"4dfc68f6-ce49-4bb4-a7ae-\
c8b478a9de14"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"theGfun0", "[", 
     RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], "/.", "grule2x"}], ",", 
   RowBox[{
    RowBox[{"theGfun0", "[", 
     RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], "/.", "grule2"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.726162554662532*^9, 3.726162555136507*^9}, {
  3.726163762556666*^9, 
  3.726163782330325*^9}},ExpressionUUID->"6498cf6b-055b-43ae-9ba2-\
899984b56b0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Gfun0", ",", 
   RowBox[{
    RowBox[{"-", "Gfun0"}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["p2", "3"]}], "+", 
    RowBox[{"54", " ", 
     SuperscriptBox["p3", "2"]}], "-", 
    RowBox[{"144", " ", "p2", " ", "p4"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7261625558073606`*^9, {3.726163757615705*^9, 
   3.72616378265453*^9}},ExpressionUUID->"17ddc0f2-09ff-483d-844e-\
ad1b1d58b094"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Test for a Sqrt[-1]:",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox["  so there ",
  FontWeight->"Bold"],
 StyleBox[" is ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" a minus sign inside - how to deal with it?",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.726159370099896*^9, 3.726159379891728*^9}, {
  3.726162330999956*^9, 
  3.726162350672035*^9}},ExpressionUUID->"f9a35a63-50ac-4376-9a95-\
1b5fb998713d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", " ", 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]], ",", 
    RowBox[{"3", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["p2", "3"], " ", 
        SuperscriptBox["p3", "2"]}], "+", 
       RowBox[{"81", " ", 
        SuperscriptBox["p3", "4"]}], "-", 
       RowBox[{"48", " ", 
        SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
       RowBox[{"432", " ", "p2", " ", 
        SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
       RowBox[{"384", " ", 
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["p4", "2"]}], "-", 
       RowBox[{"768", " ", 
        SuperscriptBox["p4", "3"]}]}]]}]}], "}"}], "/.", 
  "pnRandom0"}]], "Input",
 CellChangeTimes->{{3.726159385908176*^9, 3.726159399587706*^9}, {
   3.726159449540262*^9, 3.726159454019298*^9}, 
   3.726162050337263*^9},ExpressionUUID->"3a58c67a-07b2-4799-b709-\
96bdf6e1fbe1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"0.`", "\[VeryThinSpace]", "+", 
     RowBox[{"32.86249812209677`", " ", "\[ImaginaryI]"}]}], ",", 
    RowBox[{"0.`", "\[VeryThinSpace]", "+", 
     RowBox[{"32.862498122096724`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.726162182264927*^9, 
  3.726162182269004*^9}},ExpressionUUID->"e8200106-1376-44cf-a1c3-\
c1b279824764"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "48"}], " ", 
   SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
  RowBox[{"432", " ", "p2", " ", 
   SuperscriptBox["p3", "2"], " ", "p4"}], "+"}]], "Input",ExpressionUUID->\
"4247d3f2-a2e7-4d42-98fc-db5f50b6e497"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], " ", 
   "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["p2", "6"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"6", " ", "2", "phiX", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", 
                  SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                 RowBox[{"432", " ", "p2", " ", 
                  SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "24"], " ", "2", " ", "phiX", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", 
                SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
               RowBox[{"432", " ", "p2", " ", 
                SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}], "/.", " ", "grule2x"}], "//", 
    "Together"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.726154422883141*^9, 3.726154428874041*^9}, {
   3.72615450569129*^9, 3.726154533098084*^9}, {3.726162596885635*^9, 
   3.726162604408883*^9}, {3.726162638184037*^9, 3.726162766773348*^9}, {
   3.726162810957062*^9, 3.726162884579112*^9}, {3.72616300101828*^9, 
   3.726163038073093*^9}, {3.7261631501477222`*^9, 3.726163152896625*^9}, 
   3.726163238604924*^9, {3.726163337868703*^9, 3.72616334079275*^9}, {
   3.726163371619463*^9, 3.7261634021741877`*^9}, {3.726163435746479*^9, 
   3.726163494909705*^9}, 
   3.726163815755991*^9},ExpressionUUID->"b9b04cc6-02e7-4a88-b790-\
18a431ceb31b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["p2", "6"]}], "+", 
  FractionBox[
   SuperscriptBox["p2", "2"], 
   RowBox[{"6", " ", 
    SuperscriptBox["2", 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Gfun0", "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"54", " ", 
        SuperscriptBox["p3", "2"]}], "+", 
       RowBox[{"144", " ", "p2", " ", "p4"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", "phiX"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]], " ", "p4"}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Gfun0", "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"54", " ", 
        SuperscriptBox["p3", "2"]}], "+", 
       RowBox[{"144", " ", "p2", " ", "p4"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", "phiX"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"Gfun0", "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["p2", "3"]}], "-", 
       RowBox[{"54", " ", 
        SuperscriptBox["p3", "2"]}], "+", 
       RowBox[{"144", " ", "p2", " ", "p4"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", "phiX"}], 
   RowBox[{"12", " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.72616260521517*^9, {3.726162643240705*^9, 3.726162662329234*^9}, {
   3.726162694482319*^9, 3.7261627039045*^9}, 3.726162767872897*^9, 
   3.7261628851272078`*^9, {3.726163019240611*^9, 3.726163038776925*^9}, 
   3.726163153280094*^9, {3.726163375752981*^9, 3.726163402638776*^9}, {
   3.726163469886475*^9, 3.7261634958698997`*^9}, 
   3.72616381681618*^9},ExpressionUUID->"186e1d81-5111-4f9c-bb42-\
77ad7bf35841"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"xxyyzzRoot", "[", 
    RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], " ", 
   "*)"}], "  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", "2", "phiX", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
             RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", 
                   SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                  RowBox[{"432", " ", "p2", " ", 
                   SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", "2", " ", "phiX", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", 
                 SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                RowBox[{"432", " ", "p2", " ", 
                 SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], "/.", " ", "grule2"}], " ", "//", 
     "Expand"}], "//", "Simplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.726154422883141*^9, 3.726154428874041*^9}, {
   3.72615450569129*^9, 3.726154533098084*^9}, {3.726162596885635*^9, 
   3.726162604408883*^9}, {3.726162638184037*^9, 3.726162766773348*^9}, {
   3.726162810957062*^9, 3.726162884579112*^9}, {3.72616300101828*^9, 
   3.726163038073093*^9}, {3.7261631501477222`*^9, 3.726163152896625*^9}, 
   3.726163238604924*^9, {3.726163337868703*^9, 3.72616334079275*^9}, {
   3.726163371619463*^9, 3.7261634021741877`*^9}, {3.726163435746479*^9, 
   3.726163494909705*^9}, {3.726163829147956*^9, 
   3.7261639267211237`*^9}},ExpressionUUID->"ba6a8fbf-d27f-4642-adbd-\
bb799c644c30"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["p2", "6"]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox["p2", "2"]}], 
   RowBox[{"6", " ", 
    SuperscriptBox["2", 
     RowBox[{"2", "/", "3"}]], " ", "Gfun0", " ", "phiX"}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", "p4"}], 
   RowBox[{"Gfun0", " ", "phiX"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", "phiX"}], 
   RowBox[{"12", " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]]}]]}]], "Output",
 CellChangeTimes->{{3.72616382097569*^9, 
  3.7261639270985193`*^9}},ExpressionUUID->"266444db-f73d-44d6-9923-\
7a5d6c7c13fd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["p2", "6"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]], 
    RowBox[{"(", " ", 
     RowBox[{
      SuperscriptBox["p2", "2"], "+", 
      RowBox[{"12", " ", "p4"}]}], ")"}]}], 
   RowBox[{"12", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", " ", "Gfun0"}], " ", ")"}], 
     RowBox[{"1", "/", "3"}]], "phiX"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", "phiX"}], 
   RowBox[{"12", " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]]}]]}]], "Input",
 CellChangeTimes->{{3.7261641410795403`*^9, 3.7261641774238653`*^9}, {
  3.726164209354217*^9, 3.7261642448386087`*^9}, {3.726164283670187*^9, 
  3.726164301974099*^9}},ExpressionUUID->"de5ebfc2-9a69-4483-80be-\
dbb36dd24c41"],

Cell[TextData[StyleBox["------------------------------",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726164374980268*^9, 
  3.726164376417622*^9}},ExpressionUUID->"76ec34c1-c127-4a22-af2d-\
d6c30d843bd8"],

Cell[CellGroupData[{

Cell[BoxData["grule2"], "Input",
 CellChangeTimes->{{3.726164577198279*^9, 
  3.72616458017848*^9}},ExpressionUUID->"2ac86d5e-f7df-4e6f-87a1-\
a8df758c1e47"],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{"12", " ", 
     SuperscriptBox["p2", "3"], " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    RowBox[{"81", " ", 
     SuperscriptBox["p3", "4"]}], "-", 
    RowBox[{"48", " ", 
     SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
    RowBox[{"432", " ", "p2", " ", 
     SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
    RowBox[{"384", " ", 
     SuperscriptBox["p2", "2"], " ", 
     SuperscriptBox["p4", "2"]}], "-", 
    RowBox[{"768", " ", 
     SuperscriptBox["p4", "3"]}]}]], "\[Rule]", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "Gfun0"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["p2", "3"]}], "+", 
     RowBox[{"27", " ", 
      SuperscriptBox["p3", "2"]}], "-", 
     RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.726164580828519*^9},ExpressionUUID->"0e40ec8b-90d3-4719-947f-\
d211110f7808"]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"xxyyzzRoot", "[", 
   RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.726164382676613*^9, 
  3.726164385884903*^9}},ExpressionUUID->"521d6301-065a-46fc-9cc0-\
93a8a1427cc0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["p2", "6"]}], "+", 
      RowBox[{"p2sqP12p4", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "phiY", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", 
                  SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                 RowBox[{"432", " ", "p2", " ", 
                  SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "12"], "phiY", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", 
                SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
               RowBox[{"432", " ", "p2", " ", 
                SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}], "/.", "grule2"}], " ", "//", "Expand"}],
    "//", "Simplify"}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.726164445027441*^9, 3.7261644617239027`*^9}, {
  3.726164494488283*^9, 3.726164524027302*^9}, {3.72616473096916*^9, 
  3.72616473334203*^9}, {3.726164796739019*^9, 
  3.726164819434198*^9}},ExpressionUUID->"da3cb858-dc21-4e0f-93bc-\
f1a96e8cd0b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["p2", "6"]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", "p2sqP12p4"}], 
   RowBox[{"6", " ", 
    SuperscriptBox["2", 
     RowBox[{"2", "/", "3"}]], " ", "Gfun0", " ", "phiY"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", "phiY"}], 
   RowBox[{"12", " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]]}]]}]], "Output",
 CellChangeTimes->{{3.726164496931039*^9, 3.7261645251594763`*^9}, 
   3.7261647533772783`*^9, 
   3.726164827993499*^9},ExpressionUUID->"ba58bca3-cd66-4f8d-aa8c-\
b1b44f84ec68"]
}, Open  ]],

Cell[TextData[StyleBox["------------------------------",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726164374980268*^9, 
  3.726164376417622*^9}},ExpressionUUID->"93fe7075-be2e-410a-b52b-\
0cc024e0a9b0"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"xxyyzzRoot", "[", 
   RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.726164382676613*^9, 
  3.726164404364462*^9}},ExpressionUUID->"a860efb5-5fd4-4089-a7de-\
85128b1d9640"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       FractionBox["p2sqP12p4", 
        RowBox[{"12", " ", "phiZ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["p2", "3"], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 RowBox[{"81", " ", 
                  SuperscriptBox["p3", "4"]}], "-", 
                 RowBox[{"48", " ", 
                  SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                 RowBox[{"432", " ", "p2", " ", 
                  SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                 RowBox[{"384", " ", 
                  SuperscriptBox["p2", "2"], " ", 
                  SuperscriptBox["p4", "2"]}], "-", 
                 RowBox[{"768", " ", 
                  SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]], "+", 
       RowBox[{
        FractionBox["phiZ", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
           RowBox[{
            FractionBox["3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", 
                 SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
                RowBox[{"432", " ", "p2", " ", 
                 SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], "/.", "grule2"}], " ", "//", 
     "Expand"}], "//", "Simplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7261647384321527`*^9, 3.726164761645323*^9}, 
   3.726164825673072*^9, {3.726165771689403*^9, 
   3.726165808719676*^9}},ExpressionUUID->"756923b7-fe22-4c72-8c94-\
cdedc261e55a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["p2", "6"]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", "p2sqP12p4"}], 
   RowBox[{"6", " ", 
    SuperscriptBox["2", 
     RowBox[{"2", "/", "3"}]], " ", "Gfun0", " ", "phiZ"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", "phiZ"}], 
   RowBox[{"12", " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.72616476216807*^9, 3.726164831254356*^9, {3.726165787882318*^9, 
   3.726165809498102*^9}},ExpressionUUID->"f9440cf1-cfb3-4b31-8ca8-\
aa500f62f5c8"]
}, Open  ]],

Cell[TextData[StyleBox["------------------------------",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726164374980268*^9, 
  3.726164376417622*^9}},ExpressionUUID->"c7db0fac-788f-4c4b-86e8-\
38188391f9d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["p2", "6"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]], 
    RowBox[{"(", " ", 
     RowBox[{
      SuperscriptBox["p2", "2"], "+", 
      RowBox[{"12", " ", "p4"}]}], ")"}]}], 
   RowBox[{"12", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", " ", "Gfun0"}], " ", ")"}], 
     RowBox[{"1", "/", "3"}]], "phiX"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "Gfun0"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", "phiX"}], 
   RowBox[{"12", " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]]}]]}]], "Input",ExpressionUUID->"c3dc3b28-900a-\
4f11-a95f-60b9b453f814"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.7261664008529053`*^9},ExpressionUUID->"627b33c0-43a0-4fd4-b401-\
45cbb46882e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"theGfun", "[", 
     RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}], "\[Rule]", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"27", " ", 
           SuperscriptBox["p3", "2"]}], "-", 
          RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}], "]"}]}]}], "//",
    "Simplify"}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.726166175343295*^9, 
  3.7261662632578506`*^9}},ExpressionUUID->"7b90a541-81f9-47b2-b527-\
ab84de8c2cae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"27", " ", 
   SuperscriptBox["p3", "2"]}], "-", 
  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
  RowBox[{"3", " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["p2", "3"], " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     RowBox[{"81", " ", 
      SuperscriptBox["p3", "4"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
     RowBox[{"432", " ", "p2", " ", 
      SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
     RowBox[{"384", " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p4", "2"]}], "-", 
     RowBox[{"768", " ", 
      SuperscriptBox["p4", "3"]}]}]]}]}]], "Output",
 CellChangeTimes->{
  3.726166186153298*^9, {3.7261662184663153`*^9, 
   3.726166263685855*^9}},ExpressionUUID->"9981ad70-38f9-4b26-a803-\
1e31ec70ea5a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theGfun0", "[", 
  RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellChangeTimes->{{3.726166093223118*^9, 
  3.72616610997935*^9}},ExpressionUUID->"e17539ba-4ace-44e2-a1f0-\
eb3e4c285740"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"27", " ", 
   SuperscriptBox["p3", "2"]}], "-", 
  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
  RowBox[{"3", " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["p2", "3"], " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     RowBox[{"81", " ", 
      SuperscriptBox["p3", "4"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
     RowBox[{"432", " ", "p2", " ", 
      SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
     RowBox[{"384", " ", 
      SuperscriptBox["p2", "2"], " ", 
      SuperscriptBox["p4", "2"]}], "-", 
     RowBox[{"768", " ", 
      SuperscriptBox["p4", "3"]}]}]]}]}]], "Output",
 CellChangeTimes->{
  3.726166110453167*^9},ExpressionUUID->"12ab3633-98eb-44db-b60c-\
abba0a66931d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"newXYZRoot1", "[", 
   RowBox[{"root3_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qq3", ",", 
      RowBox[{"phi", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{"root3", ",", "\"\<x\>\"", ",", 
         FractionBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<y\>\"", ",", 
         FractionBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<z\>\"", ",", 
         RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       FractionBox[
        RowBox[{"  ", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}]}], 
        RowBox[{"12", " ", "phi", "  ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"theGfun0", "[", 
             RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]], "+", 
       RowBox[{
        FractionBox["phi", 
         RowBox[{"12", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]]}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"theGfun0", "[", 
            RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726166067910952*^9, 3.726166070126423*^9}, {
  3.726166136191486*^9, 3.7261661500442533`*^9}, {3.726166539748973*^9, 
  3.726166586689093*^9}},ExpressionUUID->"46d1b39f-2127-4b19-9a8d-\
58d4ac780084"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newXYZRoot2", "[", 
   RowBox[{"root3_", ",", "p2_", ",", "p3_", ",", "p4_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"qq3", ",", 
      RowBox[{"phi", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{"root3", ",", "\"\<x\>\"", ",", 
         FractionBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<y\>\"", ",", 
         FractionBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["3"]}]}], ")"}], "2"], ",", "\"\<z\>\"", ",", 
         RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["p2", "6"]}], "+", 
       FractionBox[
        RowBox[{"  ", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            RowBox[{"12", " ", "p4"}]}], ")"}]}]}], 
        RowBox[{"12", " ", "phi", "  ", 
         SuperscriptBox[
          RowBox[{"(", " ", 
           RowBox[{"theGfun0", "[", 
            RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], ")"}], 
          RowBox[{"1", "/", "3"}]]}]], "+", 
       RowBox[{
        FractionBox["phi", 
         RowBox[{"12", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "3"}]]}]], " ", 
        SuperscriptBox[
         RowBox[{"(", " ", 
          RowBox[{"theGfun0", "[", 
           RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.726166067910952*^9, 3.726166070126423*^9}, {
  3.726166136191486*^9, 3.7261661500442533`*^9}, {3.726166539748973*^9, 
  3.726166611520609*^9}},ExpressionUUID->"ec2477dd-5e61-4513-8b53-\
366fc252850a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The question is - who is right...", "Subsubsection",
 CellChangeTimes->{{3.726166769948647*^9, 
  3.7261667754283543`*^9}},ExpressionUUID->"d10ef776-1c0b-4fd9-bfe0-\
1583ffaf8cfd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SqrtBox["xx"], "+", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    SqrtBox["xx"], "-", 
    SqrtBox["yy"], "-", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "+", 
    SqrtBox["yy"], "-", 
    SqrtBox["zz"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["xx"]}], "-", 
    SqrtBox["yy"], "+", 
    SqrtBox["zz"]}]}], "}"}]], "Input",ExpressionUUID->"69b2f2ab-90e2-47f9-\
921c-8615db8a3af5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"subForxx", ",", "subForee"}], "}"}]], "Input",
 CellChangeTimes->{{3.72616748037809*^9, 
  3.726167503389963*^9}},ExpressionUUID->"6a5c7e19-2b9e-4c1b-b954-\
662c2f88f053"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ee1", "\[Rule]", 
      RowBox[{
       SqrtBox["xx"], "+", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}]}], ",", 
     RowBox[{"ee2", "\[Rule]", 
      RowBox[{
       SqrtBox["xx"], "-", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}]}], ",", 
     RowBox[{"ee3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "+", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}]}], ",", 
     RowBox[{"ee4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "-", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ee1", "\[Rule]", 
      RowBox[{"xE", "+", "yE", "+", "zE"}]}], ",", 
     RowBox[{"ee2", "\[Rule]", 
      RowBox[{"xE", "-", "yE", "-", "zE"}]}], ",", 
     RowBox[{"ee3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "xE"}], "+", "yE", "-", "zE"}]}], ",", 
     RowBox[{"ee4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "xE"}], "-", "yE", "+", "zE"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.726167487319478*^9, 
  3.7261675037638197`*^9}},ExpressionUUID->"4e263b24-ce8c-45f3-b7d6-\
e51430756b36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["pnRandom0"], "Input",
 CellChangeTimes->{{3.726166958518734*^9, 
  3.726166961834888*^9}},ExpressionUUID->"66c945a4-b4f2-45cf-bd40-\
492aa2e170f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", "0.2621670574518047`"}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "2.347438927680793`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "3.589172779025842`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726166962247568*^9},ExpressionUUID->"9d92310b-dfb7-43f0-bffe-\
f82fd271bb00"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Usage", " ", "to", " ", "get", " ", "random", " ", 
    RowBox[{"test", ":"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"makePnNumRule", "[", 
   RowBox[{"makeXYZnumRule", "[", 
    RowBox[{"makeMxxmat", "[", 
     RowBox[{"makeExxmat", "@@", " ", 
      RowBox[{
       RowBox[{"buildXRMSDdataset", "[", "10", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.726156517993895*^9, 3.7261566050459557`*^9}, 
   3.726159122636169*^9},ExpressionUUID->"c76fb55a-67f5-4791-a4fe-\
3a40c4aca070"],

Cell[CellGroupData[{

Cell[BoxData["thePRule"], "Input",
 CellChangeTimes->{{3.7261668408234377`*^9, 
  3.726166846455274*^9}},ExpressionUUID->"7c9d2f3b-d4ab-41b8-b77b-\
9e5d2de7761e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["aa", "2"]}], "-", 
     RowBox[{"2", " ", "a", " ", "aa", " ", "b", " ", "bb"}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["bb", "2"]}], "-", 
     RowBox[{"2", " ", "a", " ", "aa", " ", "c", " ", "cc"}], "-", 
     RowBox[{"2", " ", "b", " ", "bb", " ", "c", " ", "cc"}], "+", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox["cc", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["cc", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["bb", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["aa", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "x"}], "+", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "b", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "y", "-", "z"}], ")"}]}], "+", 
        RowBox[{"a", " ", "bb", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}], "+", 
        RowBox[{"a", " ", "b", " ", "cc", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}], "+", 
        RowBox[{"aa", " ", "bb", " ", "cc", " ", 
         RowBox[{"(", 
          RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", "x", " ", "y", " ", "z"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", "bb", " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "cc"}], "+", 
        RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["aa", "2"]}], ")"}], " ", "x"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["bb", "2"]}], ")"}], " ", "y"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["c", "2"], "-", 
           SuperscriptBox["cc", "2"]}], ")"}], " ", "z"}]}], ")"}]}]}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "-", 
     SuperscriptBox["aa", "2"], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["bb", "2"], "-", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox["cc", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726166987206278*^9},ExpressionUUID->"ec0fb25b-6abc-47c2-b6fc-\
51f854c5148d"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testMxxmat", " ", "=", 
  RowBox[{"makeMxxmat", "[", 
   RowBox[{"makeExxmat", "@@", " ", 
    RowBox[{
     RowBox[{"buildXRMSDdataset", "[", "10", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.726166783195149*^9, 3.726166820616743*^9}, {
   3.726166888302519*^9, 3.726166891303241*^9}, 3.7261669740238333`*^9, {
   3.726167118746643*^9, 
   3.726167132041745*^9}},ExpressionUUID->"1b3f0563-d781-42ef-bddf-\
ecd78a56cbf3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "6.741250233312106`", ",", "2.217521091034664`", ",", 
     "0.8223524284520032`", ",", "3.091488169715993`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.217521091034664`", ",", 
     RowBox[{"-", "2.261539390496657`"}], ",", 
     RowBox[{"-", "3.1861177157702056`"}], ",", 
     RowBox[{"-", "0.13646988709973779`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8223524284520032`", ",", 
     RowBox[{"-", "3.1861177157702056`"}], ",", 
     RowBox[{"-", "3.7940511576024507`"}], ",", "0.6243584720064155`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.091488169715993`", ",", 
     RowBox[{"-", "0.13646988709973779`"}], ",", "0.6243584720064155`", ",", 
     RowBox[{"-", "0.6856596852129977`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.719780879594652*^9, 3.7261668215831413`*^9, 
  3.726167005400332*^9, 
  3.726167132526574*^9},ExpressionUUID->"5be6b874-33fc-4fc1-9fcf-\
f18fe6db73c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Eigenvalues", "[", "testMxxmat", "]"}], "//", "Sort"}], "//", 
  "Reverse"}]], "Input",
 CellChangeTimes->{{3.726167071061624*^9, 3.726167074969832*^9}, {
  3.726167138118349*^9, 
  3.7261671610173817`*^9}},ExpressionUUID->"6298be96-65ca-4dda-9335-\
6bcc1eece29c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.268982911659652`", ",", "0.46379646581115935`", ",", 
   RowBox[{"-", "2.11654778208616`"}], ",", 
   RowBox[{"-", "6.616231595384651`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7261670755961103`*^9, {3.72616713915343*^9, 
   3.726167161453525*^9}},ExpressionUUID->"c0da8f1a-6a08-4695-945d-\
55cef6fdd705"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testxyzRule", "=", 
  RowBox[{"makeXYZnumRule", "[", "testMxxmat", "]"}]}]], "Input",
 CellChangeTimes->{{3.726167043353983*^9, 3.726167061146131*^9}, 
   3.726167189003529*^9},ExpressionUUID->"aa49f412-2f4d-4ebc-b44a-\
2595e72466a3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "2.239855421407724`"}], ",", 
   RowBox[{"y", "\[Rule]", "1.4735995378548274`"}], ",", 
   RowBox[{"z", "\[Rule]", "3.027795274049554`"}], ",", 
   RowBox[{"a", "\[Rule]", "2.217521091034664`"}], ",", 
   RowBox[{"b", "\[Rule]", "0.8223524284520032`"}], ",", 
   RowBox[{"c", "\[Rule]", "3.091488169715993`"}], ",", 
   RowBox[{"aa", "\[Rule]", "0.6243584720064155`"}], ",", 
   RowBox[{"bb", "\[Rule]", 
    RowBox[{"-", "0.13646988709973779`"}]}], ",", 
   RowBox[{"cc", "\[Rule]", 
    RowBox[{"-", "3.1861177157702056`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.726167049288034*^9, 
  3.7261671915115767`*^9},ExpressionUUID->"cee06f80-a2c8-486f-ba97-\
51431af50f71"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testPnRule", " ", "=", " ", 
  RowBox[{"makePnNumRule", "[", "testxyzRule", "]"}]}]], "Input",
 CellChangeTimes->{{3.726167225476129*^9, 
  3.726167233560059*^9}},ExpressionUUID->"e9a191d6-d916-4b30-bce5-\
0e1e045b8078"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", "0"}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "58.422740296319056`"}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "88.79878905610867`"}]}], ",", 
   RowBox[{"p4", "\[Rule]", "53.70544328533404`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726167233998727*^9},ExpressionUUID->"827f5011-23ca-46e6-85d4-\
3866175c31f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"theEigValN", " ", "[", 
      RowBox[{"i", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", "testPnRule"}],
   "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.7261673421914997`*^9, 
  3.726167364918605*^9}},ExpressionUUID->"9489b222-3d7b-4801-9718-\
8452aeea1323"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.268982911659648`", ",", "0.46379646581115974`", ",", 
   RowBox[{"-", "2.1165477820861613`"}], ",", 
   RowBox[{"-", "6.616231595384647`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.726167350293686*^9, 
  3.726167365743561*^9}},ExpressionUUID->"77e085fb-83e5-485c-836c-\
7ffe4c61ace8"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.7261675276726093`*^9},ExpressionUUID->"78b32fa5-8a60-47d7-ae35-\
391be16cbab5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"the4DEig", ",", "the3DEig"}], "}"}], "/.", "testPnRule"}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.726168305017251*^9, 
  3.726168320401478*^9}},ExpressionUUID->"3fe6be68-9549-487d-bdd0-\
f5dce3d9a50a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.268982911659648`", ",", "8.268982911659648`"}], "}"}]], "Output",\

 CellChangeTimes->{
  3.726168321865838*^9},ExpressionUUID->"07c93748-ae2f-4c7b-8332-\
be637f622444"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      FractionBox[
       SqrtBox["3"], "12"], 
      SqrtBox[
       RowBox[{" ", 
        RowBox[{
         RowBox[{
          RowBox[{"+", "3"}], " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"theFfun", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
          " "}]}]}]]}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"xxyyzzRoot", "[", 
       RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "]"}]}],
     "}"}], "/.", "testPnRule"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.726168347448536*^9, 3.726168425503037*^9}, 
   3.726168455633708*^9, {3.726168516483327*^9, 3.726168516998642*^9}, {
   3.726168559468813*^9, 
   3.726168647468523*^9}},ExpressionUUID->"279e9979-2682-43f7-98fe-\
a51731c94a6a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.366389688735405`", ",", "4.366389688735404`"}], "}"}]], "Output",\

 CellChangeTimes->{{3.726168406985372*^9, 3.726168426286824*^9}, 
   3.726168521272625*^9, {3.726168560149235*^9, 3.726168571517047*^9}, {
   3.726168610727578*^9, 
   3.726168648607525*^9}},ExpressionUUID->"93582518-b808-47a9-8a8b-\
b72426ffc930"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Build up the matching with x:", "Subsubsection",
 CellChangeTimes->{{3.726168774456242*^9, 
  3.726168782392082*^9}},ExpressionUUID->"ca99359c-246e-45f8-9f4a-\
dabbf6dac20a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SqrtBox["3"], "12"], 
      SqrtBox[
       RowBox[{" ", 
        RowBox[{
         RowBox[{
          RowBox[{"+", "3"}], " ", 
          SuperscriptBox["p1", "2"]}], "-", 
         RowBox[{"8", " ", "p2"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"theFfun", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
          " "}]}]}]]}], ")"}], "2"], "//", "PowerExpand"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.726168794752733*^9, 
  3.726168814355754*^9}},ExpressionUUID->"df46acb5-4fcb-46e7-86ac-\
468f96ab1803"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "48"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["p1", "2"]}], "-", 
    RowBox[{"8", " ", "p2"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", 
       SuperscriptBox["2", 
        RowBox[{"1", "/", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "-", 
         RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}]}], ")"}], "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"9", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "p3"}], "+", 
           RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
        RowBox[{"27", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p3", "2"], "+", 
           RowBox[{
            SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"p1", " ", "p3"}], "+", 
                RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
             RowBox[{"27", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p3", "2"], "+", 
                RowBox[{
                 SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
           "2"]}]]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["2", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "-", 
        RowBox[{"9", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "p3"}], "+", 
           RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
        RowBox[{"27", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p3", "2"], "+", 
           RowBox[{
            SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "-", 
              RowBox[{"3", " ", "p1", " ", "p3"}], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "-", 
             RowBox[{"9", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"p1", " ", "p3"}], "+", 
                RowBox[{"8", " ", "p4"}]}], ")"}]}], "+", 
             RowBox[{"27", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p3", "2"], "+", 
                RowBox[{
                 SuperscriptBox["p1", "2"], " ", "p4"}]}], ")"}]}]}], ")"}], 
           "2"]}]]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.726168807600975*^9, 
  3.726168829269024*^9}},ExpressionUUID->"f162fa06-26a6-4e93-a486-\
418036701d2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"theFfun", "[", 
   RowBox[{"0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7261688834684963`*^9, 
  3.726168908518895*^9}},ExpressionUUID->"558654db-8ac7-42c6-a0ba-\
dbb95d14924f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"1", "/", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["p2", "2"]}], "+", 
     RowBox[{"24", " ", "p4"}], "+", 
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["p3", "2"]}], "-", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "2"], "+", 
               RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], ")"}], 
       RowBox[{"2", "/", "3"}]]}]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["p2", "3"]}], "+", 
     RowBox[{"27", " ", 
      SuperscriptBox["p3", "2"]}], "-", 
     RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"27", " ", 
           SuperscriptBox["p3", "2"]}], "-", 
          RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], ")"}], 
   RowBox[{"1", "/", "3"}]]]], "Output",
 CellChangeTimes->{{3.7261689032579403`*^9, 
  3.726168908943741*^9}},ExpressionUUID->"c3fd9236-b7f2-4c41-8e50-\
f58012b034f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SqrtBox["3"], "12"], 
       SqrtBox[
        RowBox[{" ", 
         RowBox[{
          RowBox[{
           RowBox[{"+", "3"}], " ", 
           SuperscriptBox["p1", "2"]}], "-", 
          RowBox[{"8", " ", "p2"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"theFfun", "[", 
            RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], 
           " "}]}]}]]}], ")"}], "2"], "/.", 
    RowBox[{"p1", "\[Rule]", "0"}]}], "//", "PowerExpand"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.726168857119631*^9, 
  3.726168860191697*^9}},ExpressionUUID->"76e24d9d-5ed2-41e7-8ed6-\
c039ff369458"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "48"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", "p2"}], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      SuperscriptBox["2", 
       RowBox[{"1", "/", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "+", 
        RowBox[{"12", " ", "p4"}]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["p3", "2"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], ")"}], 
      
      RowBox[{"1", "/", "3"}]]], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["2", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["p3", "2"]}], "-", 
        RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["p3", "2"]}], "-", 
             RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], ")"}], 
      
      RowBox[{"1", "/", "3"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.726168864876732*^9},ExpressionUUID->"d70e7748-3ec9-4f26-8c52-\
719214f91326"]
}, Open  ]],

Cell[TextData[StyleBox["Compare the \[OpenCurlyDoubleQuote]xx\
\[CloseCurlyDoubleQuote] version:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7261689497184772`*^9, 
  3.7261689690780363`*^9}},ExpressionUUID->"21833b4c-7ffe-402c-8704-\
296b7dd6de20"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xxyyzzRoot", "[", 
  RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",Expr\
essionUUID->"af2c5c54-3603-4208-8b9c-95e27b20bb34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["p2", "6"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p2", "2"], "+", 
    RowBox[{"12", " ", "p4"}]}], 
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", 
           SuperscriptBox["p3", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"81", " ", 
             SuperscriptBox["p3", "4"]}], "-", 
            RowBox[{"48", " ", "p2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["p2", "3"], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["p2", "2"], " ", 
             SuperscriptBox["p4", "2"]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]], "+", 
  RowBox[{
   FractionBox["1", "24"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["p2", "3"]}], "+", 
      RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "9"}], " ", 
          SuperscriptBox["p3", "2"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"12", " ", 
            SuperscriptBox["p2", "3"], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           RowBox[{"81", " ", 
            SuperscriptBox["p3", "4"]}], "-", 
           RowBox[{"48", " ", "p2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "3"], "+", 
              RowBox[{"9", " ", 
               SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
           RowBox[{"384", " ", 
            SuperscriptBox["p2", "2"], " ", 
            SuperscriptBox["p4", "2"]}], "-", 
           RowBox[{"768", " ", 
            SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}]}]], "Output",
 CellChangeTimes->{
  3.726168934871044*^9},ExpressionUUID->"1fb61822-338a-4d6d-b113-\
253ba759bfb9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 Here is more stuff, don\[CloseCurlyQuote]t need it if I can reexpress  \
Sqrt[xx] in terms of FIRST root in theEigValN[1]\
\>", "Subsubsection",
 CellChangeTimes->{{3.726168707977035*^9, 
  3.726168748472497*^9}},ExpressionUUID->"efa785ce-a92a-43a8-af92-\
22f7b9716bf1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"the4DEig", "=", 
  RowBox[{"theEigValN", " ", "[", 
   RowBox[{"1", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]], "Input",\

 CellChangeTimes->{
  3.726168140335401*^9, {3.7261682838627577`*^9, 
   3.7261682888140306`*^9}},ExpressionUUID->"bab49aa3-e8a4-4576-b83f-\
f5ca9abaf879"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", 
     SqrtBox["3"]}]], 
   RowBox[{"(", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "p2"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "/", "3"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p2", "2"], "+", 
              RowBox[{"12", " ", "p4"}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]], "+", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"27", " ", 
               SuperscriptBox["p3", "2"]}], "-", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
             ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]], 
   RowBox[{"(", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "p2"}], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["2", 
          RowBox[{"1", "/", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           RowBox[{"12", " ", "p4"}]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"27", " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "2"], "+", 
                 RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["p2", "3"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "-", 
                RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
          ")"}], 
         RowBox[{"1", "/", "3"}]]], "-", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"2", "/", "3"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"27", " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "2"], "+", 
                 RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["p2", "3"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "-", 
                RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
          ")"}], 
         RowBox[{"1", "/", "3"}]]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"24", " ", 
          SqrtBox["3"], " ", "p3"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "p2"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{"2", " ", 
                 SuperscriptBox["2", 
                  RowBox[{"1", "/", "3"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "2"], "+", 
                   RowBox[{"12", " ", "p4"}]}], ")"}]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                  ")"}], 
                 RowBox[{"1", "/", "3"}]]], "+", 
               RowBox[{
                SuperscriptBox["2", 
                 RowBox[{"2", "/", "3"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "2"], "+", 
                    RowBox[{"12", " ", "p4"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["p2", "3"]}], "+", 
                    RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "-", 
                    RowBox[{"72", " ", "p2", " ", "p4"}]}], ")"}], "2"]}]]}], 
                  ")"}], 
                 RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], 
      ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.72616814414151*^9, 
  3.7261682896531887`*^9},ExpressionUUID->"a8a069d7-f9ee-4db5-a3e0-\
fb0318d61f88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"the3DEig", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SqrtBox["xx"], "+", 
     SqrtBox["yy"], "+", 
     SqrtBox["zz"]}], ")"}], "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xx", "\[Rule]", 
      RowBox[{"xxyyzzRoot", "[", 
       RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
     RowBox[{"yy", "->", 
      RowBox[{"xxyyzzRoot", "[", 
       RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
     RowBox[{"zz", "->", 
      RowBox[{"xxyyzzRoot", "[", 
       RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.726168058432911*^9, 3.726168112015111*^9}, {
  3.726168180697564*^9, 3.726168208024279*^9}, {3.72616829317586*^9, 
  3.726168296342434*^9}},ExpressionUUID->"c4606a39-1da7-47d6-a633-\
2cbb8c3d1e27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sqrt]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["p2", "6"]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["p2", "2"], "+", 
       RowBox[{"12", " ", "p4"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]], "-", 
     RowBox[{
      FractionBox["1", "12"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
  RowBox[{"\[Sqrt]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["p2", "6"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["p2", "2"], "+", 
       RowBox[{"12", " ", "p4"}]}], 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]], "+", 
     RowBox[{
      FractionBox["1", "24"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "+", 
  RowBox[{"\[Sqrt]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["p2", "6"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["p2", "2"], "+", 
       RowBox[{"12", " ", "p4"}]}], 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]], "+", 
     RowBox[{
      FractionBox["1", "24"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7261681055725403`*^9, 3.726168113367073*^9}, {
   3.7261681845333223`*^9, 3.726168211004195*^9}, 
   3.72616829701814*^9},ExpressionUUID->"caf8b914-64f6-40f5-8a67-\
5ead18ef488e"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.726168048891171*^9},ExpressionUUID->"55ebbbd6-5129-4a25-aa2d-\
75c15e1b46af"],

Cell[TextData[StyleBox["Old one is right: HOW can these add up to ",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7261680091998863`*^9, 
  3.726168021904043*^9}},ExpressionUUID->"9ae8ff14-2b17-4ecc-a2ac-\
529307822345"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SqrtBox["xx"], "+", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       SqrtBox["xx"], "-", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "+", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "-", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}]}], "}"}], "/.", "\[IndentingNewLine]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "\[Rule]", 
       RowBox[{"xxyyzzRoot", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"yy", "->", 
       RowBox[{"xxyyzzRoot", "[", 
        RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"zz", "->", 
       RowBox[{"xxyyzzRoot", "[", 
        RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
     "}"}]}], "/.", "testPnRule"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.726167933593848*^9, 
  3.726167946156163*^9}},ExpressionUUID->"a46ab581-5588-4327-8150-\
b0a40d7c3c39"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.268982911659648`", ",", "0.46379646581115885`", ",", 
   RowBox[{"-", "2.11654778208616`"}], ",", 
   RowBox[{"-", "6.616231595384647`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726167947563415*^9},ExpressionUUID->"2959a759-0ef0-4b09-8e37-\
0da56426f886"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.726167927684888*^9},ExpressionUUID->"747f9591-d44c-4877-84e0-\
b111a94820c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"newXYZRoot1", "[", 
    RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
   RowBox[{"newXYZRoot2", "[", 
    RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.726167581531887*^9, 
  3.726167650957089*^9}},ExpressionUUID->"d8a7cfef-898b-443d-919d-\
35e4a2af9403"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["p2", "6"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"3", " ", 
         SuperscriptBox["2", 
          RowBox[{"2", "/", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["p2", "3"]}], "-", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
            RowBox[{"3", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", 
                SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
               RowBox[{"432", " ", "p2", " ", 
                SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["p2", "3"]}], "-", 
           RowBox[{"27", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", 
               SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
              RowBox[{"432", " ", "p2", " ", 
               SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], 
       RowBox[{"24", " ", 
        SuperscriptBox["2", 
         RowBox[{"1", "/", "3"}]]}]]}], ")"}], 
    RowBox[{"1", "/", "3"}]], ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["p2", "6"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"12", " ", "p4"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"3", " ", 
         SuperscriptBox["2", 
          RowBox[{"2", "/", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["p2", "3"]}], "+", 
            RowBox[{"27", " ", 
             SuperscriptBox["p3", "2"]}], "-", 
            RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
            RowBox[{"3", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", 
                SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
               RowBox[{"432", " ", "p2", " ", 
                SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
          RowBox[{"1", "/", "3"}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"27", " ", 
            SuperscriptBox["p3", "2"]}], "-", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", 
               SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
              RowBox[{"432", " ", "p2", " ", 
               SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], 
       RowBox[{"24", " ", 
        SuperscriptBox["2", 
         RowBox[{"1", "/", "3"}]]}]]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.726167595351596*^9, 
  3.726167651441266*^9}},ExpressionUUID->"e639a290-b785-4e26-98e6-\
c89fda0e0f40"]
}, Closed]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.726167681319471*^9},ExpressionUUID->"9416af3d-39f3-4fe0-85dc-\
7bb533894987"],

Cell[TextData[StyleBox["All Wrong...",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.726167850721738*^9, 3.7261678539694557`*^9}, {
  3.726168002328436*^9, 
  3.726168003343857*^9}},ExpressionUUID->"b254904d-5177-468b-a344-\
5403f9b8e929"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SqrtBox["xx"], "+", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       SqrtBox["xx"], "-", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "+", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "-", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}]}], "}"}], "/.", "\[IndentingNewLine]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "\[Rule]", 
       RowBox[{"newXYZRoot1", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"yy", "->", 
       RowBox[{"newXYZRoot1", "[", 
        RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"zz", "->", 
       RowBox[{"newXYZRoot1", "[", 
        RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
     "}"}]}], "/.", "testPnRule"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.7261675438930798`*^9, 3.7261675485879297`*^9}, {
   3.726167696747787*^9, 3.726167723356505*^9}, 
   3.726167772375402*^9},ExpressionUUID->"3844387a-02ce-4fa8-80fa-\
57ed28e3c5f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.0272306713356585`", ",", 
   RowBox[{"-", "1.1185078062654032`"}], ",", 
   RowBox[{"-", "0.7583116675217909`"}], ",", 
   RowBox[{"-", "2.150411197548464`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7261677749754343`*^9},ExpressionUUID->"c4eb6bf2-74a8-41d7-a94a-\
703640ed6281"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SqrtBox["xx"], "+", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       SqrtBox["xx"], "-", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "+", 
       SqrtBox["yy"], "-", 
       SqrtBox["zz"]}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["xx"]}], "-", 
       SqrtBox["yy"], "+", 
       SqrtBox["zz"]}]}], "}"}], "/.", "\[IndentingNewLine]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "\[Rule]", 
       RowBox[{"newXYZRoot2", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"yy", "->", 
       RowBox[{"newXYZRoot2", "[", 
        RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"zz", "->", 
       RowBox[{"newXYZRoot2", "[", 
        RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
     "}"}]}], "/.", "testPnRule"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.7261675438930798`*^9, 3.7261675485879297`*^9}, 
   3.726167696747787*^9, {3.7261677282925863`*^9, 
   3.726167777453833*^9}},ExpressionUUID->"236aefe0-e5eb-447d-b1d5-\
cf60d2103463"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.9601162002465955`", ",", 
   RowBox[{"-", "0.6990746972022301`"}], ",", 
   RowBox[{"-", "1.0239732533901102`"}], ",", 
   RowBox[{"-", "2.2370682496542553`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7261677790617228`*^9},ExpressionUUID->"fc9a30a3-52d5-4773-88d7-\
244e722c5dce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "+", "yy", "+", "zz"}], ",", 
      RowBox[{"xx", "-", "yy", "-", "zz"}], ",", 
      RowBox[{
       RowBox[{"-", "xx"}], "+", "yy", "-", "zz"}], ",", 
      RowBox[{
       RowBox[{"-", "xx"}], "-", "yy", "+", "zz"}]}], "}"}], "/.", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "\[Rule]", 
       RowBox[{"newXYZRoot1", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"yy", "->", 
       RowBox[{"newXYZRoot1", "[", 
        RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"zz", "->", 
       RowBox[{"newXYZRoot1", "[", 
        RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
     "}"}]}], "/.", "testPnRule"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.7261675438930798`*^9, 3.7261675485879297`*^9}, {
   3.726167696747787*^9, 3.726167723356505*^9}, 3.726167772375402*^9, {
   3.726167861922592*^9, 
   3.726167876647718*^9}},ExpressionUUID->"9cbb889a-ad6d-4f5a-9e51-\
9eef2bc680a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.6672378741162`", ",", 
   RowBox[{"-", "1.4369035212249437`"}], ",", 
   RowBox[{"-", "0.32432214736847653`"}], ",", 
   RowBox[{"-", "3.9060122055227793`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726167878687254*^9},ExpressionUUID->"fc822c57-2d3c-4a00-8191-\
a69e2474e330"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "+", "yy", "+", "zz"}], ",", 
      RowBox[{"xx", "-", "yy", "-", "zz"}], ",", 
      RowBox[{
       RowBox[{"-", "xx"}], "+", "yy", "-", "zz"}], ",", 
      RowBox[{
       RowBox[{"-", "xx"}], "-", "yy", "+", "zz"}]}], "}"}], "/.", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "\[Rule]", 
       RowBox[{"newXYZRoot2", "[", 
        RowBox[{"\"\<x\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"yy", "->", 
       RowBox[{"newXYZRoot2", "[", 
        RowBox[{"\"\<y\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}], ",", 
      
      RowBox[{"zz", "->", 
       RowBox[{"newXYZRoot2", "[", 
        RowBox[{"\"\<z\>\"", ",", "p2", ",", "p3", ",", "p4"}], "]"}]}]}], 
     "}"}]}], "/.", "testPnRule"}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.7261675438930798`*^9, 3.7261675485879297`*^9}, 
   3.726167696747787*^9, {3.7261677282925863`*^9, 3.726167777453833*^9}, 
   3.726167888215232*^9},ExpressionUUID->"bca6b66a-7764-46be-bf8c-\
f187236a6770"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.556055332248352`", ",", 
   RowBox[{"-", "0.2388594899594243`"}], ",", 
   RowBox[{"-", "1.245587630060808`"}], ",", 
   RowBox[{"-", "4.071608212228119`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.726167889429644*^9},ExpressionUUID->"cebe77b4-bd0d-4127-9d34-\
140427853b01"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Add treatment of the  Bar-Itzhack method for converting the\nHorn matrix to \
the  RotToQuat problem, ",
 StyleBox["nonsingular by construction.",
  FontSlant->"Italic"]
}], "Subchapter",
 CellChangeTimes->{{3.73004158158711*^9, 
  3.730041627397938*^9}},ExpressionUUID->"dea249ad-3d82-4765-9e5a-\
66f2374b0cba"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["One more thing to add!   The  4D Horn matrix to\n  \
have a special form that corresponds to the  Bar-Itzhack\n  \
\[OpenCurlyDoubleQuote]Davenport q method\[CloseCurlyDoubleQuote] for finding \
the quaternion  for any\n  SO3 rotation matrix, without singularities?\n  ",
 FontWeight->"Bold"]], "Section",
 CellChangeTimes->{{3.729823408031938*^9, 3.7298234843118963`*^9}, {
   3.7298235201077137`*^9, 3.729823550158936*^9}, 3.7300419082827806`*^9, 
   3.730042001419681*^9},ExpressionUUID->"e07e3747-2f1f-4287-a3c6-\
ad415c41ddcb"],

Cell[TextData[StyleBox["MUST account for ArcTan[0,0] = 0, and then you get \
the  ortho-matrix limit ->\nxx,yy,zz all = 1/9,  eigenvalues = {1, -1/3, \
-1/3, -1/3}",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.729966186711382*^9, 
  3.729966244647458*^9}},ExpressionUUID->"98318130-04e5-46e6-a155-\
55cb2461ecb4"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["But so far, there is some glitch in getting from the \
data to the pk rules that go\ninto the eigenvalue and eigenvector...",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.7298235585502653`*^9, 
  3.729823596414145*^9}},ExpressionUUID->"7e5514b3-76e3-4306-a3ee-\
3dcfd87bde94"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"UNIVERSAL", " ", "for", " ", "all", " ", "SO3", " ", "matrices"}],
    " ", "*)"}], "  ", "pnSO3Rule"}]], "Input",
 CellChangeTimes->{{3.729966319320846*^9, 
  3.729966329294676*^9}},ExpressionUUID->"4b2fe16e-110f-4303-973b-\
80338c3d8f69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", "27"]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["8", "27"]}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["2", "3"]}]}], ",", 
   RowBox[{"p1", "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729966311869237*^9},ExpressionUUID->"31856571-753e-43a9-ac0b-\
b2d3bdb13409"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"checkXX3D", "[", 
     RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], ",", 
    RowBox[{"checkYY3D", "[", 
     RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], ",", 
    RowBox[{"checkZZ3D", "[", 
     RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], ",", 
    RowBox[{"check4Eigenvals3D", "[", 
     RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}]}], "}"}], "/.", 
  "pnSO3Rule"}]], "Input",
 CellChangeTimes->{{3.7299662936635113`*^9, 
  3.729966304132506*^9}},ExpressionUUID->"f10e9980-b48c-4580-a998-\
8c8507c9ed49"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "9"], ",", 
   FractionBox["1", "9"], ",", 
   FractionBox["1", "9"], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729966305119424*^9},ExpressionUUID->"4a356485-5dfc-40e2-b9a7-\
db87a993b234"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set up the environment:", "Subsubsection",
 CellChangeTimes->{{3.729959901996961*^9, 
  3.729959906444807*^9}},ExpressionUUID->"f8d413d3-b8bb-48e8-a322-\
7f4f4682db6d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sxxMat4", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"sym", "[", 
     RowBox[{"\"\<s\>\"", ",", "i", ",", "j"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.730056240631371*^9, 
  3.730056257135562*^9}},ExpressionUUID->"bb562291-7ee4-41ce-a32f-\
2dee7e77bbe6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s11", ",", "s12", ",", "s13", ",", "s14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s21", ",", "s22", ",", "s23", ",", "s24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s31", ",", "s32", ",", "s33", ",", "s34"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s41", ",", "s42", ",", "s43", ",", "s44"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.730056259286734*^9},ExpressionUUID->"8bed5c1a-952f-453e-8279-\
6bc885f90918"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sxxMat3", " ", "=", "  ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sxx", ",", "sxy", ",", "sxz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"syx", ",", "syy", ",", "syz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"szx", ",", "szy", ",", "szz"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729960053703747*^9, 
  3.729960061427822*^9}},ExpressionUUID->"39988314-0d0e-4fdc-9fd5-\
3e3ecad71ca0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qqMat3", " ", "=", " ", 
  RowBox[{"QuatToRot", "[", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}]}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.7299601001984053`*^9, 
  3.729960123715465*^9}},ExpressionUUID->"cf02d56d-4ae3-4d77-a8d5-\
55611461a906"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729960124667677*^9},ExpressionUUID->"74dea895-ecb9-4851-9a15-\
9af54e23795a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sxxToMat3Rule", " ", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sxxMat3", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Rule]", " ", 
      RowBox[{"qqMat3", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7299599608582363`*^9, 3.729959983156365*^9}, {
  3.729960068051464*^9, 3.729960079180163*^9}, {3.729960131485861*^9, 
  3.729960149484846*^9}},ExpressionUUID->"db7c990d-c841-4eb6-89b5-\
8fbd371bce04"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"sxx", "\[Rule]", 
    RowBox[{
     SuperscriptBox["q0", "2"], "+", 
     SuperscriptBox["q1", "2"], "-", 
     SuperscriptBox["q2", "2"], "-", 
     SuperscriptBox["q3", "2"]}]}], ",", 
   RowBox[{"sxy", "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
     RowBox[{"2", " ", "q0", " ", "q3"}]}]}], ",", 
   RowBox[{"sxz", "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
     RowBox[{"2", " ", "q1", " ", "q3"}]}]}], ",", 
   RowBox[{"syx", "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
     RowBox[{"2", " ", "q0", " ", "q3"}]}]}], ",", 
   RowBox[{"syy", "\[Rule]", 
    RowBox[{
     SuperscriptBox["q0", "2"], "-", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "-", 
     SuperscriptBox["q3", "2"]}]}], ",", 
   RowBox[{"syz", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
     RowBox[{"2", " ", "q2", " ", "q3"}]}]}], ",", 
   RowBox[{"szx", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
     RowBox[{"2", " ", "q1", " ", "q3"}]}]}], ",", 
   RowBox[{"szy", "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
     RowBox[{"2", " ", "q2", " ", "q3"}]}]}], ",", 
   RowBox[{"szz", "\[Rule]", 
    RowBox[{
     SuperscriptBox["q0", "2"], "-", 
     SuperscriptBox["q1", "2"], "-", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729960150154215*^9},ExpressionUUID->"7968bf23-821a-4d8e-9b61-\
0e615169b0a2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornSmat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sxx", "+", "syy", "+", "szz"}], ",", 
       RowBox[{"syz", "-", "szy"}], ",", 
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
       RowBox[{"sxy", "-", "syx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"syz", "-", "szy"}], ",", 
       RowBox[{"sxx", "-", "syy", "-", "szz"}], ",", 
       RowBox[{"sxy", "+", "syx"}], ",", 
       RowBox[{"sxz", "+", "szx"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
       RowBox[{"sxy", "+", "syx"}], ",", 
       RowBox[{
        RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ",", 
       RowBox[{"syz", "+", "szy"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sxy", "-", "syx"}], ",", 
       RowBox[{"sxz", "+", "szx"}], ",", 
       RowBox[{"syz", "+", "szy"}], ",", 
       RowBox[{
        RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.729960648814858*^9, 
  3.729960658366823*^9}},ExpressionUUID->"a21478ea-5ff8-4ec2-8e21-\
daf4b23040f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hornSmatInv", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sxx", "+", "syy", "+", "szz"}], ",", 
       RowBox[{
        RowBox[{"-", "syz"}], "+", "szy"}], ",", 
       RowBox[{"sxz", "-", "szx"}], ",", 
       RowBox[{
        RowBox[{"-", "sxy"}], "+", "syx"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "syz"}], "+", "szy"}], ",", 
       RowBox[{"sxx", "-", "syy", "-", "szz"}], ",", 
       RowBox[{"sxy", "+", "syx"}], ",", 
       RowBox[{"sxz", "+", "szx"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sxz", "-", "szx"}], ",", 
       RowBox[{"sxy", "+", "syx"}], ",", 
       RowBox[{
        RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ",", 
       RowBox[{"syz", "+", "szy"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "sxy"}], "+", "syx"}], ",", 
       RowBox[{"sxz", "+", "szx"}], ",", 
       RowBox[{"syz", "+", "szy"}], ",", 
       RowBox[{
        RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7299606117259407`*^9, 3.729960642976762*^9}, {
  3.729961237520905*^9, 
  3.729961249600115*^9}},ExpressionUUID->"75d6debf-5e50-4459-a87d-\
0282bc3bff80"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornSmat", "-", "hornSmatInv"}]], "Input",
 CellChangeTimes->{{3.7299611362480087`*^9, 
  3.7299611387597733`*^9}},ExpressionUUID->"a907d08a-cf7b-4d9f-8b28-\
2a919c91701d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"2", " ", "syz"}], "-", 
      RowBox[{"2", " ", "szy"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "sxz"}], "+", 
      RowBox[{"2", " ", "szx"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "sxy"}], "-", 
      RowBox[{"2", " ", "syx"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "szy"}], ",", "0", ",", "0", ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "sxz"}], "+", 
      RowBox[{"2", " ", "szx"}]}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "sxy"}], "-", 
      RowBox[{"2", " ", "syx"}]}], ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7299611392519817`*^9},ExpressionUUID->"25f218b1-0c8e-4edb-97c1-\
1f07b27ccf33"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "matrixFromCoeff"}]], "Input",
 CellChangeTimes->{{3.7299602364008503`*^9, 
  3.729960256593295*^9}},ExpressionUUID->"6133bf13-7d18-41f3-b26f-\
ee61b2e4178e"],

Cell[CellGroupData[{

Cell["Global`matrixFromCoeff", "Print", "PrintUsage",
 CellChangeTimes->{3.729960257634159*^9},
 CellTags->
  "Info5613729942257-2554935",ExpressionUUID->"06c2aa12-8347-4274-beb6-\
764b90cbd11d"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"matrixFromCoeff", "[", 
          RowBox[{"matrix_", ",", "coeffvars_"}], "]"}], ":=", 
         RowBox[{"Module", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"i", "\[Equal]", "j"}], ",", 
               RowBox[{"Coefficient", "[", 
                RowBox[{"matrix", ",", 
                 RowBox[{
                  RowBox[{
                  "coeffvars", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], " ", 
                  RowBox[{
                  "coeffvars", "\[LeftDoubleBracket]", "j", 
                   "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Coefficient", "[", 
                 RowBox[{"matrix", ",", 
                  RowBox[{
                   RowBox[{
                   "coeffvars", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], " ", 
                   RowBox[{
                   "coeffvars", "\[LeftDoubleBracket]", "j", 
                    "\[RightDoubleBracket]"}]}]}], "]"}]}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "coeffvars", "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "coeffvars", "]"}]}], "}"}]}], "]"}]}], 
          "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`matrixFromCoeff],
  Editable->False]], "Print",
 CellChangeTimes->{3.729960257656559*^9},
 CellTags->
  "Info5613729942257-2554935",ExpressionUUID->"ade43138-ac0c-433e-88da-\
ca368dfb8ad1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testBarStd", " ", "=", " ", 
  RowBox[{
   RowBox[{"matrixFromCoeff", "[", 
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{"qqMat3", ".", "sxxMat3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.729960264884926*^9, 3.7299603041531973`*^9}, {
  3.72996033580224*^9, 3.729960374811863*^9}, {3.729960431643796*^9, 
  3.729960482065446*^9}},ExpressionUUID->"15ced56d-9e55-4505-87e1-\
740ee0d8b71e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxx", "+", "syy", "+", "szz"}], ",", 
     RowBox[{"syz", "-", "szy"}], ",", 
     RowBox[{
      RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
     RowBox[{"sxy", "-", "syx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"syz", "-", "szy"}], ",", 
     RowBox[{"sxx", "-", "syy", "-", "szz"}], ",", 
     RowBox[{"sxy", "+", "syx"}], ",", 
     RowBox[{"sxz", "+", "szx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
     RowBox[{"sxy", "+", "syx"}], ",", 
     RowBox[{
      RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ",", 
     RowBox[{"syz", "+", "szy"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxy", "-", "syx"}], ",", 
     RowBox[{"sxz", "+", "szx"}], ",", 
     RowBox[{"syz", "+", "szy"}], ",", 
     RowBox[{
      RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.72996037655398*^9, {3.729960457292799*^9, 
   3.729960484032075*^9}},ExpressionUUID->"2983a6a5-2aa5-4db6-b114-\
a9059df716bd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"testBarStd", "-", "hornSmat"}], ",", " ", 
   RowBox[{"testBarStd", "-", "hornSmatInv"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.729960534967134*^9, 3.729960559102973*^9}, {
  3.729960678632642*^9, 3.729960679045081*^9}, {3.7299610029493723`*^9, 
  3.729961016076989*^9}},ExpressionUUID->"4dd08596-be9d-46af-a9ea-\
7f9ce8c3f7d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"2", " ", "syz"}], "-", 
        RowBox[{"2", " ", "szy"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "sxz"}], "+", 
        RowBox[{"2", " ", "szx"}]}], ",", 
       RowBox[{
        RowBox[{"2", " ", "sxy"}], "-", 
        RowBox[{"2", " ", "syx"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "szy"}], ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "sxz"}], "+", 
        RowBox[{"2", " ", "szx"}]}], ",", "0", ",", "0", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "sxy"}], "-", 
        RowBox[{"2", " ", "syx"}]}], ",", "0", ",", "0", ",", "0"}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729960559474708*^9, 3.7299606794131727`*^9, {3.729961003707494*^9, 
   3.729961016980618*^9}},ExpressionUUID->"6da58bf1-32cd-4eea-ae24-\
69a590180ecd"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The difference between these two is that the sign of all qvec -> -qvec \
(conjugate = inverse):\
\>", "Subsubsection",
 CellChangeTimes->{{3.729960850539119*^9, 
  3.729960882602786*^9}},ExpressionUUID->"e9f5784b-5967-4021-b910-\
8fd9ec0484cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theQQBar4x4Std", "=", 
  RowBox[{
   RowBox[{"testBarStd", "/.", "sxxToMat3Rule"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.729960755652746*^9, 
  3.729960798195712*^9}},ExpressionUUID->"71802f1e-a2a4-4c1b-a855-\
ef9b43ab2ace"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q1"}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q2"}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q1"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q1", "2"]}], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{"4", " ", "q1", " ", "q2"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q2"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q2"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q2", "2"]}], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{"4", " ", "q2", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q3"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q3"}], ",", 
     RowBox[{"4", " ", "q2", " ", "q3"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q3", "2"]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7299607994459257`*^9},ExpressionUUID->"ac73fe84-803c-4a51-9640-\
980bea751de4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hornSmat", "/.", "sxxToMat3Rule"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.729961055093589*^9, 
  3.7299610566894693`*^9}},ExpressionUUID->"650b8e5a-ff61-46e3-9397-\
9863a94a4ec9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q1"}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q2"}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q1"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q1", "2"]}], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{"4", " ", "q1", " ", "q2"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q2"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q2"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q2", "2"]}], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{"4", " ", "q2", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "q0", " ", "q3"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q3"}], ",", 
     RowBox[{"4", " ", "q2", " ", "q3"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q3", "2"]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7299610571529922`*^9},ExpressionUUID->"dc0a0e99-e18e-4a22-8024-\
608c9139b06c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theQQBar4x4Inv", "=", 
  RowBox[{
   RowBox[{"hornSmatInv", "/.", "sxxToMat3Rule"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.729960828315775*^9, 
  3.729960841143515*^9}},ExpressionUUID->"a04c6470-d847-40f0-b064-\
3c73c190444e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{"4", " ", "q0", " ", "q1"}], ",", 
     RowBox[{"4", " ", "q0", " ", "q2"}], ",", 
     RowBox[{"4", " ", "q0", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", "q0", " ", "q1"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q1", "2"]}], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{"4", " ", "q1", " ", "q2"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", "q0", " ", "q2"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q2"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q2", "2"]}], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{"4", " ", "q2", " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", "q0", " ", "q3"}], ",", 
     RowBox[{"4", " ", "q1", " ", "q3"}], ",", 
     RowBox[{"4", " ", "q2", " ", "q3"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["q3", "2"]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729960841811564*^9, 
  3.7299612986735477`*^9},ExpressionUUID->"0d94d3fe-fe3e-4618-9fb0-\
d2f0610838cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"theQQBar4x4Std", ".", " ", 
      RowBox[{"{", 
       RowBox[{"q0", ",", 
        RowBox[{"-", "q1"}], ",", 
        RowBox[{"-", "q2"}], ",", 
        RowBox[{"-", "q3"}]}], "}"}]}], "//", "Simplify"}], ",", 
    RowBox[{
     RowBox[{"theQQBar4x4Inv", " ", ".", " ", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], " ", "//", 
     " ", "Simplify"}]}], "}"}], "/.", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["q0", "2"], "+", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.729960900487495*^9, 3.729960942299288*^9}, {
  3.729961105626726*^9, 3.729961106328861*^9}, {3.729961321288982*^9, 
  3.729961347454836*^9}},ExpressionUUID->"cf4cbdaf-5259-4a18-a280-\
05f80c764b6c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", " ", "q0"}], ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", "q1"}], ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", "q2"}], ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", "q3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", " ", "q0"}], ",", 
     RowBox[{"3", " ", "q1"}], ",", 
     RowBox[{"3", " ", "q2"}], ",", 
     RowBox[{"3", " ", "q3"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7299609427019663`*^9, 3.729961106757822*^9, 
  3.729961311080543*^9, 
  3.729961348354192*^9},ExpressionUUID->"9b9d8413-5b5d-4c4e-9cf0-\
2c87b9735da6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeHornMat", "[", "rot3D_", "]"}], " ", ":=", "  ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", "=", "rot3D"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "-", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
          RowBox[{"m", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}]}], "}"}]}], 
      "}"}]}], "]"}]}], "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729739665530719*^9, 3.7297399624809933`*^9}, {
   3.729739997617916*^9, 3.7297400089283524`*^9}, 3.729782321373281*^9, 
   3.729784236334249*^9, 3.729785042554781*^9, {3.729785126543738*^9, 
   3.729785128982798*^9}, {3.729797177668494*^9, 3.729797178043521*^9}, 
   3.7297972522047358`*^9, 3.7297974720780067`*^9, {3.7298196857936172`*^9, 
   3.7298197128205757`*^9}, {3.729820138388483*^9, 
   3.7298201587647142`*^9}},ExpressionUUID->"00875229-2a54-4048-a638-\
292b68f11e3c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
This is an exact match to Bar-Itzhack\[CloseCurlyQuote]s K3 matrix,  \
Eigenvector = conjugate of q.\
\>", "Subsubsection",
 CellChangeTimes->{{3.729961713010322*^9, 
  3.729961753490612*^9}},ExpressionUUID->"ebe00750-65c5-4487-bea6-\
37e320157ab8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeBarIzMat", "[", "rot3D_", "]"}], " ", ":=", "  ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", "=", "rot3D"}], "}"}], ",", 
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}]}], "}"}]}], 
       "}"}]}]}], "]"}]}], "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729739665530719*^9, 3.7297399624809933`*^9}, {
   3.729739997617916*^9, 3.7297400089283524`*^9}, 3.729782321373281*^9, 
   3.729784236334249*^9, 3.729785042554781*^9, {3.729785126543738*^9, 
   3.729785128982798*^9}, {3.729797177668494*^9, 3.729797178043521*^9}, 
   3.7297972522047358`*^9, 3.7297974720780067`*^9, {3.7298196857936172`*^9, 
   3.7298197128205757`*^9}, {3.729857816884253*^9, 3.729857875293354*^9}, {
   3.72996138541803*^9, 
   3.729961387928483*^9}},ExpressionUUID->"6c6f8167-316c-4cf6-aaae-\
a5f812ba88e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"q0", ",", 
       RowBox[{"-", "q1"}], ",", 
       RowBox[{"-", "q2"}], ",", 
       RowBox[{"-", "q3"}]}], "}"}]}], " ", "//", " ", "Simplify"}], ")"}], "/.", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["q0", "2"], "+", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.729961417317816*^9, 
  3.729961467197003*^9}},ExpressionUUID->"04793b22-7eda-4989-b476-\
467c11ac011e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"q0", ",", 
   RowBox[{"-", "q1"}], ",", 
   RowBox[{"-", "q2"}], ",", 
   RowBox[{"-", "q3"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729961435999708*^9, 
  3.729961468795282*^9},ExpressionUUID->"44b8c98d-5f8e-4b3e-9c23-\
aaa751c90e52"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Eigensystem", "[", 
     RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}], "]"}], "//", " ", 
    "Simplify"}], ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7300522726753273`*^9, 
  3.730052337860189*^9}},ExpressionUUID->"86a67f13-1ce5-4e36-83aa-\
a73dc2a50bae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["q3", "q0"], ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["q2", "q0"], ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["q1", "q0"], ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["q0", "q3"]}], ",", 
       FractionBox["q1", "q3"], ",", 
       FractionBox["q2", "q3"], ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.730052332932715*^9, 
  3.7300523383048153`*^9}},ExpressionUUID->"82b33f14-5cb7-4f30-adb8-\
801210488c2b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}], "]"}], "//", "Simplify"}], 
   ",", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"makeHornMat", "[", "qqMat3", "]"}], "]"}], "//", "Simplify"}]}],
   "}"}]], "Input",
 CellChangeTimes->{{3.729962132582296*^9, 3.729962142374604*^9}, {
  3.730052433130431*^9, 
  3.730052450666258*^9}},ExpressionUUID->"2ba249c6-2979-4b5c-a963-\
cd2532c4e9f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "27"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "4"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.72996214286968*^9, 
  3.73005245175316*^9},ExpressionUUID->"cfe189ec-c83b-4af4-b924-bf261060b2e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testBarMat", "=", " ", 
  RowBox[{
   RowBox[{"matrixFromCoeff", "[", 
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{"qqMat3", ".", "sxxMat3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.729960264884926*^9, 3.7299603041531973`*^9}, {
  3.72996033580224*^9, 3.729960374811863*^9}, {3.729960431643796*^9, 
  3.729960482065446*^9}, {3.729961996329253*^9, 
  3.7299619972644157`*^9}},ExpressionUUID->"f8252dbb-5584-4b2d-b568-\
878d968cb70a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxx", "+", "syy", "+", "szz"}], ",", 
     RowBox[{"syz", "-", "szy"}], ",", 
     RowBox[{
      RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
     RowBox[{"sxy", "-", "syx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"syz", "-", "szy"}], ",", 
     RowBox[{"sxx", "-", "syy", "-", "szz"}], ",", 
     RowBox[{"sxy", "+", "syx"}], ",", 
     RowBox[{"sxz", "+", "szx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
     RowBox[{"sxy", "+", "syx"}], ",", 
     RowBox[{
      RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ",", 
     RowBox[{"syz", "+", "szy"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxy", "-", "syx"}], ",", 
     RowBox[{"sxz", "+", "szx"}], ",", 
     RowBox[{"syz", "+", "szy"}], ",", 
     RowBox[{
      RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.72996037655398*^9, {3.729960457292799*^9, 3.729960484032075*^9}, 
   3.72996206172675*^9},ExpressionUUID->"8f95f0db-f29c-4b9c-9a68-\
7b78764e1885"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornSmat", "-", "testBarMat"}]], "Input",
 CellChangeTimes->{{3.7299620201799927`*^9, 3.729962023750956*^9}, {
  3.729962083192666*^9, 
  3.729962083473146*^9}},ExpressionUUID->"24b75deb-d704-4774-b08a-\
b55ec6c3d3a3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.72996202464575*^9, 
  3.7299620855499163`*^9},ExpressionUUID->"165414b5-e42a-4c23-87f4-\
a96f23a236ee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makeBarIzMat", "[", "sxxMat3", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.7299614912049637`*^9, 
  3.7299615193802757`*^9}},ExpressionUUID->"f8fd27c7-db62-420e-ad92-\
59aec13e772f"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"sxx", "+", "syy", "+", "szz"}], ")"}]}], 
      FractionBox[
       RowBox[{"syz", "-", "szy"}], "3"], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "sxz"}], "+", "szx"}], ")"}]}], 
      FractionBox[
       RowBox[{"sxy", "-", "syx"}], "3"]},
     {
      FractionBox[
       RowBox[{"syz", "-", "szy"}], "3"], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}], 
      FractionBox[
       RowBox[{"sxy", "+", "syx"}], "3"], 
      FractionBox[
       RowBox[{"sxz", "+", "szx"}], "3"]},
     {
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "sxz"}], "+", "szx"}], ")"}]}], 
      FractionBox[
       RowBox[{"sxy", "+", "syx"}], "3"], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}], 
      FractionBox[
       RowBox[{"syz", "+", "szy"}], "3"]},
     {
      FractionBox[
       RowBox[{"sxy", "-", "syx"}], "3"], 
      FractionBox[
       RowBox[{"sxz", "+", "szx"}], "3"], 
      FractionBox[
       RowBox[{"syz", "+", "szy"}], "3"], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.729961519821802*^9},
 FontSize->14,ExpressionUUID->"4f9c971f-ee8d-4832-aac7-3dbce30fdd4e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
This is  the PLUS eigenvalue version of Bar-Itzhack\[CloseCurlyQuote]s K3 \
matrix,  Eigenvector =  q  itself...\
\>", "Subsubsection",
 CellChangeTimes->{{3.729961713010322*^9, 3.729961753490612*^9}, {
  3.729961811817243*^9, 
  3.729961843537141*^9}},ExpressionUUID->"38df78d5-7c3c-4413-9a5f-\
0d9b590dd2b9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"m", "=", "qqMat3"}], "}"}], ",", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sxx", " ", "=", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"sxy", "=", " ", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"sxz", "=", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"syx", "=", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"syy", " ", "=", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"syz", "=", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"szx", "=", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"szy", "=", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"szz", "=", 
        RowBox[{"m", "\[LeftDoubleBracket]", 
         RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"sxx", ",", "sxy", ",", "sxz"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"syx", ",", "syy", ",", "syz"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"szx", ",", "szy", ",", "szz"}], "}"}]}], "}"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.729990764711145*^9, 
  3.729991009435692*^9}},ExpressionUUID->"72627476-44a2-4521-a2a8-\
f6f9388c9931"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729991020881784*^9},ExpressionUUID->"4e5c8420-03a1-40e3-9993-\
b59602a4274b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeQBarIzMat", "[", "rot3D_", "]"}], " ", ":=", "  ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", "=", "rot3D"}], "}"}], ",", 
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", " ", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"+", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"+", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}]}], "}"}]}], 
       "}"}]}]}], "]"}]}], "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729739665530719*^9, 3.7297399624809933`*^9}, {
   3.729739997617916*^9, 3.7297400089283524`*^9}, 3.729782321373281*^9, 
   3.729784236334249*^9, 3.729785042554781*^9, {3.729785126543738*^9, 
   3.729785128982798*^9}, {3.729797177668494*^9, 3.729797178043521*^9}, 
   3.7297972522047358`*^9, 3.7297974720780067`*^9, {3.7298196857936172`*^9, 
   3.7298197128205757`*^9}, {3.729857816884253*^9, 3.729857875293354*^9}, {
   3.72996138541803*^9, 3.729961387928483*^9}, {3.729961848772686*^9, 
   3.72996190986786*^9}},ExpressionUUID->"766b49a5-8f6b-48a5-8b2d-\
e77722ab9ac2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Det", "[", 
   RowBox[{"makeQBarIzMat", "[", "qqMat3", "]"}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{
  3.7299621673826923`*^9},ExpressionUUID->"2e7c05b2-82c7-49ac-a67d-\
86300d685e17"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "27"]}], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["q0", "2"], "+", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}], "4"]}]], "Output",
 CellChangeTimes->{
  3.729962168305972*^9},ExpressionUUID->"364fbe2d-57ca-4153-b1fc-\
a55430693e10"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"makeQBarIzMat", "[", "qqMat3", "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"q0", ",", " ", "q1", ",", " ", "q2", ",", " ", "q3"}], "}"}]}],
     " ", "//", " ", "Simplify"}], ")"}], "/.", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["q0", "2"], "+", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.729961417317816*^9, 3.729961467197003*^9}, {
  3.729961920889305*^9, 
  3.729961932552519*^9}},ExpressionUUID->"fded999b-54bd-4a1a-b6ad-\
bdb1db1396a3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]], "Output",
 CellChangeTimes->{
  3.729961435999708*^9, 3.729961468795282*^9, {3.729961922234264*^9, 
   3.729961934837927*^9}},ExpressionUUID->"58d6f35a-d431-4aad-8799-\
eb7343c99400"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makeQBarIzMat", "[", "sxxMat3", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.7299614912049637`*^9, 3.7299615193802757`*^9}, {
  3.729961940352953*^9, 
  3.72996194248501*^9}},ExpressionUUID->"7f0b8b7e-d53a-4ecd-8d51-\
38524f413bc7"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"sxx", "+", "syy", "+", "szz"}], ")"}]}], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "syz"}], "+", "szy"}], ")"}]}], 
      FractionBox[
       RowBox[{"sxz", "-", "szx"}], "3"], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "sxy"}], "+", "syx"}], ")"}]}]},
     {
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "syz"}], "+", "szy"}], ")"}]}], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}], 
      FractionBox[
       RowBox[{"sxy", "+", "syx"}], "3"], 
      FractionBox[
       RowBox[{"sxz", "+", "szx"}], "3"]},
     {
      FractionBox[
       RowBox[{"sxz", "-", "szx"}], "3"], 
      FractionBox[
       RowBox[{"sxy", "+", "syx"}], "3"], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}], 
      FractionBox[
       RowBox[{"syz", "+", "szy"}], "3"]},
     {
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "sxy"}], "+", "syx"}], ")"}]}], 
      FractionBox[
       RowBox[{"sxz", "+", "szx"}], "3"], 
      FractionBox[
       RowBox[{"syz", "+", "szy"}], "3"], 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.729961519821802*^9, 3.729961942820981*^9},
 FontSize->14,ExpressionUUID->"2f88b1da-8420-4a96-8b75-3bb6a53696ee"]
}, Open  ]],

Cell[TextData[StyleBox[" Look at the pk coefficients:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.729962217621118*^9, 
  3.729962228661303*^9}},ExpressionUUID->"7170e754-7a1b-4bec-bcc3-\
2d15bc3371c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CoefficientList", "[", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{
      RowBox[{"makeQBarIzMat", "[", "qqMat3", "]"}], " ", "-", " ", 
      RowBox[{"e", " ", 
       RowBox[{"IdentityMatrix", "[", "4", "]"}]}]}], "]"}], ",", "e"}], 
   "]"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.729962232145082*^9, 
  3.7299623408088512`*^9}},ExpressionUUID->"939e954c-f0ca-4dfa-93e9-\
f64c814861a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "27"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["8", "27"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "3"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["2", "3"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "2"]}], ",", "0", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7299623325608377`*^9, 
  3.729962341410777*^9}},ExpressionUUID->"e590bceb-ceff-47b2-b9b9-\
76b051740de2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["q0", "2"], "+", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.729962391483083*^9, 
  3.729962398525909*^9}},ExpressionUUID->"52f441fd-3f1b-46b7-824b-\
19bb6d19b4b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pnSO3Rule", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p4", "\[Rule]", " ", 
     RowBox[{"-", 
      FractionBox["1", "27"]}]}], ",", 
    RowBox[{"p3", "\[Rule]", " ", 
     RowBox[{"-", 
      FractionBox["8", "27"]}]}], ",", 
    RowBox[{"p2", "->", 
     RowBox[{"-", 
      FractionBox["2", "3"]}]}], ",", 
    RowBox[{"p1", "->", "0"}]}], " ", "}"}]}]], "Input",
 CellChangeTimes->{{3.729962411906995*^9, 
  3.729962470107255*^9}},ExpressionUUID->"4a53c152-0e49-482d-9954-\
52f3abd9ecaa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p4", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", "27"]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["8", "27"]}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["2", "3"]}]}], ",", 
   RowBox[{"p1", "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729962473420093*^9},ExpressionUUID->"22a41f87-de3f-48b5-98e5-\
6b6981c1625c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"check4Eigenvals3D", "[", 
   RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], "/.", "pnSO3Rule"}]], "Input",\

 CellChangeTimes->{{3.729962577754425*^9, 
  3.729962579388172*^9}},ExpressionUUID->"dfe8af71-82a7-4182-8943-\
771d50725e67"],

Cell[BoxData[
 TemplateBox[{
  "ArcTan","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"ArcTan\\\", \\\"[\\\", \
RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"]\\\"}]\\) encountered.\"",2,
   601,123,27249899353035857831,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.729962581066051*^9},ExpressionUUID->"c31fc08b-72dc-441d-97e9-\
901613535c7f"],

Cell[BoxData[
 TemplateBox[{
  "ArcTan","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"ArcTan\\\", \\\"[\\\", \
RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"]\\\"}]\\) encountered.\"",2,
   601,124,27249899353035857831,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.729962581067636*^9},ExpressionUUID->"8cb890ea-339c-4239-8002-\
509390486014"],

Cell[BoxData[
 TemplateBox[{
  "ArcTan","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"ArcTan\\\", \\\"[\\\", \
RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"]\\\"}]\\) encountered.\"",2,
   601,125,27249899353035857831,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7299625810796022`*^9},ExpressionUUID->"bbf7db40-4e50-475e-adf0-\
3f1ac980379e"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"ArcTan\\\", \\\"::\\\", \
\\\"indet\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,601,126,27249899353035857831,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.729962581091395*^9},ExpressionUUID->"7cf9a150-21d5-405b-a780-\
6b1fe16b7cab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "Indeterminate", ",", "Indeterminate", ",", "Indeterminate", ",", 
   "Indeterminate"}], "}"}]], "Output",
 CellChangeTimes->{
  3.72996258110393*^9},ExpressionUUID->"5d979d2a-01c4-4c4b-b7d4-a091926042df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{"check4Eigenvals3D", "[", 
     RowBox[{"p2", ",", "p3", ",", "p4"}], "]"}], "]"}], "/.", "pnSO3Rule"}], 
  "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.729962630665268*^9, 
  3.729962644537125*^9}},ExpressionUUID->"3edae438-e9b5-43e9-9093-\
18ab267c78f7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.`", ",", 
   RowBox[{"-", "0.33333333333333337`"}], ",", 
   RowBox[{"-", "0.33333333333333337`"}], ",", 
   RowBox[{"-", "0.33333333333333337`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729962637599484*^9, 
  3.7299626449724197`*^9}},ExpressionUUID->"68eb6fca-5d39-4c87-b572-\
5cef3520420b"]
}, Open  ]],

Cell[TextData[StyleBox["Now check the symbolic eigenvalues?",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.729962688424418*^9, 
  3.729962703431859*^9}},ExpressionUUID->"6f51ee58-c55d-4ccf-bafe-\
c290ac33a121"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q0", ",", "q0", ",", "q0", ",", 
     RowBox[{"-", "q3"}]}], "}"}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Eigenvectors", "[", 
      RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}], "]"}], "//", "Simplify"}],
     ")"}]}], "/.", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["q0", "2"], "+", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.729962788983601*^9, 3.7299628009355164`*^9}, {
  3.729962940919963*^9, 
  3.7299629626069603`*^9}},ExpressionUUID->"8b40e888-5d7e-474f-ba8c-\
e6a53854a816"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q3", ",", "0", ",", "0", ",", "q0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q2", ",", "0", ",", "q0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q1", ",", "q0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", 
     RowBox[{"-", "q1"}], ",", 
     RowBox[{"-", "q2"}], ",", 
     RowBox[{"-", "q3"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729962870472645*^9, 
  3.729962963757592*^9},ExpressionUUID->"0fae188a-ce7c-4090-b1be-\
ba79cbe9c3c3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.729966369894508*^9, 
  3.729966370398219*^9}},ExpressionUUID->"b551254a-9a5a-4974-9dc0-\
22d98ce25eab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["q0", "2"], "+", 
    SuperscriptBox["q1", "2"], "+", 
    SuperscriptBox["q2", "2"], "+", 
    SuperscriptBox["q3", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.72996637154056*^9},ExpressionUUID->"3277be49-5349-4d34-a9d8-7f15e8b65e47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Eigenvalues", "[", 
     RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}], "]"}], "//", "Simplify"}], 
   ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.729962772920684*^9, 3.729962804119729*^9}, 
   3.729962886389442*^9},ExpressionUUID->"cffb80a7-da9d-4b13-9568-\
9f2c5ccc611d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "3"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "3"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "3"]}], ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{{3.729962877078945*^9, 
  3.7299628874152937`*^9}},ExpressionUUID->"354c99bd-9008-4154-a846-\
57d3aeb8c6f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q0", ",", "q0", ",", "q0", ",", " ", "q3"}], "}"}], "*", 
   RowBox[{"Eigenvectors", "[", 
    RowBox[{"makeQBarIzMat", "[", "qqMat3", "]"}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7299627423529778`*^9, 3.729962743496209*^9}, {
  3.729962973633606*^9, 
  3.7299629758078938`*^9}},ExpressionUUID->"7d53b038-e08c-4985-a023-\
157490dcb88a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "q3"}], ",", "0", ",", "0", ",", "q0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "q2"}], ",", "0", ",", "q0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "q1"}], ",", "q0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.729962744787977*^9, 
  3.729962976980953*^9},ExpressionUUID->"72e7244b-0456-4eca-b4f2-\
1d62000a0641"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"makeQBarIzMat", "[", "qqMat3", "]"}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.729962710400405*^9, 
  3.729962720536365*^9}},ExpressionUUID->"1e8c0f20-56da-4687-bc25-\
7486f4363858"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["q0", "2"], "+", 
    SuperscriptBox["q1", "2"], "+", 
    SuperscriptBox["q2", "2"], "+", 
    SuperscriptBox["q3", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.729962721219713*^9, 3.7299628107716007`*^9, 
  3.729962857479775*^9},ExpressionUUID->"3999f0c7-f639-4a0a-85d1-\
422dfaf36626"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", " ", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7299628145837097`*^9, 
  3.7299628621595488`*^9}},ExpressionUUID->"af1fed60-8e4c-43f1-b8d0-\
b50c29f0731b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "3"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "3"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "3"]}], ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.7299628278392563`*^9, 
  3.729962862886435*^9},ExpressionUUID->"8d86c7b4-a58c-4346-82d5-\
7541fd8c142e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Last check -need to get the eigenvectors:",
 FontSize->24,
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.729966389573989*^9, 
  3.729966400126059*^9}},ExpressionUUID->"0f773ee7-5633-4764-a0b4-\
45c531d7c038"],

Cell[CellGroupData[{

Cell[BoxData["hornSmat"], "Input",
 CellChangeTimes->{{3.7299665265045223`*^9, 
  3.72996653057286*^9}},ExpressionUUID->"f95994bb-ad27-488c-9229-\
b1b2e8cbc643"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxx", "+", "syy", "+", "szz"}], ",", 
     RowBox[{"syz", "-", "szy"}], ",", 
     RowBox[{
      RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
     RowBox[{"sxy", "-", "syx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"syz", "-", "szy"}], ",", 
     RowBox[{"sxx", "-", "syy", "-", "szz"}], ",", 
     RowBox[{"sxy", "+", "syx"}], ",", 
     RowBox[{"sxz", "+", "szx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "sxz"}], "+", "szx"}], ",", 
     RowBox[{"sxy", "+", "syx"}], ",", 
     RowBox[{
      RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ",", 
     RowBox[{"syz", "+", "szy"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxy", "-", "syx"}], ",", 
     RowBox[{"sxz", "+", "szx"}], ",", 
     RowBox[{"syz", "+", "szy"}], ",", 
     RowBox[{
      RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.72996653104497*^9},ExpressionUUID->"aad57d81-dc0d-4eac-82cf-0f24540baff1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["sxxMat3"], "Input",
 CellChangeTimes->{{3.729967214867063*^9, 
  3.72996721993157*^9}},ExpressionUUID->"3dc7634e-9de6-4946-8a86-\
4af2a017707f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sxx", ",", "sxy", ",", "sxz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"syx", ",", "syy", ",", "syz"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"szx", ",", "szy", ",", "szz"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729967220593334*^9},ExpressionUUID->"e2104a76-6a0a-46b4-9680-\
627151dfc1fe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["qqMat3"], "Input",ExpressionUUID->"5ccac34d-7d82-4aeb-aab7-c85166c1d91e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "-", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "q1", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q0", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "q0", " ", "q2"}], "+", 
      RowBox[{"2", " ", "q1", " ", "q3"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "q0", " ", "q1"}], "+", 
      RowBox[{"2", " ", "q2", " ", "q3"}]}], ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729966523804696*^9},ExpressionUUID->"b4105868-ac99-4340-bf02-\
1c2067bc42dd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}]], "Input",
 CellChangeTimes->{{3.7299665056849623`*^9, 3.7299665095652514`*^9}, 
   3.729967008692058*^9, 
   3.729967044639943*^9},ExpressionUUID->"84abafc8-2409-4211-a1bb-\
e6341fd1d097"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q1"}], "3"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q2"}], "3"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q3"}], "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q1"}], "3"]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q1", "2"]}], "-", 
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q2"}], "3"], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q3"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q2"}], "3"]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q2"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q2", "2"]}], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q2", " ", "q3"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q3"}], "3"]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q3"}], "3"], ",", 
     FractionBox[
      RowBox[{"4", " ", "q2", " ", "q3"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["q2", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q3", "2"]}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7299670453007717`*^9},ExpressionUUID->"8ee20102-ae18-4628-8e7a-\
702c52e2a137"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"q0", ",", 
      RowBox[{"-", "q1"}], ",", 
      RowBox[{"-", "q2"}], ",", 
      RowBox[{"-", "q3"}]}], "}"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.729967088336485*^9, 
  3.729967134903819*^9}},ExpressionUUID->"86f01d23-f816-4f3e-a030-\
43202b4a5904"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"q0", ",", 
   RowBox[{"-", "q1"}], ",", 
   RowBox[{"-", "q2"}], ",", 
   RowBox[{"-", "q3"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729967114059168*^9, 
  3.729967135571067*^9}},ExpressionUUID->"f38ca781-3198-4dcc-ab30-\
bddc95e5e27b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeBarIzMat", "[", "sxxMat3", "]"}]], "Input",
 CellChangeTimes->{{3.729966473085339*^9, 3.7299664853500347`*^9}, {
  3.729967025028458*^9, 
  3.729967049968959*^9}},ExpressionUUID->"ed8e9b54-8419-4a9e-b288-\
960b710f77aa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"sxx", "+", "syy", "+", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"syz", "-", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "-", "syx"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"syz", "-", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "+", "syx"}], "3"], ",", 
     FractionBox[
      RowBox[{"sxz", "+", "szx"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "+", "syx"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"syz", "+", "szy"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"sxy", "-", "syx"}], "3"], ",", 
     FractionBox[
      RowBox[{"sxz", "+", "szx"}], "3"], ",", 
     FractionBox[
      RowBox[{"syz", "+", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.729967051315297*^9},ExpressionUUID->"473af762-f3c6-4238-914d-\
5d75d9913b36"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Last Check step:  Data to test eigenvectors:",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.729967291269671*^9, 3.729967301694371*^9}, {
  3.729967363365601*^9, 
  3.729967368461277*^9}},ExpressionUUID->"6e8f8ba9-3f36-4b5a-a802-\
4364fb60946e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rot3DListX", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"makeRotation", "[", 
      RowBox[{
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", 
          RowBox[{"2", " ", "Pi"}]}], "}"}], "]"}], ",", " ", 
       RowBox[{"Normalize", "[", 
        RowBox[{"RandomReal", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], "]"}]}],
       "]"}], ",", 
     RowBox[{"{", "1000", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729818367839921*^9, 3.729818465337792*^9}, 
   3.72996731227141*^9},ExpressionUUID->"20dc2ef4-c83c-47ce-95e6-\
7fce8abf2874"],

Cell[TextData[StyleBox["Maybe better to do this with random Quat uniform \
distribution... ?",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.729821920294194*^9, 
  3.729821943238741*^9}},ExpressionUUID->"97135793-8073-4b2e-a596-\
391ac9774fbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genUniformQuatSample", "[", "n_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"0.2", "\[LessEqual]", " ", 
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "1.0"}], ",", 
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", 
             RowBox[{"Normalize", "[", "test", "]"}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", "out"}]}], "]"}]}]], "Input",ExpressionUUID->"ce3789f7-6e2c-\
4abd-882e-e0fb91af6236"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.729967401393663*^9, 
  3.729967428820677*^9}},ExpressionUUID->"588fdb5c-20a9-4b7a-a181-\
ed1742f0ff54"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatSampleList", " ", "=", " ", 
   RowBox[{"genUniformQuatSample", "[", "1000", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7299679654345703`*^9, 
  3.729967978072134*^9}},ExpressionUUID->"96dddb66-9342-4adc-a829-\
a08c08c59af8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"First", "/@", "quatSampleList"}], ",", "30"}], "]"}]], "Input",
 CellChangeTimes->{{3.729967987810698*^9, 
  3.729968020283763*^9}},ExpressionUUID->"16bbb3db-d923-4fff-88a4-\
1dda4445ee8c"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.40599999999999997`], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.40599999999999997`], Thickness[Small]}], 
     RectangleBox[{-1., 0}, {-0.95, 3.},
      RoundingRadius->0], RectangleBox[{-0.95, 0}, {-0.9, 10.},
      RoundingRadius->0], RectangleBox[{-0.9, 0}, {-0.85, 10.},
      RoundingRadius->0], RectangleBox[{-0.85, 0}, {-0.8, 17.},
      RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.75, 23.},
      RoundingRadius->0], RectangleBox[{-0.75, 0}, {-0.7, 21.},
      RoundingRadius->0], RectangleBox[{-0.7, 0}, {-0.65, 22.},
      RoundingRadius->0], RectangleBox[{-0.65, 0}, {-0.6, 23.},
      RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.55, 26.},
      RoundingRadius->0], RectangleBox[{-0.55, 0}, {-0.5, 16.},
      RoundingRadius->0], RectangleBox[{-0.5, 0}, {-0.45, 28.},
      RoundingRadius->0], RectangleBox[{-0.45, 0}, {-0.4, 24.},
      RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.35, 28.},
      RoundingRadius->0], RectangleBox[{-0.35, 0}, {-0.3, 37.},
      RoundingRadius->0], RectangleBox[{-0.3, 0}, {-0.25, 37.},
      RoundingRadius->0], RectangleBox[{-0.25, 0}, {-0.2, 35.},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {-0.15, 27.},
      RoundingRadius->0], RectangleBox[{-0.15, 0}, {-0.1, 29.},
      RoundingRadius->0], RectangleBox[{-0.1, 0}, {-0.05, 29.},
      RoundingRadius->0], RectangleBox[{-0.05, 0}, {0., 35.},
      RoundingRadius->0], RectangleBox[{0., 0}, {0.05, 30.},
      RoundingRadius->0], RectangleBox[{0.05, 0}, {0.1, 30.},
      RoundingRadius->0], RectangleBox[{0.1, 0}, {0.15, 35.},
      RoundingRadius->0], RectangleBox[{0.15, 0}, {0.2, 34.},
      RoundingRadius->0], RectangleBox[{0.2, 0}, {0.25, 37.},
      RoundingRadius->0], RectangleBox[{0.25, 0}, {0.3, 25.},
      RoundingRadius->0], RectangleBox[{0.3, 0}, {0.35, 41.},
      RoundingRadius->0], RectangleBox[{0.35, 0}, {0.4, 30.},
      RoundingRadius->0], RectangleBox[{0.4, 0}, {0.45, 34.},
      RoundingRadius->0], RectangleBox[{0.45, 0}, {0.5, 25.},
      RoundingRadius->0], RectangleBox[{0.5, 0}, {0.55, 37.},
      RoundingRadius->0], RectangleBox[{0.55, 0}, {0.6, 24.},
      RoundingRadius->0], RectangleBox[{0.6, 0}, {0.65, 23.},
      RoundingRadius->0], RectangleBox[{0.65, 0}, {0.7, 18.},
      RoundingRadius->0], RectangleBox[{0.7, 0}, {0.75, 28.},
      RoundingRadius->0], RectangleBox[{0.75, 0}, {0.8, 20.},
      RoundingRadius->0], RectangleBox[{0.8, 0}, {0.85, 17.},
      RoundingRadius->0], RectangleBox[{0.85, 0}, {0.9, 12.},
      RoundingRadius->0], RectangleBox[{0.9, 0}, {0.95, 10.},
      RoundingRadius->0], RectangleBox[{0.95, 0}, {1., 10.},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-1.04, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-1., 1.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.729968005834536*^9, 
  3.729968021006813*^9}},ExpressionUUID->"d78789c3-8028-446d-803e-\
4c210b99da0d"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rot3DList", " ", "=", "  ", 
   RowBox[{"QuatToRot", "/@", "quatSampleList"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729967349122163*^9, 3.729967387853169*^9}, {
  3.729968039447689*^9, 3.729968057375125*^9}, {3.729968727586028*^9, 
  3.7299687283771353`*^9}},ExpressionUUID->"c3d94627-7394-479e-a2c7-\
4da67e5823b6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Det", "/@", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "4"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729968065753916*^9, 
  3.729968079727211*^9}},ExpressionUUID->"e89362b7-0a4e-4fa5-b9dd-\
0aaa71b8638f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.0000000000000002`", ",", "1.`", ",", "1.`", ",", "1.0000000000000002`"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.7299680809312963`*^9},ExpressionUUID->"eb678012-3d78-4bcf-80be-\
d29d33f17151"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"barMat3DList", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"makeBarIzMat", ",", "rot3DList"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729966465885948*^9, 3.729966466341763*^9}, 
   3.7299681545188*^9},ExpressionUUID->"ec2d21fa-c08d-46de-b7b6-875724ed9dba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "/@", 
  RowBox[{"barMat3DList", "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "4"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729968165893302*^9, 
  3.7299681808867702`*^9}},ExpressionUUID->"262bdb2d-63ea-496c-bfb1-\
0267717bf7de"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.6199787304727086`", 
        RowBox[{"-", "0.39136063943839927`"}], 
        RowBox[{"-", "0.2596297649991026`"}], 
        RowBox[{"-", "0.37644135767491377`"}]},
       {
        RowBox[{"-", "0.39136063943839927`"}], 
        RowBox[{"-", "0.1726691018432398`"}], "0.10658510964565235`", 
        "0.15453945884470377`"},
       {
        RowBox[{"-", "0.2596297649991026`"}], "0.10658510964565235`", 
        RowBox[{"-", "0.2626244674407018`"}], "0.10252191799490956`"},
       {
        RowBox[{"-", "0.37644135767491377`"}], "0.15453945884470377`", 
        "0.10252191799490956`", 
        RowBox[{"-", "0.184685161188767`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.3115385435909947`"}], 
        RowBox[{"-", "0.09748877405654291`"}], "0.09522029698974954`", 
        "0.10006868026847804`"},
       {
        RowBox[{"-", "0.09748877405654291`"}], "0.10273699262099692`", 
        RowBox[{"-", "0.42592335730578884`"}], 
        RowBox[{"-", "0.4476103268791306`"}]},
       {"0.09522029698974954`", 
        RowBox[{"-", "0.42592335730578884`"}], "0.08267916625975713`", 
        "0.43719483267262593`"},
       {"0.10006868026847804`", 
        RowBox[{"-", "0.4476103268791306`"}], "0.43719483267262593`", 
        "0.12612238471024065`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.4811820410475801`", "0.3233761123099068`", 
        RowBox[{"-", "0.417830149392438`"}], "0.37872293344567215`"},
       {"0.3233761123099068`", 
        RowBox[{"-", "0.20494765357602818`"}], 
        RowBox[{"-", "0.1658854989926884`"}], "0.15035928567137297`"},
       {
        RowBox[{"-", "0.417830149392438`"}], 
        RowBox[{"-", "0.1658854989926884`"}], 
        RowBox[{"-", "0.11899479629343865`"}], 
        RowBox[{"-", "0.19427731487600475`"}]},
       {"0.37872293344567215`", "0.15035928567137297`", 
        RowBox[{"-", "0.19427731487600475`"}], 
        RowBox[{"-", "0.15723959117811337`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.07297299150762139`"}], "0.3506322576658164`", 
        RowBox[{"-", "0.23523774887424787`"}], "0.3179305525227638`"},
       {"0.3506322576658164`", "0.13886984190341928`", 
        RowBox[{"-", "0.31679918069556157`"}], "0.428163162754721`"},
       {
        RowBox[{"-", "0.23523774887424787`"}], 
        RowBox[{"-", "0.31679918069556157`"}], 
        RowBox[{"-", "0.12079405754582974`"}], 
        RowBox[{"-", "0.2872529162827169`"}]},
       {"0.3179305525227638`", "0.428163162754721`", 
        RowBox[{"-", "0.2872529162827169`"}], "0.05489720715003186`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.729968172629225*^9, 
  3.7299681815186*^9}},ExpressionUUID->"08ab67c5-2496-4957-9b3a-c70ec8c9e970"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatCheckList", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"uniformRotToQuat", ",", "rot3DList"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729968356204636*^9, 
  3.729968357124238*^9}},ExpressionUUID->"f4455f83-005d-4476-9f35-\
4d08658e573d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"quatSampleList", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ".", 
     RowBox[{"quatCheckList", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "quatSampleList", "]"}]}], "}"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.729968366612255*^9, 3.729968408651064*^9}, 
   3.7299688048672323`*^9},ExpressionUUID->"1e8a6f31-ffac-4230-8bf5-\
93fce4e6820d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9999999999999999`"}], ",", "337"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0000000000000002`"}], ",", "146"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "310"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0000000000000002`", ",", "176"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9999999999999998`", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9999999999999997`"}], ",", "19"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.729968752769642*^9, 
  3.7299688061619453`*^9},ExpressionUUID->"0e6e3203-c4ee-4d41-8370-\
c615b0980937"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Now get the eigenvectors - they seem to agree...",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.729968917822982*^9, 3.729968927591332*^9}, {
  3.729969835407157*^9, 
  3.7299698409030724`*^9}},ExpressionUUID->"bb2ee3ea-4385-4af4-969b-\
ea0935e794de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", " ", 
  RowBox[{
   RowBox[{"Eigenvalues", "[", 
    RowBox[{"barMat3DList", "[", 
     RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7299690763346453`*^9, 
  3.72996908801404*^9}},ExpressionUUID->"728f4214-f101-423a-adf3-\
70388deebe98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9999999999999994`", ",", 
     RowBox[{"-", "0.3333333333333334`"}], ",", 
     RowBox[{"-", "0.3333333333333332`"}], ",", 
     RowBox[{"-", "0.3333333333333331`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9999999999999999`", ",", 
     RowBox[{"-", "0.3333333333333333`"}], ",", 
     RowBox[{"-", "0.33333333333333326`"}], ",", 
     RowBox[{"-", "0.3333333333333331`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"-", "0.3333333333333335`"}], ",", 
     RowBox[{"-", "0.3333333333333333`"}], ",", 
     RowBox[{"-", "0.333333333333333`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9999999999999997`", ",", 
     RowBox[{"-", "0.33333333333333326`"}], ",", 
     RowBox[{"-", "0.33333333333333315`"}], ",", 
     RowBox[{"-", "0.3333333333333329`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729969089572536*^9},ExpressionUUID->"f36382ec-4ef1-40dd-9856-\
47036d5128f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"barmatEigVecs", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"First", "[", 
     RowBox[{"Eigenvectors", "[", 
      RowBox[{"barMat3DList", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729968946877645*^9, 3.7299689860228167`*^9}, {
  3.72996902316228*^9, 
  3.7299690239111757`*^9}},ExpressionUUID->"dfd6d525-f664-4df8-afb8-\
eb61bb50680f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.014710143161435313`"}], ",", "0.10929067025330165`", ",", 
     RowBox[{"-", "0.2457250082069869`"}], ",", "0.9630464066832036`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.47134947722162895`"}], ",", "0.5487219748645381`", ",", 
     RowBox[{"-", "0.4222275658403717`"}], ",", "0.5463128657355352`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4191788470857362`", ",", "0.38523404940672673`", ",", 
     RowBox[{"-", "0.29499570328768376`"}], ",", "0.7673730229656067`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9594519634220566`"}], ",", 
     RowBox[{"-", "0.23359201693879572`"}], ",", 
     RowBox[{"-", "0.1358619836853323`"}], ",", "0.08017618659622357`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729968987656966*^9, 
  3.729969024651688*^9},ExpressionUUID->"b9ed29e5-da8e-4d1e-aa1e-\
1cd152ba1959"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quatSampleList", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "4"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729969002360868*^9, 
  3.729969004182432*^9}},ExpressionUUID->"c70fd04e-08e5-4c76-9bdc-\
9c5befdd6378"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.014710143161435311`"}], ",", 
     RowBox[{"-", "0.10929067025330166`"}], ",", "0.24572500820698692`", ",", 
     
     RowBox[{"-", "0.9630464066832034`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.47134947722162895`"}], ",", 
     RowBox[{"-", "0.5487219748645381`"}], ",", "0.42222756584037163`", ",", 
     RowBox[{"-", "0.5463128657355352`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4191788470857364`", ",", 
     RowBox[{"-", "0.38523404940672673`"}], ",", "0.2949957032876839`", ",", 
     RowBox[{"-", "0.7673730229656065`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9594519634220564`"}], ",", "0.2335920169387957`", ",", 
     "0.13586198368533217`", ",", 
     RowBox[{"-", "0.08017618659622354`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7299690045224733`*^9},ExpressionUUID->"20fba401-2c8f-4df7-9a72-\
1e6ce22733b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rot3DList", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.72997009147691*^9, 
  3.7299700929256487`*^9}},ExpressionUUID->"8c8d40c1-1fb7-4236-bc89-\
40b7cf641893"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9756783221675079`"}], ",", 
     RowBox[{"-", "0.08204400271671086`"}], ",", "0.2032746744447428`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.025377800663047755`"}], ",", 
     RowBox[{"-", "0.8788056640596922`"}], ",", 
     RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21773327464102138`", ",", 
     RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729970093473913*^9},ExpressionUUID->"cbda5880-f6e7-4812-b320-\
9920df584b4a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"2", ";;", "3"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729970102005556*^9, 
  3.729970158052579*^9}},ExpressionUUID->"b874b9b3-4f88-4926-b287-\
9247266ff9e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.025377800663047755`"}], ",", 
     RowBox[{"-", "0.8788056640596922`"}], ",", 
     RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21773327464102138`", ",", 
     RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7299701050661983`*^9, 
  3.729970158816222*^9}},ExpressionUUID->"43095691-a7f9-4756-94a2-\
b665697dec01"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testSolve4vecs", " ", "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vv", ",", "soln"}], "}"}], ",", "\[IndentingNewLine]", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"soln", " ", "=", " ", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"barMat3DList", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"2", ";;", "4"}], "]"}], "]"}], ".", 
             RowBox[{"{", " ", 
              RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], 
            "\[Equal]", " ", 
            RowBox[{"{", 
             RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"vv", " ", "=", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}], "/.", 
         "soln"}]}], ";", 
       RowBox[{"vv", " ", "=", " ", 
        RowBox[{"normalize", "[", "vv", "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.729969879263579*^9, 3.7299699578713093`*^9}, {
  3.729970173517207*^9, 3.7299702422850933`*^9}, {3.729970272319311*^9, 
  3.729970335260517*^9}, {3.7299703671896677`*^9, 
  3.7299703674295073`*^9}},ExpressionUUID->"5879ab8b-ffd6-48b6-9576-\
053b50cb31c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.014710143161459365`", ",", 
     RowBox[{"-", "0.10929067025330165`"}], ",", "0.24572500820698692`", ",", 
     
     RowBox[{"-", "0.9630464066832032`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.47134947722162907`", ",", 
     RowBox[{"-", "0.5487219748645381`"}], ",", "0.4222275658403717`", ",", 
     RowBox[{"-", "0.5463128657355352`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.41917884708573644`", ",", "0.3852340494067267`", ",", 
     RowBox[{"-", "0.2949957032876838`"}], ",", "0.7673730229656066`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.9594519634220567`", ",", "0.23359201693879567`", ",", 
     "0.13586198368533217`", ",", 
     RowBox[{"-", "0.08017618659622353`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.27534927061432773`", ",", 
     RowBox[{"-", "0.7175946143360085`"}], ",", "0.18141710083750098`", ",", 
     "0.6134562610095597`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.011465035628222021`", ",", 
     RowBox[{"-", "0.5075922916482474`"}], ",", "0.5221963992905003`", ",", 
     RowBox[{"-", "0.6852222551737216`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.1923788006279672`", ",", "0.9408918805769005`", ",", 
     "0.2358926596355483`", ",", 
     RowBox[{"-", "0.1485514027650891`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.07752485158176754`", ",", "0.4575507613281687`", ",", 
     RowBox[{"-", "0.31356185759136723`"}], ",", "0.8284420074206095`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7210872855458389`", ",", "0.18600686275944547`", ",", 
     RowBox[{"-", "0.18334328893599683`"}], ",", 
     RowBox[{"-", "0.6417318848496265`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.7118654012165558`", ",", "0.5226133599346932`", ",", 
     "0.45695424967820764`", ",", "0.106375468363666`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.729970243662784*^9, {3.7299703126892557`*^9, 3.729970337047454*^9}, 
   3.7299703686450872`*^9},ExpressionUUID->"97646823-07f7-4fd0-b072-\
734335ac17ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quatSampleList", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "10"}], "]"}], "]"}]], "Input",ExpressionUUID->\
"8022f630-c9c9-424d-89c8-b0f16479deab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.014710143161435311`"}], ",", 
     RowBox[{"-", "0.10929067025330166`"}], ",", "0.24572500820698692`", ",", 
     
     RowBox[{"-", "0.9630464066832034`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.47134947722162895`"}], ",", 
     RowBox[{"-", "0.5487219748645381`"}], ",", "0.42222756584037163`", ",", 
     RowBox[{"-", "0.5463128657355352`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4191788470857364`", ",", 
     RowBox[{"-", "0.38523404940672673`"}], ",", "0.2949957032876839`", ",", 
     RowBox[{"-", "0.7673730229656065`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9594519634220564`"}], ",", "0.2335920169387957`", ",", 
     "0.13586198368533217`", ",", 
     RowBox[{"-", "0.08017618659622354`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.27534927061432724`", ",", "0.7175946143360085`", ",", 
     RowBox[{"-", "0.18141710083750093`"}], ",", 
     RowBox[{"-", "0.6134562610095597`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.011465035628225482`", ",", "0.5075922916482473`", ",", 
     RowBox[{"-", "0.5221963992905003`"}], ",", "0.6852222551737215`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.19237880062796722`", ",", 
     RowBox[{"-", "0.9408918805769005`"}], ",", 
     RowBox[{"-", "0.2358926596355483`"}], ",", "0.1485514027650891`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.07752485158177111`", ",", 
     RowBox[{"-", "0.45755076132816863`"}], ",", "0.3135618575913672`", ",", 
     RowBox[{"-", "0.8284420074206095`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7210872855458389`"}], ",", "0.1860068627594455`", ",", 
     RowBox[{"-", "0.18334328893599686`"}], ",", 
     RowBox[{"-", "0.6417318848496265`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7118654012165556`", ",", 
     RowBox[{"-", "0.5226133599346932`"}], ",", 
     RowBox[{"-", "0.4569542496782077`"}], ",", 
     RowBox[{"-", "0.10637546836366597`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7299704993249187`*^9},ExpressionUUID->"8eb0e034-0477-470a-b4f8-\
9bbf38ccc1d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#", ".", "#"}], " ", "&"}], ",", 
   RowBox[{"quatSampleList", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "10"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.729970462168994*^9, 
  3.729970488041482*^9}},ExpressionUUID->"aacbaa7d-23c3-4ccd-84fb-\
9d76469a265f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9999999999999997`", ",", "1.`", ",", "1.`", ",", "0.9999999999999996`", 
   ",", "0.9999999999999998`", ",", "1.0000000000000002`", ",", "1.`", ",", 
   "1.0000000000000004`", ",", "1.`", ",", "0.9999999999999999`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.729970468884021*^9, 
  3.729970488614601*^9}},ExpressionUUID->"cfd54a0a-9d34-452d-a249-\
9d2c7916e86c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Here we go: the important part is that the ",
 StyleBox["quatSampleList",
  FontSlant->"Italic"],
 "  produced the REFERENCE\nmatrix,  ",
 StyleBox["rot3DList",
  FontSlant->"Italic"],
 ".  But the EIGENVECTORS are for the INVERSE of that quaternion\n  that \
sends the    ",
 StyleBox["rot3Dlist ",
  FontSlant->"Italic"],
 " matrices back to the identity matrix, maximizing the \n   Horn measure."
}], "Subsubsection",
 CellChangeTimes->{{3.7299707835312853`*^9, 
  3.729970924140993*^9}},ExpressionUUID->"8b679976-3c63-43af-ad24-\
28426480b79d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"quatSampleList", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"qinverse", "[", 
    RowBox[{"testSolve4vecs", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"quatSampleList", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ".", 
    RowBox[{"qinverse", "[", 
     RowBox[{"testSolve4vecs", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.729970607749271*^9, 3.729970629736474*^9}, {
  3.729970663970706*^9, 
  3.7299706818237257`*^9}},ExpressionUUID->"aebb3569-e017-430a-9ad1-\
4b41e35c3872"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.014710143161435311`"}], ",", 
     RowBox[{"-", "0.10929067025330166`"}], ",", "0.24572500820698692`", ",", 
     
     RowBox[{"-", "0.9630464066832034`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.014710143161459365`", ",", "0.10929067025330165`", ",", 
     RowBox[{"-", "0.24572500820698692`"}], ",", "0.9630464066832032`"}], 
    "}"}], ",", 
   RowBox[{"-", "0.9999999999999998`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.72997063209382*^9, 
  3.729970682467964*^9},ExpressionUUID->"e227f4a6-6a77-4844-a0ec-\
6ecca6d9cdc5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "@", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Chop", "[", 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"quatSampleList", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ".", 
       RowBox[{"qinverse", "[", 
        RowBox[{"testSolve4vecs", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729970388494177*^9, 3.7299704326660347`*^9}, {
  3.729970524563652*^9, 3.729970545891103*^9}, {3.7299707011379128`*^9, 
  3.729970761370078*^9}},ExpressionUUID->"31951883-09d0-472e-b773-\
db2f64779211"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9999999999999998`", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7299704332412024`*^9, 3.72997054928469*^9, {3.729970734304525*^9, 
   3.729970761754105*^9}},ExpressionUUID->"0f01bd0f-a376-455c-9339-\
54f2f4a44fdc"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Now build the function that does this, take the BarMat and produce the \
Quaternion
that gave the original matrix.\
\>", "Subsubsection",
 CellChangeTimes->{{3.729970967483754*^9, 
  3.729970995781589*^9}},ExpressionUUID->"8898f12e-d68a-4e38-85b4-\
844a06d24a07"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeBarIzMat", "[", "qqMat3", "]"}]], "Input",
 CellChangeTimes->{{3.7299711807079372`*^9, 
  3.7299711826944304`*^9}},ExpressionUUID->"76dd7336-beaf-4a49-9618-\
036b2f540450"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q1"}], "3"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q2"}], "3"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q3"}], "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q1"}], "3"]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q1", "2"]}], "-", 
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q2"}], "3"], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q3"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q2"}], "3"]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q2"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q2", "2"]}], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q2", " ", "q3"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q3"}], "3"]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q3"}], "3"], ",", 
     FractionBox[
      RowBox[{"4", " ", "q2", " ", "q3"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["q2", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q3", "2"]}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729971184800815*^9},ExpressionUUID->"5dbf3e10-b8ce-4ef9-b8a8-\
fa4e97a7148e"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"axisMat3", "=", 
  RowBox[{
   RowBox[{"makeRotation", "[", 
    RowBox[{"th", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.", "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"-", "1."}], "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.729971266842523*^9, 
  3.729971325890571*^9}},ExpressionUUID->"c7fc41b6-e358-49a5-ba83-\
fe90ccc644f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "+", 
      RowBox[{"Cos", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"x", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "-", 
      RowBox[{"z", " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"x", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "+", 
      RowBox[{"y", " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "+", 
      RowBox[{"z", " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "+", 
      RowBox[{"Cos", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"y", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "-", 
      RowBox[{"x", " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "-", 
      RowBox[{"y", " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"y", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "+", 
      RowBox[{"Cos", "[", "th", "]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729971276909499*^9, 3.7299712858175087`*^9}, 
   3.729971326369442*^9},ExpressionUUID->"ff494ee5-4a52-4f7b-91f6-\
659a702c9bd3"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"makeBarIzMat", "[", "axisMat3", "]"}], "//", "Simplify"}], 
  ")"}]], "Input",ExpressionUUID->"263c9fbe-5f0f-4541-aa18-49456530ec3b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], " ", 
         RowBox[{"Cos", "[", "th", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "y", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "z", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"], "-", 
        SuperscriptBox["z", "2"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], " ", 
         RowBox[{"Cos", "[", "th", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "y", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x", "2"]}], "+", 
        SuperscriptBox["y", "2"], "-", 
        SuperscriptBox["z", "2"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["x", "2"], "-", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], " ", 
         RowBox[{"Cos", "[", "th", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "y", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "z", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "y", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x", "2"]}], "-", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"], "-", 
           SuperscriptBox["z", "2"]}], ")"}], " ", 
         RowBox[{"Cos", "[", "th", "]"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.729971697973608*^9},ExpressionUUID->"bf2b90a2-fa27-4e2a-ba00-\
c3b9baf406c7"]
}, Open  ]],

Cell[TextData[StyleBox["  Attempt to construct a constraint  on the M matrix \
from orthonormality...",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.729972231809433*^9, 
  3.729972251697805*^9}},ExpressionUUID->"5447b17c-1377-47fc-bfbe-\
b2588b12c2ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"makeBarIzMat", "[", "axisMat3", "]"}], "//", "Simplify"}], 
     ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], "\[Rule]", "1"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"], "-", 
        SuperscriptBox["z", "2"]}], "\[Rule]", " ", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["x", "2"]}], "-", "1"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x", "2"]}], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], "\[Rule]", " ", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["x", "2"]}]}]}], " ", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x", "2"]}], "+", 
        SuperscriptBox["y", "2"], "-", 
        SuperscriptBox["z", "2"]}], "\[Rule]", " ", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["y", "2"]}], "-", "1"}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], " ", "->", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", "2"]}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x", "2"]}], "-", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], "\[Rule]", "  ", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"]}], "-", "1"}]}], " ", ",", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "-", 
        SuperscriptBox["z", "2"]}], "->", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"]}]}]}]}], "}"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], "\[Rule]", "1"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"], "-", 
       SuperscriptBox["z", "2"]}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["x", "2"]}], "-", "1"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["x", "2"]}], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], "\[Rule]", " ", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["x", "2"]}]}]}], " ", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["x", "2"]}], "+", 
       SuperscriptBox["y", "2"], "-", 
       SuperscriptBox["z", "2"]}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["y", "2"]}], "-", "1"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], " ", "->", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", "2"]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["x", "2"]}], "-", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], "\[Rule]", "  ", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["z", "2"]}], "-", "1"}]}], " ", ",", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "-", 
       SuperscriptBox["z", "2"]}], "->", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["z", "2"]}]}]}]}], "}"}]}], "/.", 
  "\[IndentingNewLine]", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"Cos", "[", "th", "]"}]}]}], "\[Rule]", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "2"], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["y", "2"], " ", 
       RowBox[{"Cos", "[", "th", "]"}]}]}], "\[Rule]", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["y", "2"], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["z", "2"]}], "-", 
      RowBox[{"2", 
       SuperscriptBox["z", "2"], " ", 
       RowBox[{"Cos", "[", "th", "]"}]}]}], "\[Rule]", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["z", "2"], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7299712097081947`*^9, 3.729971229139669*^9}, {
  3.72997129252341*^9, 3.729971293283239*^9}, {3.7299713491231127`*^9, 
  3.7299714537463617`*^9}, {3.72997148702567*^9, 3.729971675464253*^9}, {
  3.729971716482148*^9, 3.7299717454469337`*^9}, {3.729971775513628*^9, 
  3.729971814766554*^9}, {3.7299718710418*^9, 
  3.7299720325213747`*^9}},ExpressionUUID->"82996c19-553d-46c9-bcae-\
fe997c51e79c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "th", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "y", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "z", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["x", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "y", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "y", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "z", " ", 
      RowBox[{"Sin", "[", "th", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "x", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", "y", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.729971229792267*^9, 3.729971294540469*^9, {3.7299713512579203`*^9, 
   3.729971368714493*^9}, {3.729971706453918*^9, 3.729971746762959*^9}, {
   3.729971780237053*^9, 3.7299718152189827`*^9}, {3.7299718729309397`*^9, 
   3.7299718799542828`*^9}, 3.7299719413837967`*^9, {3.7299720213428164`*^9, 
   3.7299720337205267`*^9}},ExpressionUUID->"73b29324-ec76-46c6-a40c-\
852a90d39694"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sxxBarMat4", "=", 
  RowBox[{"makeBarIzMat", "[", "sxxMat3", "]"}]}]], "Input",
 CellChangeTimes->{{3.7299711127349863`*^9, 3.729971140468384*^9}, {
  3.729972281995059*^9, 
  3.729972290682444*^9}},ExpressionUUID->"a2645a1c-d924-44a8-8f74-\
b251d86f5c4d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"sxx", "+", "syy", "+", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"syz", "-", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "-", "syx"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"syz", "-", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "+", "syx"}], "3"], ",", 
     FractionBox[
      RowBox[{"sxz", "+", "szx"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "+", "syx"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"syz", "+", "szy"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"sxy", "-", "syx"}], "3"], ",", 
     FractionBox[
      RowBox[{"sxz", "+", "szx"}], "3"], ",", 
     FractionBox[
      RowBox[{"syz", "+", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.729971141591793*^9, 
  3.729972292234074*^9},ExpressionUUID->"76b5d9a2-3d9b-4d53-b7f9-\
38a759b847e4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toprow", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"sxxBarMat4", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ".", 
    RowBox[{"{", " ", 
     RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.729972307793313*^9, 3.7299723503529863`*^9}, {
  3.729972481889204*^9, 
  3.729972485903781*^9}},ExpressionUUID->"5992a122-3c58-42ab-8553-\
baa93d4735cc"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "3"], " ", 
  RowBox[{"(", 
   RowBox[{"sxx", "+", "syy", "+", "szz", "+", 
    RowBox[{"syz", " ", "v1"}], "-", 
    RowBox[{"szy", " ", "v1"}], "-", 
    RowBox[{"sxz", " ", "v2"}], "+", 
    RowBox[{"szx", " ", "v2"}], "+", 
    RowBox[{"sxy", " ", "v3"}], "-", 
    RowBox[{"syx", " ", "v3"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.729972315465187*^9, 3.729972351260597*^9}, 
   3.729972487331647*^9},ExpressionUUID->"fd1be11e-eb1f-4334-ab1d-\
0f6aad8f9c7e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"rot3DList", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"quatSampleList", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"QuatToRot", "[", 
    RowBox[{"quatSampleList", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.729972693701806*^9, 
  3.729972745437017*^9}},ExpressionUUID->"127fccc9-e871-4657-8657-\
61808f6874db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.9756783221675079`"}], ",", 
       RowBox[{"-", "0.08204400271671086`"}], ",", "0.2032746744447428`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.025377800663047755`"}], ",", 
       RowBox[{"-", "0.8788056640596922`"}], ",", 
       RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.21773327464102138`", ",", 
       RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.014710143161435311`"}], ",", 
     RowBox[{"-", "0.10929067025330166`"}], ",", "0.24572500820698692`", ",", 
     
     RowBox[{"-", "0.9630464066832034`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.9756783221675079`"}], ",", 
       RowBox[{"-", "0.08204400271671086`"}], ",", "0.2032746744447428`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.025377800663047755`"}], ",", 
       RowBox[{"-", "0.8788056640596922`"}], ",", 
       RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.21773327464102138`", ",", 
       RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729972730041436*^9, 
  3.729972747870225*^9}},ExpressionUUID->"156db2b1-8dc6-4cb5-8f0e-\
382bac48b45d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toprow", "/.", "solnvvv"}], "//", "Expand"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.729972494111918*^9, 
  3.7299725255914*^9}},ExpressionUUID->"613f8e85-2de0-4c7f-bff0-838521c4043e"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.7299725042933283`*^9, 
  3.7299725642190857`*^9},ExpressionUUID->"96f5c0fb-c3c6-430b-9dbf-\
b13d17acd2ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"solnvvv", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"sxxBarMat4", "[", 
          RowBox[{"[", 
           RowBox[{"2", ";;", "4"}], "]"}], "]"}], ".", 
         RowBox[{"{", " ", 
          RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], "\[Equal]",
         " ", 
        RowBox[{"{", 
         RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.729972386646286*^9, 3.729972408352511*^9}, {
  3.7299724555853987`*^9, 
  3.729972468193145*^9}},ExpressionUUID->"bf86a4be-c25b-409b-998c-\
fc285c65c338"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"v1", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["sxz", "2"], "+", 
          SuperscriptBox["syz", "2"], "-", 
          SuperscriptBox["szx", "2"], "-", 
          SuperscriptBox["szy", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
          RowBox[{"sxy", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "sxx", "+", "syy", "-", "szz"}], ")"}]}], "+", 
          RowBox[{"syx", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "sxx", "+", "syy", "-", "szz"}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"syz", "-", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "sxx", "+", "syy", "-", "szz"}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "sxx", "-", "syy", "+", "szz"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
          RowBox[{"sxy", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "sxx", "+", "syy", "-", "szz"}], ")"}]}], "+", 
          RowBox[{"syx", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "sxx", "+", "syy", "-", "szz"}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sxz", " ", "syx"}], "+", 
          RowBox[{"3", " ", "syz"}], "-", 
          RowBox[{"sxx", " ", "syz"}], "+", 
          RowBox[{"syy", " ", "syz"}], "+", 
          RowBox[{"syx", " ", "szx"}], "+", 
          RowBox[{"sxy", " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
          RowBox[{"3", " ", "szy"}], "-", 
          RowBox[{"sxx", " ", "szy"}], "+", 
          RowBox[{"syy", " ", "szy"}], "+", 
          RowBox[{"syz", " ", "szz"}], "+", 
          RowBox[{"szy", " ", "szz"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          SuperscriptBox["sxx", "2"], "+", 
          SuperscriptBox["sxz", "2"], "-", 
          RowBox[{"6", " ", "syy"}], "-", 
          SuperscriptBox["syy", "2"], "+", 
          RowBox[{"2", " ", "sxz", " ", "szx"}], "+", 
          SuperscriptBox["szx", "2"], "-", 
          RowBox[{"2", " ", "sxx", " ", "szz"}], "+", 
          SuperscriptBox["szz", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"syx", " ", "syz"}], "+", 
          RowBox[{"3", " ", "szx"}], "+", 
          RowBox[{"sxx", " ", "szx"}], "-", 
          RowBox[{"syy", " ", "szx"}], "+", 
          RowBox[{"syx", " ", "szy"}], "+", 
          RowBox[{"sxy", " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
          RowBox[{"szx", " ", "szz"}], "+", 
          RowBox[{"sxz", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "sxx", "-", "syy", "+", "szz"}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{"v2", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["sxz", "3"]}], "-", 
       RowBox[{"2", " ", "sxx", " ", "syx", " ", "syz"}], "-", 
       RowBox[{"9", " ", "szx"}], "+", 
       RowBox[{
        SuperscriptBox["sxx", "2"], " ", "szx"}], "-", 
       RowBox[{
        SuperscriptBox["sxy", "2"], " ", "szx"}], "-", 
       RowBox[{
        SuperscriptBox["sxz", "2"], " ", "szx"}], "+", 
       RowBox[{
        SuperscriptBox["syx", "2"], " ", "szx"}], "-", 
       RowBox[{"6", " ", "syy", " ", "szx"}], "-", 
       RowBox[{
        SuperscriptBox["syy", "2"], " ", "szx"}], "-", 
       RowBox[{
        SuperscriptBox["syz", "2"], " ", "szx"}], "+", 
       SuperscriptBox["szx", "3"], "+", 
       RowBox[{"6", " ", "syx", " ", "szy"}], "+", 
       RowBox[{"2", " ", "syx", " ", "syy", " ", "szy"}], "+", 
       RowBox[{"szx", " ", 
        SuperscriptBox["szy", "2"]}], "+", 
       RowBox[{"2", " ", "syx", " ", "syz", " ", "szz"}], "-", 
       RowBox[{"2", " ", "sxx", " ", "szx", " ", "szz"}], "+", 
       RowBox[{"szx", " ", 
        SuperscriptBox["szz", "2"]}], "+", 
       RowBox[{"sxz", " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", 
          SuperscriptBox["sxx", "2"], "-", 
          SuperscriptBox["sxy", "2"], "+", 
          SuperscriptBox["syx", "2"], "+", 
          RowBox[{"6", " ", "syy"}], "+", 
          SuperscriptBox["syy", "2"], "-", 
          SuperscriptBox["syz", "2"], "+", 
          SuperscriptBox["szx", "2"], "+", 
          SuperscriptBox["szy", "2"], "+", 
          RowBox[{"2", " ", "sxx", " ", "szz"}], "-", 
          SuperscriptBox["szz", "2"]}], ")"}]}], "-", 
       RowBox[{"2", " ", "sxy", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", "syy"}], ")"}], " ", "syz"}], "+", 
          RowBox[{"szy", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "sxx"}], "+", "szz"}], ")"}]}]}], ")"}]}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "27"}], "+", 
       SuperscriptBox["sxx", "3"], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["sxz", "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["syx", "2"]}], "-", 
       RowBox[{"9", " ", "syy"}], "-", 
       RowBox[{
        SuperscriptBox["sxz", "2"], " ", "syy"}], "+", 
       RowBox[{
        SuperscriptBox["syx", "2"], " ", "syy"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["syy", "2"]}], "+", 
       SuperscriptBox["syy", "3"], "+", 
       RowBox[{"2", " ", "sxz", " ", "syx", " ", "syz"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["syz", "2"]}], "+", 
       RowBox[{"syy", " ", 
        SuperscriptBox["syz", "2"]}], "+", 
       RowBox[{"6", " ", "sxz", " ", "szx"}], "-", 
       RowBox[{"2", " ", "sxz", " ", "syy", " ", "szx"}], "+", 
       RowBox[{"2", " ", "syx", " ", "syz", " ", "szx"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["szx", "2"]}], "-", 
       RowBox[{"syy", " ", 
        SuperscriptBox["szx", "2"]}], "+", 
       RowBox[{"2", " ", "sxz", " ", "syx", " ", "szy"}], "+", 
       RowBox[{"6", " ", "syz", " ", "szy"}], "+", 
       RowBox[{"2", " ", "syy", " ", "syz", " ", "szy"}], "+", 
       RowBox[{"2", " ", "syx", " ", "szx", " ", "szy"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["szy", "2"]}], "+", 
       RowBox[{"syy", " ", 
        SuperscriptBox["szy", "2"]}], "+", 
       RowBox[{"2", " ", "sxy", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
          RowBox[{"syx", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "syy", "-", "szz"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["sxy", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "syy", "-", "szz"}], ")"}]}], "-", 
       RowBox[{"9", " ", "szz"}], "+", 
       RowBox[{
        SuperscriptBox["sxz", "2"], " ", "szz"}], "-", 
       RowBox[{
        SuperscriptBox["syx", "2"], " ", "szz"}], "-", 
       RowBox[{"6", " ", "syy", " ", "szz"}], "-", 
       RowBox[{
        SuperscriptBox["syy", "2"], " ", "szz"}], "+", 
       RowBox[{
        SuperscriptBox["syz", "2"], " ", "szz"}], "+", 
       RowBox[{"2", " ", "sxz", " ", "szx", " ", "szz"}], "+", 
       RowBox[{
        SuperscriptBox["szx", "2"], " ", "szz"}], "+", 
       RowBox[{"2", " ", "syz", " ", "szy", " ", "szz"}], "+", 
       RowBox[{
        SuperscriptBox["szy", "2"], " ", "szz"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["szz", "2"]}], "-", 
       RowBox[{"syy", " ", 
        SuperscriptBox["szz", "2"]}], "+", 
       SuperscriptBox["szz", "3"], "-", 
       RowBox[{
        SuperscriptBox["sxx", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "syy", "+", "szz"}], ")"}]}], "+", 
       RowBox[{"sxx", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          SuperscriptBox["sxy", "2"], "+", 
          SuperscriptBox["sxz", "2"], "+", 
          RowBox[{"2", " ", "sxy", " ", "syx"}], "+", 
          SuperscriptBox["syx", "2"], "-", 
          RowBox[{"6", " ", "syy"}], "-", 
          SuperscriptBox["syy", "2"], "-", 
          SuperscriptBox["syz", "2"], "+", 
          RowBox[{"2", " ", "sxz", " ", "szx"}], "+", 
          SuperscriptBox["szx", "2"], "-", 
          RowBox[{"2", " ", "syz", " ", "szy"}], "-", 
          SuperscriptBox["szy", "2"], "-", 
          RowBox[{"6", " ", "szz"}], "+", 
          RowBox[{"2", " ", "syy", " ", "szz"}], "-", 
          SuperscriptBox["szz", "2"]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{"v3", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["sxy", "3"], "+", 
       RowBox[{
        SuperscriptBox["sxy", "2"], " ", "syx"}], "-", 
       SuperscriptBox["syx", "3"], "+", 
       RowBox[{"2", " ", "sxx", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "sxz"}], " ", "syz"}], "+", 
          RowBox[{"szx", " ", "szy"}]}], ")"}]}], "+", 
       RowBox[{"sxy", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          SuperscriptBox["sxx", "2"], "+", 
          SuperscriptBox["sxz", "2"], "-", 
          SuperscriptBox["syx", "2"], "-", 
          RowBox[{"2", " ", "sxx", " ", "syy"}], "+", 
          SuperscriptBox["syy", "2"], "-", 
          SuperscriptBox["syz", "2"], "-", 
          SuperscriptBox["szx", "2"], "+", 
          SuperscriptBox["szy", "2"], "-", 
          RowBox[{"6", " ", "szz"}], "-", 
          SuperscriptBox["szz", "2"]}], ")"}]}], "+", 
       RowBox[{"syx", " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", 
          SuperscriptBox["sxx", "2"], "+", 
          SuperscriptBox["sxz", "2"], "+", 
          RowBox[{"2", " ", "sxx", " ", "syy"}], "-", 
          SuperscriptBox["syy", "2"], "-", 
          SuperscriptBox["syz", "2"], "-", 
          SuperscriptBox["szx", "2"], "+", 
          SuperscriptBox["szy", "2"], "+", 
          RowBox[{"6", " ", "szz"}], "+", 
          SuperscriptBox["szz", "2"]}], ")"}]}], "-", 
       RowBox[{"2", " ", "szx", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"syy", " ", "szy"}], "+", 
          RowBox[{"syz", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "szz"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", "sxz", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"syy", " ", "syz"}], "+", 
          RowBox[{"szy", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "szz"}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "27"}], "+", 
       SuperscriptBox["sxx", "3"], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["sxz", "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["syx", "2"]}], "-", 
       RowBox[{"9", " ", "syy"}], "-", 
       RowBox[{
        SuperscriptBox["sxz", "2"], " ", "syy"}], "+", 
       RowBox[{
        SuperscriptBox["syx", "2"], " ", "syy"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["syy", "2"]}], "+", 
       SuperscriptBox["syy", "3"], "+", 
       RowBox[{"2", " ", "sxz", " ", "syx", " ", "syz"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["syz", "2"]}], "+", 
       RowBox[{"syy", " ", 
        SuperscriptBox["syz", "2"]}], "+", 
       RowBox[{"6", " ", "sxz", " ", "szx"}], "-", 
       RowBox[{"2", " ", "sxz", " ", "syy", " ", "szx"}], "+", 
       RowBox[{"2", " ", "syx", " ", "syz", " ", "szx"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["szx", "2"]}], "-", 
       RowBox[{"syy", " ", 
        SuperscriptBox["szx", "2"]}], "+", 
       RowBox[{"2", " ", "sxz", " ", "syx", " ", "szy"}], "+", 
       RowBox[{"6", " ", "syz", " ", "szy"}], "+", 
       RowBox[{"2", " ", "syy", " ", "syz", " ", "szy"}], "+", 
       RowBox[{"2", " ", "syx", " ", "szx", " ", "szy"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["szy", "2"]}], "+", 
       RowBox[{"syy", " ", 
        SuperscriptBox["szy", "2"]}], "+", 
       RowBox[{"2", " ", "sxy", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
          RowBox[{"syx", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "syy", "-", "szz"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["sxy", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "syy", "-", "szz"}], ")"}]}], "-", 
       RowBox[{"9", " ", "szz"}], "+", 
       RowBox[{
        SuperscriptBox["sxz", "2"], " ", "szz"}], "-", 
       RowBox[{
        SuperscriptBox["syx", "2"], " ", "szz"}], "-", 
       RowBox[{"6", " ", "syy", " ", "szz"}], "-", 
       RowBox[{
        SuperscriptBox["syy", "2"], " ", "szz"}], "+", 
       RowBox[{
        SuperscriptBox["syz", "2"], " ", "szz"}], "+", 
       RowBox[{"2", " ", "sxz", " ", "szx", " ", "szz"}], "+", 
       RowBox[{
        SuperscriptBox["szx", "2"], " ", "szz"}], "+", 
       RowBox[{"2", " ", "syz", " ", "szy", " ", "szz"}], "+", 
       RowBox[{
        SuperscriptBox["szy", "2"], " ", "szz"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["szz", "2"]}], "-", 
       RowBox[{"syy", " ", 
        SuperscriptBox["szz", "2"]}], "+", 
       SuperscriptBox["szz", "3"], "-", 
       RowBox[{
        SuperscriptBox["sxx", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "syy", "+", "szz"}], ")"}]}], "+", 
       RowBox[{"sxx", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          SuperscriptBox["sxy", "2"], "+", 
          SuperscriptBox["sxz", "2"], "+", 
          RowBox[{"2", " ", "sxy", " ", "syx"}], "+", 
          SuperscriptBox["syx", "2"], "-", 
          RowBox[{"6", " ", "syy"}], "-", 
          SuperscriptBox["syy", "2"], "-", 
          SuperscriptBox["syz", "2"], "+", 
          RowBox[{"2", " ", "sxz", " ", "szx"}], "+", 
          SuperscriptBox["szx", "2"], "-", 
          RowBox[{"2", " ", "syz", " ", "szy"}], "-", 
          SuperscriptBox["szy", "2"], "-", 
          RowBox[{"6", " ", "szz"}], "+", 
          RowBox[{"2", " ", "syy", " ", "szz"}], "-", 
          SuperscriptBox["szz", "2"]}], ")"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.729972395146261*^9, 3.729972409864555*^9}, 
   3.729972477474957*^9},ExpressionUUID->"cda9554f-718c-4ea3-a10b-\
0d35758a1b8c"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule", " ", "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", "=", "1"}], "}"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"sxxMat3", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Rule]", " ", 
        RowBox[{
         RowBox[{"rot3DList", "[", 
          RowBox[{"[", "k", "]"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.729972630353413*^9, 3.729972658359168*^9}, {
  3.729972782473569*^9, 
  3.729972820549842*^9}},ExpressionUUID->"a111f1aa-4790-4ba9-a454-\
69035e80cc12"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"sxx", "\[Rule]", 
    RowBox[{"-", "0.9756783221675079`"}]}], ",", 
   RowBox[{"sxy", "\[Rule]", 
    RowBox[{"-", "0.08204400271671086`"}]}], ",", 
   RowBox[{"sxz", "\[Rule]", "0.2032746744447428`"}], ",", 
   RowBox[{"syx", "\[Rule]", 
    RowBox[{"-", "0.025377800663047755`"}]}], ",", 
   RowBox[{"syy", "\[Rule]", 
    RowBox[{"-", "0.8788056640596922`"}]}], ",", 
   RowBox[{"syz", "\[Rule]", 
    RowBox[{"-", "0.4765045351831494`"}]}], ",", 
   RowBox[{"szx", "\[Rule]", "0.21773327464102138`"}], ",", 
   RowBox[{"szy", "\[Rule]", 
    RowBox[{"-", "0.4700738095606083`"}]}], ",", 
   RowBox[{"szz", "\[Rule]", "0.8553495394745203`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729972821567113*^9},ExpressionUUID->"4e1361f9-cb88-4479-86b1-\
268d39c14616"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}], "/.", 
   RowBox[{"(", 
    RowBox[{"solnvvv", "/.", "rule"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7299725887549667`*^9, 3.729972616783671*^9}, 
   3.729972838010536*^9, {3.7299728765260344`*^9, 
   3.729972910412404*^9}},ExpressionUUID->"2ec76564-c2fc-4530-8259-\
cc0c3dd363c2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.014710143161453186`", ",", 
   RowBox[{"-", "0.10929067025328143`"}], ",", "0.24572500820698764`", ",", 
   RowBox[{"-", "0.9630464066832053`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729972840636591*^9, 
  3.729972911068845*^9},ExpressionUUID->"4a359c9f-af06-4bfb-84e8-\
56320bf1c28f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Collapse the derivation, create the function test:", "Subsubsection",
 CellChangeTimes->{{3.7299710461241503`*^9, 
  3.72997105585223*^9}},ExpressionUUID->"090340f9-d18e-4386-9ab7-\
2713aefa5e0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"//", "Expand"}], "//", "Together"}], "//", "Simplify"}]], "Input",\
ExpressionUUID->"d21aad07-eee0-48bf-930a-9fc6f3a9c5b8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"v1Rule", " ", "=", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"sxxBarMat4", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "4"}], "]"}], "]"}], ".", 
          RowBox[{"{", " ", 
           RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], 
         "\[Equal]", " ", 
         RowBox[{"{", 
          RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.7299731238527517`*^9, 3.729973135133325*^9}, {
  3.729973175309349*^9, 3.7299732674107924`*^9}, {3.729973378075671*^9, 
  3.729973382606904*^9}, {3.7299735151442003`*^9, 3.7299735282622023`*^9}, {
  3.729973561642321*^9, 3.7299735791671352`*^9}, {3.7299736204228354`*^9, 
  3.729973652297505*^9}},ExpressionUUID->"d08c4d4d-4092-4002-914a-\
acd7df8a3b01"],

Cell[BoxData[
 RowBox[{"v1", "\[Rule]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
           RowBox[{
            FractionBox["1", "9"], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "-", "szy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "-", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "9"], " ", 
            RowBox[{"(", 
             RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}],
           ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"sxz", "+", "szx"}], ")"}], "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7299735810417643`*^9, {3.729973625568749*^9, 
   3.729973656668652*^9}},ExpressionUUID->"ee4a8dd8-1cd2-4796-98c3-\
a1169ecac87b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"v2Rule", " ", "=", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"sxxBarMat4", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "4"}], "]"}], "]"}], ".", 
          RowBox[{"{", " ", 
           RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], 
         "\[Equal]", " ", 
         RowBox[{"{", 
          RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"v2", ",", "v1", ",", "v3"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ")"}], " "}]}]], "Input",
 CellChangeTimes->{{3.7299731238527517`*^9, 3.729973135133325*^9}, {
   3.729973175309349*^9, 3.7299732388894444`*^9}, {3.729973270425272*^9, 
   3.729973279608724*^9}, {3.729973336241761*^9, 3.729973336863422*^9}, {
   3.7299734028754053`*^9, 3.729973419849187*^9}, 
   3.7299735927773943`*^9},ExpressionUUID->"bfd9a233-0169-404c-b7fb-\
b09044222937"],

Cell[BoxData[
 RowBox[{"v2", "\[Rule]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "9"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
           RowBox[{
            FractionBox["1", "9"], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "-", "szy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "9"], " ", 
            RowBox[{"(", 
             RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}], "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.72997330941448*^9, 3.729973386542609*^9, 
  3.7299734217840767`*^9, 
  3.729973593871066*^9},ExpressionUUID->"0a521b5e-f856-4f3f-a47d-\
e8cd27f00ad9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"v3Rule", " ", "=", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"sxxBarMat4", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "4"}], "]"}], "]"}], ".", 
          RowBox[{"{", " ", 
           RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], 
         "\[Equal]", " ", 
         RowBox[{"{", 
          RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"v3", ",", "v1", ",", "v2"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ")"}], " "}]}]], "Input",
 CellChangeTimes->{{3.7299731238527517`*^9, 3.729973135133325*^9}, {
   3.729973175309349*^9, 3.729973222609646*^9}, {3.729973284120233*^9, 
   3.729973302272648*^9}, {3.729973481113077*^9, 3.729973489239291*^9}, 
   3.729973600361579*^9},ExpressionUUID->"01a3f283-60b9-4458-89af-\
ce687edd6110"],

Cell[BoxData[
 RowBox[{"v3", "\[Rule]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "-", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "9"], " ", 
            RowBox[{"(", 
             RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}], "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.72997309718011*^9, {3.7299731274902267`*^9, 3.7299731363273497`*^9}, {
   3.729973181295084*^9, 3.7299732047657824`*^9}, 3.729973305424185*^9, 
   3.7299734916236477`*^9, 
   3.7299736009101477`*^9},ExpressionUUID->"1952d420-befd-4fc5-b9c6-\
db98005c1311"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"v0Rule", " ", "=", " ", 
   RowBox[{"v0", "\[Rule]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "9"]}], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], "2"]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}], " ", 
          
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729973859119562*^9, 
  3.729973888020844*^9}},ExpressionUUID->"72fd4b52-065f-44bb-bce3-\
996047ed4c1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv0", "=", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "9"], " ", 
         RowBox[{"(", 
          RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
          ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "9"]}], " ", 
         RowBox[{"(", 
          RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
          ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "9"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}], "2"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
          ")"}]}]}], ")"}]}]}], ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729974157363984*^9, 
  3.7299741909385366`*^9}},ExpressionUUID->"1db74f9e-ee1e-4850-9386-\
d3cff4973468"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv1", " ", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "-", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "9"]}], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "-", "szy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729973948179624*^9, 3.7299739771860733`*^9}, 
   3.729974010811677*^9, 3.729974044355515*^9, {3.729974080612422*^9, 
   3.729974082459306*^9}},ExpressionUUID->"b343c8ea-3a80-4501-9026-\
e52df81bb591"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv2", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "9"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "-", "szy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "9"]}], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7299740247632008`*^9, 3.729974038356151*^9}, 
   3.729974088397182*^9},ExpressionUUID->"dd8d70a8-1522-457e-a747-\
21d6d724d620"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv3", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "9"]}], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "9"]}], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "-", "szy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729974066034976*^9, 
  3.729974094514784*^9}},ExpressionUUID->"d7c2ce70-d255-41f8-9384-\
20e9d2257381"],

Cell[TextData[StyleBox[" OK, what we want is a SINGLE function that maps to \
all three (all four?)\n  - AND BE CAREFUL at the last step to take the \
INVERSE quaternion.\n  \n  OK this works --- must be something different \
among the three denominators...",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.729974408660265*^9, 3.7299744510443363`*^9}, {
  3.729992315845462*^9, 
  3.729992335469746*^9}},ExpressionUUID->"27469f78-e04b-407e-8456-\
fcf1f185173c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"theRotToQuat", "[", "mat3_List", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vv", ",", "v1", ",", "v2", ",", "v3", ",", "v0", ",", 
      RowBox[{"m", "=", "mat3"}]}], "}"}], ",", "\[IndentingNewLine]", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sxx", " ", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"sxy", "=", " ", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"sxz", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"syx", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"syy", " ", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"syz", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"szx", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"szy", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"szz", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"v0", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"v1", " ", "=", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FractionBox["1", "9"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
                 RowBox[{
                  FractionBox["1", "9"], " ", 
                  RowBox[{"(", 
                   RowBox[{"syz", "-", "szy"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "9"]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "-", "szy"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FractionBox["1", "9"], " ", 
                  RowBox[{"(", 
                   RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
                 RowBox[{
                  FractionBox["1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"syz", "+", "szy"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
                   ")"}]}]}], ")"}]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "9"]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"sxz", "+", "szx"}], ")"}], "2"]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}],
                  " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"v2", "=", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox["1", "9"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
                 RowBox[{
                  FractionBox["1", "9"], " ", 
                  RowBox[{"(", 
                   RowBox[{"syz", "-", "szy"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "9"]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
                  ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FractionBox["1", "9"], " ", 
                  RowBox[{"(", 
                   RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                 RowBox[{
                  FractionBox["1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                    ")"}]}]}], ")"}]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "9"]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
                  ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"syz", "+", "szy"}], ")"}], "2"]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                   ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"v3", "=", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "9"]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
                  ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "9"]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}]}], "+", 
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "-", "szy"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FractionBox["1", "9"], " ", 
                  RowBox[{"(", 
                   RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                 RowBox[{
                  FractionBox["1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                    ")"}]}]}], ")"}]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "9"]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
                  ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"syz", "+", "szy"}], ")"}], "2"]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                   ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    FractionBox["1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                   ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"vv", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"v0", ",", 
          RowBox[{"-", "v1"}], ",", 
          RowBox[{"-", "v2"}], ",", 
          RowBox[{"-", "v3"}]}], "}"}]}], ";", "  ", 
       RowBox[{"Normalize", "[", "vv", "]"}]}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729972969276599*^9, 3.72997303963441*^9}, {
   3.7299910510579557`*^9, 3.7299912207665462`*^9}, {3.7299913697777243`*^9, 
   3.729991373993952*^9}, {3.729991789198868*^9, 3.7299918043466873`*^9}, 
   3.729991993891129*^9, 3.729992048004306*^9, {3.729992182246468*^9, 
   3.729992221027707*^9}, {3.729992252448661*^9, 
   3.7299922575991697`*^9}},ExpressionUUID->"16de1c50-3d8b-4234-866e-\
67b2ad1db656"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.7299922661308327`*^9},ExpressionUUID->"6cc0520d-e988-4daf-a415-\
a3249b347d66"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"quatSampleList", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ".", 
      RowBox[{"qinverse", "[", 
       RowBox[{"testSolve4vecs", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",ExpressionUUI\
D->"180a23dd-d82c-4f42-a1ee-a1e1426b3432"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule", " ", "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", "=", "1"}], "}"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"sxxMat3", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Rule]", " ", 
        RowBox[{
         RowBox[{"rot3DList", "[", 
          RowBox[{"[", "k", "]"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.729972630353413*^9, 3.729972658359168*^9}, {
  3.729972782473569*^9, 
  3.729972820549842*^9}},ExpressionUUID->"c4622e26-408b-4099-a776-\
b3822c1401e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"sxx", "\[Rule]", 
    RowBox[{"-", "0.9756783221675079`"}]}], ",", 
   RowBox[{"sxy", "\[Rule]", 
    RowBox[{"-", "0.08204400271671086`"}]}], ",", 
   RowBox[{"sxz", "\[Rule]", "0.2032746744447428`"}], ",", 
   RowBox[{"syx", "\[Rule]", 
    RowBox[{"-", "0.025377800663047755`"}]}], ",", 
   RowBox[{"syy", "\[Rule]", 
    RowBox[{"-", "0.8788056640596922`"}]}], ",", 
   RowBox[{"syz", "\[Rule]", 
    RowBox[{"-", "0.4765045351831494`"}]}], ",", 
   RowBox[{"szx", "\[Rule]", "0.21773327464102138`"}], ",", 
   RowBox[{"szy", "\[Rule]", 
    RowBox[{"-", "0.4700738095606083`"}]}], ",", 
   RowBox[{"szz", "\[Rule]", "0.8553495394745203`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729972821567113*^9},ExpressionUUID->"20c47784-ce0c-42f6-9ca7-\
4fdbd325a514"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quatSampleList", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729990586477118*^9, 
  3.7299905873731833`*^9}},ExpressionUUID->"28f4bb3d-c131-4120-ab64-\
730f7f42bc9e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.014710143161435311`"}], ",", 
   RowBox[{"-", "0.10929067025330166`"}], ",", "0.24572500820698692`", ",", 
   RowBox[{"-", "0.9630464066832034`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729990588973501*^9},ExpressionUUID->"08c2a916-77fc-47b8-92d0-\
c08e3245f6c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuatToRot", "[", 
  RowBox[{"quatSampleList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7299905935702963`*^9, 
  3.729990607365283*^9}},ExpressionUUID->"8b23ba7e-e6cd-4a8a-9266-\
59ada3dac772"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9756783221675079`"}], ",", 
     RowBox[{"-", "0.08204400271671086`"}], ",", "0.2032746744447428`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.025377800663047755`"}], ",", 
     RowBox[{"-", "0.8788056640596922`"}], ",", 
     RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21773327464102138`", ",", 
     RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7299906080760527`*^9},ExpressionUUID->"64ff0906-630d-461d-a7c0-\
806383da49de"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rot3DList", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729990576653359*^9, 
  3.729990577469577*^9}},ExpressionUUID->"8f655ce1-8887-47a1-b77b-\
41a10f291497"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9756783221675079`"}], ",", 
     RowBox[{"-", "0.08204400271671086`"}], ",", "0.2032746744447428`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.025377800663047755`"}], ",", 
     RowBox[{"-", "0.8788056640596922`"}], ",", 
     RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21773327464102138`", ",", 
     RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729990578150084*^9},ExpressionUUID->"d510948a-fd47-42da-a15a-\
c986be37adf1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RotToQuat", "[", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7299914398828087`*^9, 
  3.7299914507332363`*^9}},ExpressionUUID->"ef9a8765-b315-44c9-85ff-\
8816a3c0aabf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.014710143161435318`"}], ",", 
   RowBox[{"-", "0.1092906702533017`"}], ",", "0.245725008206987`", ",", 
   RowBox[{"-", "0.9630464066832036`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729991451563129*^9},ExpressionUUID->"11b9ac54-6b8f-45e4-a454-\
71f44d62d5a4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"barMat3DList", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729990566785482*^9, 
  3.729990572397729*^9}},ExpressionUUID->"99f5afd3-93c5-43f1-865c-\
dd80776e0ddb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.33304481558422655`"}], ",", 
     RowBox[{"-", "0.0021435752075137`"}], ",", "0.004819533398759531`", ",", 
     
     RowBox[{"-", "0.018888734017887703`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0021435752075137`"}], ",", 
     RowBox[{"-", "0.317407399194112`"}], ",", 
     RowBox[{"-", "0.03580726779325287`"}], ",", "0.14033598302858805`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.004819533398759531`", ",", 
     RowBox[{"-", "0.03580726779325287`"}], ",", 
     RowBox[{"-", "0.25282562712223483`"}], ",", 
     RowBox[{"-", "0.3155261149145859`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.018888734017887703`"}], ",", "0.14033598302858805`", ",", 
     RowBox[{"-", "0.3155261149145859`"}], ",", "0.9032778419005734`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729990572891548*^9},ExpressionUUID->"0eae39f1-b024-4c10-a3ca-\
4378ca268ac4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigenvectors", "[", 
   RowBox[{"barMat3DList", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729991262523616*^9, 
  3.7299912747028522`*^9}},ExpressionUUID->"cea869db-0c30-4aec-944c-\
1b7154dfe749"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.014710143161435313`"}], ",", "0.10929067025330165`", ",", 
   RowBox[{"-", "0.2457250082069869`"}], ",", "0.9630464066832036`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.729991277312687*^9},ExpressionUUID->"35bed5fb-8c6b-4041-8b49-\
3b9821c563de"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theRotToQuat", "[", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.729991242654258*^9, 
  3.729991283500106*^9}},ExpressionUUID->"ab4e7038-60f1-468d-8e17-\
96707d302743"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.006574751526623898`", ",", "0.04884785914091481`", ",", 
   "0.2469323970813677`", ",", 
   RowBox[{"-", "0.9677784098497767`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7299912841366377`*^9, 
  3.729991458638481*^9},ExpressionUUID->"da7e8463-9adc-4db3-9df8-\
82c17831aed3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "0.006574751526623898`", ",", "0.04884785914091481`", ",", 
    "0.2469323970813677`", ",", 
    RowBox[{"-", "0.9677784098497767`"}]}], "}"}], ".", 
  RowBox[{"{", 
   RowBox[{
   "0.006574751526623898`", ",", "0.04884785914091481`", ",", 
    "0.2469323970813677`", ",", 
    RowBox[{"-", "0.9677784098497767`"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.72999130275098*^9, 
  3.729991302892926*^9}},ExpressionUUID->"2c167861-3141-43d0-ae03-\
66ce3b37500e"],

Cell[BoxData["1.0000000000000002`"], "Output",
 CellChangeTimes->{
  3.729991303488049*^9},ExpressionUUID->"6906cc3a-5ae6-48d7-ad9e-\
7b8fef1bafea"]
}, Open  ]],

Cell[TextData[StyleBox["FAILS  with the  functions of v1 = sxx + ...   that I \
thought would work",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.7300416685975933`*^9, 
  3.730041693029541*^9}},ExpressionUUID->"c9fae57b-ac56-43dc-8ddb-\
62c3e7b81ba7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theRotToQuat", "[", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", "]"}]], "Input",ExpressionUUID->\
"0ac097cb-116e-4f7e-aecc-ceb337562214"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.006574751526623898`", ",", "0.04884785914091481`", ",", 
   "0.2469323970813677`", ",", 
   RowBox[{"-", "0.9677784098497767`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729992072404008*^9},ExpressionUUID->"fad37f6a-15d1-4196-bfef-\
4231bf78d0ff"]
}, Open  ]],

Cell[TextData[StyleBox["SUCCEEDS with the current version that is just \
straight out\nof the rule for the algebraic solution.  Some subtlety \
missing...",
 FontSize->24,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7300416995972223`*^9, 
  3.7300417350774307`*^9}},ExpressionUUID->"fcccf5e8-61e5-4755-bdb3-\
6066c66962ba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theRotToQuat", "[", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", "]"}]], "Input",ExpressionUUID->\
"fc4c3097-74d4-4dd8-8709-c950ca572f21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.014710143161458973`", ",", "0.10929067025330091`", ",", 
   RowBox[{"-", "0.24572500820698684`"}], ",", "0.9630464066832033`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7299922822063*^9},ExpressionUUID->"d357fd82-567e-417d-aace-ddfc138a3b38"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"rot3DList", "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", ",", 
   RowBox[{"QuatToRot", "[", 
    RowBox[{"theRotToQuat", "[", 
     RowBox[{"rot3DList", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.7299923685893793`*^9, 
  3.729992392742038*^9}},ExpressionUUID->"45433c52-7a1a-4c71-9f89-\
17ac6d07be14"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.9756783221675079`"}], ",", 
       RowBox[{"-", "0.08204400271671086`"}], ",", "0.2032746744447428`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.025377800663047755`"}], ",", 
       RowBox[{"-", "0.8788056640596922`"}], ",", 
       RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.21773327464102138`", ",", 
       RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.9756783221675072`"}], ",", 
       RowBox[{"-", "0.08204400271675603`"}], ",", "0.20327467444472969`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.025377800663001795`"}], ",", 
       RowBox[{"-", "0.8788056640596912`"}], ",", 
       RowBox[{"-", "0.47650453518315433`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.21773327464103154`", ",", 
       RowBox[{"-", "0.4700738095606029`"}], ",", "0.8553495394745209`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729992393152075*^9},ExpressionUUID->"819c2668-472e-4b20-ad3a-\
3bcd0a2116a0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
So - this function works,
 that is the  v1Rule works, but I can\[CloseCurlyQuote]t get the  \
rationalized pieces to
   work, must be something wrong with the denominators...\
\>", "Subsubsection",
 CellChangeTimes->{{3.7299920945842113`*^9, 3.7299921173030443`*^9}, {
  3.729992412804859*^9, 
  3.7299924495085907`*^9}},ExpressionUUID->"867f88fc-739f-4950-9634-\
6fdad66baf8a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vtest", "=", 
  RowBox[{"Normalize", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{"v1Rule", ",", "v2Rule", ",", "v3Rule"}], "}"}]}], ")"}], "/.",
     " ", "rule"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7299915640959377`*^9, 3.729991641628211*^9}, {
  3.729991693915957*^9, 
  3.729991698899684*^9}},ExpressionUUID->"354d0bc6-7e15-4442-a834-\
8b447ae2c94b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.014710143161458973`", ",", 
   RowBox[{"-", "0.10929067025330091`"}], ",", "0.24572500820698684`", ",", 
   RowBox[{"-", "0.9630464066832033`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729991699601816*^9},ExpressionUUID->"e2b963b4-5dd7-437c-ae62-\
d2eef9205f87"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["TODO  on the RotToQuat:   there must be some drastic \
simplifications in the\n         form of vi[sxx,...] due to orthonormality \
that can be exploited -- work on that",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.7300417504528*^9, 
  3.730041799669065*^9}},ExpressionUUID->"2d322cad-43ce-4c91-911a-\
a342e1d51cf5"],

Cell[TextData[StyleBox["TODO  on the RotToQuat:  this must also work on 4D!  \
So the same method should give:\n    1.  A way to reconstruct the SL2C matrix \
from a Lorentz Transform\n    2.  A way to reconstruct the quaternion pair \
for SO(4) matrix R4[p,q].",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.7300417504528*^9, 
  3.730041872396329*^9}},ExpressionUUID->"9fc61eea-1a2d-4b47-be51-\
f77c9f332ee4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Summary of the final results of the Horn \[OpenCurlyQuote]profile\
\[CloseCurlyQuote]  = Davenport \[OpenCurlyQuote]q\[CloseCurlyQuote] 
   method for the RotToQuat problem\
\>", "Subchapter",
 CellChangeTimes->{{3.72529440868812*^9, 3.7252944094478273`*^9}, {
  3.730043420766189*^9, 
  3.730043452006097*^9}},ExpressionUUID->"e9f101fe-f952-4de2-9348-\
8bd43d7143a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"hornSmat", "//", "MatrixForm"}], ",", 
   RowBox[{"hornAmat", "//", "MatrixForm"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.7300453731389227`*^9, 
  3.7300454255003347`*^9}},ExpressionUUID->"b1ab3183-a210-4824-a8a8-\
c55c26894a35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"sxx", "+", "syy", "+", "szz"}], 
        RowBox[{"syz", "-", "szy"}], 
        RowBox[{
         RowBox[{"-", "sxz"}], "+", "szx"}], 
        RowBox[{"sxy", "-", "syx"}]},
       {
        RowBox[{"syz", "-", "szy"}], 
        RowBox[{"sxx", "-", "syy", "-", "szz"}], 
        RowBox[{"sxy", "+", "syx"}], 
        RowBox[{"sxz", "+", "szx"}]},
       {
        RowBox[{
         RowBox[{"-", "sxz"}], "+", "szx"}], 
        RowBox[{"sxy", "+", "syx"}], 
        RowBox[{
         RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], 
        RowBox[{"syz", "+", "szy"}]},
       {
        RowBox[{"sxy", "-", "syx"}], 
        RowBox[{"sxz", "+", "szx"}], 
        RowBox[{"syz", "+", "szy"}], 
        RowBox[{
         RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"x", "+", "y", "+", "z"}], "a", "b", "c"},
       {"a", 
        RowBox[{"x", "-", "y", "-", "z"}], "cc", "bb"},
       {"b", "cc", 
        RowBox[{
         RowBox[{"-", "x"}], "+", "y", "-", "z"}], "aa"},
       {"c", "bb", "aa", 
        RowBox[{
         RowBox[{"-", "x"}], "-", "y", "+", "z"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.730045383222301*^9, 3.730045393323639*^9}, 
   3.73004542580042*^9},ExpressionUUID->"d2937f02-b456-4fa3-b3cc-\
02fea6b8f44e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["DERIVED  v1->v2->v3 substitutions: sxx ->  xyzabcABC  \
- needed for v1,v2,v3 permutation concept",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.730044126631565*^9, 3.730044142591529*^9}, {
  3.730045151871574*^9, 3.73004517751152*^9}, {3.73004857179568*^9, 
  3.730048597059346*^9}},ExpressionUUID->"54625e08-5e18-4db0-a5d5-\
b52864239f3b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1eq", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"hornAmat", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"v0", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], "\[Equal]", 
   "v1"}]}]], "Input",
 CellChangeTimes->{{3.730046054392477*^9, 3.730046071888638*^9}, {
  3.7300464912868013`*^9, 
  3.7300465023895273`*^9}},ExpressionUUID->"72a14f17-02a7-497f-9f08-\
d918e220c35c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"a", " ", "v0"}], "+", 
   RowBox[{"cc", " ", "v2"}], "+", 
   RowBox[{"bb", " ", "v3"}], "+", 
   RowBox[{"v1", " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", "y", "-", "z"}], ")"}]}]}], "\[Equal]", 
  "v1"}]], "Output",
 CellChangeTimes->{3.730046073049426*^9, 
  3.7300465035323544`*^9},ExpressionUUID->"79c90fda-4507-487c-b99e-\
4c638101ff4e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v2eq", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"hornAmat", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"v0", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], "\[Equal]", 
   "v2"}]}]], "Input",
 CellChangeTimes->{
  3.7300460838797903`*^9, {3.730046506750259*^9, 
   3.730046516603943*^9}},ExpressionUUID->"3143e5ab-c83e-46d9-9468-\
d4dc5a0e11b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", " ", "v0"}], "+", 
   RowBox[{"cc", " ", "v1"}], "+", 
   RowBox[{"aa", " ", "v3"}], "+", 
   RowBox[{"v2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], "+", "y", "-", "z"}], ")"}]}]}], "\[Equal]", 
  "v2"}]], "Output",
 CellChangeTimes->{3.730046091875641*^9, 
  3.73004653469204*^9},ExpressionUUID->"aaca863b-7427-4a0f-b633-1e9768ece16d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v3eq", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"hornAmat", "[", 
     RowBox[{"[", "4", "]"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"v0", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], "\[Equal]", 
   "v3"}]}]], "Input",
 CellChangeTimes->{
  3.7300460882080507`*^9, {3.7300465237560787`*^9, 
   3.730046530820046*^9}},ExpressionUUID->"e24a16a2-019d-424c-bf99-\
f2a9a0f7d744"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", " ", "v0"}], "+", 
   RowBox[{"bb", " ", "v1"}], "+", 
   RowBox[{"aa", " ", "v2"}], "+", 
   RowBox[{"v3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], "-", "y", "+", "z"}], ")"}]}]}], "\[Equal]", 
  "v3"}]], "Output",
 CellChangeTimes->{3.730046088924131*^9, 
  3.730046531880598*^9},ExpressionUUID->"c9101bb8-83f9-4743-8f7f-\
131f79d892bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "q0", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "9"], " ", 
           RowBox[{"(", 
            RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "9"]}], " ", 
          RowBox[{"(", 
           RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"syz", "+", "szy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "9"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"syz", "+", "szy"}], ")"}], "2"]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/.", " ", "hornS2ARule"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.730048371357005*^9, 
  3.730048408882503*^9}},ExpressionUUID->"49fd5125-300e-40e6-9f74-\
ac6a1ed466e8"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "81"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "bb"}], "+", 
        RowBox[{"cc", " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
     " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", "cc"}], "+", 
       RowBox[{"bb", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["aa", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bb", " ", "cc"}], "+", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.730048390786476*^9, 
  3.730048411484158*^9}},ExpressionUUID->"44c7eb48-6d6b-4502-9c67-\
bd2d93b3737d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"v1eq", ",", "v2eq", ",", "v3eq"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}], ")"}], "/.", 
  "\[IndentingNewLine]", 
  RowBox[{"v0", "->", 
   RowBox[{
    RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["cc", "2"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], 
      ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.730046543809979*^9, 3.730046602907892*^9}, {
  3.730046654924777*^9, 3.730046656059757*^9}, {3.730046712323263*^9, 
  3.7300467415929337`*^9}},ExpressionUUID->"047a741c-e85e-4932-91ba-\
bb01ddbb304d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vvvRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"v1", "\[Rule]", 
      RowBox[{
       RowBox[{"a", " ", 
        SuperscriptBox["aa", "2"]}], "-", 
       RowBox[{"aa", " ", "b", " ", "bb"}], "-", 
       RowBox[{"bb", " ", "c"}], "-", 
       RowBox[{"b", " ", "cc"}], "-", 
       RowBox[{"aa", " ", "c", " ", "cc"}], "-", 
       RowBox[{"bb", " ", "c", " ", "x"}], "-", 
       RowBox[{"b", " ", "cc", " ", "x"}], "+", 
       RowBox[{"bb", " ", "c", " ", "y"}], "-", 
       RowBox[{"b", " ", "cc", " ", "y"}], "-", 
       RowBox[{"bb", " ", "c", " ", "z"}], "+", 
       RowBox[{"b", " ", "cc", " ", "z"}], "-", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}]}]}], ",", 
     RowBox[{"v2", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "aa", " ", "bb"}], "-", 
       RowBox[{"bb", " ", "c", " ", "cc"}], "+", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["bb", "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x", "-", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
       "-", 
       RowBox[{"a", " ", "cc", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
       RowBox[{"aa", " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}]}]}], ",", 
     RowBox[{"v3", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "bb"}], "-", "c", "-", 
       RowBox[{"b", " ", "bb", " ", "cc"}], "-", 
       RowBox[{"a", " ", "bb", " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["cc", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "y"}], ")"}], "2"], "-", 
          RowBox[{"z", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "z"}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", "cc"}], "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.730046831473716*^9, 
  3.730046837824095*^9}},ExpressionUUID->"75e1b6c5-3a6f-4447-8d4e-\
f860bb0611f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vvvRule", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "//", "Expand"}], "//", 
   "FullSimplify"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.730046872297092*^9, 3.730046879782597*^9}, {
  3.7300478496549377`*^9, 
  3.730047858622703*^9}},ExpressionUUID->"93cefd13-46eb-467b-b8e1-\
8b679616c074"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "bb"}], " ", "c"}], "-", 
  RowBox[{"b", " ", "cc"}], "-", 
  RowBox[{"aa", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b", " ", "bb"}], "+", 
     RowBox[{"c", " ", "cc"}]}], ")"}]}], "-", 
  RowBox[{"bb", " ", "c", " ", "x"}], "-", 
  RowBox[{"b", " ", "cc", " ", "x"}], "+", 
  RowBox[{"bb", " ", "c", " ", "y"}], "-", 
  RowBox[{"b", " ", "cc", " ", "y"}], "-", 
  RowBox[{"bb", " ", "c", " ", "z"}], "+", 
  RowBox[{"b", " ", "cc", " ", "z"}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["aa", "2"], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.730046880500002*^9, {3.7300478517630033`*^9, 
   3.730047859205146*^9}},ExpressionUUID->"365224d0-c0fa-4cff-abbc-\
6e8900925cb7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vvvRule", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "2"}], "]"}], "]"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.730046909841848*^9},ExpressionUUID->"5328f72c-9087-4b2f-91b8-\
4ee900f786d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "a"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"aa", " ", "bb"}], "+", 
     RowBox[{"cc", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{"b", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["bb", "2"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "x", "-", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], "-", 
  RowBox[{"c", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"bb", " ", "cc"}], "+", 
     RowBox[{"aa", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.730046910841628*^9},ExpressionUUID->"53481ff8-b671-44cd-9844-\
4c102fd8df11"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"v1Tov2Rule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "y"}], ",", 
     RowBox[{"y", "\[Rule]", "z"}], ",", 
     RowBox[{"z", "->", "x"}], ",", 
     RowBox[{"a", "\[Rule]", "b"}], ",", 
     RowBox[{"aa", "\[Rule]", "bb"}], ",", 
     RowBox[{"b", "\[Rule]", "c"}], ",", " ", 
     RowBox[{"bb", "\[Rule]", "cc"}], ",", 
     RowBox[{"c", "\[Rule]", "a"}], ",", 
     RowBox[{"cc", "\[Rule]", "aa"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.730046974275568*^9, 3.730047057812142*^9}, {
  3.730047105483247*^9, 3.730047149177944*^9}, {3.730047218383816*^9, 
  3.730047254593173*^9}, {3.730047409448132*^9, 
  3.730047429206555*^9}},ExpressionUUID->"a9b81567-ee6d-439f-92e5-\
1afbdccf455b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"vvvRule", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "//", "FullSimplify"}], 
       ")"}], "/.", "v1Tov2Rule"}], "//", "Simplify"}], ")"}], " ", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"aa", " ", "bb"}], "+", 
        RowBox[{"cc", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
     "+", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["bb", "2"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "x", "-", "y", "-", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
     "-", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"bb", " ", "cc"}], "+", 
        RowBox[{"aa", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
    ")"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.730047291526574*^9, 3.7300473003791733`*^9}, {
  3.730047332831592*^9, 3.7300473343578377`*^9}, {3.730047454495284*^9, 
  3.730047467700933*^9}},ExpressionUUID->"ae0cf2a4-8ac4-414f-beb3-\
b7fd544342d6"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.730047301490609*^9, 3.730047334826442*^9, {3.730047435763122*^9, 
   3.730047468148405*^9}},ExpressionUUID->"78ab691d-8716-443d-927f-\
0ebbbe2404da"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"v1Tov3Rule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "z"}], ",", 
     RowBox[{"y", "\[Rule]", "x"}], ",", 
     RowBox[{"z", "\[Rule]", "y"}], ",", 
     RowBox[{"a", "\[Rule]", "c"}], ",", 
     RowBox[{"aa", "\[Rule]", "cc"}], ",", 
     RowBox[{"b", "\[Rule]", "a"}], ",", " ", 
     RowBox[{"bb", "\[Rule]", "aa"}], ",", 
     RowBox[{"c", "\[Rule]", "b"}], ",", 
     RowBox[{"cc", "\[Rule]", "bb"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.730047515221204*^9, 
  3.730047550461214*^9}},ExpressionUUID->"77b1ddde-8545-4d5c-9a3b-\
862bc78ff7d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"vvvRule", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "//", "FullSimplify"}], 
       ")"}], "/.", "v1Tov3Rule"}], "//", "Simplify"}], ")"}], " ", "-", 
   "\[IndentingNewLine]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", "bb"}], "-", "c", "-", 
     RowBox[{"b", " ", "bb", " ", "cc"}], "-", 
     RowBox[{"a", " ", "bb", " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "+", "z"}], ")"}]}], "+", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["cc", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "y"}], ")"}], "2"], "-", 
        RowBox[{"z", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "z"}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"aa", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "cc"}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
    ")"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.730047572827532*^9, 
  3.730047598787709*^9}},ExpressionUUID->"7fbb1a98-4605-4857-8407-\
341fd5ef0d28"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.730047599204588*^9},ExpressionUUID->"866fd94f-9b6c-4a8b-9cbb-\
e5fb9642c4b2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"v2Tov1Rule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y", "\[Rule]", "x"}], ",", 
     RowBox[{"z", "\[Rule]", "y"}], ",", 
     RowBox[{"x", "\[Rule]", "z"}], ",", 
     RowBox[{"b", "\[Rule]", "a"}], ",", 
     RowBox[{"bb", "\[Rule]", "aa"}], ",", 
     RowBox[{"c", "\[Rule]", "b"}], ",", " ", 
     RowBox[{"cc", "\[Rule]", "bb"}], ",", 
     RowBox[{"a", "\[Rule]", "c"}], ",", 
     RowBox[{"aa", "\[Rule]", "cc"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7300479218504257`*^9, 
  3.730047973273283*^9}},ExpressionUUID->"4ab39b15-2528-4324-b6f0-\
bdd23ee62089"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Must", " ", "invert", " ", "to", " ", "form", " ", "of", " ", "v2"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", "aa", " ", "bb"}], "-", 
     RowBox[{"bb", " ", "c", " ", "cc"}], "+", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["bb", "2"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "x", "-", "y", "-", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
     "-", 
     RowBox[{"a", " ", "cc", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
     RowBox[{"aa", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}], "/.", 
   " ", "v2Tov1Rule"}]}]], "Input",
 CellChangeTimes->{{3.730047897838455*^9, 3.730047906535945*^9}, {
  3.7300479804643087`*^9, 
  3.730048006327889*^9}},ExpressionUUID->"a6e8ed35-fdb3-41ec-9ad1-\
f4f9ae94cdf8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "aa"}], " ", "b", " ", "bb"}], "-", 
  RowBox[{"aa", " ", "c", " ", "cc"}], "-", 
  RowBox[{"b", " ", "cc", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
  RowBox[{"bb", " ", "c", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["aa", "2"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", "x", "-", "y", "+", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.730048007544361*^9},ExpressionUUID->"0ce946b8-0002-4363-abab-\
945ca6622138"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "-", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox["aa", "2"]}], "-", 
     RowBox[{"aa", " ", "b", " ", "bb"}], "-", 
     RowBox[{"bb", " ", "c"}], "-", 
     RowBox[{"b", " ", "cc"}], "-", 
     RowBox[{"aa", " ", "c", " ", "cc"}], "-", 
     RowBox[{"bb", " ", "c", " ", "x"}], "-", 
     RowBox[{"b", " ", "cc", " ", "x"}], "+", 
     RowBox[{"bb", " ", "c", " ", "y"}], "-", 
     RowBox[{"b", " ", "cc", " ", "y"}], "-", 
     RowBox[{"bb", " ", "c", " ", "z"}], "+", 
     RowBox[{"b", " ", "cc", " ", "z"}], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7300480129015923`*^9, 
  3.730048031832183*^9}},ExpressionUUID->"a4aa7674-eb9a-4e25-b821-\
a7fdfeac2adb"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.730048032284012*^9},ExpressionUUID->"64653358-5246-4433-8a4a-\
639bd1532408"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GOT THE RULE:  NOTE - you may want to get rid of the overall canceling minus \
signs.
   To decide, check on some random data, and the numerical Eigenvectors  that \
are returned.\
\>", "Subsubsection",
 CellChangeTimes->{{3.730047485122843*^9, 3.730047488615272*^9}, {
  3.730048468404492*^9, 
  3.730048516659937*^9}},ExpressionUUID->"564f0c08-6fe6-4750-8eea-\
bde2429770e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v1Tov2Rule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "y"}], ",", 
     RowBox[{"y", "\[Rule]", "z"}], ",", 
     RowBox[{"z", "->", "x"}], ",", 
     RowBox[{"a", "\[Rule]", "b"}], ",", 
     RowBox[{"aa", "\[Rule]", "bb"}], ",", 
     RowBox[{"b", "\[Rule]", "c"}], ",", " ", 
     RowBox[{"bb", "\[Rule]", "cc"}], ",", 
     RowBox[{"c", "\[Rule]", "a"}], ",", 
     RowBox[{"cc", "\[Rule]", "aa"}]}], "}"}]}], ";"}]], "Input",ExpressionUUI\
D->"94402875-1b7f-46ba-bb16-766aa1f5a66d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v1Tov3Rule", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "z"}], ",", 
     RowBox[{"y", "\[Rule]", "x"}], ",", 
     RowBox[{"z", "\[Rule]", "y"}], ",", 
     RowBox[{"a", "\[Rule]", "c"}], ",", 
     RowBox[{"aa", "\[Rule]", "cc"}], ",", 
     RowBox[{"b", "\[Rule]", "a"}], ",", " ", 
     RowBox[{"bb", "\[Rule]", "aa"}], ",", 
     RowBox[{"c", "\[Rule]", "b"}], ",", 
     RowBox[{"cc", "\[Rule]", "bb"}]}], "}"}]}], ";"}]], "Input",ExpressionUUI\
D->"1a6217fb-322a-4f78-89ac-47d3ec67276e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"hornA2SRule", ",", "hornS2ARule"}], "}"}]], "Input",
 CellChangeTimes->{{3.73004763488628*^9, 
  3.730047672195414*^9}},ExpressionUUID->"7ba3309a-c851-4b8f-b9a0-\
676145ee206b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "sxx"}], ",", 
     RowBox[{"y", "\[Rule]", "syy"}], ",", 
     RowBox[{"z", "\[Rule]", "szz"}], ",", 
     RowBox[{"a", "\[Rule]", 
      RowBox[{"syz", "-", "szy"}]}], ",", 
     RowBox[{"b", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "sxz"}], "+", "szx"}]}], ",", 
     RowBox[{"c", "\[Rule]", 
      RowBox[{"sxy", "-", "syx"}]}], ",", 
     RowBox[{"cc", "\[Rule]", 
      RowBox[{"sxy", "+", "syx"}]}], ",", 
     RowBox[{"bb", "\[Rule]", 
      RowBox[{"sxz", "+", "szx"}]}], ",", 
     RowBox[{"aa", "\[Rule]", 
      RowBox[{"syz", "+", "szy"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxx", "\[Rule]", "x"}], ",", 
     RowBox[{"syy", "\[Rule]", "y"}], ",", 
     RowBox[{"szz", "\[Rule]", "z"}], ",", 
     RowBox[{
      RowBox[{"syz", "-", "szy"}], "\[Rule]", "a"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "sxz"}], "+", "szx"}], "\[Rule]", "b"}], ",", 
     RowBox[{
      RowBox[{"sxy", "-", "syx"}], "\[Rule]", "c"}], ",", 
     RowBox[{
      RowBox[{"sxy", "+", "syx"}], "\[Rule]", "cc"}], ",", 
     RowBox[{
      RowBox[{"sxz", "+", "szx"}], "\[Rule]", "bb"}], ",", 
     RowBox[{
      RowBox[{"syz", "+", "szy"}], "\[Rule]", "aa"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7300476441868343`*^9, 
  3.730047673391062*^9}},ExpressionUUID->"1022d30a-f326-47a6-b421-\
a83127ed3ef5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rtqZVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"aa_", ",", "bb_", ",", "cc_"}], "}"}]}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", "bb"}], "+", 
       RowBox[{"cc", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"aa", " ", "cc"}], "+", 
      RowBox[{"bb", " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], "-", 
   
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["aa", "2"], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bb", " ", "cc"}], "+", 
      RowBox[{"aa", " ", 
       RowBox[{"(", 
        RowBox[{"3", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
     ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73004844144919*^9, 
  3.7300484501899433`*^9}},ExpressionUUID->"30413919-ddc3-45fe-869f-\
b8eb29cd7829"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rtqVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"aa_", ",", "bb_", ",", "cc_"}], "}"}]}], "]"}], " ", ":=", " ", 
  
  RowBox[{
   RowBox[{
    RowBox[{"-", "aa"}], " ", "b", " ", "bb"}], "-", 
   RowBox[{"aa", " ", "c", " ", "cc"}], "-", 
   RowBox[{"b", " ", "cc", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
   RowBox[{"bb", " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["aa", "2"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", "x", "-", "y", "+", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], 
     ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.730048071299305*^9, 
  3.7300480979448*^9}},ExpressionUUID->"d1db127b-580d-48ef-ba68-1d21e76bacd1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"test", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"rtqVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"aa", ",", "bb", ",", "cc"}], "}"}]}], "]"}], " ", ",", 
    RowBox[{"rtqVec", "[", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{"y", ",", "z", ",", "x"}], "}"}], ",", 
      RowBox[{"{", " ", 
       RowBox[{"b", ",", "c", ",", "a"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"bb", ",", "cc", ",", "aa"}], "}"}]}], "]"}], ",", 
    RowBox[{"rtqVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z", ",", "x", ",", "y"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"c", ",", "a", ",", "b"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"cc", ",", "aa", ",", "bb"}], " ", "}"}]}], "]"}]}], "}"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.730047770407629*^9, 3.730047825747308*^9}, {
  3.730048123711398*^9, 3.730048156136779*^9}, {3.7300481895129147`*^9, 
  3.7300482461691523`*^9}},ExpressionUUID->"2472035c-8a56-4eb0-9981-\
d3418b2958f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "aa"}], " ", "b", " ", "bb"}], "-", 
    RowBox[{"aa", " ", "c", " ", "cc"}], "-", 
    RowBox[{"b", " ", "cc", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
    RowBox[{"bb", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["aa", "2"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", "x", "-", "y", "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "aa", " ", "bb"}], "-", 
    RowBox[{"bb", " ", "c", " ", "cc"}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["bb", "2"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "x", "-", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"a", " ", "cc", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
    RowBox[{"aa", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "aa", " ", "cc"}], "-", 
    RowBox[{"b", " ", "bb", " ", "cc"}], "-", 
    RowBox[{"a", " ", "bb", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x", "-", "y", "+", "z"}], ")"}]}], "-", 
    RowBox[{"aa", " ", "b", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["cc", "2"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", "x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.730048249045814*^9},ExpressionUUID->"17f9543f-c0a6-4550-a7dc-\
c52552ce8b3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"test", "-", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"vvvRule", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.730048258622081*^9, 
  3.730048295419581*^9}},ExpressionUUID->"33f14055-47d6-4c0e-b767-\
891d5069fe7f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.730048295885889*^9},ExpressionUUID->"c6899f01-8391-4bac-ad0f-\
f9babe82933e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figure out substitutions: sxx ->  xyzabcABC  - need \
v1,v2,v3 permutation concept",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.730044126631565*^9, 3.730044142591529*^9}, {
  3.730045151871574*^9, 
  3.73004517751152*^9}},ExpressionUUID->"2a597259-8922-4d10-9997-\
c726d540a2d1"],

Cell[CellGroupData[{

Cell[BoxData["hornAmat"], "Input",
 CellChangeTimes->{{3.7300441506826973`*^9, 
  3.7300441556319513`*^9}},ExpressionUUID->"80f748d4-9c1a-42ef-905d-\
ba63c8b78ef5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "+", "y", "+", "z"}], ",", "a", ",", "b", ",", "c"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"x", "-", "y", "-", "z"}], ",", "cc", ",", "bb"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "cc", ",", 
     RowBox[{
      RowBox[{"-", "x"}], "+", "y", "-", "z"}], ",", "aa"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "bb", ",", "aa", ",", 
     RowBox[{
      RowBox[{"-", "x"}], "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730044158996039*^9},ExpressionUUID->"59ad59da-9cba-4e97-8081-\
6cabb5628015"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["hornA2SRule"], "Input",
 CellChangeTimes->{{3.730044161706258*^9, 
  3.7300441664020367`*^9}},ExpressionUUID->"498bc3d4-485b-42f6-abf1-\
f8bfd362fa47"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "sxx"}], ",", 
   RowBox[{"y", "\[Rule]", "syy"}], ",", 
   RowBox[{"z", "\[Rule]", "szz"}], ",", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"syz", "-", "szy"}]}], ",", 
   RowBox[{"b", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "sxz"}], "+", "szx"}]}], ",", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"sxy", "-", "syx"}]}], ",", 
   RowBox[{"cc", "\[Rule]", 
    RowBox[{"sxy", "+", "syx"}]}], ",", 
   RowBox[{"bb", "\[Rule]", 
    RowBox[{"sxz", "+", "szx"}]}], ",", 
   RowBox[{"aa", "\[Rule]", 
    RowBox[{"syz", "+", "szy"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730044167159137*^9},ExpressionUUID->"fdb47613-9391-4d1b-9b38-\
171c79d808d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["hornS2ARule"], "Input",
 CellChangeTimes->{{3.730044180612598*^9, 
  3.7300441854371023`*^9}},ExpressionUUID->"c46b4d97-e86d-4690-aacf-\
95fbbe29c098"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"sxx", "\[Rule]", "x"}], ",", 
   RowBox[{"syy", "\[Rule]", "y"}], ",", 
   RowBox[{"szz", "\[Rule]", "z"}], ",", 
   RowBox[{
    RowBox[{"syz", "-", "szy"}], "\[Rule]", "a"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "sxz"}], "+", "szx"}], "\[Rule]", "b"}], ",", 
   RowBox[{
    RowBox[{"sxy", "-", "syx"}], "\[Rule]", "c"}], ",", 
   RowBox[{
    RowBox[{"sxy", "+", "syx"}], "\[Rule]", "cc"}], ",", 
   RowBox[{
    RowBox[{"sxz", "+", "szx"}], "\[Rule]", "bb"}], ",", 
   RowBox[{
    RowBox[{"syz", "+", "szy"}], "\[Rule]", "aa"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7300441862365093`*^9},ExpressionUUID->"07f4ad45-6128-4da0-8c66-\
9f1723a93be0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"theR2QEigvecs", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"v0", "->", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", "9"], " ", 
             RowBox[{"(", 
              RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "9"], " ", 
            RowBox[{"(", 
             RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "9"]}], " ", 
            RowBox[{"(", 
             RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"syz", "+", "szy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], ")"}]}]}],
           ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "9"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"syz", "+", "szy"}], ")"}], "2"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
             ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"v1", " ", "->", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["1", "9"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
              RowBox[{
               FractionBox["1", "9"], " ", 
               RowBox[{"(", 
                RowBox[{"syz", "-", "szy"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "9"], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               FractionBox["1", "9"]}], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "9"], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "-", "szy"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}], ")"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"v2", "->", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "9"]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
              RowBox[{
               FractionBox["1", "9"], " ", 
               RowBox[{"(", 
                RowBox[{"syz", "-", "szy"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "9"], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               FractionBox["1", "9"]}], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "9"], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}], ")"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"v3", "->", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               FractionBox["1", "9"]}], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               FractionBox["1", "9"]}], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}]}], "+", 
             RowBox[{
              FractionBox["1", "9"], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "-", "szy"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}], 
           "\[IndentingNewLine]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "9"], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}], ")"}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7300442016436043`*^9, 
  3.730044281193706*^9}},ExpressionUUID->"622b51cc-9f82-4671-8b6e-\
70861ddddb79"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theR2QEigvecsXYZ", "=", " ", 
  RowBox[{
   RowBox[{"theR2QEigvecs", "/.", "hornS2ARule"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7300442992554493`*^9, 
  3.730044330574518*^9}},ExpressionUUID->"625a1e91-f67f-4167-8181-\
505a1183f64d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"v0", "\[Rule]", 
    RowBox[{
     FractionBox["1", "81"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"aa", " ", "bb"}], "+", 
           RowBox[{"cc", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
        " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "cc"}], "+", 
          RowBox[{"bb", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], 
       "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["aa", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bb", " ", "cc"}], "+", 
          RowBox[{"aa", " ", 
           RowBox[{"(", 
            RowBox[{"3", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}],
       ")"}]}]}], ",", 
   RowBox[{"v1", "\[Rule]", 
    RowBox[{
     FractionBox["1", "81"], " ", "bb", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        SuperscriptBox["aa", "2"]}], "+", 
       RowBox[{"aa", " ", "b", " ", "bb"}], "+", 
       RowBox[{"3", " ", "bb", " ", "c"}], "+", 
       RowBox[{"3", " ", "b", " ", "cc"}], "+", 
       RowBox[{"aa", " ", "c", " ", "cc"}], "+", 
       RowBox[{"bb", " ", "c", " ", "x"}], "+", 
       RowBox[{"b", " ", "cc", " ", "x"}], "-", 
       RowBox[{"bb", " ", "c", " ", "y"}], "+", 
       RowBox[{"b", " ", "cc", " ", "y"}], "+", 
       RowBox[{"bb", " ", "c", " ", "z"}], "-", 
       RowBox[{"b", " ", "cc", " ", "z"}], "+", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
   ",", 
   RowBox[{"v2", "\[Rule]", 
    RowBox[{
     FractionBox["1", "81"], " ", "aa", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "aa", " ", "bb"}], "+", 
       RowBox[{"bb", " ", "c", " ", "cc"}], "-", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["bb", "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x", "-", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], ")"}]}], 
       "+", 
       RowBox[{"a", " ", "cc", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "x", "+", "y", "-", "z"}], ")"}]}], "+", 
       RowBox[{"aa", " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
   ",", 
   RowBox[{"v3", "\[Rule]", 
    RowBox[{
     FractionBox["1", "81"], " ", "aa", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "bb", " ", "cc"}], "+", 
       RowBox[{"a", " ", "bb", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}], "-", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["cc", "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x", "-", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ")"}]}], 
       "+", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", "cc"}], "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{"3", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ")"}]}]}],
       ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.730044312370802*^9, 
  3.73004433475653*^9}},ExpressionUUID->"24a7a406-ec94-4dfa-83ad-\
2f0e42ca958f"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theR2QEigvecsXYZ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "\[Rule]", " ", 
      RowBox[{"81", " ", 
       RowBox[{"(", 
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ")"}]}]}], "&"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"theR2QEigvecs", "/.", "hornS2ARule"}], "//", "Expand"}], "//",
         "Simplify"}], ")"}], "//", "Expand"}], "//", "Factor"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7300442992554493`*^9, 3.730044330574518*^9}, {
  3.730044505856309*^9, 3.730044514140608*^9}, {3.730044570078825*^9, 
  3.730044667851419*^9}},ExpressionUUID->"20818587-7d5c-4b72-9671-\
a81a127c0071"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"v0", "\[Rule]", 
    RowBox[{"aa", " ", 
     RowBox[{"(", 
      RowBox[{"27", "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["aa", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["bb", "2"]}], "-", 
       RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["cc", "2"]}], "+", 
       RowBox[{"9", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", "x"}], "-", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", "x"}], "-", 
       RowBox[{
        SuperscriptBox["cc", "2"], " ", "x"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       SuperscriptBox["x", "3"], "+", 
       RowBox[{"9", " ", "y"}], "-", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", "y"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", "y"}], "-", 
       RowBox[{
        SuperscriptBox["cc", "2"], " ", "y"}], "+", 
       RowBox[{"6", " ", "x", " ", "y"}], "+", 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "y"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"x", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       SuperscriptBox["y", "3"], "+", 
       RowBox[{"9", " ", "z"}], "-", 
       RowBox[{
        SuperscriptBox["aa", "2"], " ", "z"}], "-", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", "z"}], "+", 
       RowBox[{
        SuperscriptBox["cc", "2"], " ", "z"}], "+", 
       RowBox[{"6", " ", "x", " ", "z"}], "+", 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "z"}], "+", 
       RowBox[{"6", " ", "y", " ", "z"}], "-", 
       RowBox[{"2", " ", "x", " ", "y", " ", "z"}], "+", 
       RowBox[{
        SuperscriptBox["y", "2"], " ", "z"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"x", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"y", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       SuperscriptBox["z", "3"]}], ")"}]}]}], ",", 
   RowBox[{"v1", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "bb"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "9"}], " ", "a"}], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["aa", "2"]}], "-", 
       RowBox[{"aa", " ", "b", " ", "bb"}], "-", 
       RowBox[{"3", " ", "bb", " ", "c"}], "-", 
       RowBox[{"3", " ", "b", " ", "cc"}], "-", 
       RowBox[{"aa", " ", "c", " ", "cc"}], "-", 
       RowBox[{"6", " ", "a", " ", "x"}], "-", 
       RowBox[{"bb", " ", "c", " ", "x"}], "-", 
       RowBox[{"b", " ", "cc", " ", "x"}], "-", 
       RowBox[{"a", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"bb", " ", "c", " ", "y"}], "-", 
       RowBox[{"b", " ", "cc", " ", "y"}], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"bb", " ", "c", " ", "z"}], "+", 
       RowBox[{"b", " ", "cc", " ", "z"}], "-", 
       RowBox[{"2", " ", "a", " ", "y", " ", "z"}], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["z", "2"]}]}], ")"}]}]}], ",", 
   RowBox[{"v2", "\[Rule]", 
    RowBox[{"aa", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", "b"}], "+", 
       RowBox[{"a", " ", "aa", " ", "bb"}], "-", 
       RowBox[{"b", " ", 
        SuperscriptBox["bb", "2"]}], "+", 
       RowBox[{"3", " ", "aa", " ", "c"}], "+", 
       RowBox[{"3", " ", "a", " ", "cc"}], "+", 
       RowBox[{"bb", " ", "c", " ", "cc"}], "-", 
       RowBox[{"aa", " ", "c", " ", "x"}], "+", 
       RowBox[{"a", " ", "cc", " ", "x"}], "-", 
       RowBox[{"b", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"6", " ", "b", " ", "y"}], "+", 
       RowBox[{"aa", " ", "c", " ", "y"}], "+", 
       RowBox[{"a", " ", "cc", " ", "y"}], "+", 
       RowBox[{"b", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"aa", " ", "c", " ", "z"}], "-", 
       RowBox[{"a", " ", "cc", " ", "z"}], "+", 
       RowBox[{"2", " ", "b", " ", "x", " ", "z"}], "-", 
       RowBox[{"b", " ", 
        SuperscriptBox["z", "2"]}]}], ")"}]}]}], ",", 
   RowBox[{"v3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "aa"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "aa", " ", "b"}], "-", 
       RowBox[{"3", " ", "a", " ", "bb"}], "-", 
       RowBox[{"9", " ", "c"}], "-", 
       RowBox[{"a", " ", "aa", " ", "cc"}], "-", 
       RowBox[{"b", " ", "bb", " ", "cc"}], "+", 
       RowBox[{"c", " ", 
        SuperscriptBox["cc", "2"]}], "+", 
       RowBox[{"aa", " ", "b", " ", "x"}], "-", 
       RowBox[{"a", " ", "bb", " ", "x"}], "+", 
       RowBox[{"c", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"aa", " ", "b", " ", "y"}], "+", 
       RowBox[{"a", " ", "bb", " ", "y"}], "-", 
       RowBox[{"2", " ", "c", " ", "x", " ", "y"}], "+", 
       RowBox[{"c", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"aa", " ", "b", " ", "z"}], "-", 
       RowBox[{"a", " ", "bb", " ", "z"}], "-", 
       RowBox[{"6", " ", "c", " ", "z"}], "-", 
       RowBox[{"c", " ", 
        SuperscriptBox["z", "2"]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730044694542138*^9},ExpressionUUID->"23d28412-7032-4fc0-b668-\
1fa5fd059390"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TODO - convert these to a single function of 9 args", "Subsubsection",
 CellChangeTimes->{{3.7300449461363363`*^9, 
  3.7300449719125433`*^9}},ExpressionUUID->"4bf5fce4-1258-4005-bb88-\
b7d43e00d065"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"hornSmat", "//", "MatrixForm"}], ",", 
   RowBox[{"hornAmat", "//", "MatrixForm"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.7300453731389227`*^9, 
  3.7300454255003347`*^9}},ExpressionUUID->"085b53e7-059a-4b20-928d-\
54afb950ac4e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"sxx", "+", "syy", "+", "szz"}], 
        RowBox[{"syz", "-", "szy"}], 
        RowBox[{
         RowBox[{"-", "sxz"}], "+", "szx"}], 
        RowBox[{"sxy", "-", "syx"}]},
       {
        RowBox[{"syz", "-", "szy"}], 
        RowBox[{"sxx", "-", "syy", "-", "szz"}], 
        RowBox[{"sxy", "+", "syx"}], 
        RowBox[{"sxz", "+", "szx"}]},
       {
        RowBox[{
         RowBox[{"-", "sxz"}], "+", "szx"}], 
        RowBox[{"sxy", "+", "syx"}], 
        RowBox[{
         RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], 
        RowBox[{"syz", "+", "szy"}]},
       {
        RowBox[{"sxy", "-", "syx"}], 
        RowBox[{"sxz", "+", "szx"}], 
        RowBox[{"syz", "+", "szy"}], 
        RowBox[{
         RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"x", "+", "y", "+", "z"}], "a", "b", "c"},
       {"a", 
        RowBox[{"x", "-", "y", "-", "z"}], "cc", "bb"},
       {"b", "cc", 
        RowBox[{
         RowBox[{"-", "x"}], "+", "y", "-", "z"}], "aa"},
       {"c", "bb", "aa", 
        RowBox[{
         RowBox[{"-", "x"}], "-", "y", "+", "z"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.730045383222301*^9, 3.730045393323639*^9}, 
   3.73004542580042*^9},ExpressionUUID->"b8fb0225-b80f-4707-a82e-\
5cf7c105191d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1abc", "=", 
  RowBox[{
   RowBox[{"v1", "/.", "theR2QEigvecsXYZ"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7300447295234623`*^9, 3.730044742797983*^9}, {
  3.73004629984664*^9, 
  3.7300463032228107`*^9}},ExpressionUUID->"cc287a30-238e-4b8a-bafe-\
5016934bb222"],

Cell[BoxData[
 RowBox[{
  RowBox[{"9", " ", "a", " ", "bb"}], "-", 
  RowBox[{"a", " ", 
   SuperscriptBox["aa", "2"], " ", "bb"}], "+", 
  RowBox[{"aa", " ", "b", " ", 
   SuperscriptBox["bb", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["bb", "2"], " ", "c"}], "+", 
  RowBox[{"3", " ", "b", " ", "bb", " ", "cc"}], "+", 
  RowBox[{"aa", " ", "bb", " ", "c", " ", "cc"}], "+", 
  RowBox[{"6", " ", "a", " ", "bb", " ", "x"}], "+", 
  RowBox[{
   SuperscriptBox["bb", "2"], " ", "c", " ", "x"}], "+", 
  RowBox[{"b", " ", "bb", " ", "cc", " ", "x"}], "+", 
  RowBox[{"a", " ", "bb", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["bb", "2"], " ", "c", " ", "y"}], "+", 
  RowBox[{"b", " ", "bb", " ", "cc", " ", "y"}], "-", 
  RowBox[{"a", " ", "bb", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["bb", "2"], " ", "c", " ", "z"}], "-", 
  RowBox[{"b", " ", "bb", " ", "cc", " ", "z"}], "+", 
  RowBox[{"2", " ", "a", " ", "bb", " ", "y", " ", "z"}], "-", 
  RowBox[{"a", " ", "bb", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.730044733807108*^9, 3.730044743455605*^9}, 
   3.730046306120307*^9},ExpressionUUID->"3ae63459-2e9b-4f73-b3c3-\
632bd37f735a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v2abc", "=", 
  RowBox[{
   RowBox[{"v2", "/.", "theR2QEigvecsXYZ"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.730044750778886*^9, {3.730046310127441*^9, 
   3.730046311934811*^9}},ExpressionUUID->"7947e3d4-3de1-4274-9eaf-\
47bdd6569680"],

Cell[BoxData[
 RowBox[{
  RowBox[{"9", " ", "aa", " ", "b"}], "+", 
  RowBox[{"a", " ", 
   SuperscriptBox["aa", "2"], " ", "bb"}], "-", 
  RowBox[{"aa", " ", "b", " ", 
   SuperscriptBox["bb", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["aa", "2"], " ", "c"}], "+", 
  RowBox[{"3", " ", "a", " ", "aa", " ", "cc"}], "+", 
  RowBox[{"aa", " ", "bb", " ", "c", " ", "cc"}], "-", 
  RowBox[{
   SuperscriptBox["aa", "2"], " ", "c", " ", "x"}], "+", 
  RowBox[{"a", " ", "aa", " ", "cc", " ", "x"}], "-", 
  RowBox[{"aa", " ", "b", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"6", " ", "aa", " ", "b", " ", "y"}], "+", 
  RowBox[{
   SuperscriptBox["aa", "2"], " ", "c", " ", "y"}], "+", 
  RowBox[{"a", " ", "aa", " ", "cc", " ", "y"}], "+", 
  RowBox[{"aa", " ", "b", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["aa", "2"], " ", "c", " ", "z"}], "-", 
  RowBox[{"a", " ", "aa", " ", "cc", " ", "z"}], "+", 
  RowBox[{"2", " ", "aa", " ", "b", " ", "x", " ", "z"}], "-", 
  RowBox[{"aa", " ", "b", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{3.730044751550598*^9, 
  3.730046312430991*^9},ExpressionUUID->"7b89ef2a-3368-4a6f-8634-\
a36399c83651"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v3abc", "=", 
  RowBox[{
   RowBox[{"v3", "/.", "theR2QEigvecsXYZ"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.730044803322988*^9, {3.7300463156788387`*^9, 
   3.730046317518759*^9}},ExpressionUUID->"5cb3d48f-a599-4869-b5e4-\
d24241a8c117"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   SuperscriptBox["aa", "2"], " ", "b"}], "+", 
  RowBox[{"3", " ", "a", " ", "aa", " ", "bb"}], "+", 
  RowBox[{"9", " ", "aa", " ", "c"}], "+", 
  RowBox[{"a", " ", 
   SuperscriptBox["aa", "2"], " ", "cc"}], "+", 
  RowBox[{"aa", " ", "b", " ", "bb", " ", "cc"}], "-", 
  RowBox[{"aa", " ", "c", " ", 
   SuperscriptBox["cc", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["aa", "2"], " ", "b", " ", "x"}], "+", 
  RowBox[{"a", " ", "aa", " ", "bb", " ", "x"}], "-", 
  RowBox[{"aa", " ", "c", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["aa", "2"], " ", "b", " ", "y"}], "-", 
  RowBox[{"a", " ", "aa", " ", "bb", " ", "y"}], "+", 
  RowBox[{"2", " ", "aa", " ", "c", " ", "x", " ", "y"}], "-", 
  RowBox[{"aa", " ", "c", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["aa", "2"], " ", "b", " ", "z"}], "+", 
  RowBox[{"a", " ", "aa", " ", "bb", " ", "z"}], "+", 
  RowBox[{"6", " ", "aa", " ", "c", " ", "z"}], "+", 
  RowBox[{"aa", " ", "c", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{3.730044804707696*^9, 
  3.730046318660306*^9},ExpressionUUID->"90f87150-eada-4f85-8b8f-\
140621749201"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
***** Summary of the RotToQuat:  ***  
          This sign matches numerical Eigenvectors:\
\>", "Section",
 CellChangeTimes->{{3.73004278802715*^9, 
  3.730042852984473*^9}},ExpressionUUID->"32a0bcaf-052e-4fb3-a724-\
488027d914f6"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Making the samples:  rot3Dlist = \
genUniformQuatSample// QuatToRot",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.730043189152776*^9, 3.730043205528319*^9}, {
  3.730043242631768*^9, 
  3.73004327158399*^9}},ExpressionUUID->"69fa5f77-e559-46f1-bd9a-\
623fecda5ccb"],

Cell[TextData[StyleBox["Maybe better to do this with random Quat uniform \
distribution... ?",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.729821920294194*^9, 
  3.729821943238741*^9}},ExpressionUUID->"d1846b9f-6dae-4c8d-bf4f-\
2377d99a9f36"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genUniformQuatSample", "[", "n_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"0.2", "\[LessEqual]", " ", 
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "1.0"}], ",", 
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", 
             RowBox[{"Normalize", "[", "test", "]"}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", "out"}]}], "]"}]}]], "Input",ExpressionUUID->"a25d2c8c-2e6a-\
46aa-bf60-312699149a2c"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.729967401393663*^9, 
  3.729967428820677*^9}},ExpressionUUID->"7c901581-f4a8-4825-8fdf-\
56e1f25c3bd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatSampleList", " ", "=", " ", 
   RowBox[{"genUniformQuatSample", "[", "1000", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7299679654345703`*^9, 
  3.729967978072134*^9}},ExpressionUUID->"824468ef-6687-43c4-a599-\
56ee010d8dcb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"First", "/@", "quatSampleList"}], ",", "30"}], "]"}]], "Input",
 CellChangeTimes->{{3.729967987810698*^9, 
  3.729968020283763*^9}},ExpressionUUID->"78ee4dc3-567d-4c01-9f61-\
7d8597332f4e"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.40599999999999997`], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.40599999999999997`], Thickness[Small]}], 
     RectangleBox[{-1., 0}, {-0.95, 3.},
      RoundingRadius->0], RectangleBox[{-0.95, 0}, {-0.9, 10.},
      RoundingRadius->0], RectangleBox[{-0.9, 0}, {-0.85, 10.},
      RoundingRadius->0], RectangleBox[{-0.85, 0}, {-0.8, 17.},
      RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.75, 23.},
      RoundingRadius->0], RectangleBox[{-0.75, 0}, {-0.7, 21.},
      RoundingRadius->0], RectangleBox[{-0.7, 0}, {-0.65, 22.},
      RoundingRadius->0], RectangleBox[{-0.65, 0}, {-0.6, 23.},
      RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.55, 26.},
      RoundingRadius->0], RectangleBox[{-0.55, 0}, {-0.5, 16.},
      RoundingRadius->0], RectangleBox[{-0.5, 0}, {-0.45, 28.},
      RoundingRadius->0], RectangleBox[{-0.45, 0}, {-0.4, 24.},
      RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.35, 28.},
      RoundingRadius->0], RectangleBox[{-0.35, 0}, {-0.3, 37.},
      RoundingRadius->0], RectangleBox[{-0.3, 0}, {-0.25, 37.},
      RoundingRadius->0], RectangleBox[{-0.25, 0}, {-0.2, 35.},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {-0.15, 27.},
      RoundingRadius->0], RectangleBox[{-0.15, 0}, {-0.1, 29.},
      RoundingRadius->0], RectangleBox[{-0.1, 0}, {-0.05, 29.},
      RoundingRadius->0], RectangleBox[{-0.05, 0}, {0., 35.},
      RoundingRadius->0], RectangleBox[{0., 0}, {0.05, 30.},
      RoundingRadius->0], RectangleBox[{0.05, 0}, {0.1, 30.},
      RoundingRadius->0], RectangleBox[{0.1, 0}, {0.15, 35.},
      RoundingRadius->0], RectangleBox[{0.15, 0}, {0.2, 34.},
      RoundingRadius->0], RectangleBox[{0.2, 0}, {0.25, 37.},
      RoundingRadius->0], RectangleBox[{0.25, 0}, {0.3, 25.},
      RoundingRadius->0], RectangleBox[{0.3, 0}, {0.35, 41.},
      RoundingRadius->0], RectangleBox[{0.35, 0}, {0.4, 30.},
      RoundingRadius->0], RectangleBox[{0.4, 0}, {0.45, 34.},
      RoundingRadius->0], RectangleBox[{0.45, 0}, {0.5, 25.},
      RoundingRadius->0], RectangleBox[{0.5, 0}, {0.55, 37.},
      RoundingRadius->0], RectangleBox[{0.55, 0}, {0.6, 24.},
      RoundingRadius->0], RectangleBox[{0.6, 0}, {0.65, 23.},
      RoundingRadius->0], RectangleBox[{0.65, 0}, {0.7, 18.},
      RoundingRadius->0], RectangleBox[{0.7, 0}, {0.75, 28.},
      RoundingRadius->0], RectangleBox[{0.75, 0}, {0.8, 20.},
      RoundingRadius->0], RectangleBox[{0.8, 0}, {0.85, 17.},
      RoundingRadius->0], RectangleBox[{0.85, 0}, {0.9, 12.},
      RoundingRadius->0], RectangleBox[{0.9, 0}, {0.95, 10.},
      RoundingRadius->0], RectangleBox[{0.95, 0}, {1., 10.},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-1.04, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-1., 1.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.729968005834536*^9, 
  3.729968021006813*^9}},ExpressionUUID->"700fcaf9-13a7-4665-a6e3-\
2d3713696c07"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rot3DList", " ", "=", "  ", 
   RowBox[{"QuatToRot", "/@", "quatSampleList"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729967349122163*^9, 3.729967387853169*^9}, {
  3.729968039447689*^9, 3.729968057375125*^9}, {3.729968727586028*^9, 
  3.7299687283771353`*^9}},ExpressionUUID->"a0eb6fdd-41d9-45fa-aab1-\
efc97b5aab2e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Det", "/@", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "4"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729968065753916*^9, 
  3.729968079727211*^9}},ExpressionUUID->"e95eb5a4-f387-421e-ae6d-\
3759fafbbbc3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.0000000000000002`", ",", "1.`", ",", "1.`", ",", "1.0000000000000002`"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.7299680809312963`*^9},ExpressionUUID->"dde9f8e1-457d-4667-9ac9-\
36f32527d0f7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"quatCheckList", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"uniformRotToQuat", ",", "rot3DList"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729968356204636*^9, 
  3.729968357124238*^9}},ExpressionUUID->"522f2206-df5c-4365-912d-\
14e400295800"],

Cell[BoxData[
 RowBox[{
  RowBox[{"barMat3DList", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"makeBarIzMat", ",", "rot3DList"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729966465885948*^9, 3.729966466341763*^9}, 
   3.7299681545188*^9},ExpressionUUID->"27b0dbec-18c5-46bd-be7a-f18dcf5b0d77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["In Horn xx[p] formula,\n     MUST account for \
ArcTan[0,0] = 0, and then you get the  ortho-matrix limit ->\nxx,yy,zz all = \
1/9,  eigenvalues = {1, -1/3, -1/3, -1/3}",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.729966186711382*^9, 3.729966244647458*^9}, {
  3.7300429406587963`*^9, 
  3.7300429623304033`*^9}},ExpressionUUID->"2868eda6-ad11-4944-8b52-\
11a861e8d383"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeBarIzMat", "[", "rot3D_", "]"}], " ", ":=", "  ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", "=", "rot3D"}], "}"}], ",", 
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "-", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"m", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}]}], "}"}]}], 
       "}"}]}]}], "]"}]}], "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729739665530719*^9, 3.7297399624809933`*^9}, {
   3.729739997617916*^9, 3.7297400089283524`*^9}, 3.729782321373281*^9, 
   3.729784236334249*^9, 3.729785042554781*^9, {3.729785126543738*^9, 
   3.729785128982798*^9}, {3.729797177668494*^9, 3.729797178043521*^9}, 
   3.7297972522047358`*^9, 3.7297974720780067`*^9, {3.7298196857936172`*^9, 
   3.7298197128205757`*^9}, {3.729857816884253*^9, 3.729857875293354*^9}, {
   3.72996138541803*^9, 
   3.729961387928483*^9}},ExpressionUUID->"240bc202-8e00-4703-8ef8-\
5c078e3394b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeBarIzMat", "[", 
  RowBox[{"QuatToRot", "[", 
   RowBox[{"{", 
    RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7300429883621893`*^9, 
  3.730043001402739*^9}},ExpressionUUID->"4e6eeb9c-51e7-4abf-9509-\
78a82e702d81"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q1"}], "3"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q2"}], "3"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q3"}], "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q1"}], "3"]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q1", "2"]}], "-", 
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q2"}], "3"], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q3"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q2"}], "3"]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q2"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q2", "2"]}], "-", 
        SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q2", " ", "q3"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "q0", " ", "q3"}], "3"]}], ",", 
     FractionBox[
      RowBox[{"4", " ", "q1", " ", "q3"}], "3"], ",", 
     FractionBox[
      RowBox[{"4", " ", "q2", " ", "q3"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["q0", "2"]}], "-", 
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["q2", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["q3", "2"]}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730043002850822*^9},ExpressionUUID->"545965ab-d797-4a23-821c-\
450d21304c6f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Eigensystem", "[", "%", "]"}], "//", "Simplify"}], ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["q0", "2"]}], "-", 
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["q3", "2"]}], "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.730043011974142*^9, 3.73004302240204*^9}, {
  3.73004310217723*^9, 
  3.730043106808333*^9}},ExpressionUUID->"ae712fb2-38a1-4d4b-9b4e-\
a72fa4af38a7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["q3", "q0"], ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["q2", "q0"], ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["q1", "q0"], ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["q0", "q3"]}], ",", 
       FractionBox["q1", "q3"], ",", 
       FractionBox["q2", "q3"], ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.730043108424048*^9},ExpressionUUID->"d0055a4e-2c44-47f4-a67a-\
6a1cecb0ff4c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"sxxMat3", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sxx", ",", "sxy", ",", "sxz"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"syx", ",", "syy", ",", "syz"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"szx", ",", "szy", ",", "szz"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.730043972378046*^9, 
  3.7300439730773907`*^9}},ExpressionUUID->"1e0094ff-a2f2-4d25-9279-\
5fe77ac789b6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sxxBarMat4", "=", 
  RowBox[{"makeBarIzMat", "[", "sxxMat3", "]"}]}]], "Input",
 CellChangeTimes->{{3.7299711127349863`*^9, 3.729971140468384*^9}, {
  3.729972281995059*^9, 
  3.729972290682444*^9}},ExpressionUUID->"2a2ec4af-9732-42d3-9cf0-\
3ce268a2b6dc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"sxx", "+", "syy", "+", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"syz", "-", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "-", "syx"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"syz", "-", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "+", "syx"}], "3"], ",", 
     FractionBox[
      RowBox[{"sxz", "+", "szx"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxz"}], "+", "szx"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"sxy", "+", "syx"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"syz", "+", "szy"}], "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"sxy", "-", "syx"}], "3"], ",", 
     FractionBox[
      RowBox[{"sxz", "+", "szx"}], "3"], ",", 
     FractionBox[
      RowBox[{"syz", "+", "szy"}], "3"], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.729971141591793*^9, 
  3.729972292234074*^9},ExpressionUUID->"9804546f-c538-41da-b975-\
c9caad7ab325"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"theRotToQuat4", "[", "mat3_List", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vv", ",", "v1", ",", "v2", ",", "v3", ",", "v0", ",", 
      RowBox[{"m", "=", "mat3"}]}], "}"}], ",", "\[IndentingNewLine]", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sxx", " ", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"sxy", "=", " ", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"sxz", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"syx", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"syy", " ", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"syz", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"szx", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"szy", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"szz", "=", 
         RowBox[{"m", "\[LeftDoubleBracket]", 
          RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"v0", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["1", "9"], " ", 
               RowBox[{"(", 
                RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  FractionBox["1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                 ")"}]}]}], ")"}]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "9"], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               FractionBox["1", "9"]}], " ", 
              RowBox[{"(", 
               RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"syz", "+", "szy"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "9"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"syz", "+", "szy"}], ")"}], "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 FractionBox["1", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"v1", " ", "=", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "-", "szy"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", "9"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                  ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "9"]}], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}]}], "+", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                  ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", "9"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"sxz", "+", "szx"}], ")"}]}], "-", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "-", "szy"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                  ")"}]}]}], ")"}]}]}], ")"}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"v2", "=", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "9"]}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
                RowBox[{
                 FractionBox["1", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "-", "szy"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", "9"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                  ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "9"]}], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
                 ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", "9"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "-", "syy", "+", "szz"}], ")"}]}]}],
                  ")"}]}]}], ")"}]}]}], ")"}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"v3", "=", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "9"]}], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"sxz", "+", "szx"}], ")"}]}], "+", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"sxx", "-", "syy", "-", "szz"}], ")"}]}]}], 
                 ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", "9"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "sxz"}], "+", "szx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                  ")"}]}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "9"]}], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "-", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "+", "syx"}], ")"}]}], "+", 
               RowBox[{
                FractionBox["1", "9"], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "-", "szy"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", "9"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxy", "+", "syx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"syz", "+", "szy"}], ")"}]}], "-", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"sxz", "+", "szx"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   FractionBox["1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "sxx"}], "+", "syy", "-", "szz"}], ")"}]}]}],
                  ")"}]}]}], ")"}]}]}], ")"}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "The", " ", "INVERSE", " ", "is", " ", "the", " ", "solution"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"vv", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"v0", ",", 
          RowBox[{"-", "v1"}], ",", 
          RowBox[{"-", "v2"}], ",", 
          RowBox[{"-", "v3"}]}], "}"}]}], ";", "  ", 
       RowBox[{"Normalize", "[", "vv", "]"}]}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.729972969276599*^9, 3.72997303963441*^9}, {
   3.7299910510579557`*^9, 3.7299912207665462`*^9}, {3.7299913697777243`*^9, 
   3.729991373993952*^9}, {3.729991789198868*^9, 3.7299918043466873`*^9}, 
   3.729991993891129*^9, 3.729992048004306*^9, {3.729992182246468*^9, 
   3.729992221027707*^9}, {3.729992252448661*^9, 3.7299922575991697`*^9}, 
   3.730042179996223*^9, {3.73004223106734*^9, 3.7300422410158157`*^9}, {
   3.7300422871795*^9, 3.7300422996965437`*^9}, {3.7300440529412193`*^9, 
   3.730044065166492*^9}},ExpressionUUID->"0df779e9-a3c8-4163-adfe-\
5b02ad2573f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rot3DList", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7300424610731792`*^9, 
  3.730042476670735*^9}},ExpressionUUID->"916d03fc-9bc9-42b1-829b-\
3948d06c3dc4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9756783221675079`"}], ",", 
     RowBox[{"-", "0.08204400271671086`"}], ",", "0.2032746744447428`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.025377800663047755`"}], ",", 
     RowBox[{"-", "0.8788056640596922`"}], ",", 
     RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21773327464102138`", ",", 
     RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730042477661798*^9},ExpressionUUID->"6e836af4-464e-4e74-8509-\
3f871f6b884a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeBarIzMat", "[", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.730042541191999*^9, 
  3.730042552501938*^9}},ExpressionUUID->"dd11988c-aa5a-46df-92d9-\
11f3578bf623"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.33304481558422655`"}], ",", 
     RowBox[{"-", "0.0021435752075137`"}], ",", "0.004819533398759531`", ",", 
     
     RowBox[{"-", "0.018888734017887703`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0021435752075137`"}], ",", 
     RowBox[{"-", "0.317407399194112`"}], ",", 
     RowBox[{"-", "0.03580726779325287`"}], ",", "0.14033598302858805`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.004819533398759531`", ",", 
     RowBox[{"-", "0.03580726779325287`"}], ",", 
     RowBox[{"-", "0.25282562712223483`"}], ",", 
     RowBox[{"-", "0.3155261149145859`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.018888734017887703`"}], ",", "0.14033598302858805`", ",", 
     RowBox[{"-", "0.3155261149145859`"}], ",", "0.9032778419005734`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730042553061791*^9},ExpressionUUID->"e139fd6a-85c5-4463-ad26-\
8edf29a4c13f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"barMat3DList", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729990566785482*^9, 
  3.729990572397729*^9}},ExpressionUUID->"46fba87f-ecb5-4492-bd44-\
8652a3966dc3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.33304481558422655`"}], ",", 
     RowBox[{"-", "0.0021435752075137`"}], ",", "0.004819533398759531`", ",", 
     
     RowBox[{"-", "0.018888734017887703`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0021435752075137`"}], ",", 
     RowBox[{"-", "0.317407399194112`"}], ",", 
     RowBox[{"-", "0.03580726779325287`"}], ",", "0.14033598302858805`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.004819533398759531`", ",", 
     RowBox[{"-", "0.03580726779325287`"}], ",", 
     RowBox[{"-", "0.25282562712223483`"}], ",", 
     RowBox[{"-", "0.3155261149145859`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.018888734017887703`"}], ",", "0.14033598302858805`", ",", 
     RowBox[{"-", "0.3155261149145859`"}], ",", "0.9032778419005734`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729990572891548*^9, 
  3.730042446316064*^9},ExpressionUUID->"0005be04-4aee-43d5-bf59-\
883c1c5a8506"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigenvectors", "[", 
   RowBox[{"barMat3DList", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.729991262523616*^9, 
  3.7299912747028522`*^9}},ExpressionUUID->"914004c9-11fa-4446-afb2-\
f31733377d06"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.014710143161435313`"}], ",", "0.10929067025330165`", ",", 
   RowBox[{"-", "0.2457250082069869`"}], ",", "0.9630464066832036`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.729991277312687*^9},ExpressionUUID->"88fc40b3-7722-482b-9f2b-\
f3ec3a2a5ab5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wrong - this eigenvector is the INVERSE matrix", "Subsubsection",
 CellChangeTimes->{{3.7300425816052217`*^9, 
  3.7300425987657127`*^9}},ExpressionUUID->"432462e5-be2f-47a9-b08a-\
af4b2417e41b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuatToRot", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "0.014710143161435313`"}], ",", "0.10929067025330165`", ",", 
    
    RowBox[{"-", "0.2457250082069869`"}], ",", "0.9630464066832036`"}], "}"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.730042359210567*^9, 
  3.730042376401045*^9}},ExpressionUUID->"a410bffc-5430-4935-9273-\
ee014f9298a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9756783221675084`"}], ",", 
     RowBox[{"-", "0.025377800663047734`"}], ",", "0.21773327464102138`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.08204400271671085`"}], ",", 
     RowBox[{"-", "0.8788056640596926`"}], ",", 
     RowBox[{"-", "0.47007380956060835`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2032746744447428`", ",", 
     RowBox[{"-", "0.47650453518314945`"}], ",", "0.8553495394745207`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7300423769633503`*^9},ExpressionUUID->"ac73e5b3-f6e1-4a76-a423-\
6e7c178bf6ab"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["To get RotToQuat - it is the INVERSE", "Subsubsection",
 CellChangeTimes->{{3.730042389446878*^9, 3.73004239427106*^9}, {
  3.7300426084049053`*^9, 
  3.730042616252996*^9}},ExpressionUUID->"73af533d-7abd-4770-904d-\
e412e6cdb5de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rot3DList", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",ExpressionUUID->"06370a4e-b3f2-\
432c-8a4f-9d4568101acd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9756783221675079`"}], ",", 
     RowBox[{"-", "0.08204400271671086`"}], ",", "0.2032746744447428`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.025377800663047755`"}], ",", 
     RowBox[{"-", "0.8788056640596922`"}], ",", 
     RowBox[{"-", "0.4765045351831494`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21773327464102138`", ",", 
     RowBox[{"-", "0.4700738095606083`"}], ",", "0.8553495394745203`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7300426360431967`*^9},ExpressionUUID->"7f44689a-e2b1-4561-9f19-\
339ee9901b87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuatToRot", "[", 
  RowBox[{"qinverse", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.014710143161435313`"}], ",", "0.10929067025330165`", ",", 
     RowBox[{"-", "0.2457250082069869`"}], ",", "0.9630464066832036`"}], 
    "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.730042420642201*^9, 
  3.730042427279112*^9}},ExpressionUUID->"d43d8a92-80c4-4ee8-bd55-\
e1f9e5fabeeb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9756783221675084`"}], ",", 
     RowBox[{"-", "0.08204400271671085`"}], ",", "0.2032746744447428`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.025377800663047734`"}], ",", 
     RowBox[{"-", "0.8788056640596926`"}], ",", 
     RowBox[{"-", "0.47650453518314945`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21773327464102138`", ",", 
     RowBox[{"-", "0.47007380956060835`"}], ",", "0.8553495394745207`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730042427893065*^9},ExpressionUUID->"ad4ee11e-e2f2-4087-8687-\
af44ea2119a0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"RotToQuat", "[", 
   RowBox[{"rot3DList", "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.729991242654258*^9, 3.729991283500106*^9}, 
   3.7300423401360073`*^9},ExpressionUUID->"635f0a44-ab0f-49b3-a2ef-\
fd7b24750544"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.014710143161435318`", ",", "0.1092906702533017`", ",", 
   RowBox[{"-", "0.245725008206987`"}], ",", "0.9630464066832036`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7299912841366377`*^9, 3.729991458638481*^9, 
  3.730042345005413*^9},ExpressionUUID->"a5370445-be7c-4bb4-a2a1-\
8935e3bc321b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theRotToQuat", "[", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", "]"}]], "Input",ExpressionUUID->\
"ea1ab6f9-e3d1-4f96-a813-261679da8d6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.014710143161458973`", ",", "0.10929067025330091`", ",", 
   RowBox[{"-", "0.24572500820698684`"}], ",", "0.9630464066832033`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.729992072404008*^9, 
  3.7300426640541477`*^9},ExpressionUUID->"1a65b022-a7a8-4d65-afcc-\
ba10ec8d27ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theRotToQuat4", "[", 
  RowBox[{"rot3DList", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", "]"}]], "Input",
 CellChangeTimes->{
  3.730042685693159*^9},ExpressionUUID->"645e4813-d9c6-4139-bdf6-\
415f55834fd4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.014781127135312372`"}], ",", "0.04884357836811569`", ",", 
   "0.2469107572079477`", ",", 
   RowBox[{"-", "0.967693598773809`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730042688464478*^9},ExpressionUUID->"4f39a0c9-bb1f-4c21-95d4-\
d566f8972066"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delete", "Section",
 CellChangeTimes->{{3.719259540393046*^9, 
  3.719259542201043*^9}},ExpressionUUID->"09d47710-31a7-4f36-bd93-\
59c343307a8f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Example", " ", "solution"}], " ", "*)"}], "  ", 
  RowBox[{"solnxxyyzzN", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.718566729644546*^9, 3.718566732652195*^9}, {
   3.7185667698797073`*^9, 3.7185667977156057`*^9}, {3.718566883276229*^9, 
   3.718566890506445*^9}, 
   3.7189958827035217`*^9},ExpressionUUID->"0233b268-8a26-4a6f-ad5d-\
bc5063c0bf74"],

Cell[BoxData[
 RowBox[{"xx", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["p2", "6"]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], 
    RowBox[{"12", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "3"], "-", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", 
              SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
             RowBox[{"432", " ", "p2", " ", 
              SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]], "+", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p2", "3"], "-", 
       RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["p3", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"81", " ", 
             SuperscriptBox["p3", "4"]}], "-", 
            RowBox[{"48", " ", 
             SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
            RowBox[{"432", " ", "p2", " ", 
             SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["p2", "2"], " ", 
             SuperscriptBox["p4", "2"]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]}]}]], "Output",
 CellChangeTimes->{
  3.718995929675215*^9},ExpressionUUID->"9c3bc960-988b-4a75-aaf0-\
2d002ba9f7e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqHorn", "[", 
  RowBox[{"[", 
   RowBox[{"2", ";;", "3"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.718996216727236*^9, 
  3.718996229807289*^9}},ExpressionUUID->"2015eb24-828d-42cc-a644-\
6d088806b10b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"aa", " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", "bb", " ", "c"}], "+", 
      RowBox[{"a", " ", "b", " ", "cc"}], "+", 
      RowBox[{"aa", " ", "bb", " ", "cc"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["aa", "2"], " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "y"}], "-", 
      RowBox[{
       SuperscriptBox["bb", "2"], " ", "y"}], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", "z"}], "-", 
      RowBox[{
       SuperscriptBox["cc", "2"], " ", "z"}], "+", 
      RowBox[{"4", " ", "x", " ", "y", " ", "z"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "-", 
    SuperscriptBox["aa", "2"], "-", 
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["bb", "2"], "-", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox["cc", "2"], "-", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.718996225512021*^9, 
  3.718996230286399*^9}},ExpressionUUID->"0d1d4b6f-d83a-460b-a1c6-\
179708cf3854"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}], "/.", 
      RowBox[{"(", 
       RowBox[{"solnxxyyzzN", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"p4", " ", "\[Rule]", " ", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ",", 
          RowBox[{"p3", " ", "\[Rule]", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ",", 
          RowBox[{"p2", "\[Rule]", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0"}], "}"}], "]"}]}]}], "}"}]}], 
       ")"}]}], ")"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", 
       SuperscriptBox["10", 
        RowBox[{"(", 
         RowBox[{"-", "9"}], ")"}]]}], "]"}], "&"}]}], ",", "1"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7182424452377872`*^9, 3.718242562356514*^9}, {
   3.7182431232471333`*^9, 3.71824312387772*^9}, 3.7182792639351*^9, {
   3.718566586109161*^9, 3.718566587477112*^9}, {3.718566665001318*^9, 
   3.718566686461568*^9}, {3.718996205693577*^9, 
   3.718996209469789*^9}},ExpressionUUID->"696e4812-eb46-4d6f-be2c-\
10c34f23bd1c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.5562646872156685`", ",", 
      RowBox[{
       RowBox[{"-", "0.04564376716228967`"}], "+", 
       RowBox[{"0.0990453990696693`", " ", "\[ImaginaryI]"}]}], ",", 
      RowBox[{
       RowBox[{"-", "0.04564376716228967`"}], "-", 
       RowBox[{"0.0990453990696693`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{"0.5562646872156685`", ",", 
      RowBox[{
       RowBox[{"-", "0.04564376716228968`"}], "-", 
       RowBox[{"0.0990453990696693`", " ", "\[ImaginaryI]"}]}], ",", 
      RowBox[{
       RowBox[{"-", "0.04564376716228967`"}], "+", 
       RowBox[{"0.0990453990696693`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.04564376716228967`"}], "+", 
       RowBox[{"0.09904539906966926`", " ", "\[ImaginaryI]"}]}], ",", 
      "0.5562646872156685`", ",", 
      RowBox[{
       RowBox[{"-", "0.045643767162289614`"}], "-", 
       RowBox[{"0.09904539906966925`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.04564376716228967`"}], "+", 
       RowBox[{"0.09904539906966926`", " ", "\[ImaginaryI]"}]}], ",", 
      RowBox[{
       RowBox[{"-", "0.04564376716228971`"}], "-", 
       RowBox[{"0.09904539906966928`", " ", "\[ImaginaryI]"}]}], ",", 
      "0.5562646872156685`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.04564376716228967`"}], "-", 
       RowBox[{"0.09904539906966926`", " ", "\[ImaginaryI]"}]}], ",", 
      "0.5562646872156685`", ",", 
      RowBox[{
       RowBox[{"-", "0.045643767162289614`"}], "+", 
       RowBox[{"0.09904539906966925`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.04564376716228967`"}], "-", 
       RowBox[{"0.09904539906966926`", " ", "\[ImaginaryI]"}]}], ",", 
      RowBox[{
       RowBox[{"-", "0.04564376716228971`"}], "+", 
       RowBox[{"0.09904539906966928`", " ", "\[ImaginaryI]"}]}], ",", 
      "0.5562646872156685`"}], "}"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.718996262338346*^9},ExpressionUUID->"11bb5624-f5aa-43f3-bd9c-\
f3d94dcfb4cb"]
}, Open  ]],

Cell[TextData[{
 StyleBox["----------------------- ",
  FontSize->16],
 StyleBox["Next, see if squaring p3 helps at all: it seems to introduce more \
roots",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" -------------------------",
  FontSize->16]
}], "Text",
 CellChangeTimes->{{3.718995846559026*^9, 3.7189958542163563`*^9}, {
  3.718996174341619*^9, 
  3.718996194165303*^9}},ExpressionUUID->"669067b8-0d1c-44ea-9aa4-\
4e07ee253427"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"convert", " ", "to", " ", "p3sq"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqnsxxyyzz", "=", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["xx", "2"], "-", 
        RowBox[{"2", " ", "xx", " ", "yy"}], "+", 
        SuperscriptBox["yy", "2"], "-", 
        RowBox[{"2", " ", "xx", " ", "zz"}], "-", 
        RowBox[{"2", " ", "yy", " ", "zz"}], "+", 
        SuperscriptBox["zz", "2"]}], "\[Equal]", "p4"}], ",", 
      RowBox[{
       RowBox[{"64", " ", "xx", " ", "yy", " ", "zz"}], "\[Equal]", 
       SuperscriptBox["p3", "2"]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{"xx", "+", "yy", "+", "zz"}], ")"}]}], "\[Equal]", "p2"}]}], 
     "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.718239887083992*^9, 3.7182399901036453`*^9}, {
   3.718240791303701*^9, 3.718240799621731*^9}, {3.7182408955467787`*^9, 
   3.718240914318993*^9}, 3.718240984413211*^9, {3.71830239090114*^9, 
   3.718302396188451*^9}, {3.718965969710548*^9, 
   3.71896597823615*^9}},ExpressionUUID->"7c3126ec-4802-49dd-8a8b-\
427971215117"],

Cell[TextData[StyleBox["  the set of equations in {xx,yy,zz}  runs for 1 \
minute and gets an answer:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.718268135077319*^9, 3.7182682029245033`*^9}, {
  3.718566109874337*^9, 3.718566135309482*^9}, {3.718566499759536*^9, 
  3.7185665194930973`*^9}},ExpressionUUID->"94ea9652-c7e5-4337-a8b0-\
27f08cfae47e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"solnxxyyzz", " ", "=", " ", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"eqnsxxyyzz", ",", 
       RowBox[{"{", 
        RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}]}], "]"}], "//", 
     "Simplify"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7182409772892*^9, 3.718240991567073*^9}, {
   3.718242410990157*^9, 3.718242413268931*^9}, 
   3.718242612270728*^9},ExpressionUUID->"1e8cb6b0-aa89-40a9-976d-\
394500d6129b"],

Cell[BoxData["75.621503`"], "Output",
 CellChangeTimes->{3.718242699464625*^9, 3.7182796602963037`*^9, 
  3.71856660705029*^9, 3.718995670959694*^9, 
  3.719170972747797*^9},ExpressionUUID->"8d7a24b7-5324-476f-a015-\
b131d5b8f5d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"ByteCount", ",", "solnxxyyzz", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.718566621440036*^9, 
  3.718566631973278*^9}},ExpressionUUID->"7274a59c-ea26-4ecb-863d-\
2b582f893a4e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4584", ",", "19544", ",", "21552"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4584", ",", "19448", ",", "21552"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22232", ",", "28640"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22400", ",", "28736"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22256", ",", "28632"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5224", ",", "22392", ",", "28728"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.718566632372364*^9, 3.718995741308429*^9, 
  3.719171018166819*^9},ExpressionUUID->"5293705b-0c89-4c8c-a9cc-\
f22386e266f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Example", " ", "solution"}], " ", "*)"}], "  ", 
  RowBox[{"solnxxyyzz", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.718566729644546*^9, 3.718566732652195*^9}, {
  3.7185667698797073`*^9, 3.7185667977156057`*^9}, {3.718566883276229*^9, 
  3.718566890506445*^9}},ExpressionUUID->"968fb97e-9d0c-4bdf-a049-\
a4b23b5f9d7a"],

Cell[BoxData[
 RowBox[{"xx", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["p2", "6"]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"12", " ", "p4"}]}], 
    RowBox[{"12", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", 
              SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
             RowBox[{"432", " ", "p2", " ", 
              SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]], "-", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "3"]}], "+", 
       RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", 
           SuperscriptBox["p3", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            RowBox[{"81", " ", 
             SuperscriptBox["p3", "4"]}], "-", 
            RowBox[{"48", " ", 
             SuperscriptBox["p2", "4"], " ", "p4"}], "-", 
            RowBox[{"432", " ", "p2", " ", 
             SuperscriptBox["p3", "2"], " ", "p4"}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["p2", "2"], " ", 
             SuperscriptBox["p4", "2"]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]}]}]], "Output",
 CellChangeTimes->{
  3.719170982846155*^9},ExpressionUUID->"1b32cdc0-4e5d-457f-ab9e-\
99922770d1b1"]
}, Open  ]],

Cell[TextData[StyleBox["Check: Must use the a,b,c, not p2,p3,p4, because they \
are not independent:\n   We can see that soln[[4]] is rank ordered, and also \
has zz =0.",
 FontWeight->"Bold",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.718566562300927*^9, 3.718566572740781*^9}, {
  3.718566829819333*^9, 3.718566854803788*^9}, {3.719171110515544*^9, 
  3.719171116947194*^9}, {3.719171165107234*^9, 
  3.7191712109310703`*^9}},ExpressionUUID->"e82ca50e-97f5-419d-8733-\
a93da837ff34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}], "/.", 
     RowBox[{"(", 
      RowBox[{"solnxxyyzz", "/.", 
       RowBox[{"randomPs", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", 
       SuperscriptBox["10", 
        RowBox[{"(", 
         RowBox[{"-", "9"}], ")"}]]}], "]"}], "&"}]}], ",", "1"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7182424452377872`*^9, 3.718242562356514*^9}, {
   3.7182431232471333`*^9, 3.71824312387772*^9}, 3.7182792639351*^9, {
   3.718566586109161*^9, 3.718566587477112*^9}, {3.718566665001318*^9, 
   3.718566686461568*^9}, {3.7189964047735643`*^9, 3.71899640497194*^9}, 
   3.7191708794501247`*^9, {3.719170923268937*^9, 3.7191709369888163`*^9}, {
   3.719171029422929*^9, 
   3.719171030276751*^9}},ExpressionUUID->"0ba883db-2747-4d8f-83f4-\
4afc9e13830e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "0.11992954714059262`", ",", "0.34623921306945143`", ",", 
      "0.852625543341908`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "0.11992954714059262`", ",", "0.8526255433419079`", ",", 
      "0.3462392130694515`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "0.8526255433419079`", ",", "0.11992954714059273`", ",", 
      "0.3462392130694513`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "0.8526255433419079`", ",", "0.3462392130694515`", ",", 
      "0.11992954714059267`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "0.3462392130694516`", ",", "0.11992954714059245`", ",", 
      "0.8526255433419078`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "0.3462392130694516`", ",", "0.852625543341908`", ",", 
      "0.11992954714059248`"}], "}"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7182796604132757`*^9, {3.718566653808446*^9, 3.718566687237893*^9}, {
   3.718996380322249*^9, 3.718996406476458*^9}, {3.719171007747448*^9, 
   3.719171030991744*^9}},ExpressionUUID->"a118077f-7f62-4555-9890-\
6937fbabb87a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}], "/.", 
     RowBox[{"(", 
      RowBox[{"solnxxyyzz", "/.", 
       RowBox[{"randomPsX", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", 
       SuperscriptBox["10", 
        RowBox[{"(", 
         RowBox[{"-", "9"}], ")"}]]}], "]"}], "&"}]}], ",", "1"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.7191710985967216`*^9},ExpressionUUID->"198fe20f-af1c-4fa9-b002-\
88e9b4c10fc2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0.07383508537023845`", ",", "0.36140386061886687`"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.36140386061886687`", ",", "0.07383508537023845`"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.3614038606188668`", ",", "0", ",", "0.0738350853702385`"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.3614038606188668`", ",", "0.0738350853702385`", ",", "0"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.07383508537023847`", ",", "0", ",", "0.3614038606188668`"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.07383508537023847`", ",", "0.36140386061886687`", ",", "0"}], 
     "}"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.719171100601375*^9},ExpressionUUID->"3678dd18-2b90-4642-8047-\
fc977dfda77d"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7191712503067093`*^9, 
  3.719171252025798*^9}},ExpressionUUID->"64fd5a9e-abf0-4b48-a6c1-\
9d72f394f716"],

Cell[CellGroupData[{

Cell["These are the basic solutions:", "Subsection",
 CellChangeTimes->{{3.719107267828803*^9, 3.7191072785163317`*^9}, {
  3.719189877699585*^9, 
  3.7191898849230433`*^9}},ExpressionUUID->"2b23e24f-021e-4d1e-be66-\
eb84326e5151"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"xxarg0", ",", "yyarg0", ",", "zzarg0"}], "}"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xx", ",", "yy", ",", "zz"}], "}"}], "/.", 
    RowBox[{"(", 
     RowBox[{"solnxxyyzz", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ")"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.719171261978456*^9, 
  3.719171305906023*^9}},ExpressionUUID->"3b0f4c26-a51c-4b0a-a9e2-\
80b171c9fb8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["p2", "6"]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p2", "2"], "+", 
        RowBox[{"12", " ", "p4"}]}], ")"}]}], 
     RowBox[{"24", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}]], "+", 
    RowBox[{
     FractionBox["1", "24"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p2", "3"]}], "+", 
        RowBox[{"36", " ", "p2", " ", "p4"}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            SuperscriptBox["p3", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["p3", "4"]}], "-", 
             RowBox[{"48", " ", "p2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["p2", "3"], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
             RowBox[{"384", " ", 
              SuperscriptBox["p2", "2"], " ", 
              SuperscriptBox["p4", "2"]}], "-", 
             RowBox[{"768", " ", 
              SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
      RowBox[{"1", "/", "3"}]]}]}], ",", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"16", " ", "p2"}], "3"]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}], 
         RowBox[{"1", "/", "3"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["p2", "2"], "+", 
          RowBox[{"12", " ", "p4"}]}], ")"}]}], 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["p2", "3"]}], "+", 
           RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["p2", "3"], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"81", " ", 
                 SuperscriptBox["p3", "4"]}], "-", 
                RowBox[{"48", " ", "p2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["p2", "3"], "+", 
                   RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                RowBox[{"384", " ", 
                 SuperscriptBox["p2", "2"], " ", 
                 SuperscriptBox["p4", "2"]}], "-", 
                RowBox[{"768", " ", 
                 SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "2"}], ")"}], 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["3"]], 
       RowBox[{"2", " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "2"}], ")"}], 
               RowBox[{"2", "/", "3"}]], " ", 
              SuperscriptBox["p2", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "2"}], ")"}], 
               RowBox[{"1", "/", "3"}]], " ", 
              SuperscriptBox["p2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "9"}], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], "+", 
             RowBox[{"72", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["3"]}]}], ")"}], " ", "p2", " ", "p4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
                 RowBox[{"6", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "9"}], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "9"}], "-", 
                   RowBox[{"9", " ", "\[ImaginaryI]", " ", 
                    SqrtBox["3"]}]}], ")"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
                   SqrtBox["3"]}], ")"}], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"4", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                   RowBox[{"16", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                   RowBox[{"128", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                   RowBox[{"256", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox["p2", "3"]}], "+", 
                 RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
                 RowBox[{"6", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "9"}], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["p2", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "12"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"-", "2"}], ")"}], 
                  RowBox[{"2", "/", "3"}]], " ", "p4"}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                 RowBox[{"2", "/", "3"}]]}], ")"}]}], "+", 
             RowBox[{"96", " ", "p4", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "6"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"-", "2"}], ")"}], 
                  RowBox[{"2", "/", "3"}]], " ", "p4"}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["p2", "3"]}], "-", 
                   RowBox[{"27", " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                   RowBox[{"3", " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                 RowBox[{"2", "/", "3"}]]}], ")"}]}]}], ")"}], "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["p2", "3"]}], "+", 
              RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "9"}], " ", 
                  SuperscriptBox["p3", "2"]}], "+", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                   RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                   RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                   RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
            RowBox[{"2", "/", "3"}]]}], ")"}]}]}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "2"}], ")"}], 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["p2", "2"]}], "-", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "2"}], ")"}], 
        RowBox[{"1", "/", "3"}]], " ", "p4"}], "-", 
      RowBox[{"16", " ", "p2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"2", "/", "3"}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"2", "/", "3"}]]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["p2", "3"]}], "+", 
          RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              SuperscriptBox["p3", "2"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["p2", "3"], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["p3", "4"]}], "-", 
               RowBox[{"48", " ", "p2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["p2", "3"], "+", 
                  RowBox[{"9", " ", 
                   SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
               RowBox[{"384", " ", 
                SuperscriptBox["p2", "2"], " ", 
                SuperscriptBox["p4", "2"]}], "-", 
               RowBox[{"768", " ", 
                SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
        RowBox[{"1", "/", "3"}]], " ", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}], 
              RowBox[{"2", "/", "3"}]], " ", 
             SuperscriptBox["p2", "4"]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}], 
              RowBox[{"1", "/", "3"}]], " ", 
             SuperscriptBox["p2", "3"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["p2", "3"]}], "-", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                RowBox[{"3", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                   RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                   RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                   RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
              RowBox[{"1", "/", "3"}]]}], "+", 
            RowBox[{"144", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}], 
              RowBox[{"1", "/", "3"}]], " ", "p2", " ", "p4", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["p2", "3"]}], "-", 
                RowBox[{"27", " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                RowBox[{"3", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                   RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                   RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                   RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
              RowBox[{"1", "/", "3"}]]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox["p2", "3"]}], "-", 
                RowBox[{"54", " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                RowBox[{"144", " ", "p2", " ", "p4"}], "+", 
                RowBox[{"6", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                   RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                   RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                   RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                   RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
              RowBox[{"1", "/", "3"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "18"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], 
                 RowBox[{"1", "/", "3"}]], " ", 
                SuperscriptBox["p3", "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
                  SqrtBox["3"]}], ")"}], " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"4", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"16", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"128", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"256", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["p2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "12"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "2"}], ")"}], 
                 RowBox[{"2", "/", "3"}]], " ", "p4"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                RowBox[{"2", "/", "3"}]]}], ")"}]}], "+", 
            RowBox[{"96", " ", "p4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "2"}], ")"}], 
                 RowBox[{"2", "/", "3"}]], " ", "p4"}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["p2", "3"]}], "-", 
                  RowBox[{"27", " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
                  RowBox[{"3", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["p2", "3"], " ", 
                    SuperscriptBox["p3", "2"]}], "+", 
                    RowBox[{"81", " ", 
                    SuperscriptBox["p3", "4"]}], "-", 
                    RowBox[{"48", " ", "p2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                    RowBox[{"384", " ", 
                    SuperscriptBox["p2", "2"], " ", 
                    SuperscriptBox["p4", "2"]}], "-", 
                    RowBox[{"768", " ", 
                    SuperscriptBox["p4", "3"]}]}]]}]}], ")"}], 
                RowBox[{"2", "/", "3"}]]}], ")"}]}]}], ")"}], "/", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox["p2", "3"]}], "+", 
             RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SuperscriptBox["p3", "2"]}], "+", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"12", " ", 
                   SuperscriptBox["p2", "3"], " ", 
                   SuperscriptBox["p3", "2"]}], "+", 
                  RowBox[{"81", " ", 
                   SuperscriptBox["p3", "4"]}], "-", 
                  RowBox[{"48", " ", "p2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["p2", "3"], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
                  RowBox[{"384", " ", 
                   SuperscriptBox["p2", "2"], " ", 
                   SuperscriptBox["p4", "2"]}], "-", 
                  RowBox[{"768", " ", 
                   SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
           RowBox[{"2", "/", "3"}]]}], ")"}]}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"96", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox["p2", "3"]}], "+", 
         RowBox[{"72", " ", "p2", " ", "p4"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["p3", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["p2", "3"], " ", 
               SuperscriptBox["p3", "2"]}], "+", 
              RowBox[{"81", " ", 
               SuperscriptBox["p3", "4"]}], "-", 
              RowBox[{"48", " ", "p2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["p2", "3"], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox["p3", "2"]}]}], ")"}], " ", "p4"}], "+", 
              RowBox[{"384", " ", 
               SuperscriptBox["p2", "2"], " ", 
               SuperscriptBox["p4", "2"]}], "-", 
              RowBox[{"768", " ", 
               SuperscriptBox["p4", "3"]}]}]]}], ")"}]}]}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.719171266995141*^9, 
  3.7191736033905888`*^9},ExpressionUUID->"4a935d7c-2882-488e-ba45-\
c2b680a36246"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Frobenius stuff", "Section",
 CellChangeTimes->{{3.739841586712942*^9, 
  3.7398416026159*^9}},ExpressionUUID->"a80d2cd5-7fee-4bba-88ab-3d0ddc89456b"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Question about ",
  FontSize->16,
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox["Frobenius: ",
  FontSize->24,
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox[" Quaternion distances are the Chord distance squared.",
  FontSize->16,
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}]
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739806716713468*^9, 3.7398067228896637`*^9}, {
  3.739807077430435*^9, 3.73980709065504*^9}, {3.739808325954028*^9, 
  3.739808337550983*^9}},ExpressionUUID->"a0007cfc-d553-4d02-9cad-\
79baf854c4d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"frobenius", "[", "mat_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"mvec", " ", "=", " ", 
      RowBox[{"Flatten", "[", "mat", "]"}]}], "}"}], ",", " ", 
    RowBox[{"Plus", "@@", 
     RowBox[{"(", 
      RowBox[{"mvec", "*", "mvec"}], ")"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739806820237549*^9, 3.739806875168723*^9}, {
   3.73980694662043*^9, 3.739806995240099*^9}, 3.7398083375520477`*^9},
 CellLabel->
  "In[851]:=",ExpressionUUID->"885e5a96-4d43-4811-9ed9-33b01d5e3924"],

Cell[BoxData[
 RowBox[{"frobenius", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a0", ",", 
      RowBox[{"-", "a1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a1", ",", "a0"}], "}"}]}], "}"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739806877307336*^9, 3.739806889275646*^9}, 
   3.739808337552946*^9},
 CellLabel->
  "In[852]:=",ExpressionUUID->"cf64b268-437f-4c47-b289-55e1bbea4f4d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["a0", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a1", "2"]}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.739806889829774*^9, {3.7398069570304317`*^9, 3.7398069990989733`*^9}, 
   3.739808337553844*^9},
 CellLabel->
  "Out[852]=",ExpressionUUID->"a731074d-0ce4-4555-97f8-66c2174417ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"quat", " ", "diffs", " ", "are", " ", "nice"}], " ", "*)"}], 
  RowBox[{"frobABsqrt", " ", "=", 
   RowBox[{
    RowBox[{"frobenius", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"a0", ",", 
          RowBox[{"-", "a1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"a1", ",", "a0"}], "}"}]}], "}"}], "-", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"b0", ",", 
          RowBox[{"-", "b1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"b1", ",", "b0"}], "}"}]}], "}"}]}], "]"}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7398067289098*^9, 3.7398068145771437`*^9}, {
   3.739806912762686*^9, 3.739806920080269*^9}, {3.739807027267857*^9, 
   3.739807063761531*^9}, {3.7398074652008867`*^9, 3.7398074735530167`*^9}, 
   3.7398083375548286`*^9},ExpressionUUID->"4b419a38-b5c0-457f-ad9f-\
14552104bfaa"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a0", "-", "b0"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a1", "-", "b1"}], ")"}], "2"]}], ")"}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.739806920876092*^9, {3.7398070217088623`*^9, 3.739807064509158*^9}, 
   3.739808337555731*^9},
 CellLabel->
  "Out[857]=",ExpressionUUID->"12b7fd20-e8b7-4993-8535-2eb6e6fe0a0b"],

Cell[BoxData[
 RowBox[{"abToRot2D", "[", 
  RowBox[{"{", 
   RowBox[{"a0", ",", "a1"}], "}"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739807217038047*^9, 3.739807220821471*^9}, 
   3.7398083375566187`*^9},
 CellLabel->
  "In[860]:=",ExpressionUUID->"d363e8c1-bb2c-4e4a-b518-beb24b9e3a16"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a0", "2"], "-", 
      SuperscriptBox["a1", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "a0", " ", "a1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "a0", " ", "a1"}], ",", 
     RowBox[{
      SuperscriptBox["a0", "2"], "-", 
      SuperscriptBox["a1", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739807192239366*^9, 3.7398072216916113`*^9}, 
   3.739808337557496*^9},
 CellLabel->
  "Out[860]=",ExpressionUUID->"9004ac4c-960d-4f54-a54d-cdb355f8a4d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"frobenius", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a0", ",", 
         RowBox[{"-", "a1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a1", ",", "a0"}], "}"}]}], "}"}], "]"}], ",", 
    RowBox[{"frobenius", "[", 
     RowBox[{"abToRot2D", "[", 
      RowBox[{"{", 
       RowBox[{"a0", ",", "a1"}], "}"}], "]"}], " ", "]"}]}], "}"}], "//", 
  "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739807741786353*^9, 3.739807751313323*^9}, {
   3.739807864750454*^9, 3.7398078771294813`*^9}, 3.739808337558461*^9},
 CellLabel->
  "In[874]:=",ExpressionUUID->"c6517c3e-a552-4c23-a53f-212e9e73740e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a0", "2"], "+", 
      SuperscriptBox["a1", "2"]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a0", "2"], "+", 
       SuperscriptBox["a1", "2"]}], ")"}], "2"]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739807746109396*^9, 3.7398077517183323`*^9}, 
   3.739807877556336*^9, 3.739808337559346*^9},
 CellLabel->
  "Out[874]=",ExpressionUUID->"62b09102-7a19-47e0-8d20-8c7346ce4c70"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "SO2", " ", "diffs", " ", "are", " ", "Same", " ", "as", " ", "a"}], ",", 
    
    RowBox[{"b", " ", "mat", " ", "diffs"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"frobenius", "[", 
      RowBox[{
       RowBox[{"abToRot2D", "[", 
        RowBox[{"{", 
         RowBox[{"a0", ",", "a1"}], "}"}], "]"}], " ", "-", 
       RowBox[{"abToRot2D", "[", 
        RowBox[{"{", 
         RowBox[{"b0", ",", "b1"}], "}"}], "]"}]}], "]"}], "//", "Expand"}], "//",
     "Factor"}], "//", "FullSimplify"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.73980711767905*^9, 3.7398071528222237`*^9}, {
   3.739807210651512*^9, 3.7398072394109297`*^9}, {3.739807478061982*^9, 
   3.739807486283842*^9}, {3.739807956419558*^9, 3.739807982848258*^9}, {
   3.73980802043607*^9, 3.7398080339276943`*^9}, 
   3.7398083375600348`*^9},ExpressionUUID->"e4ff0e76-4ce0-4762-a9c4-\
ec14f4f59519"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a0", "-", "b0"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a1", "-", "b1"}], ")"}], "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a0", "+", "b0"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a1", "+", "b1"}], ")"}], "2"]}], ")"}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7398071563695383`*^9, {3.7398072314867477`*^9, 3.739807240626886*^9}, {
   3.739807960355335*^9, 3.739807983430389*^9}, 3.739808337560356*^9},
 CellLabel->
  "Out[877]=",ExpressionUUID->"6b79fd25-ee36-415a-a742-1016ca59f734"],

Cell[BoxData[
 RowBox[{
  RowBox[{"frobenius", "[", 
   RowBox[{
    RowBox[{"abToRot2D", "[", 
     RowBox[{"{", 
      RowBox[{"a0", ",", "a1"}], "}"}], "]"}], " ", ".", 
    RowBox[{"abToRot2D", "[", 
     RowBox[{"{", 
      RowBox[{"b0", ",", "b1"}], "}"}], "]"}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7398075595395184`*^9, 3.7398075899605293`*^9}, 
   3.739808337560691*^9},
 CellLabel->
  "In[868]:=",ExpressionUUID->"df4ec2c7-9c9b-4bb5-a5a7-0b481088e3d3"],

Cell[BoxData[
 RowBox[{"2", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a0", "2"], "+", 
     SuperscriptBox["a1", "2"]}], ")"}], "2"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["b0", "2"], "+", 
     SuperscriptBox["b1", "2"]}], ")"}], "2"]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7398075730492983`*^9, 3.739807590857493*^9}, 
   3.739808337561036*^9},
 CellLabel->
  "Out[868]=",ExpressionUUID->"ed24a996-f9bb-4714-b6db-b0d2dad54fcc"],

Cell[TextData[StyleBox["Now look at 3D, regular quaternions:",
 FontSlant->"Italic"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7398075412587357`*^9, 3.739807552171002*^9}, 
   3.739808337561211*^9},ExpressionUUID->"17cb2650-636f-42f1-9c71-\
84792bb0bd11"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"quatmat4", "[", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], ".", 
   RowBox[{"Transpose", "[", 
    RowBox[{"quatmat4", "[", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], "]"}]}], 
  "//", "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739807290849441*^9, 3.739807330484642*^9}, 
   3.739808337561517*^9},
 CellLabel->
  "In[864]:=",ExpressionUUID->"77d515db-cb09-4a43-9a07-554f646b3b9d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.739807299911292*^9, 3.7398073310360518`*^9, 
  3.739808337561843*^9},
 CellLabel->
  "Out[864]=",ExpressionUUID->"9a22414b-622c-4dd5-a5e4-b0e803cdfa2e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"frobenius", "[", 
     RowBox[{"quatmat4", "[", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], "]"}], 
    ",", 
    RowBox[{"frobenius", "[", 
     RowBox[{"QuatToRot", "[", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], "]"}]}],
    "}"}], "//", "FullSimplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7398077739700613`*^9, 3.739807841481874*^9}, 
   3.7398083375622663`*^9},
 CellLabel->
  "In[873]:=",ExpressionUUID->"b449b426-e1b5-40ee-8fdd-f040e1c56717"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}], ")"}]}], ",", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q0", "2"], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}], "2"]}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739807796917144*^9, 3.739807841848332*^9}, 
   3.739808337570457*^9},
 CellLabel->
  "Out[873]=",ExpressionUUID->"0784f127-d2b5-4da6-b343-1915522819cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"quat", " ", "diffs", " ", "are", " ", "nice"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"frobenius", "[", 
    RowBox[{
     RowBox[{"quatmat4", "[", 
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "-", 
     RowBox[{"quatmat4", "[", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}]}], "]"}],
    "//", "FullSimplify"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.73980735626906*^9, 3.7398073895346537`*^9}, {
   3.739807490208997*^9, 3.739807496984477*^9}, 
   3.739808337570834*^9},ExpressionUUID->"24be717f-ede8-468c-a00d-\
d2c5b279a577"],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"p0", "-", "q0"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"p1", "-", "q1"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"p2", "-", "q2"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"p3", "-", "q3"}], ")"}], "2"]}], ")"}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.739807391511175*^9, 3.7398083375711737`*^9},
 CellLabel->
  "Out[865]=",ExpressionUUID->"6754f1cc-ead8-4a3b-9894-6a8e714fcaf4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"SO3", " ", "diffs", " ", "are", " ", "ugly"}], " ", "*)"}], 
  RowBox[{"test", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"frobenius", "[", 
      RowBox[{
       RowBox[{"QuatToRot", "[", 
        RowBox[{"{", 
         RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "-", 
       RowBox[{"QuatToRot", "[", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}]}], 
      "]"}], "//", "Expand"}], "//", "FullSimplify"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7398074427245197`*^9, 3.73980744976105*^9}, {
   3.73980750077693*^9, 3.7398075072258053`*^9}, {3.7398080490091877`*^9, 
   3.739808066167692*^9}, {3.739808116811359*^9, 3.739808125299882*^9}, 
   3.739808337571533*^9},
 CellLabel->
  "In[880]:=",ExpressionUUID->"8a330c22-738c-4ba2-8abd-f42c28de9af9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   SuperscriptBox["p0", "4"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["p1", "4"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["p2", "4"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["p3", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["p3", "4"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["q0", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["p3", "2"], " ", 
   SuperscriptBox["q0", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["q0", "4"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["p3", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["q1", "4"]}], "-", 
  RowBox[{"6", " ", 
   SuperscriptBox["p2", "2"], " ", 
   SuperscriptBox["q2", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["p3", "2"], " ", 
   SuperscriptBox["q2", "2"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q2", "2"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["q1", "2"], " ", 
   SuperscriptBox["q2", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["q2", "4"]}], "-", 
  RowBox[{"16", " ", "p2", " ", "p3", " ", "q2", " ", "q3"}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p2", "2"], "+", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p3", "2"]}], "+", 
        SuperscriptBox["q0", "2"], "+", 
        SuperscriptBox["q1", "2"], "+", 
        SuperscriptBox["q2", "2"]}], ")"}]}]}], ")"}], " ", 
   SuperscriptBox["q3", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["q3", "4"]}], "-", 
  RowBox[{"16", " ", "p1", " ", "q1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p2", " ", "q2"}], "+", 
     RowBox[{"p3", " ", "q3"}]}], ")"}]}], "-", 
  RowBox[{"16", " ", "p0", " ", "q0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p1", " ", "q1"}], "+", 
     RowBox[{"p2", " ", "q2"}], "+", 
     RowBox[{"p3", " ", "q3"}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["p1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["p2", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["p3", "2"]}], "+", 
     SuperscriptBox["q0", "2"], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["q1", "2"]}], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["p0", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["p1", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["p2", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["p3", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["q0", "2"]}], "+", 
     SuperscriptBox["q1", "2"], "+", 
     SuperscriptBox["q2", "2"], "+", 
     SuperscriptBox["q3", "2"]}], ")"}]}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7398074524473057`*^9, {3.739808056363946*^9, 3.7398080682125797`*^9}, 
   3.7398081270415277`*^9, 3.739808337571862*^9},
 CellLabel->
  "Out[880]=",ExpressionUUID->"59583d9d-74ed-4216-80f3-b97deeafe9be"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"test", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q0", "\[Rule]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"], "-", 
         SuperscriptBox["q3", "2"]}], "]"}]}], ",", 
      RowBox[{"p0", "\[Rule]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         SuperscriptBox["p1", "2"], "-", 
         SuperscriptBox["p2", "2"], "-", 
         SuperscriptBox["p3", "2"]}], "]"}]}]}], "}"}]}], "//", "Expand"}], "//",
   "FullSimplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7398081335216913`*^9, 3.739808191570306*^9}, {
   3.739808246187695*^9, 3.739808264390152*^9}, 3.739808337572217*^9},
 CellLabel->
  "In[883]:=",ExpressionUUID->"2a23bd89-a8cf-49a4-a8fd-81e1947d7bcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "8"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["q1", "2"]}], "-", 
    SuperscriptBox["q2", "2"], "-", 
    SuperscriptBox["q3", "2"], "+", 
    RowBox[{"2", " ", "p3", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["p1", "2"], "-", 
       SuperscriptBox["p2", "2"], "-", 
       SuperscriptBox["p3", "2"]}]], " ", "q3", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["q1", "2"], "-", 
       SuperscriptBox["q2", "2"], "-", 
       SuperscriptBox["q3", "2"]}]]}], "+", 
    RowBox[{
     SuperscriptBox["p1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["q1", "2"]}], "+", 
       SuperscriptBox["q2", "2"], "+", 
       SuperscriptBox["q3", "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["p2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["q1", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["q2", "2"]}], "+", 
       SuperscriptBox["q3", "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["p3", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["q1", "2"], "+", 
       SuperscriptBox["q2", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["q3", "2"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "p2", " ", "q2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"p3", " ", "q3"}], "+", 
       RowBox[{
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["p1", "2"], "-", 
          SuperscriptBox["p2", "2"], "-", 
          SuperscriptBox["p3", "2"]}]], " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["q1", "2"], "-", 
          SuperscriptBox["q2", "2"], "-", 
          SuperscriptBox["q3", "2"]}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "p1", " ", "q1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"p2", " ", "q2"}], "+", 
       RowBox[{"p3", " ", "q3"}], "+", 
       RowBox[{
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["p1", "2"], "-", 
          SuperscriptBox["p2", "2"], "-", 
          SuperscriptBox["p3", "2"]}]], " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["q1", "2"], "-", 
          SuperscriptBox["q2", "2"], "-", 
          SuperscriptBox["q3", "2"]}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7398081945011168`*^9, {3.739808251071659*^9, 3.739808264927225*^9}, 
   3.739808337572536*^9},
 CellLabel->
  "Out[883]=",ExpressionUUID->"e2d4a5eb-4463-4c6c-888b-beaae0a45d18"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test Frobenius norm...", "Subsection",
 CellChangeTimes->{{3.739443529587335*^9, 
  3.739443535882474*^9}},ExpressionUUID->"4ccd378b-7b2e-4877-8050-\
37b3ff4771b6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataEab3D", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"sym", "[", 
     RowBox[{"\"\<E\>\"", ",", "a", ",", "b"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "1", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7373933711132593`*^9, 3.737393371700451*^9}, {
  3.737393465537889*^9, 3.7373935057742977`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"d298f582-c78f-41e2-938d-46e69de090c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"E11", ",", "E12", ",", "E13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"E21", ",", "E22", ",", "E23"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"E31", ",", "E32", ",", "E33"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.737393506236157*^9, 3.73739747099118*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"8297f02c-32ae-4ba2-af38-1e125e80000c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cost3D", "=", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"makeRotation", "[", 
     RowBox[{"th", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", "a", "]"}], 
         RowBox[{"Sin", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", "a", "]"}], 
         RowBox[{"Sin", "[", "b", "]"}]}], ",", 
        RowBox[{"Cos", "[", "b", "]"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1.", "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"-", "1."}], "\[Rule]", 
       RowBox[{"-", "1"}]}]}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.737389811729731*^9, 3.737389844475828*^9}, {
  3.737393279815975*^9, 3.737393349239002*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"94e79792-4568-4124-90b4-788741a682dc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "th", "]"}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", "a", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "b", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "b", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "b", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "th", "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "a", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "b", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "th", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", "b", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "th", "]"}]}], ")"}]}], "+", 
      RowBox[{"Cos", "[", "th", "]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7373933319511414`*^9, 3.7373933496640987`*^9}, 
   3.7373974750280743`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"007c6cae-74ad-4ddc-8ac0-8cac7e0e72f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cost3Ds", "=", 
  RowBox[{"cost3D", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "th", "]"}], "\[Rule]", "c"}], ",", 
     RowBox[{
      RowBox[{"Sin", "[", "th", "]"}], "\[Rule]", "s"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.737393541957801*^9, 3.7373935611407223`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"7c7050fb-b127-47ce-ba43-8e98661b80fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "a", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "b", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "s"}], " ", 
       RowBox[{"Cos", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "b", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}], "+", 
      RowBox[{"s", " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"s", " ", 
       RowBox[{"Cos", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "b", "]"}], "2"]}]}], ",", 
     RowBox[{"c", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "a", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "b", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "s"}], " ", 
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}], "-", 
      RowBox[{"s", " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"s", " ", 
       RowBox[{"Cos", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       RowBox[{"Cos", "[", "b", "]"}], " ", 
       RowBox[{"Sin", "[", "a", "]"}], " ", 
       RowBox[{"Sin", "[", "b", "]"}]}]}], ",", 
     RowBox[{"c", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "c"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "b", "]"}], "2"]}]}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.73739356175518*^9, 3.7373974792632236`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"ca16a347-8989-4a94-951d-2da1b41c7ea8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testCost3D", " ", "=", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Frobenius", " ", "Distance"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"Plus", "@@", 
    RowBox[{"Flatten", "[", 
     RowBox[{"cost3Ds", "*", "dataEab3D"}], "]"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.737393580127343*^9, 3.7373936313891363`*^9}, {
  3.737393671017071*^9, 3.737393684368691*^9}, {3.737395395114913*^9, 
  3.7373954126890383`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"4ed188b1-3f1e-4bf8-b818-9ab04f9c2494"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", " ", 
   RowBox[{"(", 
    RowBox[{"E11", "+", "E22", "+", "E33"}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "E33", " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "b", "]"}], "2"]}], "+", 
  RowBox[{"s", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "E23"}], "+", "E32"}], ")"}], " ", 
      RowBox[{"Cos", "[", "a", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"E13", "-", "E31"}], ")"}], " ", 
      RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}], " ", 
   RowBox[{"Sin", "[", "b", "]"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"E11", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "a", "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"E12", "+", "E21"}], ")"}], " ", 
      RowBox[{"Cos", "[", "a", "]"}], " ", 
      RowBox[{"Sin", "[", "a", "]"}]}], "+", 
     RowBox[{"E22", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "a", "]"}], "2"]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "b", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", "b", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "E12"}], "+", "E21"}], ")"}], " ", "s"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E13", "+", "E31"}], ")"}], " ", 
         RowBox[{"Cos", "[", "a", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E23", "+", "E32"}], ")"}], " ", 
         RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}], " ", 
      RowBox[{"Sin", "[", "b", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.737393616487815*^9, 3.7373936327493763`*^9}, {
   3.737393673690184*^9, 3.7373936847955*^9}, {3.737395405153722*^9, 
   3.737395431279793*^9}, 3.737397501759266*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"f9c41d7d-10eb-4d80-9abe-2edd2498a128"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Share", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7373975067778587`*^9, 3.737397508173959*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"4bd46fd2-d59a-4555-8aca-f07411f7e15b"],

Cell[BoxData["3570608"], "Output",
 CellChangeTimes->{3.737397509247758*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"91123455-b586-4f62-b2a2-fc797b07518c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Special", " ", "case", " ", "looks", " ", "right"}], " ", "*)"}], 
  " ", 
  RowBox[{
   RowBox[{"testCost3D", "/.", 
    RowBox[{"b", "\[Rule]", "0"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.737395467718007*^9, 3.737395533109457*^9}, {
  3.737395563742281*^9, 3.737395571822009*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"7c0e73a4-de32-4f33-8608-9ca3c9540553"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", " ", 
   RowBox[{"(", 
    RowBox[{"E11", "+", "E22"}], ")"}]}], "+", "E33", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "E12"}], "+", "E21"}], ")"}], " ", "s"}]}]], "Output",
 CellChangeTimes->{{3.737395513810809*^9, 3.7373955334579363`*^9}, 
   3.737395574678465*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"97b54688-1f2c-4cb8-9f6a-160e4977e538"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"raw3DangleEqns", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"testCost3D", ",", "a"}], "]"}], "//", "Simplify"}], " ", 
      ")"}], "\[Equal]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"testCost3D", ",", "b"}], "]"}], "//", "Simplify"}], " ", 
      ")"}], "\[Equal]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.737395345521266*^9, 3.7373953811865253`*^9}, {
  3.737395582829979*^9, 3.73739567172523*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"eaea894d-3617-40bb-986c-f0510859520f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "b", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "c"}], ")"}]}], " ", 
        RowBox[{"Cos", "[", "b", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"E23", "+", "E32"}], ")"}], " ", 
           RowBox[{"Cos", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"E13", "+", "E31"}], ")"}], " ", 
           RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"E13", "-", "E31"}], ")"}], " ", 
           RowBox[{"Cos", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"E23", "-", "E32"}], ")"}], " ", 
           RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"E12", "+", "E21"}], ")"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "a"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "E11"}], "+", "E22"}], ")"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "a"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", "b", "]"}]}]}], ")"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"s", " ", 
      RowBox[{"Cos", "[", "b", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "E23"}], "+", "E32"}], ")"}], " ", 
         RowBox[{"Cos", "[", "a", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E13", "-", "E31"}], ")"}], " ", 
         RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "b", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E13", "+", "E31"}], ")"}], " ", 
         RowBox[{"Cos", "[", "a", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E23", "+", "E32"}], ")"}], " ", 
         RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
      RowBox[{"Cos", "[", "b", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"E11", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "a", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E12", "+", "E21"}], ")"}], " ", 
         RowBox[{"Cos", "[", "a", "]"}], " ", 
         RowBox[{"Sin", "[", "a", "]"}]}], "+", 
        RowBox[{"E22", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "a", "]"}], "2"]}]}], ")"}], " ", 
      RowBox[{"Sin", "[", "b", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "b", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E12", "-", "E21"}], ")"}], " ", "s"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"E13", "+", "E31"}], ")"}], " ", 
            RowBox[{"Cos", "[", "a", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"E23", "+", "E32"}], ")"}], " ", 
            RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}], " ", 
         RowBox[{"Sin", "[", "b", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "E33", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "b"}], "]"}]}]}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7373956736494827`*^9, 3.7373975278090763`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"67f3fe60-a02f-4665-b566-d44231b508ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"raw3DangleEqns", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", "a"}], "]"}]], "Input",
 CellChangeTimes->{{3.7373975444059267`*^9, 3.737397553389268*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"0735c3b0-0c7f-44ce-aab5-777f110c1083"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.7373976874683123`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"0e50e260-d8c2-4fcf-a8d8-568a3716c52c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{"raw3DangleEqns", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.737395705732623*^9, 3.7373957160607843`*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"b0958fd7-c384-4aea-8687-95900891919f"],

Cell[CellGroupData[{

Cell["Try a different way:", "Subsubsection",
 CellChangeTimes->{{3.737397570828377*^9, 
  3.737397576972426*^9}},ExpressionUUID->"3c5b377f-c54a-4528-b61e-\
3ca225511422"],

Cell[BoxData[
 RowBox[{
  RowBox[{"s2XYpoint", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "x"}], ",", 
     RowBox[{"2", "y"}], ",", " ", 
     RowBox[{"1", "-", 
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"]}]}], "}"}], "/", 
   RowBox[{"(", " ", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["y", "2"]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7373975937180557`*^9, 3.737397679220503*^9}, {
  3.737397768488134*^9, 3.737397791085494*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"811a5327-370c-4962-96cb-43d826721917"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s2XYpoint", "[", 
    RowBox[{"a", ",", "b"}], "]"}], ".", 
   RowBox[{"s2XYpoint", "[", 
    RowBox[{"a", ",", "b"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7373977413966293`*^9, 3.737397754916499*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"e1cb6280-5ef3-4d16-8678-b2f210ff0f0e"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.737397755576717*^9, 3.7373977954938726`*^9}},
 CellLabel->"Out[26]=",ExpressionUUID->"a29ff2ff-23ba-48f7-bbd7-77d4d3b4c16b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1.", "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"-", "1.`"}], "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "}"}]}]], "Input",ExpressionUUID->"97ccaf42-4354-\
4283-b6d1-eb058b142856"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rot3Dxy", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"makeRotation", "[", 
       RowBox[{"th", ",", 
        RowBox[{"s2XYpoint", "[", 
         RowBox[{"a", ",", "b"}], "]"}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", "th", "]"}], "\[Rule]", "c"}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", "th", "]"}], "\[Rule]", "s"}]}], "}"}]}], "//", 
     "Simplify"}], ")"}], "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1."}], "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{
      RowBox[{"4.", "v_"}], " ", "\[Rule]", 
      RowBox[{"4", " ", "v"}]}], ",", 
     RowBox[{"1.", "\[Rule]", "1"}], ",", 
     RowBox[{"4.", "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"-", "4."}], "\[Rule]", 
      RowBox[{"-", "4"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.737397858171486*^9, 3.737398121634733*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"d1a7caf0-1f1f-4fbc-9969-f0dc42c3a396"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "c"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}], ")"}], "2"]]}], "+", "c"}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"4", " ", "c"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "4"], " ", "s"}], "+", 
       RowBox[{"2.`", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"], " ", "s"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["b", "4"]}], ")"}], " ", "s"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], "2"]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2.`", " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "c"}], ")"}]}], "+", 
       RowBox[{"2.`", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], " ", "s"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], "2"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"4", " ", "c"}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["a", "4"], " ", "s"}], "-", 
       RowBox[{"2.`", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"], " ", "s"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["b", "4"]}], ")"}], " ", "s"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], "2"]], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "c"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}], ")"}], "2"]]}], "+", "c"}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2.`", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "c"}], ")"}]}], "-", 
       RowBox[{"2.`", " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], " ", "s"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], "2"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2.`", " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "c"}], ")"}]}], "-", 
       RowBox[{"2.`", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], " ", "s"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], "2"]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2.`", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "c"}], ")"}]}], "+", 
       RowBox[{"2.`", " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], " ", "s"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}], ")"}], "2"]], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "c"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}], ")"}], "2"]], "+", "c"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7373978993760643`*^9, 3.737397994835293*^9}, {
   3.737398026639226*^9, 3.737398091749469*^9}, 3.7373981222103148`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"7a8f7491-0451-4f90-bc97-8f305f283f75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testCost3Dxy", " ", "=", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Frobenius", " ", "Distance"}], " ", "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"Plus", "@@", 
     RowBox[{"Flatten", "[", 
      RowBox[{"rot3Dxy", "*", "dataEab3D"}], "]"}]}], "//", "FullSimplify"}], 
   "//", "Numerator"}]}]], "Input",
 CellChangeTimes->{{3.737397837028348*^9, 3.737397850869134*^9}, {
  3.7373981325452213`*^9, 3.737398166640695*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"1f1dcd15-7163-471d-8c1f-85e5616f4ecc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   SuperscriptBox["a", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "E11"}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}], "2"], " ", "c", " ", "E11"}], "-", 
  RowBox[{"4", " ", "a", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "E12"}], "+", 
  RowBox[{"2.`", " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", 
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", "c"}], ")"}], " ", "E13"}], "-", 
  RowBox[{"4", " ", "a", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "E21"}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["b", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "E22"}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}], "2"], " ", "c", " ", "E22"}], "+", 
  RowBox[{"2.`", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", 
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", "c"}], ")"}], " ", "E23"}], "+", 
  RowBox[{"2.`", " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", 
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", "c"}], ")"}], " ", "E31"}], "+", 
  RowBox[{"2.`", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", 
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", "c"}], ")"}], " ", "E32"}], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "E33"}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}], "2"], " ", "c", " ", "E33"}], "+", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", "E12", " ", "s"}], "+", 
  RowBox[{"2.`", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "E12", " ", "s"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["b", "4"]}], ")"}], " ", "E12", " ", "s"}], "+", 
  RowBox[{"2.`", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", "E13", " ", "s"}], "-", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", "E21", " ", "s"}], "-", 
  RowBox[{"2.`", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "E21", " ", "s"}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["b", "4"]}], ")"}], " ", "E21", " ", "s"}], "-", 
  RowBox[{"2.`", " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", "E23", " ", "s"}], "-", 
  RowBox[{"2.`", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", "E31", " ", "s"}], "+", 
  RowBox[{"2.`", " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", "E32", " ", "s"}]}]], "Output",
 CellChangeTimes->{{3.737398146010211*^9, 3.7373981673587027`*^9}},
 CellLabel->"Out[42]=",ExpressionUUID->"d99c3ec6-a77e-4841-92cc-e60e5f6e8ac8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"raw3Dxyqns", " ", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"testCost3Dxy", ",", "a"}], "]"}], "//", "Simplify"}], " ", 
       ")"}], "\[Equal]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"testCost3Dxy", ",", "b"}], "]"}], "//", "Simplify"}], " ", 
       ")"}], "\[Equal]", "0"}]}], "}"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7373982328896027`*^9, 3.73739827284801*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"e33fb621-421b-40e0-aa40-c16acb6a9181"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"2.`", " ", "E13"}], "+", 
     RowBox[{"2.`", " ", "E31"}], "+", 
     RowBox[{"2.`", " ", "E32", " ", "s"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{"E11", "+", "E22"}], ")"}]}], "+", "E33", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E12", "-", "E21"}], ")"}], " ", "s"}]}], ")"}]}], "+", 
     RowBox[{"4.`", " ", "a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2.`", "\[VeryThinSpace]", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1.`"}], "+", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "c"}]}], ")"}], " ", 
         "E11"}], "-", 
        RowBox[{"1.`", " ", "b", " ", "E23"}], "-", 
        RowBox[{"1.`", " ", "b", " ", "E32"}], "-", 
        RowBox[{"1.`", " ", "E33"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "E33"}], "+", 
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{"E22", "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", "E22"}], "+", 
           RowBox[{"1.`", " ", "b", " ", "E23"}], "+", 
           RowBox[{"1.`", " ", "b", " ", "E32"}], "+", 
           RowBox[{"2.`", " ", "E33"}]}], ")"}]}], "+", 
        RowBox[{"1.`", " ", 
         SuperscriptBox["b", "2"], " ", "E12", " ", "s"}], "+", 
        RowBox[{"1.`", " ", "b", " ", "E13", " ", "s"}], "-", 
        RowBox[{"1.`", " ", 
         SuperscriptBox["b", "2"], " ", "E21", " ", "s"}], "-", 
        RowBox[{"1.`", " ", "b", " ", "E31", " ", "s"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2.`"}], "+", 
           RowBox[{"2.`", " ", "c"}]}], ")"}], " ", "E13"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2.`"}], "+", 
           RowBox[{"2.`", " ", "c"}]}], ")"}], " ", "E31"}], "-", 
        RowBox[{"2.`", " ", "E23", " ", "s"}], "+", 
        RowBox[{"2.`", " ", "E32", " ", "s"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6.`"}], "+", 
           RowBox[{"6.`", " ", "c"}]}], ")"}], " ", "E13"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6.`"}], "+", 
           RowBox[{"6.`", " ", "c"}]}], ")"}], " ", "E31"}], "-", 
        RowBox[{"6.`", " ", "E23", " ", "s"}], "+", 
        RowBox[{"6.`", " ", "E32", " ", "s"}]}], ")"}]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"2.`", " ", "c", " ", "E13"}], "+", 
     RowBox[{"4", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"E12", "+", "E21"}], ")"}]}], "+", 
     RowBox[{"2.`", " ", "c", " ", "E31"}], "+", 
     RowBox[{"2.`", " ", "E23", " ", "s"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"2.`", " ", "E23"}], "+", 
     RowBox[{"2.`", " ", "E32"}], "+", 
     RowBox[{"2.`", " ", "E13", " ", "s"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{"E11", "+", "E22"}], ")"}]}], "+", "E33", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E12", "-", "E21"}], ")"}], " ", "s"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6.`"}], "+", 
           RowBox[{"6.`", " ", "c"}]}], ")"}], " ", "E23"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6.`"}], "+", 
           RowBox[{"6.`", " ", "c"}]}], ")"}], " ", "E32"}], "+", 
        RowBox[{"6.`", " ", "E13", " ", "s"}], "-", 
        RowBox[{"6.`", " ", "E31", " ", "s"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2.`"}], "+", 
           RowBox[{"2.`", " ", "c"}]}], ")"}], " ", "E23"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2.`"}], "+", 
           RowBox[{"2.`", " ", "c"}]}], ")"}], " ", "E32"}], "+", 
        RowBox[{"2.`", " ", "E13", " ", "s"}], "-", 
        RowBox[{"2.`", " ", "E31", " ", "s"}]}], ")"}]}], "+", 
     RowBox[{"4.`", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2.`", " ", "E22"}], "-", 
        RowBox[{"1.`", " ", "E33"}], "+", 
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{"E11", "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "E11"}], "+", 
           RowBox[{"1.`", " ", "a", " ", "E13"}], "-", 
           RowBox[{"1.`", " ", "E22"}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "E22"}], "+", 
           RowBox[{"1.`", " ", "a", " ", "E31"}], "+", 
           RowBox[{"2.`", " ", "E33"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"E33", "+", 
           RowBox[{"1.`", " ", "E12", " ", "s"}], "-", 
           RowBox[{"1.`", " ", "E21", " ", "s"}]}], ")"}]}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1.`"}], " ", "E13"}], "-", 
           RowBox[{"1.`", " ", "E31"}], "-", 
           RowBox[{"1.`", " ", "E23", " ", "s"}], "+", 
           RowBox[{"1.`", " ", "E32", " ", "s"}]}], ")"}]}]}], ")"}]}]}], 
    "\[Equal]", 
    RowBox[{
     RowBox[{"4", " ", "a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"E12", "+", "E21"}], ")"}]}], "+", 
     RowBox[{"2.`", " ", "c", " ", "E23"}], "+", 
     RowBox[{"2.`", " ", "c", " ", "E32"}], "+", 
     RowBox[{"2.`", " ", "E31", " ", "s"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.73739824958046*^9, 3.737398273811534*^9}},
 CellLabel->"Out[44]=",ExpressionUUID->"033a7a64-aa37-4349-93fe-366384bcccc6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Share", "[", "]"}]], "Input",
 CellChangeTimes->{{3.737398366753211*^9, 3.737398368182782*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"b078504b-9d8a-4f9e-91a6-a415e3eb8192"],

Cell[BoxData["110112"], "Output",
 CellChangeTimes->{3.7373983691085157`*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"1b70b527-7be3-4a9d-bd8e-3ce70b60e290"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Not expected to pop out - it is a cubic, but it was worth trying \
just to  make sure there\nis no ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["trivial ",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["way to get the celestial sphere direction and reduce to 2D!",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.737398469014008*^9, 
  3.73739851957465*^9}},ExpressionUUID->"f57c4268-ac10-4948-9dff-\
45aa4fd148c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"rawxysoln", " ", "=", " ", 
   RowBox[{"Solve", "[", 
    RowBox[{"raw3Dxyqns", ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.737398329831509*^9, 3.73739837826335*^9}, {
  3.737398446889738*^9, 
  3.7373984626469097`*^9}},ExpressionUUID->"6e919e1d-5e76-4b8f-af15-\
3b13a6a32fe9"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.7373983639251957`*^9, 3.7373984425373363`*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"1c5dacc5-b752-4bd7-ad56-45448f5d12ba"]
}, Open  ]]
}, Open  ]],

Cell["----", "Subsubsection",
 CellChangeTimes->{{3.737398224280347*^9, 
  3.737398224767432*^9}},ExpressionUUID->"acd850ae-7226-4bba-a8c0-\
056bd1587c5c"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RRRinv  stuff  - seems OK checked:", "Section",
 CellChangeTimes->{{3.739841586712942*^9, 3.7398416026159*^9}, {
  3.739842960924457*^9, 3.7398429846997957`*^9}, {3.739844321728324*^9, 
  3.739844324063613*^9}},ExpressionUUID->"7cdc8766-0b55-4339-b45c-\
2f5b4931f7b0"],

Cell[CellGroupData[{

Cell["2D derivation", "Subsubsection",
 CellChangeTimes->{{3.7398430333553762`*^9, 
  3.739843050403185*^9}},ExpressionUUID->"94050e2b-3e08-4b9a-b825-\
941ee545f702"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeM2Dfrm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"b0", ",", "b1"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"c0", ",", "c1"}], "}"}], "}"}]}], "]"}], "//", "Expand"}], "//",
   "Factor"}]], "Input",
 CellChangeTimes->{{3.739808890868225*^9, 3.73980892729643*^9}},
 CellLabel->
  "In[1013]:=",ExpressionUUID->"944e2b97-b31a-4fea-b5fd-185669759c40"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c0"}], "-", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "-", 
        RowBox[{"b1", " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b1"}], " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b1"}], " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b0", " ", "c0"}], "+", 
         RowBox[{"b1", " ", "c0"}], "-", 
         RowBox[{"b0", " ", "c1"}], "+", 
         RowBox[{"b1", " ", "c1"}]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "-", 
        RowBox[{"b1", " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.739841895668285*^9},
 CellLabel->
  "Out[1013]=",ExpressionUUID->"161e5717-2c08-4b1f-b571-6feb2ed9c2e2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "is", " ", "a", " ", "2", "D", " ", "matrix", " ", "that", 
    " ", "is", " ", "the", " ", "Identity", " ", "when", " ", "the", " ", 
    "rotation", " ", "\"\<q\>\"", " ", "aligns", " ", "\"\<p\>\"", " ", 
    "with", " ", "\"\<r\>\""}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"qprtoRRR2D", " ", "=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"matq", " ", "=", " ", 
          RowBox[{"abToRot2D", "[", 
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1"}], " ", "}"}], "]"}]}], ",", 
         RowBox[{"matp", " ", "=", " ", 
          RowBox[{"abToRot2D", "[", 
           RowBox[{"{", 
            RowBox[{"p0", ",", "p1"}], " ", "}"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"matr", " ", "=", "   ", 
          RowBox[{"abToRot2D", "[", 
           RowBox[{"{", 
            RowBox[{"r0", ",", "r1"}], " ", "}"}], "]"}]}], ",", "matQprinv", 
         ",", "qprinv", ",", "matMerged"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"matQprinv", "=", " ", 
         RowBox[{"matq", ".", "matp", ".", 
          RowBox[{"Transpose", "[", "matr", "]"}]}]}], ";", " ", 
        RowBox[{"qprinv", " ", "=", " ", 
         RowBox[{"cprod", "[", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1"}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"cprod", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"p0", ",", "p1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"r0", ",", 
               RowBox[{"-", "r1"}]}], " ", "}"}]}], "]"}]}], "]"}]}], ";", 
        " ", 
        RowBox[{"matMerged", " ", "=", " ", 
         RowBox[{
          RowBox[{"abToRot2D", "[", "qprinv", "]"}], "//", "Simplify"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"(*", "  ", 
         RowBox[{
          RowBox[{"matQprinv", "  ", "-", " ", "matMerged"}], " ", "//", 
          "Simplify"}], " ", "*)"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}], 
         RowBox[{"Tr", "[", "matMerged", "]"}]}]}]}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.737988896184964*^9, 3.737989294333873*^9}, {
   3.737989388027458*^9, 3.737989565027155*^9}, {3.7379896024506407`*^9, 
   3.73798961622922*^9}, 3.739229742811007*^9, {3.7392297754733677`*^9, 
   3.739229819864966*^9}, {3.7392868116306477`*^9, 3.739286812260333*^9}, {
   3.739287040248925*^9, 3.73928705974713*^9}, {3.739287188693281*^9, 
   3.739287228257307*^9}, {3.739287320859022*^9, 3.739287321768415*^9}, {
   3.7398432336756144`*^9, 3.739843235770975*^9}},
 CellLabel->
  "In[1018]:=",ExpressionUUID->"f8a6cefb-0615-49be-81b6-57c9455828a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{
    RowBox[{"metricFromForm", "[", 
     RowBox[{"qprtoRRR2D", ",", 
      RowBox[{"{", 
       RowBox[{"q0", ",", "q1"}], " ", "}"}]}], "]"}], "//", "Expand"}], "//",
    "Factor"}]}]], "Input",
 CellChangeTimes->{{3.737991514902989*^9, 3.7379915597336473`*^9}, 
   3.739229850433468*^9, {3.739287236880681*^9, 3.739287269561205*^9}, {
   3.739843254736948*^9, 3.739843257649707*^9}, 
   3.739843444501739*^9},ExpressionUUID->"c16a1107-106d-499d-b1cd-\
3d5bdf08e3ce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "-", 
        RowBox[{"p1", " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r1"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r1"}]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "-", 
        RowBox[{"p1", " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r1"}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7398432463606358`*^9, 3.739843258083682*^9}},
 CellLabel->
  "Out[1020]=",ExpressionUUID->"0562dd41-023a-479b-a573-c884a7f232a7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RRRmat2", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p0_", ",", "p1_"}], " ", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r0_", ",", "r1_"}], " ", "}"}]}], "]"}], " ", ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r1"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "-", 
         RowBox[{"p1", " ", "r0"}], "+", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r1"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p1"}], " ", "r0"}], "+", 
         RowBox[{"p0", " ", "r1"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p1"}], " ", "r0"}], "+", 
         RowBox[{"p0", " ", "r1"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}]}], ")"}]}], ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"p0", " ", "r0"}], "+", 
          RowBox[{"p1", " ", "r0"}], "-", 
          RowBox[{"p0", " ", "r1"}], "+", 
          RowBox[{"p1", " ", "r1"}]}], ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "-", 
         RowBox[{"p1", " ", "r0"}], "+", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r1"}]}], ")"}]}]}], "}"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739288561476202*^9, 3.739288579100708*^9}, 
   3.739843309640218*^9},
 CellLabel->
  "In[1021]:=",ExpressionUUID->"987b5aea-f10c-4bed-b425-140e5fbf73e3"],

Cell[TextData[StyleBox["Sum over data array to get the RRRinv 2D profile \
matrix:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.74059608981213*^9, 
  3.74059611708372*^9}},ExpressionUUID->"0890b801-d0d9-40fe-b6b1-\
7636cf754680"],

Cell[BoxData[
 RowBox[{
  RowBox[{"profileM2DFrm3", "[", "data2DFrm_", "]"}], " ", ":=", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"in", " ", "this", " ", 
     RowBox[{"order", ":", " ", "tgt"}]}], ",", " ", "ref", ",", " ", 
    "initTgt", ",", " ", "globalQuat"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "data2DFrm", "]"}]}], ",", 
      RowBox[{"tgtList", " ", "=", " ", 
       RowBox[{"data2DFrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"refList", " ", "=", " ", 
       RowBox[{"data2DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"RRmat2", "[", 
       RowBox[{
        RowBox[{"tgtList", "[", 
         RowBox[{"[", "k", "]"}], "]"}], ",", 
        RowBox[{"refList", "[", 
         RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "len"}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740595791051589*^9, 3.7405960477896338`*^9}, {
  3.740596133580175*^9, 
  3.7405961557407846`*^9}},ExpressionUUID->"4e7d15e1-688d-49ac-b7ec-\
d87b26ff7b13"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RRRmat2", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b0", ",", "b1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c0", ",", "c1"}], "}"}]}], "]"}], "-", 
   RowBox[{"makeM2Dfrm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"b0", ",", "b1"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"c0", ",", "c1"}], "}"}], "}"}]}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.739843320201601*^9, 3.739843348593074*^9}},
 CellLabel->
  "In[1022]:=",ExpressionUUID->"fbb92218-fd0c-4f3a-9b2e-49d95dbb4612"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.739843349134245*^9},
 CellLabel->
  "Out[1022]=",ExpressionUUID->"a3fa7bc8-853d-4461-9d8d-40f50636e463"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D derivation", "Subsubsection",
 CellChangeTimes->{{3.7398430333553762`*^9, 
  3.739843059418419*^9}},ExpressionUUID->"1686d8c9-cab4-4bc1-8f7c-\
4402140a57d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "is", " ", "a", " ", "matrix", " ", "that", " ", "is", " ", 
    "the", " ", "Identity", " ", "when", " ", "the", " ", "rotation", " ", 
    "\"\<q\>\"", " ", "aligns", " ", "\"\<p\>\"", " ", "with", " ", 
    "\"\<r\>\""}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"qprtoRRR", " ", "=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"matq", " ", "=", " ", 
          RowBox[{"QuatToRot", "[", 
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}]}], 
         ",", 
         RowBox[{"matp", " ", "=", " ", 
          RowBox[{"QuatToRot", "[", 
           RowBox[{"{", 
            RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "]"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"matr", " ", "=", "   ", 
          RowBox[{"QuatToRot", "[", 
           RowBox[{"{", 
            RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}], "]"}]}], 
         ",", "matQprinv", ",", "qprinv", ",", "matMerged"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"matQprinv", "=", " ", 
         RowBox[{"matq", ".", "matp", ".", 
          RowBox[{"Transpose", "[", "matr", "]"}]}]}], ";", 
        "\[IndentingNewLine]", " ", 
        RowBox[{"qprinv", " ", "=", " ", 
         RowBox[{"qprod", "[", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ",", 
           RowBox[{"qprod", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"r0", ",", 
               RowBox[{"-", "r1"}], ",", 
               RowBox[{"-", "r2"}], ",", 
               RowBox[{"-", "r3"}]}], "}"}]}], "]"}]}], "]"}]}], ";", " ", 
        RowBox[{"matMerged", " ", "=", " ", 
         RowBox[{
          RowBox[{"QuatToRot", "[", "qprinv", "]"}], "//", "Simplify"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"(*", "  ", 
         RowBox[{
          RowBox[{"matQprinv", "  ", "-", " ", "matMerged"}], " ", "//", 
          "Simplify"}], " ", "*)"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}], 
         RowBox[{"(", " ", 
          RowBox[{
           RowBox[{"Tr", "[", "matMerged", "]"}], " ", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["q0", "2"], "+", 
              SuperscriptBox["q1", "2"], "+", 
              SuperscriptBox["q2", "2"], "+", 
              SuperscriptBox["q3", "2"]}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["p0", "2"], "+", 
              SuperscriptBox["p1", "2"], "+", 
              SuperscriptBox["p2", "2"], "+", 
              SuperscriptBox["p3", "2"]}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r0", "2"], "+", 
              SuperscriptBox["r1", "2"], "+", 
              SuperscriptBox["r2", "2"], "+", 
              SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.737988896184964*^9, 3.737989294333873*^9}, {
   3.737989388027458*^9, 3.737989565027155*^9}, {3.7379896024506407`*^9, 
   3.73798961622922*^9}, 3.739229742811007*^9, {3.7392297754733677`*^9, 
   3.739229819864966*^9}, {3.739843367269329*^9, 3.739843420411235*^9}, {
   3.739843630518258*^9, 3.739843636903915*^9}, {3.739843674926059*^9, 
   3.739843707865514*^9}, {3.7405953153200274`*^9, 
   3.740595343789819*^9}},ExpressionUUID->"c2126542-e73d-4223-a9a7-\
345e21374b91"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ".", 
  RowBox[{"{", 
   RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}]], "Input",
 CellLabel->
  "In[1026]:=",ExpressionUUID->"3cb3cb1e-6a6c-4a2d-ba75-0594d67dd0d8"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["q0", "2"], "+", 
  SuperscriptBox["q1", "2"], "+", 
  SuperscriptBox["q2", "2"], "+", 
  SuperscriptBox["q3", "2"]}]], "Output",
 CellChangeTimes->{3.7398436155485363`*^9},
 CellLabel->
  "Out[1026]=",ExpressionUUID->"361b7197-b80a-4840-b1ad-f85e4472369f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"   ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"metricFromForm", "[", 
      RowBox[{"qprtoRRR", ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//",
      "Expand"}], "//", "Factor"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.737991514902989*^9, 3.7379915597336473`*^9}, 
   3.739229850433468*^9, {3.7398434403477182`*^9, 3.739843467430863*^9}, {
   3.7398435397165613`*^9, 3.739843542475841*^9}},
 CellLabel->
  "In[1028]:=",ExpressionUUID->"67f769be-f44b-4da6-a37c-9d784f98d2d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "2"]}], " ", 
       SuperscriptBox["r0", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r0", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r1", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r1", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "+", 
      RowBox[{"4", " ", "p2", " ", "p3", " ", "r2", " ", "r3"}], "-", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r3", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r3", "2"]}], "+", 
      RowBox[{"4", " ", "p1", " ", "r1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], "+", 
      RowBox[{"4", " ", "p0", " ", "r0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["p0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r0", "2"], "-", 
         SuperscriptBox["r1", "2"], "-", 
         SuperscriptBox["r2", "2"], "-", 
         SuperscriptBox["r3", "2"]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["p1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r0", "2"], "-", 
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "+", 
         SuperscriptBox["r3", "2"]}], ")"}]}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "2"]}], " ", 
       SuperscriptBox["r0", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r0", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r1", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r1", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "-", 
      RowBox[{"4", " ", "p2", " ", "p3", " ", "r2", " ", "r3"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p2", "-", "p3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"p2", "+", "p3"}], ")"}], " ", 
       SuperscriptBox["r3", "2"]}], "+", 
      RowBox[{"4", " ", "p1", " ", "r0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}], "-", 
      RowBox[{"4", " ", "p0", " ", "r1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["p1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r0", "2"], "-", 
         SuperscriptBox["r1", "2"], "-", 
         SuperscriptBox["r2", "2"], "-", 
         SuperscriptBox["r3", "2"]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["p0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r0", "2"], "-", 
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "+", 
         SuperscriptBox["r3", "2"]}], ")"}]}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r0", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r0", "2"]}], "-", 
      RowBox[{"4", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "-", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r1", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r1", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "+", 
      RowBox[{"4", " ", "p1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}]}], ")"}], " ", "r3"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         SuperscriptBox["p3", "2"]}], ")"}], " ", 
       SuperscriptBox["r3", "2"]}], "-", 
      RowBox[{"4", " ", "p0", " ", "r2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["p1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r0", "2"], "+", 
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "-", 
         SuperscriptBox["r3", "2"]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["p0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r0", "2"], "+", 
         SuperscriptBox["r1", "2"], "-", 
         SuperscriptBox["r2", "2"], "+", 
         SuperscriptBox["r3", "2"]}], ")"}]}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["p2", "2"]}], " ", 
       SuperscriptBox["r0", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r0", "2"]}], "+", 
      RowBox[{"4", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "+", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r1", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r1", "2"]}], "-", 
      RowBox[{"4", " ", "p1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}]}], ")"}], " ", "r2"}], "-", 
      RowBox[{
       SuperscriptBox["p2", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "-", 
      RowBox[{"4", " ", "p0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}]}], ")"}], " ", "r3"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p2", "2"], "+", 
         SuperscriptBox["p3", "2"]}], ")"}], " ", 
       SuperscriptBox["r3", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["p0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r0", "2"], "+", 
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "-", 
         SuperscriptBox["r3", "2"]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["p1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r0", "2"], "+", 
         SuperscriptBox["r1", "2"], "-", 
         SuperscriptBox["r2", "2"], "+", 
         SuperscriptBox["r3", "2"]}], ")"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7398434683586817`*^9, 3.739843545402063*^9, 
  3.739843714962513*^9},
 CellLabel->
  "Out[1028]=",ExpressionUUID->"9687f1ae-1847-4edd-8650-31946cc6a888"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RRRmat3", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p0_", ",", "p1_", ",", "p2_", ",", "p3_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r0_", ",", "r1_", ",", "r2_", ",", "r3_"}], "}"}]}], "]"}], " ",
   ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "+", 
       RowBox[{"4", " ", "p0", " ", "p1", " ", "r0", " ", "r1"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "+", 
       RowBox[{"4", " ", "p0", " ", "p2", " ", "r0", " ", "r2"}], "+", 
       RowBox[{"4", " ", "p1", " ", "p2", " ", "r1", " ", "r2"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "+", 
       RowBox[{"4", " ", "p0", " ", "p3", " ", "r0", " ", "r3"}], "+", 
       RowBox[{"4", " ", "p1", " ", "p3", " ", "r1", " ", "r3"}], "+", 
       RowBox[{"4", " ", "p2", " ", "p3", " ", "r2", " ", "r3"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r3", "2"]}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p1"}], " ", "r0"}], "+", 
         RowBox[{"p0", " ", "r1"}], "-", 
         RowBox[{"p3", " ", "r2"}], "+", 
         RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p2"}], " ", "r0"}], "+", 
         RowBox[{"p3", " ", "r1"}], "+", 
         RowBox[{"p0", " ", "r2"}], "-", 
         RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p3"}], " ", "r0"}], "-", 
         RowBox[{"p2", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r2"}], "+", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p1"}], " ", "r0"}], "+", 
         RowBox[{"p0", " ", "r1"}], "-", 
         RowBox[{"p3", " ", "r2"}], "+", 
         RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p0", "2"]}], " ", 
        SuperscriptBox["r0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{"4", " ", "p0", " ", "p1", " ", "r0", " ", "r1"}], "+", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "+", 
       RowBox[{"4", " ", "p1", " ", "p3", " ", "r0", " ", "r2"}], "-", 
       RowBox[{"4", " ", "p0", " ", "p3", " ", "r1", " ", "r2"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{"4", " ", "p1", " ", "p2", " ", "r0", " ", "r3"}], "+", 
       RowBox[{"4", " ", "p0", " ", "p2", " ", "r1", " ", "r3"}], "-", 
       RowBox[{"4", " ", "p2", " ", "p3", " ", "r2", " ", "r3"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r3", "2"]}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "-", 
         RowBox[{"p0", " ", "r2"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}], "-", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p2"}], " ", "r0"}], "+", 
         RowBox[{"p3", " ", "r1"}], "+", 
         RowBox[{"p0", " ", "r2"}], "-", 
         RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "-", 
         RowBox[{"p0", " ", "r2"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p0", "2"]}], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{"4", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{"4", " ", "p0", " ", "p2", " ", "r0", " ", "r2"}], "+", 
       RowBox[{"4", " ", "p0", " ", "p3", " ", "r1", " ", "r2"}], "+", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "+", 
       RowBox[{"4", " ", "p1", " ", "p2", " ", "r0", " ", "r3"}], "-", 
       RowBox[{"4", " ", "p1", " ", "p3", " ", "r1", " ", "r3"}], "-", 
       RowBox[{"4", " ", "p0", " ", "p1", " ", "r2", " ", "r3"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r3", "2"]}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}], "-", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "-", 
         RowBox[{"p0", " ", "r2"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p3"}], " ", "r0"}], "-", 
         RowBox[{"p2", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r2"}], "+", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}], "-", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}], "-", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "-", 
         RowBox[{"p0", " ", "r2"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["p0", "2"]}], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r0", "2"]}], "+", 
       RowBox[{"4", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r1", "2"]}], "-", 
       RowBox[{"4", " ", "p1", " ", "p3", " ", "r0", " ", "r2"}], "-", 
       RowBox[{"4", " ", "p1", " ", "p2", " ", "r1", " ", "r2"}], "-", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{"4", " ", "p0", " ", "p3", " ", "r0", " ", "r3"}], "-", 
       RowBox[{"4", " ", "p0", " ", "p2", " ", "r1", " ", "r3"}], "+", 
       RowBox[{"4", " ", "p0", " ", "p1", " ", "r2", " ", "r3"}], "+", 
       RowBox[{
        SuperscriptBox["p0", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p2", "2"], " ", 
        SuperscriptBox["r3", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["p3", "2"], " ", 
        SuperscriptBox["r3", "2"]}]}]}], "}"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739288399040021*^9, 3.739288468580472*^9}, 
   3.7392885162784033`*^9, 3.739843756947702*^9, 3.739843911134975*^9, 
   3.739843949533391*^9, {3.739843984183301*^9, 3.7398440125801487`*^9}},
 CellLabel->
  "In[363]:=",ExpressionUUID->"d1b7705e-ad10-45d9-a9a1-bdc6caa0c0f9"],

Cell[TextData[StyleBox["Now build the matrix that is needed for the RRRinv3D \
solution of 3D frame rotation:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.740595740863247*^9, 
  3.740595783414592*^9}},ExpressionUUID->"da9ed370-9730-4aa0-a2e6-\
089a3606b66a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"profileRRmat3XX", "[", "data3DFrm_", "]"}], " ", ":=", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"in", " ", "this", " ", 
     RowBox[{"order", ":", " ", "tgt"}]}], ",", " ", "ref", ",", " ", 
    "initTgt", ",", " ", "globalQuat"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "data3DFrm", "]"}]}], ",", 
      RowBox[{"tgtList", " ", "=", " ", 
       RowBox[{"data3DFrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"refList", " ", "=", " ", 
       RowBox[{"data3DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"RRmat3", "[", 
       RowBox[{
        RowBox[{"tgtList", "[", 
         RowBox[{"[", "k", "]"}], "]"}], ",", 
        RowBox[{"refList", "[", 
         RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "len"}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740595791051589*^9, 3.7405960477896338`*^9}, {
  3.741013490530176*^9, 
  3.741013495322693*^9}},ExpressionUUID->"cfbcf68e-7a41-4395-968a-\
62f3d1ad0bc2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"qprtoRRR", " ", "-", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], ".", 
    RowBox[{"RRRmat3", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}], " ", 
    ".", 
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.739844045434319*^9, 3.73984409582652*^9}},
 CellLabel->
  "In[1041]:=",ExpressionUUID->"688056b7-5556-4aac-a106-d06b71c257c2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.7398440994657993`*^9},
 CellLabel->
  "Out[1041]=",ExpressionUUID->"c5e4f7be-2c0a-44ef-a3db-a76b381e3ec0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Correction - traceless version of  3DFrm \
sign-resolved profile:",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.7410132925460052`*^9, 
  3.741013322659048*^9}},ExpressionUUID->"47c53e63-a183-4ca8-9a56-\
7d5911c1f601"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"2", "D", " ", "version"}], ",", " ", 
    RowBox[{"used", " ", "in", " ", 
     RowBox[{"makeM2Dfrm", "[", 
      RowBox[{"tgt", ",", "ref"}], "]"}]}]}], "  ", "*)"}], 
  RowBox[{
   RowBox[{"metricFromForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}], 
      RowBox[{"Tr", "[", 
       RowBox[{
        RowBox[{"abToRot2D", "[", 
         RowBox[{"{", 
          RowBox[{"a0", ",", "a1"}], "}"}], "]"}], ".", 
        RowBox[{"abToRot2D", "[", 
         RowBox[{"{", 
          RowBox[{"b0", ",", "b1"}], "}"}], "]"}], ".", 
        RowBox[{"abToRot2D", "[", 
         RowBox[{"{", 
          RowBox[{"c0", ",", 
           RowBox[{"-", "c1"}]}], "}"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a0", ",", "a1"}], "}"}]}], "]"}], "//", "Factor"}]}]], "Input",\

 CellChangeTimes->{{3.7410187872536373`*^9, 3.741018827076281*^9}},
 CellLabel->
  "In[403]:=",ExpressionUUID->"97964103-5295-4761-8d23-21c2af5199f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c0"}], "-", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "-", 
        RowBox[{"b1", " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b1"}], " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b1"}], " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b0", " ", "c0"}], "+", 
         RowBox[{"b1", " ", "c0"}], "-", 
         RowBox[{"b0", " ", "c1"}], "+", 
         RowBox[{"b1", " ", "c1"}]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "-", 
        RowBox[{"b1", " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.74101882102353*^9, 3.7410188276319933`*^9}},
 CellLabel->
  "Out[403]=",ExpressionUUID->"300cdb7b-66c2-4bdc-b673-172c4e625312"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "-", 
   RowBox[{"makeM2Dfrm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"b0", ",", "b1"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"c0", ",", "c1"}], "}"}], "}"}]}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.741018849993437*^9, 3.741018856804551*^9}},
 CellLabel->
  "In[404]:=",ExpressionUUID->"9f7c13cb-c65e-488b-8149-e1c6e19833e5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741018857971073*^9},
 CellLabel->
  "Out[404]=",ExpressionUUID->"06d658e8-99c1-4ccc-868c-58dfd2f24c7f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"argRRRQ", "=", 
  RowBox[{
   RowBox[{"metricFromForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}], " ", 
      RowBox[{"Tr", "[", 
       RowBox[{
        RowBox[{"QuatToRot", "[", 
         RowBox[{"{", 
          RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], ".", 
        
        RowBox[{"QuatToRot", "[", 
         RowBox[{"{", 
          RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "]"}], ".", 
        
        RowBox[{"QuatToRot", "[", 
         RowBox[{"{", 
          RowBox[{"r0", ",", 
           RowBox[{"-", "r1"}], ",", 
           RowBox[{"-", "r2"}], ",", 
           RowBox[{"-", "r3"}]}], "}"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.741011891575848*^9, 3.741012006432331*^9}, {
  3.741013343606039*^9, 3.74101334411514*^9}},
 CellLabel->
  "In[374]:=",ExpressionUUID->"a5cb1ff0-e7ea-4eb8-a42d-15638275469b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "2"]}], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "+", 
        RowBox[{"8", " ", "p2", " ", "p3", " ", "r2", " ", "r3"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["p3", "2"]}]}], ")"}], " ", 
         SuperscriptBox["r3", "2"]}], "+", 
        RowBox[{"8", " ", "p1", " ", "r1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2", " ", "r2"}], "+", 
           RowBox[{"p3", " ", "r3"}]}], ")"}]}], "+", 
        RowBox[{"8", " ", "p0", " ", "r0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "r1"}], "+", 
           RowBox[{"p2", " ", "r2"}], "+", 
           RowBox[{"p3", " ", "r3"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["r0", "2"]}], "-", 
           SuperscriptBox["r1", "2"], "-", 
           SuperscriptBox["r2", "2"], "-", 
           SuperscriptBox["r3", "2"]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r1", "2"]}], "+", 
           SuperscriptBox["r2", "2"], "+", 
           SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["p1", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "+", 
        RowBox[{"8", " ", "p1", " ", "p3", " ", "r0", " ", "r2"}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{"8", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "r0"}], "+", 
           RowBox[{"p3", " ", "r2"}]}], ")"}], " ", "r3"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p1", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["p2", "2"]}], "+", 
           SuperscriptBox["p3", "2"]}], ")"}], " ", 
         SuperscriptBox["r3", "2"]}], "-", 
        RowBox[{"8", " ", "p0", " ", "r1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "r0"}], "+", 
           RowBox[{"p3", " ", "r2"}], "-", 
           RowBox[{"p2", " ", "r3"}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r1", "2"]}], "+", 
           SuperscriptBox["r2", "2"], "+", 
           SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{"8", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "+", 
        RowBox[{"8", " ", "p1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2", " ", "r0"}], "-", 
           RowBox[{"p3", " ", "r1"}]}], ")"}], " ", "r3"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           SuperscriptBox["p3", "2"]}], ")"}], " ", 
         SuperscriptBox["r3", "2"]}], "-", 
        RowBox[{"8", " ", "p0", " ", "r2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2", " ", "r0"}], "-", 
           RowBox[{"p3", " ", "r1"}], "+", 
           RowBox[{"p1", " ", "r3"}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r3", "2"]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["r1", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r2", "2"]}], "+", 
           SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "2"]}], " ", 
         SuperscriptBox["r0", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "+", 
        RowBox[{"8", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{"8", " ", "p1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p3", " ", "r0"}], "+", 
           RowBox[{"p2", " ", "r1"}]}], ")"}], " ", "r2"}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{"8", " ", "p0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p3", " ", "r0"}], "+", 
           RowBox[{"p2", " ", "r1"}], "-", 
           RowBox[{"p1", " ", "r2"}]}], ")"}], " ", "r3"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           SuperscriptBox["p3", "2"]}], ")"}], " ", 
         SuperscriptBox["r3", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r3", "2"]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["r1", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r2", "2"]}], "+", 
           SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7410133847299767`*^9},
 CellLabel->
  "Out[374]=",ExpressionUUID->"fc618714-5d33-4cc9-8425-fc2a5be2c68a"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Tr", "[", "argRRRQ", "]"}], ",", 
    RowBox[{"argRRRQ", "-", 
     RowBox[{"Transpose", "[", "argRRRQ", "]"}]}], ",", 
    RowBox[{"Eigenvalues", "[", "argRRRQ", "]"}], ",", 
    RowBox[{"Det", "[", "argRRRQ", "]"}]}], "}"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.741013427437331*^9, 3.7410134411773453`*^9}},
 CellLabel->
  "In[376]:=",ExpressionUUID->"f3f88609-ead6-4ff1-b0ea-9dd59672029a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["3", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "16"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p0", "2"], "+", 
       SuperscriptBox["p1", "2"], "+", 
       SuperscriptBox["p2", "2"], "+", 
       SuperscriptBox["p3", "2"]}], ")"}], "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r0", "2"], "+", 
       SuperscriptBox["r1", "2"], "+", 
       SuperscriptBox["r2", "2"], "+", 
       SuperscriptBox["r3", "2"]}], ")"}], "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.74101344484435*^9},
 CellLabel->
  "Out[376]=",ExpressionUUID->"02165591-2054-439b-93d1-e9b686cc038b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RRRQmat3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p0_", ",", "p1_", ",", "p2_", ",", "p3_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r0_", ",", "r1_", ",", "r2_", ",", "r3_"}], "}"}]}], "]"}], " ",
   ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "2"]}], " ", 
          SuperscriptBox["r0", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r0", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "+", 
         RowBox[{"8", " ", "p2", " ", "p3", " ", "r2", " ", "r3"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["p3", "2"]}]}], ")"}], " ", 
          SuperscriptBox["r3", "2"]}], "+", 
         RowBox[{"8", " ", "p1", " ", "r1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", " ", "r2"}], "+", 
            RowBox[{"p3", " ", "r3"}]}], ")"}]}], "+", 
         RowBox[{"8", " ", "p0", " ", "r0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", " ", "r1"}], "+", 
            RowBox[{"p2", " ", "r2"}], "+", 
            RowBox[{"p3", " ", "r3"}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["p0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["r0", "2"]}], "-", 
            SuperscriptBox["r1", "2"], "-", 
            SuperscriptBox["r2", "2"], "-", 
            SuperscriptBox["r3", "2"]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r0", "2"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["r1", "2"]}], "+", 
            SuperscriptBox["r2", "2"], "+", 
            SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p1"}], " ", "r0"}], "+", 
         RowBox[{"p0", " ", "r1"}], "-", 
         RowBox[{"p3", " ", "r2"}], "+", 
         RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p2"}], " ", "r0"}], "+", 
         RowBox[{"p3", " ", "r1"}], "+", 
         RowBox[{"p0", " ", "r2"}], "-", 
         RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p3"}], " ", "r0"}], "-", 
         RowBox[{"p2", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r2"}], "+", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p1"}], " ", "r0"}], "+", 
         RowBox[{"p0", " ", "r1"}], "-", 
         RowBox[{"p3", " ", "r2"}], "+", 
         RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["p1", "2"], " ", 
          SuperscriptBox["r0", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r0", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r0", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "+", 
         RowBox[{"8", " ", "p1", " ", "p3", " ", "r0", " ", "r2"}], "-", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "-", 
         RowBox[{"8", " ", "p2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", " ", "r0"}], "+", 
            RowBox[{"p3", " ", "r2"}]}], ")"}], " ", "r3"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p1", "2"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["p2", "2"]}], "+", 
            SuperscriptBox["p3", "2"]}], ")"}], " ", 
          SuperscriptBox["r3", "2"]}], "-", 
         RowBox[{"8", " ", "p0", " ", "r1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1", " ", "r0"}], "+", 
            RowBox[{"p3", " ", "r2"}], "-", 
            RowBox[{"p2", " ", "r3"}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["p0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r0", "2"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["r1", "2"]}], "+", 
            SuperscriptBox["r2", "2"], "+", 
            SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "-", 
         RowBox[{"p0", " ", "r2"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}], "-", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p2"}], " ", "r0"}], "+", 
         RowBox[{"p3", " ", "r1"}], "+", 
         RowBox[{"p0", " ", "r2"}], "-", 
         RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "-", 
         RowBox[{"p0", " ", "r2"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r0", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r0", "2"]}], "-", 
         RowBox[{"8", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "-", 
         RowBox[{
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "+", 
         RowBox[{"8", " ", "p1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", " ", "r0"}], "-", 
            RowBox[{"p3", " ", "r1"}]}], ")"}], " ", "r3"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            SuperscriptBox["p3", "2"]}], ")"}], " ", 
          SuperscriptBox["r3", "2"]}], "-", 
         RowBox[{"8", " ", "p0", " ", "r2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p2", " ", "r0"}], "-", 
            RowBox[{"p3", " ", "r1"}], "+", 
            RowBox[{"p1", " ", "r3"}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r0", "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["r3", "2"]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["p0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r0", "2"], "+", 
            SuperscriptBox["r1", "2"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["r2", "2"]}], "+", 
            SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}], "-", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "-", 
         RowBox[{"p0", " ", "r2"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "p3"}], " ", "r0"}], "-", 
         RowBox[{"p2", " ", "r1"}], "+", 
         RowBox[{"p1", " ", "r2"}], "+", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p0", " ", "r0"}], "+", 
         RowBox[{"p1", " ", "r1"}], "+", 
         RowBox[{"p2", " ", "r2"}], "+", 
         RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}], "-", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "r0"}], "-", 
         RowBox[{"p0", " ", "r1"}], "+", 
         RowBox[{"p3", " ", "r2"}], "-", 
         RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p3", " ", "r0"}], "+", 
         RowBox[{"p2", " ", "r1"}], "-", 
         RowBox[{"p1", " ", "r2"}], "-", 
         RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "r0"}], "-", 
         RowBox[{"p3", " ", "r1"}], "-", 
         RowBox[{"p0", " ", "r2"}], "+", 
         RowBox[{"p1", " ", "r3"}]}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["p2", "2"]}], " ", 
          SuperscriptBox["r0", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r0", "2"]}], "+", 
         RowBox[{"8", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r1", "2"]}], "-", 
         RowBox[{"8", " ", "p1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p3", " ", "r0"}], "+", 
            RowBox[{"p2", " ", "r1"}]}], ")"}], " ", "r2"}], "-", 
         RowBox[{
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p3", "2"], " ", 
          SuperscriptBox["r2", "2"]}], "-", 
         RowBox[{"8", " ", "p0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p3", " ", "r0"}], "+", 
            RowBox[{"p2", " ", "r1"}], "-", 
            RowBox[{"p1", " ", "r2"}]}], ")"}], " ", "r3"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["p2", "2"], "+", 
            SuperscriptBox["p3", "2"]}], ")"}], " ", 
          SuperscriptBox["r3", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["p0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r0", "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["r3", "2"]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r0", "2"], "+", 
            SuperscriptBox["r1", "2"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["r2", "2"]}], "+", 
            SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}]}], "}"}]}], 
   "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741013376058155*^9, 3.741013395817677*^9}},
 CellLabel->
  "In[375]:=",ExpressionUUID->"23afd086-745d-4f2f-b87b-031342db5d2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Prototype", " ", "*)"}], "  ", 
  RowBox[{
   RowBox[{"makeM2Dfrm", "[", 
    RowBox[{"frmTgt_", ",", "frmRef_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mm11", "=", "0"}], ",", 
       RowBox[{"mm12", "=", "0"}], ",", "b0", ",", "b1", ",", "c0", ",", "c1",
        ",", "k", ",", 
       RowBox[{"num", " ", "=", " ", 
        RowBox[{"Length", "[", "frmRef", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"b0", "=", 
          RowBox[{"frmTgt", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ";", 
         RowBox[{"b1", "=", 
          RowBox[{"frmTgt", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "2"}], "]"}], "]"}]}], ";", 
         RowBox[{"c0", "=", 
          RowBox[{"frmRef", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ";", 
         RowBox[{"c1", "=", 
          RowBox[{"frmRef", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "2"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"mm11", " ", "+=", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b0", "2"], "-", 
              SuperscriptBox["b1", "2"]}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["c0", "2"], "-", 
              SuperscriptBox["c1", "2"]}], ")"}]}], " ", "+", " ", 
           RowBox[{"4", " ", "b0", " ", "b1", " ", "c0", " ", "c1"}]}]}], " ",
          ";", " ", 
         RowBox[{"mm12", "+=", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b0", "2"], "-", 
              SuperscriptBox["b1", "2"]}], ")"}], "2", " ", "c0", " ", "c1"}],
            "  ", "-", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["c0", "2"], "-", 
              SuperscriptBox["c1", "2"]}], ")"}], "2", " ", "b0", " ", 
            "b1"}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "num"}], "}"}]}], "]"}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"mm11", ",", "mm12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"mm12", ",", 
          RowBox[{"-", "mm11"}]}], "}"}]}], "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.739755342361414*^9, 3.739755360557476*^9}, 
   3.739755405557559*^9, {3.739755437749734*^9, 3.739755748875009*^9}, {
   3.739756055140979*^9, 3.739756081430745*^9}, {3.741018943417612*^9, 
   3.741018947966235*^9}},ExpressionUUID->"cdefac51-87ee-4c23-b372-\
18299ee72035"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Matches", " ", "args", " ", "of", " ", "makeM2Dfrm"}], " ", 
    "..."}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"makeM3Dfrm", "[", 
    RowBox[{"frmTgt_", ",", "frmRef_"}], "]"}], ":=", "\[IndentingNewLine]", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"MProfile", " ", "=", " ", 
        RowBox[{"Array", "[", 
         RowBox[{
          RowBox[{"0", "&"}], ",", 
          RowBox[{"{", 
           RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}], ",", "k", ",", 
       RowBox[{"num", " ", "=", " ", 
        RowBox[{"Length", "[", "frmRef", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "=", 
          RowBox[{"frmTgt", "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], ";", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}], "=", 
          RowBox[{"frmRef", "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], ";"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"MProfile", " ", "+=", " ", 
         RowBox[{"RRRQmat3D", "[", 
          RowBox[{
           RowBox[{"frmTgt", "[", 
            RowBox[{"[", "k", "]"}], "]"}], ",", 
           RowBox[{"frmRef", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "num"}], "}"}]}], "]"}], ";", 
      "MProfile"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.7410189543598022`*^9, {3.741019019486404*^9, 3.741019159549945*^9}, {
   3.741019190533391*^9, 3.741019216053938*^9}, {3.741019280950384*^9, 
   3.74101935412363*^9}, {3.741019464817266*^9, 3.741019506728881*^9}},
 CellLabel->
  "In[406]:=",ExpressionUUID->"87981f8d-0fad-4f0a-9684-3421c5c80d34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeM3Dfrm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}], "}"}]}], "]"}],
    "-", 
   RowBox[{"RRRQmat3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}]}], "//",
   "Simplify"}]], "Input",
 CellChangeTimes->{{3.7410196228542337`*^9, 3.741019711829934*^9}, {
  3.741019758290704*^9, 3.741019774733192*^9}},
 CellLabel->
  "In[411]:=",ExpressionUUID->"9ec90a50-b8ed-4ef8-a268-14bebba706be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.741019661713725*^9, 3.7410196828143997`*^9}, 
   3.74101971525313*^9, {3.741019766331665*^9, 3.741019775139969*^9}},
 CellLabel->
  "Out[411]=",ExpressionUUID->"522b499c-da93-4053-aa70-7d996ffb5c9e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Same", " ", "as", " ", "above"}], ",", " ", 
    RowBox[{
    "with", " ", "whole", " ", "\"\<build\>\"", " ", "value", " ", "as", " ", 
     "arg"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"profileRRRQmat3D", "[", "data3DFrm_", "]"}], " ", ":=", " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"in", " ", "this", " ", 
      RowBox[{"order", ":", " ", "tgt"}]}], ",", " ", "ref", ",", " ", 
     "initTgt", ",", " ", "globalQuat"}], " ", "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "data3DFrm", "]"}]}], ",", 
       RowBox[{"tgtList", " ", "=", " ", 
        RowBox[{"data3DFrm", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"refList", " ", "=", " ", 
        RowBox[{"data3DFrm", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"RRRQmat3D", "[", 
        RowBox[{
         RowBox[{"tgtList", "[", 
          RowBox[{"[", "k", "]"}], "]"}], ",", 
         RowBox[{"refList", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "len"}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740595791051589*^9, 3.7405960477896338`*^9}, {
  3.74101351292607*^9, 3.741013525925482*^9}, {3.7410195383996*^9, 
  3.741019555559946*^9}},ExpressionUUID->"9faa7562-4029-45b6-aed0-\
7aca94a1c10b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"costRRRQmat3D", "[", 
   RowBox[{"quatfor3DFrm_", ",", "profile3DFrm_"}], "]"}], ":=", " ", 
  RowBox[{
  "quatfor3DFrm", ".", "profile3DFrm", ".", "profile3DFrm"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.741013575640802*^9, 3.741013649363809*^9}},
 CellLabel->
  "In[416]:=",ExpressionUUID->"3cc92e91-917d-4b4b-9c1d-0b1a0ab3fa66"]
}, Open  ]],

Cell[TextData[StyleBox["Now do the V-only 3D frm cost: xxxx",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.741046598631679*^9, 
  3.74104661712783*^9}},ExpressionUUID->"a92af388-d58b-4230-893e-\
d36f59d88338"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4D section on rotation profiles:  RRRmat3 above seems \
wrong, use  RRRQmat3D.\n     Need traceless as in 2D?",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.741012273947392*^9, 3.741012283227141*^9}, {
  3.741012460321314*^9, 3.741012482161366*^9}, {3.741013672447846*^9, 
  3.741013687288088*^9}},ExpressionUUID->"edfe8e7d-6d30-4020-9f96-\
f6e78563e10f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ckRRR2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"metricFromForm", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}], " ", 
         RowBox[{"Tr", "[", 
          RowBox[{
           RowBox[{"abToRot2D", "[", 
            RowBox[{"{", 
             RowBox[{"a0", ",", "a1"}], "}"}], "]"}], ".", 
           RowBox[{"abToRot2D", "[", 
            RowBox[{"{", 
             RowBox[{"b0", ",", "b1"}], "}"}], "]"}], ".", 
           RowBox[{"abToRot2D", "[", 
            RowBox[{"{", 
             RowBox[{"c0", ",", 
              RowBox[{"-", "c1"}]}], "}"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"a0", ",", "a1"}], "}"}]}], "]"}], "//", "Simplify"}], "//", 
     "Expand"}], "//", "Factor"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.740963451976513*^9, 3.740963546514215*^9}, {
  3.740963904819585*^9, 3.740963906631288*^9}, {3.740964014361148*^9, 
  3.74096401658349*^9}, {3.7410125225237293`*^9, 3.7410125259772167`*^9}},
 CellLabel->
  "In[365]:=",ExpressionUUID->"361bc0c9-f704-4519-89fb-7d9f7032ae88"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Tr", "[", "ckRRR2", "]"}], ",", 
    RowBox[{"ckRRR2", "-", 
     RowBox[{"Transpose", "[", "ckRRR2", "]"}]}], ",", 
    RowBox[{"Eigenvalues", "[", "ckRRR2", "]"}], ",", 
    RowBox[{"(*", 
     RowBox[{"Prod", " ", "of", " ", "Eigenvalues"}], " ", "*)"}], ",", 
    RowBox[{"Det", "[", "ckRRR2", "]"}]}], "}"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7410125402131*^9, 3.741012577764576*^9}, {
  3.741012617193243*^9, 3.7410126470365133`*^9}},
 CellLabel->
  "In[369]:=",ExpressionUUID->"017f380f-f3ad-42d2-ab3b-bfbddcf61968"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b0", "2"], "+", 
         SuperscriptBox["b1", "2"]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["c0", "2"], "+", 
        SuperscriptBox["c1", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b0", "2"], "+", 
        SuperscriptBox["b1", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["c0", "2"], "+", 
        SuperscriptBox["c1", "2"]}], ")"}]}]}], "}"}], ",", "Null", ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b0", "2"], "+", 
        SuperscriptBox["b1", "2"]}], ")"}], "2"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["c0", "2"], "+", 
       SuperscriptBox["c1", "2"]}], ")"}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.74101257843182*^9, {3.741012633321851*^9, 3.74101264748282*^9}},
 CellLabel->
  "Out[369]=",ExpressionUUID->"c0dda40a-a920-48d0-901a-428e666fba94"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ckRRRQ", "=", 
  RowBox[{
   RowBox[{"metricFromForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}], " ", 
      RowBox[{"Tr", "[", 
       RowBox[{
        RowBox[{"QuatToRot", "[", 
         RowBox[{"{", 
          RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], ".", 
        
        RowBox[{"QuatToRot", "[", 
         RowBox[{"{", 
          RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "]"}], ".", 
        
        RowBox[{"QuatToRot", "[", 
         RowBox[{"{", 
          RowBox[{"r0", ",", 
           RowBox[{"-", "r1"}], ",", 
           RowBox[{"-", "r2"}], ",", 
           RowBox[{"-", "r3"}]}], "}"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.741011891575848*^9, 3.741012006432331*^9}},
 CellLabel->
  "In[358]:=",ExpressionUUID->"83f98ff8-c15d-4a2f-ae1c-934854f649b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "2"]}], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "+", 
        RowBox[{"8", " ", "p2", " ", "p3", " ", "r2", " ", "r3"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["p3", "2"]}]}], ")"}], " ", 
         SuperscriptBox["r3", "2"]}], "+", 
        RowBox[{"8", " ", "p1", " ", "r1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2", " ", "r2"}], "+", 
           RowBox[{"p3", " ", "r3"}]}], ")"}]}], "+", 
        RowBox[{"8", " ", "p0", " ", "r0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "r1"}], "+", 
           RowBox[{"p2", " ", "r2"}], "+", 
           RowBox[{"p3", " ", "r3"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["r0", "2"]}], "-", 
           SuperscriptBox["r1", "2"], "-", 
           SuperscriptBox["r2", "2"], "-", 
           SuperscriptBox["r3", "2"]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r1", "2"]}], "+", 
           SuperscriptBox["r2", "2"], "+", 
           SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "r0"}], "+", 
        RowBox[{"p0", " ", "r1"}], "-", 
        RowBox[{"p3", " ", "r2"}], "+", 
        RowBox[{"p2", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["p1", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "+", 
        RowBox[{"8", " ", "p1", " ", "p3", " ", "r0", " ", "r2"}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{"8", " ", "p2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "r0"}], "+", 
           RowBox[{"p3", " ", "r2"}]}], ")"}], " ", "r3"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p1", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["p2", "2"]}], "+", 
           SuperscriptBox["p3", "2"]}], ")"}], " ", 
         SuperscriptBox["r3", "2"]}], "-", 
        RowBox[{"8", " ", "p0", " ", "r1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "r0"}], "+", 
           RowBox[{"p3", " ", "r2"}], "-", 
           RowBox[{"p2", " ", "r3"}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r1", "2"]}], "+", 
           SuperscriptBox["r2", "2"], "+", 
           SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p2"}], " ", "r0"}], "+", 
        RowBox[{"p3", " ", "r1"}], "+", 
        RowBox[{"p0", " ", "r2"}], "-", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "-", 
        RowBox[{"8", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "+", 
        RowBox[{"8", " ", "p1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2", " ", "r0"}], "-", 
           RowBox[{"p3", " ", "r1"}]}], ")"}], " ", "r3"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           SuperscriptBox["p3", "2"]}], ")"}], " ", 
         SuperscriptBox["r3", "2"]}], "-", 
        RowBox[{"8", " ", "p0", " ", "r2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2", " ", "r0"}], "-", 
           RowBox[{"p3", " ", "r1"}], "+", 
           RowBox[{"p1", " ", "r3"}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r3", "2"]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["r1", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r2", "2"]}], "+", 
           SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p3"}], " ", "r0"}], "-", 
        RowBox[{"p2", " ", "r1"}], "+", 
        RowBox[{"p1", " ", "r2"}], "+", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p0", " ", "r0"}], "+", 
        RowBox[{"p1", " ", "r1"}], "+", 
        RowBox[{"p2", " ", "r2"}], "+", 
        RowBox[{"p3", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p1", " ", "r0"}], "-", 
        RowBox[{"p0", " ", "r1"}], "+", 
        RowBox[{"p3", " ", "r2"}], "-", 
        RowBox[{"p2", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p3", " ", "r0"}], "+", 
        RowBox[{"p2", " ", "r1"}], "-", 
        RowBox[{"p1", " ", "r2"}], "-", 
        RowBox[{"p0", " ", "r3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p2", " ", "r0"}], "-", 
        RowBox[{"p3", " ", "r1"}], "-", 
        RowBox[{"p0", " ", "r2"}], "+", 
        RowBox[{"p1", " ", "r3"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p2", "2"]}], " ", 
         SuperscriptBox["r0", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r0", "2"]}], "+", 
        RowBox[{"8", " ", "p2", " ", "p3", " ", "r0", " ", "r1"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r1", "2"]}], "-", 
        RowBox[{"8", " ", "p1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p3", " ", "r0"}], "+", 
           RowBox[{"p2", " ", "r1"}]}], ")"}], " ", "r2"}], "-", 
        RowBox[{
         SuperscriptBox["p2", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         SuperscriptBox["r2", "2"]}], "-", 
        RowBox[{"8", " ", "p0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p3", " ", "r0"}], "+", 
           RowBox[{"p2", " ", "r1"}], "-", 
           RowBox[{"p1", " ", "r2"}]}], ")"}], " ", "r3"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["p2", "2"], "+", 
           SuperscriptBox["p3", "2"]}], ")"}], " ", 
         SuperscriptBox["r3", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r3", "2"]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["p1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["r1", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["r2", "2"]}], "+", 
           SuperscriptBox["r3", "2"]}], ")"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.741011995389292*^9, 3.741012008852652*^9}},
 CellLabel->
  "Out[358]=",ExpressionUUID->"bd673954-c26f-42eb-b1b7-2751c1b73d64"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RRRmat3", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}], "-", 
   "ckRRRQ"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7410123849705477`*^9, 3.741012391466618*^9}},
 CellLabel->
  "In[364]:=",ExpressionUUID->"e2e21244-e0ce-42be-9252-48af6c718a6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7410123918796062`*^9},
 CellLabel->
  "Out[364]=",ExpressionUUID->"b114f2d2-11f6-4437-b992-1d1b9fdf7ba3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"NOT", " ", "ZERO"}], " ", "*)"}], "  ", 
  RowBox[{
   RowBox[{"Tr", "[", 
    RowBox[{"RRRmat3", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}], "]"}],
    "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.741012889214013*^9, 
  3.7410129116863422`*^9}},ExpressionUUID->"271bf5da-6286-4b1d-8061-\
58cdfdc997c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["p0", "2"], "+", 
    SuperscriptBox["p1", "2"], "+", 
    SuperscriptBox["p2", "2"], "+", 
    SuperscriptBox["p3", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["r0", "2"], "+", 
    SuperscriptBox["r1", "2"], "+", 
    SuperscriptBox["r2", "2"], "+", 
    SuperscriptBox["r3", "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.741012897690593*^9},
 CellLabel->
  "Out[373]=",ExpressionUUID->"07861cbe-3da7-4d30-af1c-4c174e8c9f04"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Eigenvalues", "[", 
     RowBox[{"RRRmat3", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}], 
     "]"}], ",", 
    RowBox[{"Det", "[", 
     RowBox[{"RRRmat3", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r0", ",", "r1", ",", "r2", ",", "r3"}], "}"}]}], "]"}], 
     "]"}]}], "}"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.741012717350971*^9, 3.7410127380822897`*^9}, {
   3.7410127768205023`*^9, 3.741012796863216*^9}, 3.741012841807094*^9},
 CellLabel->
  "In[372]:=",ExpressionUUID->"f33993d6-2499-4188-84de-9234051746eb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p0", "2"], "+", 
         SuperscriptBox["p1", "2"], "+", 
         SuperscriptBox["p2", "2"], "+", 
         SuperscriptBox["p3", "2"]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p0", "2"], "+", 
         SuperscriptBox["p1", "2"], "+", 
         SuperscriptBox["p2", "2"], "+", 
         SuperscriptBox["p3", "2"]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["p0", "2"], "+", 
         SuperscriptBox["p1", "2"], "+", 
         SuperscriptBox["p2", "2"], "+", 
         SuperscriptBox["p3", "2"]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["r1", "2"], "+", 
        SuperscriptBox["r2", "2"], "+", 
        SuperscriptBox["r3", "2"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p0", "2"], "+", 
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["p2", "2"], "+", 
        SuperscriptBox["p3", "2"]}], ")"}], "4"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r0", "2"], "+", 
       SuperscriptBox["r1", "2"], "+", 
       SuperscriptBox["r2", "2"], "+", 
       SuperscriptBox["r3", "2"]}], ")"}], "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.741012739741543*^9, 3.741012807165564*^9, 
  3.741012844205971*^9},
 CellLabel->
  "Out[372]=",ExpressionUUID->"b55fe443-3a25-4c5b-9b72-3686f504d3f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Det", "[", "ckRRRQ", "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7410120453484917`*^9, 3.741012046989627*^9}},
 CellLabel->
  "In[359]:=",ExpressionUUID->"d5c43cd5-49a0-4386-8dea-c045c607333e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["3", "16"]}], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p0", "2"], "+", 
     SuperscriptBox["p1", "2"], "+", 
     SuperscriptBox["p2", "2"], "+", 
     SuperscriptBox["p3", "2"]}], ")"}], "4"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r0", "2"], "+", 
     SuperscriptBox["r1", "2"], "+", 
     SuperscriptBox["r2", "2"], "+", 
     SuperscriptBox["r3", "2"]}], ")"}], "4"]}]], "Output",
 CellChangeTimes->{3.7410120493018913`*^9},
 CellLabel->
  "Out[359]=",ExpressionUUID->"cb1e296a-b518-4885-9463-4a02135ec867"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"(*", " ", 
   RowBox[{"THIS", " ", "IS", " ", "ZERO"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Tr", "[", "ckRRRQ", "]"}], ",", 
     RowBox[{"ckRRRQ", "-", 
      RowBox[{"Transpose", "[", "ckRRRQ", "]"}]}]}], "}"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{
  3.740965772650066*^9, {3.741012023980996*^9, 3.741012079668277*^9}, {
   3.741012919399602*^9, 
   3.741012923626299*^9}},ExpressionUUID->"f16162d1-51a2-49ef-b3a4-\
8885716901a6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7410120748660583`*^9, 3.741012080109346*^9}},
 CellLabel->
  "Out[361]=",ExpressionUUID->"63e6483b-6f5f-446f-92dd-0504626bd5fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigenvalues", "[", "ckRRRQ", "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7410121142609777`*^9, 3.741012117308807*^9}},
 CellLabel->
  "In[362]:=",ExpressionUUID->"895e7b7b-5303-4645-a3d8-2cd2e2fee160"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p0", "2"], "+", 
      SuperscriptBox["p1", "2"], "+", 
      SuperscriptBox["p2", "2"], "+", 
      SuperscriptBox["p3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r0", "2"], "+", 
      SuperscriptBox["r1", "2"], "+", 
      SuperscriptBox["r2", "2"], "+", 
      SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p0", "2"], "+", 
      SuperscriptBox["p1", "2"], "+", 
      SuperscriptBox["p2", "2"], "+", 
      SuperscriptBox["p3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r0", "2"], "+", 
      SuperscriptBox["r1", "2"], "+", 
      SuperscriptBox["r2", "2"], "+", 
      SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p0", "2"], "+", 
      SuperscriptBox["p1", "2"], "+", 
      SuperscriptBox["p2", "2"], "+", 
      SuperscriptBox["p3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r0", "2"], "+", 
      SuperscriptBox["r1", "2"], "+", 
      SuperscriptBox["r2", "2"], "+", 
      SuperscriptBox["r3", "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p0", "2"], "+", 
      SuperscriptBox["p1", "2"], "+", 
      SuperscriptBox["p2", "2"], "+", 
      SuperscriptBox["p3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r0", "2"], "+", 
      SuperscriptBox["r1", "2"], "+", 
      SuperscriptBox["r2", "2"], "+", 
      SuperscriptBox["r3", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.741012122289772*^9},
 CellLabel->
  "Out[362]=",ExpressionUUID->"a4da0eae-6bc3-4c0f-9c35-fd08ec93a860"]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["2Dimensional section on rotation profile manipulation",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.741012236331695*^9, 
  3.7410122554911747`*^9}},ExpressionUUID->"d14b866b-0fe9-4da8-a54f-\
26a6c6df3350"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "xxx  These are the elements of the 2D Figure library\n  coming from  ",
 StyleBox["TransRot-2D-demo-1.nb",
  FontSize->24,
  FontWeight->"Bold"],
 "\n in the  ",
 StyleBox["Horn-soln-dir/00plosCB-submit/mathka/",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox["  folder.",
  FontSize->24]
}], "Subchapter",
 CellChangeTimes->{{3.7398414046102543`*^9, 
  3.7398414434924088`*^9}},ExpressionUUID->"39d6f82b-b063-4059-b80b-\
73a348908f1b"],

Cell[CellGroupData[{

Cell["Data sample", "Subsubsection",
 CellChangeTimes->{{3.739842392913136*^9, 
  3.73984239639283*^9}},ExpressionUUID->"680b7eb2-d970-4d03-8077-\
2f528d2e5afc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Directory", "[", "]"}]], "Input",
 CellChangeTimes->{{3.73963390741082*^9, 3.7396339102958937`*^9}},
 CellLabel->
  "In[615]:=",ExpressionUUID->"28233604-b000-489b-9fca-05d7cbc192a2"],

Cell[BoxData["\<\"/home/hanson/Dropbox/Articles/Horn-soln-dir/00paper/figs\"\>\
"], "Output",
 CellChangeTimes->{3.739633910749032*^9},
 CellLabel->
  "Out[615]=",ExpressionUUID->"b8b8837d-8c5a-4b49-a83e-7da7ee1cd1f0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"angleerr", "=", " ", 
    RowBox[{"Pi", "/", "16"}]}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{"TheglobalRadP", "=", " ", ".4"}], ";", " ", 
   RowBox[{"TheglobalRadF", "=", " ", "0.2"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.739634484732428*^9, 3.739634487539481*^9}, {
  3.7396345409314632`*^9, 3.739634561130279*^9}},
 CellLabel->
  "In[619]:=",ExpressionUUID->"07152547-4efc-42b1-901b-d752f91eb959"],

Cell[BoxData[
 RowBox[{"Save", "[", 
  RowBox[{
  "\"\</home/hanson/Dropbox/Articles/Horn-soln-dir/000FIGURES/data2D100Ref.m\>\
\"", ",", "data2Dquats"}], "]"}]], "Input",
 CellChangeTimes->{{3.739634031306779*^9, 3.739634104966378*^9}, {
  3.7396341474708776`*^9, 3.739634156709741*^9}, {3.73963419515797*^9, 
  3.739634207405278*^9}, {3.739634288837405*^9, 3.73963428931682*^9}},
 CellLabel->
  "In[617]:=",ExpressionUUID->"4fb6632f-eb88-4ed3-bea0-4d4270424ceb"],

Cell[BoxData[
 RowBox[{"Save", "[", 
  RowBox[{
  "\"\</home/hanson/Dropbox/Articles/Horn-soln-dir/000FIGURES/data2D100Tgt.m\>\
\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "data2DquatsTgt", ",", " ", "TheglobalRadP", " ", ",", " ", 
     "TheglobalRadF"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.739634031306779*^9, 3.739634104966378*^9}, {
  3.7396341474708776`*^9, 3.7396341910699663`*^9}, {3.739634292389309*^9, 
  3.739634292949149*^9}, {3.7396345673000507`*^9, 3.73963461034623*^9}},
 CellLabel->
  "In[620]:=",ExpressionUUID->"29ffcf17-ac2f-4b34-adde-0a6c9af002fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Retrieve", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "Get", "[", 
    "\"\</home/hanson/Dropbox/Articles/Horn-soln-dir/000FIGURES/data2D100Ref.\
m\>\"", "]"}], ";", 
   RowBox[{
   "Get", "[", 
    "\"\</home/hanson/Dropbox/Articles/Horn-soln-dir/000FIGURES/data2D100Tgt.\
m\>\"", "]"}], ";", 
   RowBox[{"{", 
    RowBox[{"TheglobalRadP", " ", ",", " ", "TheglobalRadF"}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.739634221154203*^9, 3.7396343122614307`*^9}, {
  3.7396346246344843`*^9, 
  3.739634626265675*^9}},ExpressionUUID->"ad3c4614-55de-42a4-9b1a-\
c9855a5652be"]
}, Open  ]],

Cell["Other definitions:", "Subsubsection",
 CellChangeTimes->{{3.739842412697184*^9, 3.739842425408751*^9}, {
  3.739842775125452*^9, 
  3.739842775765655*^9}},ExpressionUUID->"4be16454-e59a-4516-9d76-\
7f9186db295c"],

Cell[CellGroupData[{

Cell["The 2D-related definitions:", "Subsubsection",
 CellChangeTimes->{{3.739842412697184*^9, 
  3.739842425408751*^9}},ExpressionUUID->"281d7328-b32e-4a95-9921-\
f9be027fbf54"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "make2DRotation", ",", "q2DToRot", ",", "abToRot2D", ",", "make2DAxes", ",",
    "\[IndentingNewLine]", "randomSphere1", ",", "randomBall2", ",", 
   "randomBall2CM", ",", "\[IndentingNewLine]", "forceCloseQframes", ",", 
   "\[IndentingNewLine]", "angleDiff", ",", "makeAngleDiffFromAB", ",", 
   "makeAngleExxFromAB", ",", "\[IndentingNewLine]", "delta2DF00", ",", 
   "chordDistance2DV12", ",", "chordCost2D", ",", "\[IndentingNewLine]", 
   "makeM2Dfrm", ",", "frmEigenvals2D", ",", "frmEigenvecs2D", ",", 
   "chordOptAngle", ",", "chordRRRCost2D"}], "}"}]], "Input",
 CellChangeTimes->{{3.7398260839246197`*^9, 3.739826145906234*^9}, {
   3.7398261785111094`*^9, 3.7398261970985823`*^9}, {3.739826345981222*^9, 
   3.739826375616811*^9}, {3.73983463387808*^9, 3.739834638637801*^9}, {
   3.739834672921761*^9, 3.73983468138524*^9}, {3.7398349432666492`*^9, 
   3.7398349799025908`*^9}, 
   3.739841460593844*^9},ExpressionUUID->"04e47709-a1af-452d-8709-\
59ef7b43e4c1"],

Cell["\<\
-------------------------------------------------------------------------\
\>", "Text",
 CellChangeTimes->{{3.739841551808001*^9, 
  3.739841554664261*^9}},ExpressionUUID->"e7dc5c12-49d4-4667-a2e5-\
76a9929404ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"make2DRotation", "[", "angle_", "  ", "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", " ", "=", " ", 
       RowBox[{
        RowBox[{"Cos", "[", "angle", "]"}], "//", "N"}]}], ",", " ", 
      RowBox[{"s", " ", "=", " ", 
       RowBox[{
        RowBox[{"Sin", "[", "angle", "]"}], "//", "N"}]}]}], " ", "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", " ", 
        RowBox[{"-", "s"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "c"}], "}"}]}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.737389564655231*^9, 3.737389593886417*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"a093c104-62cd-41eb-9bce-1370ca41f34c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cprod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x1_", ",", "y1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x2_", ",", "y2_"}], "}"}]}], "]"}], " ", ":=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"x1", " ", "x2"}], "-", 
     RowBox[{"y1", " ", "y2"}]}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x2", " ", "y1"}], "+", 
      RowBox[{"x1", " ", "y2"}]}], ")"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7392870839569263`*^9, 3.739287116104609*^9}, {
  3.739287147723661*^9, 3.739287158872325*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"d22068ce-800e-41e0-b61f-06726aa4a0ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abToRot2D", "[", 
   RowBox[{"{", 
    RowBox[{"a_", ",", "b_"}], "}"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}], ",", 
      RowBox[{
       RowBox[{"-", " ", "2"}], " ", "a", " ", "b"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b"}], ",", "  ", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}]}], "}"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7392868345814533`*^9, 3.739286913171174*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"930e35c2-ccec-49f4-99ea-20c1697c6cae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"q2DToRot", "[", 
   RowBox[{"{", 
    RowBox[{"a_", ",", "b_"}], "}"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}], ",", " ", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "a", " ", "b"}]}], "}"}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b"}], ",", " ", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}]}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.738156564476988*^9, 3.738156602260171*^9}, {
  3.73815668447661*^9, 3.7381567193884907`*^9}, {3.7393206420662107`*^9, 
  3.73932064572639*^9}},
 CellLabel->
  "In[223]:=",ExpressionUUID->"d2a5b725-b5ef-4e9f-adc7-d9838f205585"],

Cell[BoxData[
 RowBox[{
  RowBox[{"make2DAxes", "[", 
   RowBox[{"frameMat_", ",", 
    RowBox[{"center_:", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], " ", "}"}]}], ",", 
    RowBox[{"scale_:", "1.0"}], ",", 
    RowBox[{"th_:", "0.0"}], ",", 
    RowBox[{"ah_:", "0.05"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"Arrowheads", "[", "ah", "]"}], ",", "\[IndentingNewLine]", "Red",
     ",", 
    RowBox[{"Arrow", "[", "  ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"center", ",", 
        RowBox[{"center", "+", 
         RowBox[{"scale", "*", 
          RowBox[{"frameMat", ".", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}]}]}]}]}], "}"}], ",", "th"}], "]"}],
     " ", ",", "\[IndentingNewLine]", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"0", ",", " ", 
      RowBox[{"4", "/", "5"}], ",", " ", "0"}], "]"}], ",", 
    RowBox[{"Arrow", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"center", ",", 
        RowBox[{"center", "+", 
         RowBox[{"scale", "*", 
          RowBox[{"frameMat", ".", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}]}]}]}], "}"}], ",", "th"}], 
     "]"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.724962266380808*^9, 3.724962415241776*^9}, {
   3.724962579528475*^9, 3.724962643425647*^9}, {3.724962701864367*^9, 
   3.7249627200643597`*^9}, {3.724962772639485*^9, 3.724962774862871*^9}, {
   3.724962831319848*^9, 3.7249630084048777`*^9}, {3.724963121195372*^9, 
   3.724963154378106*^9}, 3.725126904660747*^9, {3.725127003827406*^9, 
   3.725127031115128*^9}, {3.7373917140531816`*^9, 3.7373917541244593`*^9}, {
   3.737392048606949*^9, 3.737392180961877*^9}, {3.737392214049733*^9, 
   3.737392218441057*^9}, 3.739383185300832*^9, {3.739383311110293*^9, 
   3.7393833126496143`*^9}, {3.739385137436995*^9, 3.7393851417222013`*^9}, 
   3.739385252164611*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"320cb707-92df-44e4-ad54-861ced6e81dd"],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"make2DAxes", "[", 
    RowBox[{
     RowBox[{"abToRot2D", "[", 
      RowBox[{
       RowBox[{"data2Dquats", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", ".5", ",", "0.02"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{".2", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.739382401047902*^9, 3.739382429023737*^9}, {
   3.739382504733777*^9, 3.7393825142238007`*^9}, {3.739382710450038*^9, 
   3.739382818189348*^9}, 3.739382871729686*^9, {3.739382910010785*^9, 
   3.739382938130518*^9}, {3.739383017860821*^9, 3.739383062787128*^9}, 
   3.739383093826009*^9, {3.739383373094935*^9, 3.739383459150187*^9}, {
   3.7397341109204903`*^9, 3.739734198047997*^9}, {3.7397342380896893`*^9, 
   3.739734293128998*^9}, {3.7398426488303843`*^9, 3.7398426545314417`*^9}, {
   3.740594624549253*^9, 
   3.740594654105072*^9}},ExpressionUUID->"96fca81f-ac50-4953-ad8b-\
d889f55c33fa"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.739842665889202*^9},ExpressionUUID->"73d041c8-7f0b-4d2a-826b-\
0d874ac55228"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Something very strange here....end points don\
\[CloseCurlyQuote]t give uniform \n     periodicity in the angle",
 FontSize->24,
 FontWeight->"Bold"]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739386878586029*^9, 3.7393868846817703`*^9}, {
   3.739441987832402*^9, 3.739442001704211*^9}, 
   3.7394421557271423`*^9},ExpressionUUID->"4cfa7922-0326-4cc5-be53-\
eeaf5e47be99"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "Pi"}], ",", 
       RowBox[{"2", "Pi"}]}], "}"}], ",", "2000"}], "]"}], ",", "20"}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.739442155727989*^9},
 CellLabel->
  "In[488]:=",ExpressionUUID->"bddf7b4c-3f09-4a2f-b0d7-ff66ceaaa5a6"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.504], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.504], Thickness[Small]}], RectangleBox[{-6.5, 0}, {-6., 34.},
      RoundingRadius->0], RectangleBox[{-6., 0}, {-5.5, 84.},
      RoundingRadius->0], RectangleBox[{-5.5, 0}, {-5., 101.},
      RoundingRadius->0], RectangleBox[{-5., 0}, {-4.5, 65.},
      RoundingRadius->0], RectangleBox[{-4.5, 0}, {-4., 77.},
      RoundingRadius->0], RectangleBox[{-4., 0}, {-3.5, 78.},
      RoundingRadius->0], RectangleBox[{-3.5, 0}, {-3., 88.},
      RoundingRadius->0], RectangleBox[{-3., 0}, {-2.5, 61.},
      RoundingRadius->0], RectangleBox[{-2.5, 0}, {-2., 68.},
      RoundingRadius->0], RectangleBox[{-2., 0}, {-1.5, 83.},
      RoundingRadius->0], RectangleBox[{-1.5, 0}, {-1., 71.},
      RoundingRadius->0], RectangleBox[{-1., 0}, {-0.5, 83.},
      RoundingRadius->0], RectangleBox[{-0.5, 0}, {0., 79.},
      RoundingRadius->0], RectangleBox[{0., 0}, {0.5, 92.},
      RoundingRadius->0], RectangleBox[{0.5, 0}, {1., 78.},
      RoundingRadius->0], RectangleBox[{1., 0}, {1.5, 93.},
      RoundingRadius->0], RectangleBox[{1.5, 0}, {2., 77.},
      RoundingRadius->0], RectangleBox[{2., 0}, {2.5, 81.},
      RoundingRadius->0], RectangleBox[{2.5, 0}, {3., 80.},
      RoundingRadius->0], RectangleBox[{3., 0}, {3.5, 83.},
      RoundingRadius->0], RectangleBox[{3.5, 0}, {4., 69.},
      RoundingRadius->0], RectangleBox[{4., 0}, {4.5, 87.},
      RoundingRadius->0], RectangleBox[{4.5, 0}, {5., 78.},
      RoundingRadius->0], RectangleBox[{5., 0}, {5.5, 74.},
      RoundingRadius->0], RectangleBox[{5.5, 0}, {6., 99.},
      RoundingRadius->0], RectangleBox[{6., 0}, {6.5, 37.},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-6.76, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-6.5, 6.5}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739441955714135*^9, 3.73944197406369*^9}, 
   3.739442155728724*^9},
 CellLabel->
  "Out[488]=",ExpressionUUID->"39ff9f14-6437-4e02-944b-8e09c1d129b9"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ArcTan", "@@", "#"}], "&"}], ",", 
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "Pi"}], ",", 
         RowBox[{"2", "Pi"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2000", ",", "2"}], "}"}]}], "]"}]}], "]"}], ",", "20"}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.73944127498905*^9, 3.739441276758918*^9}, {
   3.739441306858717*^9, 3.739441334542705*^9}, {3.739441423186163*^9, 
   3.739441460109673*^9}, {3.7394420646755*^9, 3.739442086644191*^9}, 
   3.739442155729545*^9},
 CellLabel->
  "In[489]:=",ExpressionUUID->"8d69d136-fbba-48bf-bc90-fc517f2de028"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.46199999999999997`], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.46199999999999997`], Thickness[Small]}], 
     RectangleBox[{-3.2, 0}, {-3., 31.},
      RoundingRadius->0], RectangleBox[{-3., 0}, {-2.8, 65.},
      RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.6, 54.},
      RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.4, 67.},
      RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.2, 80.},
      RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 65.},
      RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 58.},
      RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.6, 48.},
      RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.4, 64.},
      RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.2, 48.},
      RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 56.},
      RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 77.},
      RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.6, 84.},
      RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.4, 68.},
      RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.2, 53.},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 59.},
      RoundingRadius->0], RectangleBox[{0., 0}, {0.2, 51.},
      RoundingRadius->0], RectangleBox[{0.2, 0}, {0.4, 55.},
      RoundingRadius->0], RectangleBox[{0.4, 0}, {0.6, 75.},
      RoundingRadius->0], RectangleBox[{0.6, 0}, {0.8, 89.},
      RoundingRadius->0], RectangleBox[{0.8, 0}, {1., 85.},
      RoundingRadius->0], RectangleBox[{1., 0}, {1.2, 64.},
      RoundingRadius->0], RectangleBox[{1.2, 0}, {1.4, 56.},
      RoundingRadius->0], RectangleBox[{1.4, 0}, {1.6, 43.},
      RoundingRadius->0], RectangleBox[{1.6, 0}, {1.8, 52.},
      RoundingRadius->0], RectangleBox[{1.8, 0}, {2., 66.},
      RoundingRadius->0], RectangleBox[{2., 0}, {2.2, 66.},
      RoundingRadius->0], RectangleBox[{2.2, 0}, {2.4, 95.},
      RoundingRadius->0], RectangleBox[{2.4, 0}, {2.6, 87.},
      RoundingRadius->0], RectangleBox[{2.6, 0}, {2.8, 60.},
      RoundingRadius->0], RectangleBox[{2.8, 0}, {3., 49.},
      RoundingRadius->0], RectangleBox[{3., 0}, {3.2, 30.},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-3.3280000000000003`, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-3.2, 3.2}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.739442087241527*^9, 3.739442155730344*^9},
 CellLabel->
  "Out[489]=",ExpressionUUID->"ead6c54b-2805-4837-b470-a1f8db770d08"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "2000"}], "]"}], ",", 
     "20"}], "]"}], ",", 
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "Pi"}], ",", 
         RowBox[{"2", "Pi"}]}], "}"}], ",", "2000"}], "]"}], ",", "20"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "Pi"}], " ", ",", 
          RowBox[{"2", "Pi"}]}], "}"}], " ", "//", "N"}], ",", "2000"}], 
      "]"}], ",", "20"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2."}], " ", ",", "2."}], " ", "}"}], "Pi"}], ",", 
       "2000"}], "]"}], ",", "20"}], "]"}]}], "}"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739385825044024*^9, 3.73938589440278*^9}, 
   3.739385940136715*^9, {3.739385985119624*^9, 3.739386054465374*^9}, {
   3.739386324690619*^9, 3.739386338631126*^9}, 3.739442155731251*^9},
 CellLabel->
  "In[397]:=",ExpressionUUID->"56c510ba-6ecc-4d18-8374-17518496f6d1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.5459999999999999], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.5459999999999999], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-1., 0}, {-0.9, 110.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{23.70098039215688, 
            31.578431372549034`}, {-39.40964135399255, 35.84010723112947}}],
          StatusArea[#, 110]& ,
          TagBoxNote->"110"],
         StyleBox["110", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[110, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.9, 0}, {-0.8, 100.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{31.078431372549034`, 
            38.95588235294119}, {-32.614209664436, 35.84010723112947}}],
          StatusArea[#, 100]& ,
          TagBoxNote->"100"],
         StyleBox["100", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[100, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.8, 0}, {-0.7, 98.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{38.45588235294119, 
            46.33333333333335}, {-31.25512332652469, 35.84010723112947}}],
          StatusArea[#, 98]& ,
          TagBoxNote->"98"],
         StyleBox["98", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[98, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.7, 0}, {-0.6, 110.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{45.83333333333335, 
            53.710784313725505`}, {-39.40964135399255, 35.84010723112947}}],
          StatusArea[#, 110]& ,
          TagBoxNote->"110"],
         StyleBox["110", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[110, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.6, 0}, {-0.5, 83.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{53.210784313725505`, 
            61.08823529411766}, {-21.06197579218987, 35.84010723112947}}],
          StatusArea[#, 83]& ,
          TagBoxNote->"83"],
         StyleBox["83", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[83, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.5, 0}, {-0.4, 87.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{60.58823529411766, 
            68.4656862745098}, {-23.780148468012484`, 35.84010723112947}}],
          StatusArea[#, 87]& ,
          TagBoxNote->"87"],
         StyleBox["87", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[87, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.4, 0}, {-0.3, 96.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{67.9656862745098, 
            75.84313725490198}, {-29.896036988613382`, 35.84010723112947}}],
          StatusArea[#, 96]& ,
          TagBoxNote->"96"],
         StyleBox["96", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[96, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.3, 0}, {-0.2, 98.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{75.34313725490198, 
            83.22058823529413}, {-31.25512332652469, 35.84010723112947}}],
          StatusArea[#, 98]& ,
          TagBoxNote->"98"],
         StyleBox["98", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[98, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.2, 0}, {-0.1, 91.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{82.72058823529413, 
            90.59803921568628}, {-26.498321143835106`, 35.84010723112947}}],
          StatusArea[#, 91]& ,
          TagBoxNote->"91"],
         StyleBox["91", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[91, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.1, 0}, {0., 100.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{90.09803921568628, 
            97.97549019607844}, {-32.614209664436, 35.84010723112947}}],
          StatusArea[#, 100]& ,
          TagBoxNote->"100"],
         StyleBox["100", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[100, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0., 0}, {0.1, 105.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{97.47549019607844, 
            105.3529411764706}, {-36.01192550921427, 35.84010723112947}}],
          StatusArea[#, 105]& ,
          TagBoxNote->"105"],
         StyleBox["105", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[105, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.1, 0}, {0.2, 110.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{104.8529411764706, 
            112.73039215686275`}, {-39.40964135399255, 35.84010723112947}}],
          StatusArea[#, 110]& ,
          TagBoxNote->"110"],
         StyleBox["110", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[110, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.2, 0}, {0.3, 94.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{112.23039215686275`, 
            120.1078431372549}, {-28.536950650702074`, 35.84010723112947}}],
          StatusArea[#, 94]& ,
          TagBoxNote->"94"],
         StyleBox["94", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[94, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.3, 0}, {0.4, 95.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{119.6078431372549, 
            127.48529411764707`}, {-29.21649381965772, 35.84010723112947}}],
          StatusArea[#, 95]& ,
          TagBoxNote->"95"],
         StyleBox["95", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[95, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.4, 0}, {0.5, 83.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{126.98529411764707`, 
            134.86274509803923`}, {-21.06197579218987, 35.84010723112947}}],
          StatusArea[#, 83]& ,
          TagBoxNote->"83"],
         StyleBox["83", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[83, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.5, 0}, {0.6, 111.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{134.36274509803923`, 
            142.24019607843138`}, {-40.089184522948194`, 35.84010723112947}}],
          
          StatusArea[#, 111]& ,
          TagBoxNote->"111"],
         StyleBox["111", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[111, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.6, 0}, {0.7, 130.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{141.74019607843138`, 
            149.61764705882354`}, {-53.000504733105636`, 35.84010723112947}}],
          
          StatusArea[#, 130]& ,
          TagBoxNote->"130"],
         StyleBox["130", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[130, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.7, 0}, {0.8, 97.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{149.11764705882354`, 
            156.9950980392157}, {-30.57558015756903, 35.84010723112947}}],
          StatusArea[#, 97]& ,
          TagBoxNote->"97"],
         StyleBox["97", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[97, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.8, 0}, {0.9, 101.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{156.4950980392157, 
            164.37254901960785`}, {-33.29375283339166, 35.84010723112947}}],
          StatusArea[#, 101]& ,
          TagBoxNote->"101"],
         StyleBox["101", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[101, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.9, 0}, {1., 101.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{163.87254901960785`, 
            171.75}, {-33.29375283339166, 35.84010723112947}}],
          StatusArea[#, 101]& ,
          TagBoxNote->"101"],
         StyleBox["101", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[101, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{-1.04, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{-1., 1.}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.504], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.504], Thickness[Small]}], 
       RectangleBox[{-6.5, 0}, {-6., 40.},
        RoundingRadius->0], RectangleBox[{-6., 0}, {-5.5, 78.},
        RoundingRadius->0], RectangleBox[{-5.5, 0}, {-5., 66.},
        RoundingRadius->0], RectangleBox[{-5., 0}, {-4.5, 70.},
        RoundingRadius->0], RectangleBox[{-4.5, 0}, {-4., 85.},
        RoundingRadius->0], RectangleBox[{-4., 0}, {-3.5, 70.},
        RoundingRadius->0], RectangleBox[{-3.5, 0}, {-3., 85.},
        RoundingRadius->0], RectangleBox[{-3., 0}, {-2.5, 67.},
        RoundingRadius->0], RectangleBox[{-2.5, 0}, {-2., 67.},
        RoundingRadius->0], RectangleBox[{-2., 0}, {-1.5, 80.},
        RoundingRadius->0], RectangleBox[{-1.5, 0}, {-1., 80.},
        RoundingRadius->0], RectangleBox[{-1., 0}, {-0.5, 85.},
        RoundingRadius->0], RectangleBox[{-0.5, 0}, {0., 88.},
        RoundingRadius->0], RectangleBox[{0., 0}, {0.5, 87.},
        RoundingRadius->0], RectangleBox[{0.5, 0}, {1., 81.},
        RoundingRadius->0], RectangleBox[{1., 0}, {1.5, 88.},
        RoundingRadius->0], RectangleBox[{1.5, 0}, {2., 75.},
        RoundingRadius->0], RectangleBox[{2., 0}, {2.5, 89.},
        RoundingRadius->0], RectangleBox[{2.5, 0}, {3., 68.},
        RoundingRadius->0], RectangleBox[{3., 0}, {3.5, 71.},
        RoundingRadius->0], RectangleBox[{3.5, 0}, {4., 86.},
        RoundingRadius->0], RectangleBox[{4., 0}, {4.5, 87.},
        RoundingRadius->0], RectangleBox[{4.5, 0}, {5., 78.},
        RoundingRadius->0], RectangleBox[{5., 0}, {5.5, 80.},
        RoundingRadius->0], RectangleBox[{5.5, 0}, {6., 99.},
        RoundingRadius->0], RectangleBox[{6., 0}, {6.5, 50.},
        RoundingRadius->
         0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{-6.76, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{-6.5, 6.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.504], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.504], Thickness[Small]}], 
       RectangleBox[{-6.5, 0}, {-6., 46.},
        RoundingRadius->0], RectangleBox[{-6., 0}, {-5.5, 72.},
        RoundingRadius->0], RectangleBox[{-5.5, 0}, {-5., 86.},
        RoundingRadius->0], RectangleBox[{-5., 0}, {-4.5, 81.},
        RoundingRadius->0], RectangleBox[{-4.5, 0}, {-4., 88.},
        RoundingRadius->0], RectangleBox[{-4., 0}, {-3.5, 90.},
        RoundingRadius->0], RectangleBox[{-3.5, 0}, {-3., 73.},
        RoundingRadius->0], RectangleBox[{-3., 0}, {-2.5, 99.},
        RoundingRadius->0], RectangleBox[{-2.5, 0}, {-2., 79.},
        RoundingRadius->0], RectangleBox[{-2., 0}, {-1.5, 72.},
        RoundingRadius->0], RectangleBox[{-1.5, 0}, {-1., 81.},
        RoundingRadius->0], RectangleBox[{-1., 0}, {-0.5, 70.},
        RoundingRadius->0], RectangleBox[{-0.5, 0}, {0., 73.},
        RoundingRadius->0], RectangleBox[{0., 0}, {0.5, 82.},
        RoundingRadius->0], RectangleBox[{0.5, 0}, {1., 75.},
        RoundingRadius->0], RectangleBox[{1., 0}, {1.5, 83.},
        RoundingRadius->0], RectangleBox[{1.5, 0}, {2., 66.},
        RoundingRadius->0], RectangleBox[{2., 0}, {2.5, 90.},
        RoundingRadius->0], RectangleBox[{2.5, 0}, {3., 78.},
        RoundingRadius->0], RectangleBox[{3., 0}, {3.5, 85.},
        RoundingRadius->0], RectangleBox[{3.5, 0}, {4., 89.},
        RoundingRadius->0], RectangleBox[{4., 0}, {4.5, 79.},
        RoundingRadius->0], RectangleBox[{4.5, 0}, {5., 65.},
        RoundingRadius->0], RectangleBox[{5., 0}, {5.5, 83.},
        RoundingRadius->0], RectangleBox[{5.5, 0}, {6., 67.},
        RoundingRadius->0], RectangleBox[{6., 0}, {6.5, 48.},
        RoundingRadius->
         0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{-6.76, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{-6.5, 6.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.504], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.504], Thickness[Small]}], 
       RectangleBox[{-6.5, 0}, {-6., 54.},
        RoundingRadius->0], RectangleBox[{-6., 0}, {-5.5, 74.},
        RoundingRadius->0], RectangleBox[{-5.5, 0}, {-5., 84.},
        RoundingRadius->0], RectangleBox[{-5., 0}, {-4.5, 90.},
        RoundingRadius->0], RectangleBox[{-4.5, 0}, {-4., 67.},
        RoundingRadius->0], RectangleBox[{-4., 0}, {-3.5, 87.},
        RoundingRadius->0], RectangleBox[{-3.5, 0}, {-3., 73.},
        RoundingRadius->0], RectangleBox[{-3., 0}, {-2.5, 108.},
        RoundingRadius->0], RectangleBox[{-2.5, 0}, {-2., 77.},
        RoundingRadius->0], RectangleBox[{-2., 0}, {-1.5, 74.},
        RoundingRadius->0], RectangleBox[{-1.5, 0}, {-1., 110.},
        RoundingRadius->0], RectangleBox[{-1., 0}, {-0.5, 84.},
        RoundingRadius->0], RectangleBox[{-0.5, 0}, {0., 82.},
        RoundingRadius->0], RectangleBox[{0., 0}, {0.5, 59.},
        RoundingRadius->0], RectangleBox[{0.5, 0}, {1., 73.},
        RoundingRadius->0], RectangleBox[{1., 0}, {1.5, 63.},
        RoundingRadius->0], RectangleBox[{1.5, 0}, {2., 76.},
        RoundingRadius->0], RectangleBox[{2., 0}, {2.5, 80.},
        RoundingRadius->0], RectangleBox[{2.5, 0}, {3., 89.},
        RoundingRadius->0], RectangleBox[{3., 0}, {3.5, 70.},
        RoundingRadius->0], RectangleBox[{3.5, 0}, {4., 71.},
        RoundingRadius->0], RectangleBox[{4., 0}, {4.5, 83.},
        RoundingRadius->0], RectangleBox[{4.5, 0}, {5., 75.},
        RoundingRadius->0], RectangleBox[{5., 0}, {5.5, 72.},
        RoundingRadius->0], RectangleBox[{5.5, 0}, {6., 76.},
        RoundingRadius->0], RectangleBox[{6., 0}, {6.5, 49.},
        RoundingRadius->
         0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{-6.76, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{-6.5, 6.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739385829901333*^9, 3.7393858507023163`*^9}, {
   3.7393858956606693`*^9, 3.739385941353655*^9}, {3.739386014718401*^9, 
   3.739386055477933*^9}, 3.739386340228408*^9, 3.739386373251341*^9, 
   3.7394421557320013`*^9},
 CellLabel->
  "Out[397]=",ExpressionUUID->"1ade2dab-119f-4b01-838b-6b5eec8aafad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{"4", "Pi", 
        RowBox[{"{", 
         RowBox[{"0", " ", ",", "1"}], " ", "}"}]}], ",", "10000"}], "]"}], 
     ",", "10"}], "]"}], ",", 
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"2", " ", "Pi", " ", 
      RowBox[{"RandomReal", "[", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", " ", "1."}], " ", ",", "1."}], " ", "}"}], ",", 
        "10000"}], "]"}]}], ",", "10"}], "]"}]}], "}"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739385732196547*^9, 3.739385777111445*^9}, {
   3.739385902541314*^9, 3.739385903114771*^9}, {3.7393859525412207`*^9, 
   3.739385959132133*^9}, {3.7393860791838293`*^9, 3.73938611260133*^9}, {
   3.7393862438427057`*^9, 3.739386266261345*^9}, {3.739386388866968*^9, 
   3.739386425886907*^9}, {3.7393864866913233`*^9, 3.739386506819336*^9}, {
   3.7393866105789223`*^9, 3.7393866606783247`*^9}, {3.739386692320435*^9, 
   3.7393867437425632`*^9}, {3.73938679784097*^9, 3.7393868493697767`*^9}, 
   3.7394421557328167`*^9},
 CellLabel->
  "In[418]:=",ExpressionUUID->"fd8ea783-d2ba-4324-aa46-d55019370bc3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.595], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.595], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0., 0}, {1., 802.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{23.776421136909523`, 
            35.9165024327154}, {-48.06468021156459, 37.219922101227255`}}],
          StatusArea[#, 802]& ,
          TagBoxNote->"802"],
         StyleBox["802", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[802, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{1., 0}, {2., 772.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{35.4165024327154, 
            47.556583728521275`}, {-44.89318635946515, 37.219922101227255`}}],
          
          StatusArea[#, 772]& ,
          TagBoxNote->"772"],
         StyleBox["772", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[772, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{2., 0}, {3., 799.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{47.056583728521275`, 
            59.196665024327146`}, {-47.74753082635465, 37.219922101227255`}}],
          
          StatusArea[#, 799]& ,
          TagBoxNote->"799"],
         StyleBox["799", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[799, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{3., 0}, {4., 836.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{58.696665024327146`, 
            70.83674632013302}, {-51.65903991061063, 37.219922101227255`}}],
          StatusArea[#, 836]& ,
          TagBoxNote->"836"],
         StyleBox["836", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[836, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4., 0}, {5., 797.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{70.33674632013302, 
            82.47682761593889}, {-47.53609790288135, 37.219922101227255`}}],
          StatusArea[#, 797]& ,
          TagBoxNote->"797"],
         StyleBox["797", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[797, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5., 0}, {6., 800.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{81.97682761593889, 
            94.11690891174477}, {-47.853247288091296`, 37.219922101227255`}}],
          
          StatusArea[#, 800]& ,
          TagBoxNote->"800"],
         StyleBox["800", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[800, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6., 0}, {7., 857.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{93.61690891174477, 
            105.75699020755064`}, {-53.87908560708024, 37.219922101227255`}}],
          
          StatusArea[#, 857]& ,
          TagBoxNote->"857"],
         StyleBox["857", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[857, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7., 0}, {8., 786.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{105.25699020755064`, 
            117.39707150335651`}, {-46.37321682377822, 37.219922101227255`}}],
          
          StatusArea[#, 786]& ,
          TagBoxNote->"786"],
         StyleBox["786", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[786, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8., 0}, {9., 776.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{116.89707150335651`, 
            129.03715279916239`}, {-45.31605220641174, 37.219922101227255`}}],
          
          StatusArea[#, 776]& ,
          TagBoxNote->"776"],
         StyleBox["776", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[776, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9., 0}, {10., 780.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{128.53715279916239`, 
            140.67723409496827`}, {-45.73891805335833, 37.219922101227255`}}],
          
          StatusArea[#, 780]& ,
          TagBoxNote->"780"],
         StyleBox["780", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[780, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{10., 0}, {11., 774.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{140.17723409496827`, 
            152.31731539077416`}, {-45.104619282938444`, 
            37.219922101227255`}}],
          StatusArea[#, 774]& ,
          TagBoxNote->"774"],
         StyleBox["774", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[774, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11., 0}, {12., 767.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{151.81731539077416`, 
            163.95739668658004`}, {-44.36460405078191, 37.219922101227255`}}],
          
          StatusArea[#, 767]& ,
          TagBoxNote->"767"],
         StyleBox["767", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[767, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12., 0}, {13., 454.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{163.45739668658004`, 
            175.5974779823859}, {-11.275351527211022`, 37.219922101227255`}}],
          
          StatusArea[#, 454]& ,
          TagBoxNote->"454"],
         StyleBox["454", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[454, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{-0.26, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{0., 13.}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.588], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.588], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-7., 0}, {-6., 221.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{23.776421136909534`, 35.08506805444355}, {
            13.410980653571883`, 37.21992210122725}}],
          StatusArea[#, 221]& ,
          TagBoxNote->"221"],
         StyleBox["221", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[221, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-6., 0}, {-5., 804.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{34.58506805444355, 
            45.89371497197759}, {-48.07821782598955, 37.21992210122725}}],
          StatusArea[#, 804]& ,
          TagBoxNote->"804"],
         StyleBox["804", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[804, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-5., 0}, {-4., 789.}, "RoundingRadius" -> 0]},
           ImageSizeCache->{{45.39371497197759, 
            56.702361889511614`}, {-46.49616297660118, 37.21992210122725}}],
          StatusArea[#, 789]& ,
          TagBoxNote->"789"],
         StyleBox["789", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[789, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-4., 0}, {-3., 752.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{56.202361889511614`, 
            67.51100880704564}, {-42.593761014776526`, 37.21992210122725}}],
          StatusArea[#, 752]& ,
          TagBoxNote->"752"],
         StyleBox["752", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[752, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-3., 0}, {-2., 771.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{67.01100880704564, 
            78.31965572457968}, {-44.597697157335126`, 37.21992210122725}}],
          StatusArea[#, 771]& ,
          TagBoxNote->"771"],
         StyleBox["771", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[771, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-2., 0}, {-1., 784.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{77.81965572457968, 
            89.1283026421137}, {-45.96881136013838, 37.21992210122725}}],
          StatusArea[#, 784]& ,
          TagBoxNote->"784"],
         StyleBox["784", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[784, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-1., 0}, {0., 822.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{88.6283026421137, 
            99.93694955964773}, {-49.9766836452556, 37.21992210122725}}],
          StatusArea[#, 822]& ,
          TagBoxNote->"822"],
         StyleBox["822", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[822, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0., 0}, {1., 824.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{99.43694955964773, 
            110.74559647718176`}, {-50.18762429184071, 37.21992210122725}}],
          StatusArea[#, 824]& ,
          TagBoxNote->"824"],
         StyleBox["824", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[824, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{1., 0}, {2., 859.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{110.24559647718176`, 
            121.55424339471578`}, {-53.87908560708025, 37.21992210122725}}],
          StatusArea[#, 859]& ,
          TagBoxNote->"859"],
         StyleBox["859", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[859, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{2., 0}, {3., 814.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{121.05424339471578`, 
            132.36289031224982`}, {-49.13292105891514, 37.21992210122725}}],
          StatusArea[#, 814]& ,
          TagBoxNote->"814"],
         StyleBox["814", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[814, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{3., 0}, {4., 740.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{131.86289031224982`, 
            143.17153722978384`}, {-41.32811713526582, 37.21992210122725}}],
          StatusArea[#, 740]& ,
          TagBoxNote->"740"],
         StyleBox["740", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[740, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4., 0}, {5., 844.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{142.67153722978384`, 
            153.98018414731786`}, {-52.29703075769188, 37.21992210122725}}],
          StatusArea[#, 844]& ,
          TagBoxNote->"844"],
         StyleBox["844", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[844, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5., 0}, {6., 765.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{153.48018414731786`, 
            164.7888310648519}, {-43.96487521757978, 37.21992210122725}}],
          StatusArea[#, 765]& ,
          TagBoxNote->"765"],
         StyleBox["765", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[765, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6., 0}, {7., 211.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{164.2888310648519, 175.59747798238593`}, {
            14.465683886497466`, 37.21992210122725}}],
          StatusArea[#, 211]& ,
          TagBoxNote->"211"],
         StyleBox["211", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[211, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{-7.28, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{-7., 7.}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739385752600172*^9, 3.7393857959013987`*^9}, {
   3.739385857811347*^9, 3.739385861249022*^9}, {3.739385903609212*^9, 
   3.739385911833507*^9}, {3.739385953628888*^9, 3.739385960021703*^9}, {
   3.7393860896229*^9, 3.739386121500442*^9}, {3.739386229230055*^9, 
   3.739386267052478*^9}, 3.739386429065545*^9, {3.739386488732842*^9, 
   3.739386507858985*^9}, {3.739386613691244*^9, 3.739386661386656*^9}, {
   3.739386695751604*^9, 3.739386752254629*^9}, {3.739386798703167*^9, 
   3.739386850241673*^9}, 3.739442155733416*^9},
 CellLabel->
  "Out[418]=",ExpressionUUID->"273f7535-30f1-4153-bbde-df8b9e7900f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"6", "Pi", 
       RowBox[{"{", 
        RowBox[{"0", " ", ",", "1"}], " ", "}"}]}], ",", "10000"}], "]"}], 
    "]"}], ",", 
   RowBox[{"Histogram", "[", 
    RowBox[{"2", " ", "Pi", " ", 
     RowBox[{"RandomReal", "[", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", " ", "1."}], " ", ",", "1."}], " ", "}"}], ",", 
       "10000"}], "]"}]}], " ", "]"}]}], "}"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739385732196547*^9, 3.739385777111445*^9}, {
   3.739385902541314*^9, 3.739385903114771*^9}, {3.7393859525412207`*^9, 
   3.739385959132133*^9}, {3.7393860791838293`*^9, 3.73938611260133*^9}, {
   3.7393862438427057`*^9, 3.739386266261345*^9}, {3.739386388866968*^9, 
   3.739386425886907*^9}, {3.7393864866913233`*^9, 3.739386506819336*^9}, {
   3.7393866105789223`*^9, 3.7393866606783247`*^9}, {3.739386692320435*^9, 
   3.7393867770349503`*^9}, 3.739442155734333*^9},
 CellLabel->
  "In[412]:=",ExpressionUUID->"94b6accf-f211-4c54-88a0-3c96bc5ee7f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.5529999999999999], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.5529999999999999], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0., 0}, {1., 537.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{23.776421136909523`, 
            32.24068728667144}, {-50.158054933346214`, 37.21992210122725}}],
          StatusArea[#, 537]& ,
          TagBoxNote->"537"],
         StyleBox["537", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[537, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{1., 0}, {2., 518.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{31.740687286671438`, 
            40.20495343643336}, {-47.08416002895721, 37.21992210122725}}],
          StatusArea[#, 518]& ,
          TagBoxNote->"518"],
         StyleBox["518", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[518, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{2., 0}, {3., 528.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{39.70495343643336, 
            48.16921958619527}, {-48.70199945231983, 37.21992210122725}}],
          StatusArea[#, 528]& ,
          TagBoxNote->"528"],
         StyleBox["528", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[528, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{3., 0}, {4., 516.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{47.66921958619527, 
            56.13348573595718}, {-46.76059214428468, 37.21992210122725}}],
          StatusArea[#, 516]& ,
          TagBoxNote->"516"],
         StyleBox["516", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[516, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4., 0}, {5., 559.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{55.63348573595718, 
            64.09775188571909}, {-53.71730166474401, 37.21992210122725}}],
          StatusArea[#, 559]& ,
          TagBoxNote->"559"],
         StyleBox["559", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[559, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5., 0}, {6., 507.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{63.59775188571909, 
            72.06201803548102}, {-45.30453666325831, 37.21992210122725}}],
          StatusArea[#, 507]& ,
          TagBoxNote->"507"],
         StyleBox["507", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[507, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6., 0}, {7., 560.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{71.56201803548102, 
            80.02628418524293}, {-53.87908560708026, 37.21992210122725}}],
          StatusArea[#, 560]& ,
          TagBoxNote->"560"],
         StyleBox["560", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[560, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7., 0}, {8., 525.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{79.52628418524293, 
            87.99055033500484}, {-48.21664762531105, 37.21992210122725}}],
          StatusArea[#, 525]& ,
          TagBoxNote->"525"],
         StyleBox["525", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[525, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8., 0}, {9., 499.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{87.49055033500484, 
            95.95481648476675}, {-44.0102651245682, 37.21992210122725}}],
          StatusArea[#, 499]& ,
          TagBoxNote->"499"],
         StyleBox["499", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[499, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9., 0}, {10., 530.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{95.45481648476675, 
            103.91908263452866`}, {-49.02556733699236, 37.21992210122725}}],
          StatusArea[#, 530]& ,
          TagBoxNote->"530"],
         StyleBox["530", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[530, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{10., 0}, {11., 546.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{103.41908263452866`, 
            111.88334878429059`}, {-51.61411041437258, 37.21992210122725}}],
          StatusArea[#, 546]& ,
          TagBoxNote->"546"],
         StyleBox["546", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[546, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11., 0}, {12., 555.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{111.38334878429059`, 
            119.8476149340525}, {-53.07016589539895, 37.21992210122725}}],
          StatusArea[#, 555]& ,
          TagBoxNote->"555"],
         StyleBox["555", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[555, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12., 0}, {13., 513.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{119.3476149340525, 
            127.81188108381441`}, {-46.27524031727588, 37.21992210122725}}],
          StatusArea[#, 513]& ,
          TagBoxNote->"513"],
         StyleBox["513", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[513, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{13., 0}, {14., 523.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{127.31188108381441`, 
            135.77614723357635`}, {-47.89307974063852, 37.21992210122725}}],
          StatusArea[#, 523]& ,
          TagBoxNote->"523"],
         StyleBox["523", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[523, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{14., 0}, {15., 555.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{135.27614723357635`, 
            143.74041338333825`}, {-53.07016589539895, 37.21992210122725}}],
          StatusArea[#, 555]& ,
          TagBoxNote->"555"],
         StyleBox["555", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[555, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{15., 0}, {16., 514.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{143.24041338333825`, 
            151.70467953310018`}, {-46.43702425961215, 37.21992210122725}}],
          StatusArea[#, 514]& ,
          TagBoxNote->"514"],
         StyleBox["514", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[514, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{16., 0}, {17., 526.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{151.20467953310018`, 
            159.6689456828621}, {-48.37843156764732, 37.21992210122725}}],
          StatusArea[#, 526]& ,
          TagBoxNote->"526"],
         StyleBox["526", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[526, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{17., 0}, {18., 543.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{159.1689456828621, 
            167.633211832624}, {-51.128758587363784`, 37.21992210122725}}],
          StatusArea[#, 543]& ,
          TagBoxNote->"543"],
         StyleBox["543", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[543, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{18., 0}, {19., 446.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{167.133211832624, 
            175.59747798238593`}, {-35.43571618074623, 37.21992210122725}}],
          StatusArea[#, 446]& ,
          TagBoxNote->"446"],
         StyleBox["446", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[446, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{-0.38, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{0., 19.}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.504], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.504], Thickness[Small]}], 
       RectangleBox[{-6.5, 0}, {-6., 220.},
        RoundingRadius->0], RectangleBox[{-6., 0}, {-5.5, 410.},
        RoundingRadius->0], RectangleBox[{-5.5, 0}, {-5., 408.},
        RoundingRadius->0], RectangleBox[{-5., 0}, {-4.5, 382.},
        RoundingRadius->0], RectangleBox[{-4.5, 0}, {-4., 364.},
        RoundingRadius->0], RectangleBox[{-4., 0}, {-3.5, 394.},
        RoundingRadius->0], RectangleBox[{-3.5, 0}, {-3., 394.},
        RoundingRadius->0], RectangleBox[{-3., 0}, {-2.5, 411.},
        RoundingRadius->0], RectangleBox[{-2.5, 0}, {-2., 371.},
        RoundingRadius->0], RectangleBox[{-2., 0}, {-1.5, 406.},
        RoundingRadius->0], RectangleBox[{-1.5, 0}, {-1., 362.},
        RoundingRadius->0], RectangleBox[{-1., 0}, {-0.5, 406.},
        RoundingRadius->0], RectangleBox[{-0.5, 0}, {0., 378.},
        RoundingRadius->0], RectangleBox[{0., 0}, {0.5, 396.},
        RoundingRadius->0], RectangleBox[{0.5, 0}, {1., 420.},
        RoundingRadius->0], RectangleBox[{1., 0}, {1.5, 385.},
        RoundingRadius->0], RectangleBox[{1.5, 0}, {2., 394.},
        RoundingRadius->0], RectangleBox[{2., 0}, {2.5, 420.},
        RoundingRadius->0], RectangleBox[{2.5, 0}, {3., 405.},
        RoundingRadius->0], RectangleBox[{3., 0}, {3.5, 392.},
        RoundingRadius->0], RectangleBox[{3.5, 0}, {4., 399.},
        RoundingRadius->0], RectangleBox[{4., 0}, {4.5, 387.},
        RoundingRadius->0], RectangleBox[{4.5, 0}, {5., 403.},
        RoundingRadius->0], RectangleBox[{5., 0}, {5.5, 399.},
        RoundingRadius->0], RectangleBox[{5.5, 0}, {6., 446.},
        RoundingRadius->0], RectangleBox[{6., 0}, {6.5, 248.},
        RoundingRadius->
         0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{-6.76, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{-6.5, 6.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.739386778410294*^9, 3.739442155735096*^9},
 CellLabel->
  "Out[412]=",ExpressionUUID->"a80f0352-c3af-44ce-b5bd-8dbe9f17b6b1"],

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"angles", "=", " ", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"4", " ", "Pi"}]}], "}"}], ",", "100"}], "]"}]}], ",", 
     RowBox[{"save", "=", "100"}]}], "}"}], ",", 
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"samples", " ", "\[NotEqual]", "save"}], ",", " ", 
        RowBox[{
         RowBox[{"angles", " ", "=", " ", 
          RowBox[{"RandomReal", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"4.4", " ", "Pi"}]}], "}"}], ",", "samples"}], "]"}]}], 
         ";", 
         RowBox[{"save", "=", "samples"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"GraphicsRow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Graphics", " ", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Cos", "[", "t", "]"}], ",", 
                  RowBox[{"Sin", "[", "t", "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"t", ",", "0", ",", 
                  RowBox[{"2", " ", "Pi"}], ",", " ", 
                  RowBox[{"Pi", "/", "32"}]}], "}"}]}], "]"}], "]"}], ",", 
             "\[IndentingNewLine]", "Blue", ",", 
             RowBox[{"Point", "[", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"1.02", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"#", "/", "2"}], "]"}], ",", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"#", "/", "2"}], "]"}]}], "}"}]}], "&"}], ",", 
                "angles"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "Pi", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{".5", "/", "bins"}]}], ")"}]}], "]"}], ",", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", "Pi", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{".5", "/", "bins"}]}], ")"}]}], "]"}]}], "}"}]}], 
               "}"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
         RowBox[{"Histogram", "[", 
          RowBox[{"angles", ",", "bins"}], "]"}]}], "}"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"samples", ",", "100"}], "}"}], ",", "50", ",", "1000", ",", 
       "50", ",", 
       RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"bins", ",", "20"}], "}"}], ",", "10", ",", "100", ",", "10", 
       ",", 
       RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
     RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{"bins", ",", "samples"}], "}"}]}]}], "]"}]}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7394080637915087`*^9, 3.739408462186555*^9}, {
   3.739408500278488*^9, 3.739408515290049*^9}, {3.739408661121793*^9, 
   3.739408766535797*^9}, {3.739408858410459*^9, 3.739408877895554*^9}, {
   3.739408928030972*^9, 3.739408959260894*^9}, {3.73940906566031*^9, 
   3.739409071084738*^9}, {3.73940914169234*^9, 3.739409194365453*^9}, {
   3.739409303775626*^9, 3.739409323293024*^9}, {3.739409418931418*^9, 
   3.739409430938414*^9}, {3.739409468115835*^9, 3.739409517061453*^9}, {
   3.739409562100554*^9, 3.7394096238732767`*^9}, {3.7394096588602343`*^9, 
   3.739409660264144*^9}, {3.739409776130787*^9, 3.739409783303838*^9}, {
   3.7394406783223352`*^9, 3.739440678948979*^9}, 3.739442155736225*^9},
 CellLabel->
  "In[453]:=",ExpressionUUID->"a36f9607-1c6b-40ba-be81-ad71141281f8"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`angles$$ = CompressedData["
1:eJwNl2k41A0Xxscu6xgGs2DMZgxPi6SU/G9tikSJSkWJl1T2QrJFSSqSbJXS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  "], $CellContext`save$$ = 500}, 
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`bins$$ = 20, $CellContext`samples$$ = 500, 
     Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
     Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
     1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`samples$$], 100}, 50, 1000, 50}, {{
        Hold[$CellContext`bins$$], 20}, 10, 100, 10}}, Typeset`size$$ = {
     780., {192., 198.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
     Typeset`skipInitDone$$ = True, $CellContext`samples$165431$$ = 
     0, $CellContext`bins$165432$$ = 0}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, 
       "Variables" :> {$CellContext`bins$$ = 20, $CellContext`samples$$ = 
         100}, "ControllerVariables" :> {
         Hold[$CellContext`samples$$, $CellContext`samples$165431$$, 0], 
         Hold[$CellContext`bins$$, $CellContext`bins$165432$$, 0]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, 
       "Body" :> (
        If[$CellContext`samples$$ != $CellContext`save$$, \
$CellContext`angles$$ = 
           RandomReal[{
             0, 4.4 Pi}, $CellContext`samples$$]; $CellContext`save$$ = \
$CellContext`samples$$]; GraphicsRow[{
           Graphics[{Black, 
             Line[
              Table[{
                Cos[$CellContext`t], 
                Sin[$CellContext`t]}, {$CellContext`t, 0, 2 Pi, Pi/32}]], 
             Blue, 
             Point[
              Map[1.02 {
                 Cos[#/2], 
                 Sin[#/2]}& , $CellContext`angles$$]], 
             Line[{{0, 0}, {1, 0}}], 
             Line[{{0, 0}, {
                Cos[(2 Pi) (1 - 0.5/$CellContext`bins$$)], 
                Sin[(2 Pi) (1 - 0.5/$CellContext`bins$$)]}}]}, ImageSize -> 
            Medium], 
           Histogram[$CellContext`angles$$, $CellContext`bins$$]}]), 
       "Specifications" :> {{{$CellContext`samples$$, 100}, 50, 1000, 50, 
          Appearance -> "Labeled"}, {{$CellContext`bins$$, 20}, 10, 100, 10, 
          Appearance -> "Labeled"}}, 
       "Options" :> {
        TrackedSymbols :> {$CellContext`bins$$, $CellContext`samples$$}}, 
       "DefaultOptions" :> {}],
      ImageSizeCache->{827., {248., 255.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]],
  DynamicModuleValues:>{}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.739408174273234*^9, 3.7394081883813887`*^9}, 
   3.73940824248383*^9, {3.739408282773262*^9, 3.739408364782518*^9}, 
   3.739408463418672*^9, 3.739408516572358*^9, 3.739408768142684*^9, 
   3.739408888044415*^9, {3.7394089411752167`*^9, 3.7394089599887543`*^9}, 
   3.7394090719606333`*^9, 3.739409196502728*^9, {3.739409305187787*^9, 
   3.739409324139658*^9}, 3.739409432727166*^9, {3.739409495108348*^9, 
   3.739409518552556*^9}, 3.739409624998047*^9, 3.7394096620359993`*^9, 
   3.7394097851507263`*^9, 3.739440681215166*^9, 3.739442155736988*^9},
 CellLabel->
  "Out[453]=",ExpressionUUID->"1e82f836-9fb2-4848-8820-b3e08d903c55"]
}, Closed]],

Cell[TextData[StyleBox["The idea to fix the nonuniformity -- might be to do \
the  quaternion block-normalize method?",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.73944058223637*^9, 3.739440595068452*^9}, {
  3.7394407427792397`*^9, 3.739440754307127*^9}, {3.739442181982505*^9, 
  3.739442188070642*^9}},ExpressionUUID->"a4d25c03-451b-4d2e-9cb1-\
3704b2a9ab7c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomSphere1", "[", "n_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "2"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"0.2", "\[LessEqual]", " ", 
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "1.0"}], ",", 
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", 
             RowBox[{"Normalize", "[", "test", "]"}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", "out"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73944076443102*^9, 3.739440786763439*^9}, {
  3.7394408424202747`*^9, 3.739440857523859*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"3571c1fb-21dd-4bf5-8ab0-3b82aace108f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomBall2", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"size_:", "1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", "2"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "size"}], ",", 
          
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", "test"}], "]"}]}]}], "]"}]}]}], "]"}], 
     ";", "out"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73944076443102*^9, 3.739440786763439*^9}, {
  3.7394408424202747`*^9, 3.739440857523859*^9}, {3.739460952836001*^9, 
  3.73946101596912*^9}, {3.7395528751223373`*^9, 3.73955287646989*^9}},
 CellLabel->
  "In[546]:=",ExpressionUUID->"89dcecb6-9065-4114-8954-81e62972e886"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomBall2CM", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"size_:", "1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test", ",", "cm"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", "2"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "size"}], ",", 
          
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", "test"}], "]"}]}]}], "]"}]}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"cm", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Plus", "@@", "out"}], ")"}], "/", "n"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", "-", "cm"}], "&"}], ")"}], "/@", "out"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73944076443102*^9, 3.739440786763439*^9}, {
  3.7394408424202747`*^9, 3.739440857523859*^9}, {3.739460952836001*^9, 
  3.73946101596912*^9}, {3.739473446919948*^9, 3.7394735330063257`*^9}, {
  3.7395528860575743`*^9, 3.739552887102167*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"abdb136f-0733-47ba-9ad6-a643805240c7"],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.7401618268151827`*^9},ExpressionUUID->"99f4658b-cc69-4ccb-8dc5-\
afc9a973d5cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Gaussian", "!!"}], " ", "*)"}], 
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AbsolutePointSize", "[", "1", "]"}], ",", 
     RowBox[{"Point", "[", 
      RowBox[{"RandomVariate", "[", 
       RowBox[{
        RowBox[{"NormalDistribution", "[", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"10", "^", "4"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], 
    "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7401618532630043`*^9, 
  3.740161856878421*^9}},ExpressionUUID->"27e9c9c0-7486-43f2-8d97-\
ad6f07cfcb2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Match", " ", "order", " ", "of", " ", "makeExxmat"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
     "REMEMBER", " ", "move", " ", "to", " ", "center", " ", "of", " ", 
      "mass", " ", "\[IndentingNewLine]", "REMEMBER", " ", "the", " ", "DATA",
       " ", "are", " ", "uniform"}]}], ",", " ", 
    RowBox[{
    "but", " ", "the", " ", "NOISE", " ", "should", " ", "be", " ", 
     "Gaussian"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"build2DPntdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"baseAngle_:", 
      RowBox[{"Pi", "/", "8"}]}], ",", 
     RowBox[{"size_:", "1"}], ",", 
     RowBox[{"rmax_:", "0.05"}]}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xRef", " ", "=", "  ", 
        RowBox[{"randomBall2CM", "[", 
         RowBox[{"npts", ",", "size"}], "]"}]}], ",", "xRefCtr", ",", 
       "xTgtCtr", ",", "\[IndentingNewLine]", 
       RowBox[{"xJitter", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", ",", "rmax"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"npts", ",", "2"}], "}"}]}], "]"}]}], ",", "xTgt", ",", 
       "xTgtInit", ",", "th", ",", "rotTgt"}], "}"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"checkJitter", "=", "xJitter"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
          RowBox[{"xJitter", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"to", " ", "ctr", " ", "of", " ", "mass", "  ", "xRefCtr"}], 
         "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Plus", "@@", "xRef"}], ")"}], "/", "npts"}]}], ";", " ", 
        RowBox[{"xRef", " ", "=", " ", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"#", "-", "xRefCtr"}], " ", ")"}], "&"}], ",", "xRef"}], 
          "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xTgtCtr", "=", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"Plus", "@@", "xTgtInit"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xTgtInit", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xTgtCtr"}], ")"}], " ", "&"}], ",", 
         "xTgtInit"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"th", "=", 
       RowBox[{"baseAngle", "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotTgt", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", "th", "]"}], ",", 
           RowBox[{"-", 
            RowBox[{"Sin", "[", "th", "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Sin", "[", "th", "]"}], ",", 
           RowBox[{"Cos", "[", "th", "]"}]}], "}"}]}], "}"}]}], ";", "  ", 
      RowBox[{"xTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotTgt", ".", "#"}], ")"}], "&"}], ",", "xTgtInit"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"xTgt", ",", "xRef", ",", " ", "xTgtInit", ",", "th"}], 
       "}"}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7401566126087313`*^9, 3.740156637764062*^9}, {
   3.740156733131111*^9, 3.740156737806591*^9}, {3.740157022119525*^9, 
   3.740157030000266*^9}, {3.740157367687036*^9, 3.740157392800632*^9}, 
   3.740157437040656*^9, {3.740158070725053*^9, 3.740158089235664*^9}, 
   3.740159586840007*^9, {3.740159642514539*^9, 3.740159690146283*^9}, 
   3.740160005070737*^9, {3.740160196850152*^9, 3.740160199330799*^9}, {
   3.7401602613260727`*^9, 3.74016032610748*^9}, {3.740160486288015*^9, 
   3.7401604871031847`*^9}, {3.740160673001334*^9, 3.740160701017693*^9}, {
   3.740160922060377*^9, 3.740160922258162*^9}, {3.740161414698333*^9, 
   3.7401614169393044`*^9}, {3.740161536127232*^9, 3.740161542060059*^9}, {
   3.740161709918662*^9, 3.740161716226707*^9}, {3.74016218910295*^9, 
   3.740162193700897*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"72da86fa-6e86-4a50-ae22-da0ac962117d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "Gaussian", " ", "distribution", " ", "of", " ",
     "rotation", " ", "angles"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"setsOf2DPntData", " ", "[", 
     RowBox[{
      RowBox[{"npts_:", "100"}], ",", 
      RowBox[{"nsets_:", "1000"}]}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"angles", " ", "=", " ", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{
            RowBox[{"Pi", "/", "8"}], ",", 
            RowBox[{".25", " ", 
             RowBox[{"Pi", "/", "8"}]}]}], "]"}], ",", "nsets"}], "]"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"build2DPntdataset", "[", 
         RowBox[{"npts", ",", 
          RowBox[{"angles", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}], "]"}]}], 
   ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740162994297964*^9, 3.740163047317624*^9}, {
   3.740163147428155*^9, 3.740163349971508*^9}, {3.740270423657037*^9, 
   3.740270464077395*^9}, 3.7402705067764587`*^9, 3.740659316183807*^9, 
   3.741707721759708*^9},ExpressionUUID->"b5268fee-91ea-4668-b094-\
a834801c5b62"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"build2DPntdataset", "[", "2", "]"}]}]], "Input",
 CellChangeTimes->{{3.740671972433375*^9, 3.740671972825308*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"77ccda8b-30e7-4efa-950c-8fa688a7c8d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.31321699663414526`", ",", "0.09397724209918372`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.31321699663414526`"}], ",", 
       RowBox[{"-", "0.09397724209918372`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3542583152946206`", ",", "0.006918163583689463`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.3542583152946206`"}], ",", 
       RowBox[{"-", "0.006918163583689463`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32533830599566405`", ",", 
       RowBox[{"-", "0.03303930484974561`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.32533830599566405`"}], ",", "0.03303930484974561`"}], 
      "}"}]}], "}"}], ",", "0.39269908169872414`"}], "}"}]], "Output",
 CellChangeTimes->{3.740671973580316*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"183f4e4a-afbf-4f43-972f-6c14c8204bf8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"test2DPnt", " ", "=", " ", 
   RowBox[{"build2DPntdataset", "[", "200", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7401603814650383`*^9, 3.740160406537571*^9}, 
   3.740161422851264*^9},
 CellLabel->
  "In[1236]:=",ExpressionUUID->"f3d20dde-cb85-4607-bb51-e6c21cb5d4d7"],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{"{", 
   RowBox[{"Red", ",", 
    RowBox[{"Point", "[", 
     RowBox[{"test2DPnt", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", "Blue", ",", 
    RowBox[{"Point", "[", 
     RowBox[{"test2DPnt", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", " ", "Green", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Point", "[", 
     RowBox[{"test2DPnt", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "]"}], ",", 
    RowBox[{"Darker", "@", "Green"}], ",", 
    RowBox[{"Line", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"test2DPnt", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"test2DPnt", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "200"}], "}"}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", "Blue", ",", 
    RowBox[{"Line", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"test2DPnt", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"test2DPnt", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "200"}], "}"}]}], "]"}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.740160730184589*^9, 3.740160874136133*^9}, 
   3.740160996801409*^9, {3.7401610287129908`*^9, 3.740161035790326*^9}, {
   3.740161077524419*^9, 3.74016108253824*^9}, {3.7401611273614397`*^9, 
   3.74016115154941*^9}, {3.7401614387797337`*^9, 3.740161453115094*^9}, {
   3.740161670855507*^9, 3.7401616719460993`*^9}},
 CellLabel->
  "In[1241]:=",ExpressionUUID->"d57d1c12-ab26-4041-b60e-d24f302e204c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Match", " ", "order", " ", "of", " ", "makeExxmat"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"REMEMBER", " ", "these", " ", "are", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"i", " ", "th"}], "]"}]}], " ", "=", " ", 
      RowBox[{"unit", "-", 
       RowBox[{"length", " ", "TWO"}], "-", 
       RowBox[{
       "VECTOR", " ", "\[IndentingNewLine]", "REMEMBER", " ", "the", " ", 
        "DATA", " ", "are", " ", "uniform"}]}]}]}], ",", " ", 
    RowBox[{
    "but", " ", "the", " ", "NOISE", " ", "should", " ", "be", " ", 
     "Gaussian"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"build2DFrmdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"baseAngle_:", 
      RowBox[{"Pi", "/", "8"}]}], ",", 
     RowBox[{"thmax_:", "0.1"}]}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fRef", " ", "=", "  ", 
        RowBox[{"randomSphere1", "[", "npts", "]"}]}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"These", " ", "are", " ", "unit", " ", "2"}], "-", 
          "vectors"}], ",", " ", 
         RowBox[{
         "theoretically", " ", "on", " ", "a", " ", "4", " ", "Pi", " ", 
          "circle"}], ",", " ", 
         RowBox[{"not", " ", "a", " ", "2", " ", "Pi", " ", "circle"}]}], " ",
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{"fJitter", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", ",", "thmax"}], "]"}], ",", " ", "npts"}], " ", 
         "]"}]}], ",", "fTgt", ",", "fTgtInit", ",", "th", ",", "rotTgt"}], 
      "}"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"checkJitter", " ", "=", " ", "fJitter"}], ";"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"make2DRotation", "[", 
           RowBox[{"fJitter", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], ".", 
          RowBox[{"fRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"th", "=", 
       RowBox[{"baseAngle", "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotTgt", " ", "=", " ", 
       RowBox[{"make2DRotation", "[", "th", "]"}]}], ";", " ", 
      RowBox[{"fTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotTgt", ".", "#"}], ")"}], "&"}], ",", "fTgtInit"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"fTgt", ",", "fRef", ",", " ", "fTgtInit", ",", "th"}], 
       "}"}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7401566126087313`*^9, 3.740156637764062*^9}, {
   3.740156733131111*^9, 3.740156737806591*^9}, {3.740157022119525*^9, 
   3.740157030000266*^9}, {3.740157367687036*^9, 3.740157392800632*^9}, 
   3.740157437040656*^9, {3.740158070725053*^9, 3.740158089235664*^9}, 
   3.740159586840007*^9, {3.740159642514539*^9, 3.740159690146283*^9}, 
   3.740160005070737*^9, {3.740160196850152*^9, 3.740160199330799*^9}, {
   3.7401602613260727`*^9, 3.74016032610748*^9}, {3.740160486288015*^9, 
   3.7401604871031847`*^9}, {3.740160673001334*^9, 3.740160701017693*^9}, {
   3.740160922060377*^9, 3.740160922258162*^9}, {3.740161414698333*^9, 
   3.7401614169393044`*^9}, {3.740161536127232*^9, 3.740161542060059*^9}, {
   3.740161709918662*^9, 3.740161716226707*^9}, {3.7401621561908007`*^9, 
   3.740162160670905*^9}, {3.740164519876156*^9, 3.740164520283457*^9}, {
   3.7401645507482023`*^9, 3.740164555730398*^9}, {3.7401645911399612`*^9, 
   3.740164652289867*^9}, {3.74016468442553*^9, 3.740164742120146*^9}, {
   3.7401648501601257`*^9, 3.740164891911285*^9}, {3.740175548538167*^9, 
   3.740175553560605*^9}, {3.740180604924539*^9, 3.740180682396399*^9}, {
   3.740180723443481*^9, 3.7401807349799023`*^9}, {3.740180765242833*^9, 
   3.7401807900432262`*^9}, {3.7402431751514*^9, 3.740243199900683*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"fee3155f-8f70-48cc-9d9a-839706b9c893"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "Gaussian", " ", "distribution", " ", "of", " ",
     "rotation", " ", "angles"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"setsOf2DFrmData", "[", 
     RowBox[{
      RowBox[{"npts_:", "100"}], ",", 
      RowBox[{"nsets_:", "1000"}]}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"angles", " ", "=", " ", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{
            RowBox[{"Pi", "/", "8"}], ",", 
            RowBox[{".25", " ", 
             RowBox[{"Pi", "/", "8"}]}]}], "]"}], ",", "nsets"}], "]"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"build2DFrmdataset", "[", 
         RowBox[{"npts", ",", 
          RowBox[{"angles", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}], "]"}]}], 
   ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740162994297964*^9, 3.740163047317624*^9}, {
   3.740163147428155*^9, 3.740163349971508*^9}, {3.7402432449071074`*^9, 
   3.74024331869864*^9}, {3.740243390264056*^9, 3.740243400254286*^9}, 
   3.740659286877226*^9, 
   3.7417077476475067`*^9},ExpressionUUID->"53e717f1-b102-4536-8ec2-\
a48265330b51"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{"test2DFrm", " ", "=", " ", 
    RowBox[{"build2DFrmdataset", "[", "100", "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{3.7401634516315393`*^9, 
  3.740249984607029*^9},ExpressionUUID->"e346efe5-ed5a-4c6f-bb93-\
f2c3969f85ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"CHECK", " ", "-", " ", 
    RowBox[{"Here", " ", "just", " ", "2", 
     RowBox[{"D", "."}]}]}], " ", "*)"}], 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"npts", " ", "=", "100"}], ",", 
      RowBox[{"ftgt", " ", "=", " ", 
       RowBox[{"1.4", " ", 
        RowBox[{"test2DFrm", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ",", " ", 
      RowBox[{"fref", " ", "=", " ", 
       RowBox[{"test2DFrm", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", 
      RowBox[{"ftgtinit", " ", "=", 
       RowBox[{"1.2", " ", 
        RowBox[{"test2DFrm", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}]}]}], " ", "}"}], ",", " ", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"Point", "[", "fref", "]"}], ",", "Blue", ",", 
       RowBox[{"Point", "[", "ftgt", "]"}], ",", " ", "Green", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Point", "[", "ftgtinit", "]"}], ",", 
       RowBox[{"Darker", "@", "Green"}], ",", 
       RowBox[{"Line", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fref", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"ftgtinit", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}], "]"}], ",", 
       "\[IndentingNewLine]", "Blue", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ftgtinit", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"ftgt", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}], "]"}]}], 
      "}"}], "]"}]}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.74025000441995*^9, 3.740250014306535*^9}},
 FontWeight->"Plain",ExpressionUUID->"77cfae44-4382-475d-826f-96c98832fb2d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q2DToRot", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.73932062546098*^9, 3.739320632117302*^9}},
 CellLabel->
  "In[224]:=",ExpressionUUID->"8a43360a-7b92-4e06-a5ea-a145e758bdcd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "a", " ", "b"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "a", " ", "b"}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7393206324811993`*^9, 3.739320661886504*^9}},
 CellLabel->
  "Out[224]=",ExpressionUUID->"3feab029-828f-4a8b-bc72-52db4fe8fa88"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"pntref", "=", 
      RowBox[{"data2Dquats", "[", 
       RowBox[{"[", " ", "1", "]"}], "]"}]}], ",", 
     RowBox[{"frmref", "=", 
      RowBox[{"data2Dquats", "[", 
       RowBox[{"[", " ", "2", "]"}], "]"}]}], ",", 
     RowBox[{"pnttgt", "=", 
      RowBox[{"data2DquatsTgt", "[", 
       RowBox[{"[", " ", "1", "]"}], "]"}]}], ",", 
     RowBox[{"frmtgt", "=", 
      RowBox[{"data2DquatsTgt", "[", 
       RowBox[{"[", " ", "2", "]"}], "]"}]}], ",", "\[IndentingNewLine]", " ",
      "num", " ", ",", " ", 
     RowBox[{"size", "=", "380"}], ",", 
     RowBox[{"b", "=", "1.2"}]}], "}"}], ",", " ", 
   RowBox[{
    RowBox[{"num", " ", "=", " ", 
     RowBox[{"Length", "[", "pntref", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"GraphicsRow", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "b"}], ",", 
                RowBox[{"-", "b"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"b", ",", 
                RowBox[{"-", "b"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"b", ",", "b"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "b"}], ",", "b"}], "}"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Blue", ",", 
           RowBox[{"Point", "[", "pnttgt", "]"}], ",", 
           RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red", ",", 
           RowBox[{"Point", "[", "pntref", "]"}], ",", "\[IndentingNewLine]", 
           "Thin", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"pnttgt", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"pntref", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "num"}], "}"}]}], "]"}], "]"}]}], 
          "}"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "size"}], ",", "size"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "b"}], ",", 
                RowBox[{"-", "b"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"b", ",", 
                RowBox[{"-", "b"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"b", ",", "b"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "b"}], ",", "b"}], "}"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Blue", ",", 
           RowBox[{"Point", "[", "frmtgt", "]"}], ",", 
           RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red", ",", 
           RowBox[{"Point", "[", "frmref", "]"}], ",", "\[IndentingNewLine]", 
           "Thin", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"frmtgt", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"frmref", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "num"}], "}"}]}], "]"}], "]"}]}], 
          "}"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "size"}], ",", "size"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], 
     "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",\

 CellChangeTimes->{{3.739380210090495*^9, 3.739380259426689*^9}, {
  3.739380295485303*^9, 3.739380334932722*^9}, {3.739380953510827*^9, 
  3.73938100294285*^9}, {3.739381403057757*^9, 3.739381454663003*^9}, {
  3.739381540741024*^9, 3.739381643331909*^9}, {3.739381725692622*^9, 
  3.739381752079113*^9}, {3.739383534600645*^9, 3.739383544347395*^9}, {
  3.739552230921399*^9, 3.739552243646883*^9}},
 CellLabel->
  "In[541]:=",ExpressionUUID->"ca348f60-d745-4eb7-a69c-c6bd258cc67f"],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"dir", ",", "c", ",", "s"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"1.2", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", 
            RowBox[{"-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}], ",", "Blue", ",", 
      RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"data2Dquats", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"make2DAxes", "[", 
         RowBox[{
          RowBox[{"q2DToRot", "[", 
           RowBox[{"data2Dquats", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "i"}], " ", "]"}], "]"}], "]"}], ",", " ", 
          RowBox[{"data2Dquats", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "i"}], "]"}], "]"}], ",", ".2", ",", "0", ",", 
          ".02"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"data2Dquats", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], "}"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7393210717052927`*^9, 3.739321104010488*^9}, {
  3.7393211524304256`*^9, 3.739321174642144*^9}, {3.7393212081382723`*^9, 
  3.739321288889037*^9}, {3.7393213316291437`*^9, 3.7393213361524963`*^9}, {
  3.7394502075527477`*^9, 3.739450293555299*^9}, {3.739554771302565*^9, 
  3.739554875867462*^9}},
 CellLabel->
  "In[556]:=",ExpressionUUID->"566eff5e-8e2c-4938-991b-fcfeab667042"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.7398424971912823`*^9},ExpressionUUID->"14842cdd-7bbf-4bbf-923a-\
a641221b3948"],

Cell[BoxData[
 RowBox[{
  RowBox[{"angleDiff", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", " ", 
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "-", "b"}], ">", "Pi"}], ",", " ", 
    RowBox[{"a", "-", "b", " ", "-", 
     RowBox[{"2", " ", "Pi"}]}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"b", "-", "a"}], ">", "Pi"}], ",", " ", 
      RowBox[{"a", "-", "b", " ", "+", 
       RowBox[{"2", "  ", "Pi"}]}], ",", " ", 
      RowBox[{"a", "-", "b"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739579739399507*^9, 3.739579812101755*^9}, {
  3.739580032080352*^9, 3.7395800377166*^9}},
 CellLabel->
  "In[612]:=",ExpressionUUID->"e2161565-66e3-4dc3-ae7e-f75b5efaa824"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeAngleDiffFromCS", "[", 
   RowBox[{"targetList_", ",", "refList_"}], "]"}], ":=", " ", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"len", "=", 
      RowBox[{"Length", "[", "refList", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"tAngle", ",", "rAngle", ",", 
        RowBox[{"Exx", "=", "0"}], ",", 
        RowBox[{"Exy", "=", "0"}], ",", " ", 
        RowBox[{"Eyx", "=", "0"}], ",", 
        RowBox[{"Eyy", "=", "0"}], ",", " ", "i"}], " ", "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Remember", "  ", "c"}], " ", "=", " ", 
        RowBox[{"Cos", "[", "th", "]"}]}], "  ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"tAngle", "=", "  ", 
          RowBox[{"ArcTan", "@@", 
           RowBox[{"targetList", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], " ", ";", 
         RowBox[{"rAngle", "=", "  ", 
          RowBox[{"ArcTan", "@@", 
           RowBox[{"refList", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], " ", ";", "  ", 
         RowBox[{"angleDiff", "[", " ", 
          RowBox[{"tAngle", " ", ",", "rAngle"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}]}], " ", "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739556431160845*^9, 3.739556597299634*^9}, {
   3.7395566909314127`*^9, 3.739556811283141*^9}, {3.7395569112406054`*^9, 
   3.739556968533737*^9}, 3.739557199678396*^9, {3.739559911537323*^9, 
   3.739559941896106*^9}, {3.739580163230671*^9, 3.739580167221449*^9}, {
   3.739637543506227*^9, 3.739637562554707*^9}, {3.739637618882434*^9, 
   3.739637647329706*^9}, {3.739638105214053*^9, 3.739638116893384*^9}},
 CellLabel->
  "In[627]:=",ExpressionUUID->"1f454d67-0659-4977-b59d-dea6decc395a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeAngleDiffFromAB", "[", 
   RowBox[{"targetList_", ",", "refList_"}], "]"}], ":=", " ", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"len", "=", 
      RowBox[{"Length", "[", "refList", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"tAngle", ",", "rAngle", ",", 
        RowBox[{"Exx", "=", "0"}], ",", 
        RowBox[{"Exy", "=", "0"}], ",", " ", 
        RowBox[{"Eyx", "=", "0"}], ",", 
        RowBox[{"Eyy", "=", "0"}], ",", " ", "i"}], " ", "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Remember", "  ", "a"}], " ", "=", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"th", "/", "2"}], "]"}]}], "  ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"tAngle", "=", " ", 
          RowBox[{"2", " ", 
           RowBox[{"ArcTan", "@@", 
            RowBox[{"targetList", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}]}]}], " ", ";", 
         RowBox[{"rAngle", "=", 
          RowBox[{"2", " ", 
           RowBox[{"ArcTan", "@@", 
            RowBox[{"refList", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}]}]}], " ", ";", "  ", 
         RowBox[{"angleDiff", "[", " ", 
          RowBox[{"tAngle", " ", ",", "rAngle"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}]}], " ", "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739556431160845*^9, 3.739556597299634*^9}, {
   3.7395566909314127`*^9, 3.739556811283141*^9}, {3.7395569112406054`*^9, 
   3.739556968533737*^9}, 3.739557199678396*^9, {3.739559911537323*^9, 
   3.739559941896106*^9}, {3.739580163230671*^9, 3.739580167221449*^9}, {
   3.739637543506227*^9, 3.739637562554707*^9}, {3.739638146860935*^9, 
   3.739638162628558*^9}},
 CellLabel->
  "In[628]:=",ExpressionUUID->"e084d032-4852-4637-b33c-7ee3ed661093"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeAngleExxFromAB", "[", 
   RowBox[{"targetList_", ",", "refList_"}], "]"}], ":=", " ", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"len", "=", 
      RowBox[{"Length", "[", "refList", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ta", ",", "tb", ",", "ra", ",", "rb", ",", 
        RowBox[{"Exx", "=", "0"}], ",", 
        RowBox[{"Exy", "=", "0"}], ",", " ", 
        RowBox[{"Eyx", "=", "0"}], ",", 
        RowBox[{"Eyy", "=", "0"}], ",", " ", "i"}], " ", "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"ta", ",", "tb"}], "}"}], "=", 
           RowBox[{"targetList", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], " ", ";", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"ra", ",", "rb"}], "}"}], "=", 
           RowBox[{"refList", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], " ", ";", "   ", 
          RowBox[{"Exx", " ", "+=", " ", 
           RowBox[{"ta", "*", "ra"}]}], ";", " ", 
          RowBox[{"Exy", " ", "+=", " ", 
           RowBox[{"ta", "*", "rb"}]}], ";", 
          RowBox[{"Eyx", "+=", " ", 
           RowBox[{"tb", "*", "ra"}]}], ";", " ", 
          RowBox[{"Eyy", "+=", " ", 
           RowBox[{"tb", "*", "rb"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "len"}], "}"}]}], "]"}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Exx", ",", "Exy"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Eyx", ",", "Eyy"}], "}"}]}], "}"}]}]}], "]"}]}], " ", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739556431160845*^9, 3.739556597299634*^9}, {
  3.7395566909314127`*^9, 3.739556811283141*^9}, {3.7395569112406054`*^9, 
  3.7395571487673187`*^9}, {3.7395571941920156`*^9, 3.7395572234393377`*^9}},
 CellLabel->
  "In[589]:=",ExpressionUUID->"388fba6a-939d-4ab4-8b5a-84cdb86b8cad"],

Cell[BoxData["  "], "Input",
 CellChangeTimes->{{3.739842475806818*^9, 
  3.739842495752493*^9}},ExpressionUUID->"e085a96e-8cbf-42c2-9124-\
69a9355c6d44"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "perfect", " ", "pure", " ", "angle", " ", "root"}], 
    "-", "square", "-", "diffs"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"delta2DF00", "[", 
     RowBox[{"mat2Dsoln_", ",", "frmTgt_", ",", "frmRef_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"RotfrmTgt", " ", "=", " ", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"mat2Dsoln", ".", "#"}], ")"}], "&"}], ",", "frmTgt"}], 
          "]"}]}], ",", 
        RowBox[{"num", " ", "=", " ", 
         RowBox[{"Length", "[", "frmRef", "]"}]}], ",", "diffs"}], "}"}], ",",
       "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"diffs", "=", 
        RowBox[{"MapThread", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"angleDiff", "[", " ", 
            RowBox[{
             RowBox[{"ArcTan", "[", 
              RowBox[{
               RowBox[{"#1", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"#1", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", 
             RowBox[{"ArcTan", "[", 
              RowBox[{
               RowBox[{"#2", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"#2", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], " ", "]"}], " ", 
           "&"}], ",", 
          RowBox[{"{", 
           RowBox[{"RotfrmTgt", ",", "frmRef"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "Square", " ", "the", " ", "differences", " ", "and", " ", "sum", 
          " ", "them"}], ",", " ", 
         RowBox[{
          RowBox[{"take", " ", "square", " ", "root"}], "..."}]}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Plus", "@@", 
         RowBox[{"(", " ", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox["#", "2"], "&"}], ",", "diffs"}], "]"}], ")"}]}], 
        "]"}]}]}], "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739635104263731*^9, 3.7396351344933023`*^9}, {
   3.7396351797689238`*^9, 3.739635214304311*^9}, {3.739635245740369*^9, 
   3.739635258380508*^9}, {3.7396354529440727`*^9, 3.739635459315658*^9}, {
   3.73963549570757*^9, 3.739635500467848*^9}, 3.739635543874601*^9, {
   3.73963559133517*^9, 3.739635653402363*^9}, {3.7396356973139467`*^9, 
   3.73963574432904*^9}, {3.7396358050938168`*^9, 3.739635841720091*^9}, 
   3.739635901487976*^9, {3.73963609877411*^9, 3.7396361243141537`*^9}, {
   3.739636155670073*^9, 3.7396362469407*^9}},
 CellLabel->
  "In[622]:=",ExpressionUUID->"c7896208-c87b-40d6-8873-da6c8557bbbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "quaternion"}], "-", "reduced", "-", "to", "-", 
    RowBox[{"2", "D", " ", "data"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"frmTgt", " ", "=", 
       RowBox[{"data2DquatsTgt", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", 
      RowBox[{"frmRef", "=", 
       RowBox[{"data2Dquats", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", "\[IndentingNewLine]",
     " ", 
    RowBox[{"DynamicModule", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"theAngle0", " ", "=", 
         RowBox[{"-", "0.2"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"theAngleSoln", " ", "=", " ", 
         RowBox[{
          RowBox[{"-", "  ", 
           RowBox[{"makeAngleDiffFromAB", "[", 
            RowBox[{"frmTgt", ",", "frmRef"}], "]"}]}], "/", 
          RowBox[{"Length", "[", "frmRef", "]"}]}]}]}], "  ", "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Manipulate", "[", " ", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MapThread", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"Point", "[", "#1", "]"}], ",", "Blue", ",", 
                RowBox[{"Point", "[", "#2", "]"}], ",", "Black", ",", 
                RowBox[{"Line", "[", 
                 RowBox[{"{", 
                  RowBox[{"#1", ",", "#2"}], "}"}], "]"}]}], "}"}], "&"}], 
             ",", " ", 
             RowBox[{"{", 
              RowBox[{"frmRef", ",", 
               RowBox[{"Map", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1.2", 
                    RowBox[{
                    RowBox[{"make2DRotation", "[", "th", "]"}], ".", "#"}]}], 
                   ")"}], "&"}], ",", "frmTgt"}], "]"}]}], "}"}]}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"\"\<\[Theta]= \>\"", "<>", 
                RowBox[{"ToString", "[", 
                 RowBox[{
                  RowBox[{"N", "[", 
                   RowBox[{"th", ",", "4"}], "]"}], "/", "Degree"}], "]"}], 
                "<>", "\"\<\\n \[CapitalDelta]= \>\"", "<>", 
                RowBox[{"ToString", "[", " ", 
                 RowBox[{"delta2DF00", "[", 
                  RowBox[{
                   RowBox[{"make2DRotation", "[", "th", "]"}], ",", "frmTgt", 
                   ",", "frmRef"}], "]"}], "]"}]}], ",", "Black", ",", "Bold",
                ",", "20"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], "  ", "}"}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"th", ",", "theAngleSoln"}], "}"}], ",", 
          RowBox[{
           RowBox[{"-", "Pi"}], "/", "4"}], ",", 
          RowBox[{"Pi", "/", "8"}], ",", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
       "]"}]}], "]"}]}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.739554630191571*^9, 3.739554660268139*^9}, {
  3.739555071444439*^9, 3.7395552585679007`*^9}, {3.7395553245397797`*^9, 
  3.739555330740857*^9}, {3.739560067829527*^9, 3.739560108763146*^9}, {
  3.739560160322522*^9, 3.7395602266421556`*^9}, {3.739560374796484*^9, 
  3.739560386449664*^9}, {3.7395604419890823`*^9, 3.7395604503449583`*^9}, {
  3.739635085488658*^9, 3.7396350904403057`*^9}, {3.739636327861002*^9, 
  3.739636386788987*^9}, {3.739636487412158*^9, 3.7396365515475492`*^9}, {
  3.7396365957790937`*^9, 3.739636634876978*^9}, {3.739636667227674*^9, 
  3.739636754422948*^9}, {3.739636816640935*^9, 3.739636861592784*^9}, {
  3.739636902477881*^9, 3.739636906209203*^9}, {3.7396369609576674`*^9, 
  3.739637022256543*^9}, {3.739637123815077*^9, 3.739637215390133*^9}, {
  3.739637287570877*^9, 3.739637288358466*^9}, {3.739724267471093*^9, 
  3.739724269027441*^9}},
 CellLabel->
  "In[663]:=",ExpressionUUID->"e59586dc-2498-43d4-9fae-cd11bb48513d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"chordDistance2DV12", "[", 
   RowBox[{"frmTgt_", ",", "frmRef_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Wcc", ",", "Wcs", ",", "Wsc", ",", "Wss", ",", 
      RowBox[{"num", " ", "=", " ", 
       RowBox[{"Length", "[", "frmRef", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Wcc", "=", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"frmTgt", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], " ", 
         RowBox[{
          RowBox[{"frmRef", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "num"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{"Wss", "=", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"frmTgt", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], " ", 
         RowBox[{
          RowBox[{"frmRef", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "num"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Wcs", "=", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"frmTgt", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], " ", 
         RowBox[{
          RowBox[{"frmRef", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "num"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "    ", 
     RowBox[{"Wsc", "=", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"frmTgt", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], " ", 
         RowBox[{
          RowBox[{"frmRef", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "num"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Wcc", " ", "+", " ", "Wss"}], ",", " ", 
       RowBox[{"Wcs", " ", "-", " ", "Wsc"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739638422982095*^9, 3.739638442193248*^9}, {
  3.739638544711401*^9, 3.739638656658066*^9}, {3.739638899746028*^9, 
  3.739638941309627*^9}, {3.739638973509103*^9, 3.739639063925927*^9}},
 CellLabel->
  "In[630]:=",ExpressionUUID->"847957dd-b725-4875-a17b-6d1d90a22c2c"],

Cell[TextData[StyleBox["THIS IS WHAT WE MINIMIZE in the chord approx:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.739725672604764*^9, 
  3.73972568657332*^9}},ExpressionUUID->"fde7f90d-7298-41ba-8b93-\
4555732ba984"],

Cell[BoxData[
 RowBox[{
  RowBox[{"chordCost2D", "[", 
   RowBox[{"th_", ",", "frmTgt_", ",", "frmRef_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rot", "=", 
       RowBox[{"make2DRotation", "[", "th", "]"}]}], ",", 
      RowBox[{"num", " ", "=", " ", 
       RowBox[{"Length", "[", "frmRef", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"rot", ".", 
         RowBox[{"frmTgt", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ")"}], ".", 
       RowBox[{"frmRef", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "num"}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739724787932878*^9, 3.739724791668619*^9}, {
  3.739725538710827*^9, 3.739725619670326*^9}},
 CellLabel->
  "In[667]:=",ExpressionUUID->"b84886a1-a729-44b4-907f-71bcd7c10df6"],

Cell[BoxData[
 RowBox[{"theAngleSoln", "->", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "  ", 
     RowBox[{"makeAngleDiffFromAB", "[", 
      RowBox[{"frmTgt", ",", "frmRef"}], "]"}]}], "/", 
    RowBox[{"Length", "[", "frmRef", "]"}]}], "/", "Degree"}]}]], "Input",
 CellChangeTimes->{{3.739726053564447*^9, 3.739726063578017*^9}, {
  3.739842158732185*^9, 
  3.739842160163456*^9}},ExpressionUUID->"fbc6b6ef-fba3-47f1-898b-\
6db32abcfa03"],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"frmTgt", " ", "=", 
      RowBox[{"data2DquatsTgt", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ",", 
     RowBox[{"frmRef", "=", 
      RowBox[{"data2Dquats", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"frmSoln", "=", " ", 
        RowBox[{
         RowBox[{"-", "  ", 
          RowBox[{"makeAngleDiffFromCS", "[", 
           RowBox[{"frmTgt", ",", "frmRef"}], "]"}]}], "/", 
         RowBox[{"Length", "[", "frmRef", "]"}]}]}], ",", "diffs"}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"delta2DF00", "[", 
      RowBox[{
       RowBox[{"make2DRotation", "[", "frmSoln", "]"}], ",", "frmTgt", ",", 
       "frmRef"}], "]"}]}], " ", "]"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.7396359055187273`*^9, 3.739636006206965*^9}, {
  3.73963643287471*^9, 3.739636440826702*^9}, {3.739638226281466*^9, 
  3.739638226627913*^9}},
 CellLabel->
  "In[629]:=",ExpressionUUID->"777fcd54-c9df-44ad-ae4a-5a54d013c30c"],

Cell[TextData[StyleBox["Derivations from  RRRinv,  q*p.r -> q.V, and (q.V)^2 \
vs  2 (q.V)^22 + q1 = 2(q.V)^2 + q.q p.p r.r,\n     the latter === to the \
RRRinv",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.741011007709858*^9, 
  3.741011103733642*^9}},ExpressionUUID->"68aab31b-6657-41f5-99fa-\
41d64d93b9d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"2", "D", " ", "version"}], ",", " ", 
    RowBox[{"used", " ", "in", " ", 
     RowBox[{"makeM2Dfrm", "[", 
      RowBox[{"tgt", ",", "ref"}], "]"}]}]}], "  ", "*)"}], 
  RowBox[{
   RowBox[{"metricFromForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}], 
      RowBox[{"Tr", "[", 
       RowBox[{
        RowBox[{"abToRot2D", "[", 
         RowBox[{"{", 
          RowBox[{"a0", ",", "a1"}], "}"}], "]"}], ".", 
        RowBox[{"abToRot2D", "[", 
         RowBox[{"{", 
          RowBox[{"b0", ",", "b1"}], "}"}], "]"}], ".", 
        RowBox[{"abToRot2D", "[", 
         RowBox[{"{", 
          RowBox[{"c0", ",", 
           RowBox[{"-", "c1"}]}], "}"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a0", ",", "a1"}], "}"}]}], "]"}], "//", "Factor"}]}]], "Input",\

 CellChangeTimes->{{3.7410187872536373`*^9, 3.741018827076281*^9}},
 CellLabel->
  "In[403]:=",ExpressionUUID->"180caba5-a344-4db9-9ba3-c3bbf9ae6a55"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c0"}], "-", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "-", 
        RowBox[{"b1", " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b1"}], " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b1"}], " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b0", " ", "c0"}], "+", 
         RowBox[{"b1", " ", "c0"}], "-", 
         RowBox[{"b0", " ", "c1"}], "+", 
         RowBox[{"b1", " ", "c1"}]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "-", 
        RowBox[{"b1", " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.74101882102353*^9, 3.7410188276319933`*^9}},
 CellLabel->
  "Out[403]=",ExpressionUUID->"96bda185-31b6-48ab-a4d7-48620f01243f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "-", 
   RowBox[{"makeM2Dfrm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"b0", ",", "b1"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"c0", ",", "c1"}], "}"}], "}"}]}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.741018849993437*^9, 3.741018856804551*^9}},
 CellLabel->
  "In[404]:=",ExpressionUUID->"d791e78a-c93c-4cdc-8084-918756ddc316"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741018857971073*^9},
 CellLabel->
  "Out[404]=",ExpressionUUID->"58121889-0dfa-4c2d-a886-082b589a51c9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeM2Dfrm", "[", 
   RowBox[{"frmTgt_", ",", "frmRef_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mm11", "=", "0"}], ",", 
      RowBox[{"mm12", "=", "0"}], ",", "b0", ",", "b1", ",", "c0", ",", "c1", 
      ",", "k", ",", 
      RowBox[{"num", " ", "=", " ", 
       RowBox[{"Length", "[", "frmRef", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"b0", "=", 
         RowBox[{"frmTgt", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ";", 
        RowBox[{"b1", "=", 
         RowBox[{"frmTgt", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "2"}], "]"}], "]"}]}], ";", 
        RowBox[{"c0", "=", 
         RowBox[{"frmRef", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ";", 
        RowBox[{"c1", "=", 
         RowBox[{"frmRef", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", " ", 
        RowBox[{"mm11", " ", "+=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b0", "2"], "-", 
             SuperscriptBox["b1", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["c0", "2"], "-", 
             SuperscriptBox["c1", "2"]}], ")"}]}], " ", "+", " ", 
          RowBox[{"4", " ", "b0", " ", "b1", " ", "c0", " ", "c1"}]}]}], " ", 
        ";", " ", 
        RowBox[{"mm12", "+=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b0", "2"], "-", 
             SuperscriptBox["b1", "2"]}], ")"}], "2", " ", "c0", " ", "c1"}], 
          "  ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["c0", "2"], "-", 
             SuperscriptBox["c1", "2"]}], ")"}], "2", " ", "b0", " ", 
           "b1"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "num"}], "}"}]}], "]"}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"mm11", ",", "mm12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"mm12", ",", 
         RowBox[{"-", "mm11"}]}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739755342361414*^9, 3.739755360557476*^9}, 
   3.739755405557559*^9, {3.739755437749734*^9, 3.739755748875009*^9}, {
   3.739756055140979*^9, 3.739756081430745*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"42395769-ce99-4ba9-bc4b-64a4ce232a03"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeVV2Dfrm", "[", 
   RowBox[{"frmTgt_", ",", "frmRef_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mm11", "=", "0"}], ",", 
      RowBox[{"mm12", "=", "0"}], ",", "b0", ",", "b1", ",", "c0", ",", "c1", 
      ",", "k", ",", 
      RowBox[{"num", "=", 
       RowBox[{"Length", "[", "frmRef", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"b0", "=", 
         RowBox[{"frmTgt", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ";", " ", 
        RowBox[{"b1", " ", "=", " ", 
         RowBox[{"frmTgt", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "2"}], "]"}], "]"}]}], ";", 
        RowBox[{"c0", "=", 
         RowBox[{"frmRef", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ";", " ", 
        RowBox[{"c1", " ", "=", " ", 
         RowBox[{"frmRef", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"mm11", "+=", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b0", " ", "c0"}], "+", 
            RowBox[{"b1", " ", "c1"}]}], ")"}], "2"]}], ";", " ", 
        RowBox[{"mm12", "+=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b1"}], " ", "c0"}], "+", 
            RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b0", " ", "c0"}], "+", 
            RowBox[{"b1", " ", "c1"}]}], ")"}]}]}]}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "num"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"2", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"mm11", ",", "mm12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"mm12", ",", 
          RowBox[{"-", "mm11"}]}], "}"}]}], "}"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7409646979073963`*^9, 3.7409647225043*^9}, {
  3.740964774945236*^9, 3.740964987029895*^9}, {3.740965034058066*^9, 
  3.740965047361071*^9}, {3.740965178542268*^9, 3.740965201981885*^9}},
 CellLabel->
  "In[315]:=",ExpressionUUID->"6b30b609-ab92-4138-8d2d-808983ccb0d2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeVVI2Dfrm", "[", 
   RowBox[{"frmTgt_", ",", "frmRef_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mm11", "=", "0"}], ",", 
      RowBox[{"mm12", "=", "0"}], ",", "b0", ",", "b1", ",", "c0", ",", "c1", 
      ",", "k", ",", 
      RowBox[{"num", "=", 
       RowBox[{"Length", "[", "frmRef", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"b0", "=", 
         RowBox[{"frmTgt", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ";", " ", 
        RowBox[{"b1", " ", "=", " ", 
         RowBox[{"frmTgt", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "2"}], "]"}], "]"}]}], ";", 
        RowBox[{"c0", "=", 
         RowBox[{"frmRef", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ";", " ", 
        RowBox[{"c1", " ", "=", " ", 
         RowBox[{"frmRef", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"mm11", "+=", 
         RowBox[{
          RowBox[{"2", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"b0", " ", "c0"}], "+", 
              RowBox[{"b1", " ", "c1"}]}], ")"}], "2"]}], " ", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b0", "2"], "+", 
             SuperscriptBox["b1", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["c0", "2"], "+", 
             SuperscriptBox["c1", "2"]}], ")"}]}]}]}], ";", " ", 
        RowBox[{"mm12", "+=", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b1"}], " ", "c0"}], "+", 
            RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b0", " ", "c0"}], "+", 
            RowBox[{"b1", " ", "c1"}]}], ")"}]}]}]}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "num"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"mm11", ",", "mm12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"mm12", ",", 
         RowBox[{"-", "mm11"}]}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7409646979073963`*^9, 3.7409647225043*^9}, {
   3.740964774945236*^9, 3.740964987029895*^9}, {3.740965034058066*^9, 
   3.740965047361071*^9}, {3.740965178542268*^9, 3.740965201981885*^9}, 
   3.740965326910445*^9, {3.740965416435643*^9, 3.7409654242370863`*^9}, 
   3.740965656901359*^9, {3.740965688834517*^9, 3.7409657102820053`*^9}, {
   3.740965895307239*^9, 3.740965944401266*^9}},
 CellLabel->
  "In[338]:=",ExpressionUUID->"ab865f7d-5c7b-4dde-aef5-5ee5a3d7b3ea"],

Cell[TextData[StyleBox[" The VV^2 form matches the  RRRinv (M2Dfrm) form if \
you SUBTRACT \n      the trace to make it traceless->  VVI = 2(q.V)^2 + \
q^2p^2r^2.",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7410109229242373`*^9, 3.7410109666391153`*^9}, {
  3.741011157029045*^9, 
  3.7410111963575068`*^9}},ExpressionUUID->"7e29f097-d74c-4fb9-9403-\
7ddd1f9d5d99"],

Cell[BoxData[
 RowBox[{"ckRRR", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"metricFromForm", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}], " ", 
        RowBox[{"Tr", "[", 
         RowBox[{
          RowBox[{"abToRot2D", "[", 
           RowBox[{"{", 
            RowBox[{"a0", ",", "a1"}], "}"}], "]"}], ".", 
          RowBox[{"abToRot2D", "[", 
           RowBox[{"{", 
            RowBox[{"b0", ",", "b1"}], "}"}], "]"}], ".", 
          RowBox[{"abToRot2D", "[", 
           RowBox[{"{", 
            RowBox[{"c0", ",", 
             RowBox[{"-", "c1"}]}], "}"}], "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"a0", ",", "a1"}], "}"}]}], "]"}], "//", "Simplify"}], "//", 
    "Expand"}], "//", "Factor"}]}]], "Input",
 CellChangeTimes->{{3.740963451976513*^9, 3.740963546514215*^9}, {
  3.740963904819585*^9, 3.740963906631288*^9}, {3.740964014361148*^9, 
  3.74096401658349*^9}},
 CellLabel->
  "In[297]:=",ExpressionUUID->"45d8481c-e3e0-42dc-bf61-e6ad71558154"],

Cell[BoxData[
 RowBox[{"ckVV", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"metricFromForm", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cprod", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"a0", ",", "a1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b0", ",", "b1"}], "}"}]}], "]"}], ".", " ", 
          RowBox[{"{", 
           RowBox[{"c0", ",", " ", "c1"}], "}"}]}], ")"}], "2"], ",", 
       RowBox[{"{", 
        RowBox[{"a0", ",", "a1"}], "}"}]}], "]"}], "//", "Simplify"}], "//", 
    "Expand"}], "//", "Factor"}]}]], "Input",
 CellChangeTimes->{{3.7409635963952713`*^9, 3.740963644926075*^9}, {
  3.740963914050377*^9, 3.740963915936232*^9}, {3.740964023242691*^9, 
  3.740964026447324*^9}},
 CellLabel->
  "In[307]:=",ExpressionUUID->"3f2f69ed-64cd-4b06-b264-ccac365ea0a1"],

Cell[BoxData[
 RowBox[{"ckVVI", "=", 
  RowBox[{"metricFromForm", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cprod", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a0", ",", "a1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b0", ",", "b1"}], "}"}]}], "]"}], ".", " ", 
         RowBox[{"{", 
          RowBox[{"c0", ",", " ", "c1"}], "}"}]}], ")"}], "2"]}], " ", "-", 
     "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a0", "2"], "+", 
        SuperscriptBox["a1", "2"]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b0", "2"], "+", 
        SuperscriptBox["b1", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["c0", "2"], "+", 
        SuperscriptBox["c1", "2"]}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a0", ",", "a1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.740964216996829*^9, {3.740964257590028*^9, 3.7409643541910343`*^9}},
 CellLabel->
  "In[305]:=",ExpressionUUID->"25026a83-b497-4598-8e6f-1fa550ae5df6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Tr", "[", "ckVV", "]"}], ",", 
    RowBox[{"Tr", "[", "ckVVI", "]"}], ",", 
    RowBox[{"Tr", "[", "ckRRR", "]"}]}], "}"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.741010460482049*^9, 3.741010494450808*^9}},
 CellLabel->
  "In[343]:=",ExpressionUUID->"393f5017-c7d2-42d0-82d7-7e4cba087bdf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b0", "2"], "+", 
      SuperscriptBox["b1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["c0", "2"], "+", 
      SuperscriptBox["c1", "2"]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.741010495628051*^9},
 CellLabel->
  "Out[343]=",ExpressionUUID->"0002d1dc-83e9-4393-a208-42d1e7503a09"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ckVV", "-", 
     RowBox[{"Transpose", "[", "ckVV", "]"}]}], ",", 
    RowBox[{"ckVVI", "-", 
     RowBox[{"Transpose", "[", "ckVVI", "]"}]}], ",", 
    RowBox[{"ckRRR", "-", 
     RowBox[{"Transpose", "[", "ckRRR", "]"}]}]}], "}"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.741010543220188*^9, 3.741010597838262*^9}},
 CellLabel->
  "In[344]:=",ExpressionUUID->"55d4ee17-db87-405e-9320-45bf5f4dc88d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741010599400069*^9},
 CellLabel->
  "Out[344]=",ExpressionUUID->"d234b963-c93b-4ba7-aa91-bfdc2f976ef8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ckRRR", "-", " ", "ckVVI"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.740964369259131*^9, 3.740964371962488*^9}},
 CellLabel->
  "In[306]:=",ExpressionUUID->"9f1a5f2e-8d0a-448b-907b-b7df22cbccd9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.740964374059486*^9},
 CellLabel->
  "Out[306]=",ExpressionUUID->"25d6ac18-c189-4aab-a1b4-67eebdaf8697"]
}, Open  ]],

Cell[TextData[StyleBox["Checking:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7398090332959223`*^9, 
  3.739809035359764*^9}},ExpressionUUID->"97e64f99-f5f5-40ea-9a53-\
c513b4cf4119"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"makeM2Dfrm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"b0", ",", "b1"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"c0", ",", "c1"}], "}"}], "}"}]}], "]"}], "//", "Expand"}], "//",
   "Factor"}]], "Input",
 CellChangeTimes->{{3.739808890868225*^9, 3.73980892729643*^9}},
 CellLabel->
  "In[1013]:=",ExpressionUUID->"3f142ea3-7a18-44f6-af74-2949d69cbf25"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c0"}], "-", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "-", 
        RowBox[{"b1", " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b1"}], " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b1"}], " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b0", " ", "c0"}], "+", 
         RowBox[{"b1", " ", "c0"}], "-", 
         RowBox[{"b0", " ", "c1"}], "+", 
         RowBox[{"b1", " ", "c1"}]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b0", " ", "c0"}], "-", 
        RowBox[{"b1", " ", "c0"}], "+", 
        RowBox[{"b0", " ", "c1"}], "+", 
        RowBox[{"b1", " ", "c1"}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.739841895668285*^9},
 CellLabel->
  "Out[1013]=",ExpressionUUID->"603a50ec-15b6-4ec8-abf4-1a158de49d7e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"abToRot2D", "[", 
  RowBox[{"{", 
   RowBox[{"a0", ",", "a1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.7397277674994907`*^9, 3.739727773636175*^9}, {
  3.739727816529592*^9, 3.739727819964273*^9}},
 CellLabel->
  "In[690]:=",ExpressionUUID->"923f262f-63ce-4ada-99fb-3e8c948e89a2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a0", "2"], "-", 
      SuperscriptBox["a1", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "a0", " ", "a1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "a0", " ", "a1"}], ",", 
     RowBox[{
      SuperscriptBox["a0", "2"], "-", 
      SuperscriptBox["a1", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.739727774175869*^9, 3.739727820906951*^9},
 CellLabel->
  "Out[690]=",ExpressionUUID->"42811f8b-cdbc-4f55-a7c1-c00a3fce74b7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"ChecktheM2Dmat", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"metricFromForm", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}], 
       RowBox[{"Tr", "[", 
        RowBox[{
         RowBox[{"abToRot2D", "[", 
          RowBox[{"{", 
           RowBox[{"a0", ",", "a1"}], "}"}], "]"}], ".", 
         RowBox[{"abToRot2D", "[", 
          RowBox[{"{", 
           RowBox[{"b0", ",", "b1"}], "}"}], "]"}], ".", 
         RowBox[{"abToRot2D", "[", 
          RowBox[{"{", 
           RowBox[{"c0", ",", 
            RowBox[{"-", "c1"}]}], "}"}], "]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"a0", ",", "a1"}], "}"}]}], "]"}], "//", "FullSimplify"}], "//",
    "Factor"}]}]], "Input",
 CellChangeTimes->{{3.739808459329913*^9, 3.739808548595549*^9}, {
  3.7398086566965637`*^9, 3.739808683507502*^9}, {3.7398419120967627`*^9, 
  3.7398419129420424`*^9}},ExpressionUUID->"40b79cbf-3063-4463-8a3c-\
fbdc60fd7935"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Solutions", " ", "to", " ", "the", " ", "M"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", 
         RowBox[{"-", "a"}]}], "}"}]}], "}"}], "  ", "eigenvector"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", " ", 
  RowBox[{
   FractionBox["1", 
    SqrtBox[
     RowBox[{"2", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}]]], " ", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{" ", 
       RowBox[{
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}]], "+", "a"}]}]], ",", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{" ", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]], "-", "a"}]}]]}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.739841661772121*^9, 
  3.739841693246542*^9}},ExpressionUUID->"a271b296-f262-41db-bfe4-\
dde257505d5a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Normalize", "[", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]]}], ",", "b"}], "}"}], "]"}], "/.", 
   RowBox[{"Abs", "\[Rule]", "Identity"}]}]}]], "Input",
 CellChangeTimes->{{3.7398417247439947`*^9, 3.7398417549432287`*^9}},
 CellLabel->
  "In[1012]:=",ExpressionUUID->"4f0563eb-a990-4f78-a198-5ce469e8dfdb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"a", "+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"]}]]}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]]}], ")"}], "2"]}]]], ",", 
   FractionBox["b", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]]}], ")"}], "2"]}]]]}], "}"}]], "Output",\

 CellChangeTimes->{{3.739841729122621*^9, 3.7398417562734327`*^9}},
 CellLabel->
  "Out[1012]=",ExpressionUUID->"0b64f245-2210-4a73-944d-0101d4a8d3f5"]
}, Open  ]],

Cell[TextData[StyleBox[" Here we choose the FULL theta angle in Rot2D[th] as \
the parameter,\n     first compute that angle from the   2D data profile \
matrix elements, then plot the\n     cost in (1/2)Tr RRR units (which are \
cosine (th + b - c)).",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.739818328494388*^9, 
  3.739818439543253*^9}},ExpressionUUID->"8a28cf65-baac-4598-8241-\
96d2183848ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"frmEigenvals2D", "[", "mm2Dmat_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", ",", "lambda"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"lambda", " ", "=", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"lambda", ",", 
       RowBox[{"-", "lambda"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73981877786884*^9, 3.7398188864923077`*^9}, {
   3.7398189227555313`*^9, 3.739819016795796*^9}, 3.739819063406487*^9, {
   3.739819705347156*^9, 3.7398197188762703`*^9}},
 CellLabel->
  "In[989]:=",ExpressionUUID->"cf1fc22a-8fba-4eba-ac75-7a02e5a66576"],

Cell[BoxData[
 RowBox[{
  RowBox[{"frmEigenvecs2D", "[", "mm2Dmat_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", ",", "lambda"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"lambda", " ", "=", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        FractionBox["1", 
         SqrtBox[
          RowBox[{"2", "lambda"}]]], " ", 
        RowBox[{"{", 
         RowBox[{
          SqrtBox[
           RowBox[{"lambda", "+", "a"}]], ",", 
          RowBox[{
           RowBox[{"Sign", "[", "b", "]"}], 
           SqrtBox[
            RowBox[{" ", 
             RowBox[{"lambda", "-", "a"}]}]]}]}], "}"}]}], ",", 
       RowBox[{
        FractionBox["1", 
         SqrtBox[
          RowBox[{"2", "lambda"}]]], " ", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox[
            RowBox[{"lambda", "-", "a"}]]}], ",", 
          RowBox[{
           RowBox[{"Sign", "[", "b", "]"}], 
           SqrtBox[
            RowBox[{" ", 
             RowBox[{"lambda", "+", "a"}]}]]}]}], "}"}]}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73981877786884*^9, 3.7398188864923077`*^9}, {
   3.7398189227555313`*^9, 3.739819016795796*^9}, 3.739819063406487*^9, {
   3.740319285406335*^9, 3.740319299588518*^9}, {3.7403197943215313`*^9, 
   3.7403197980408792`*^9}, {3.7403316033598537`*^9, 3.740331641520644*^9}, {
   3.740332015166485*^9, 3.740332018742668*^9}, {3.740332093030027*^9, 
   3.740332100190097*^9}, {3.740333239992852*^9, 3.740333249868678*^9}},
 CellLabel->
  "In[1534]:=",ExpressionUUID->"1159eda8-58ac-4ff7-b44c-0aabfdb5bc8a"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["CHECK that the double angle map yields the same \
rotation: it does, but quite tricky!",
 FontSlant->"Italic",
 FontVariations->{"Underline"->True}]], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.740339460461679*^9, 3.7403394965337687`*^9}, 
   3.7406716015094833`*^9},ExpressionUUID->"e7c6af63-0336-432b-bd2a-\
46d611059b45"],

Cell[BoxData[
 RowBox[{"frmEigenvecs2D", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "n"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{"-", "m"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.7403399076811953`*^9, 3.740339914961381*^9}, 
   3.740671601510353*^9},
 CellLabel->
  "In[1535]:=",ExpressionUUID->"98650a9d-371b-433e-95b6-c3edbb2bc9cb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SqrtBox[
       RowBox[{"m", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["m", "2"], "+", 
          SuperscriptBox["n", "2"]}]]}]], 
      RowBox[{
       SqrtBox["2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m", "2"], "+", 
          SuperscriptBox["n", "2"]}], ")"}], 
        RowBox[{"1", "/", "4"}]]}]], ",", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{
         RowBox[{"-", "m"}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["m", "2"], "+", 
           SuperscriptBox["n", "2"]}]]}]], " ", 
       RowBox[{"Sign", "[", "n", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m", "2"], "+", 
          SuperscriptBox["n", "2"]}], ")"}], 
        RowBox[{"1", "/", "4"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SqrtBox[
        RowBox[{
         RowBox[{"-", "m"}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["m", "2"], "+", 
           SuperscriptBox["n", "2"]}]]}]], 
       RowBox[{
        SqrtBox["2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m", "2"], "+", 
           SuperscriptBox["n", "2"]}], ")"}], 
         RowBox[{"1", "/", "4"}]]}]]}], ",", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{"m", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["m", "2"], "+", 
           SuperscriptBox["n", "2"]}]]}]], " ", 
       RowBox[{"Sign", "[", "n", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m", "2"], "+", 
          SuperscriptBox["n", "2"]}], ")"}], 
        RowBox[{"1", "/", "4"}]]}]]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7403399153803797`*^9, 3.740340180098166*^9, 
  3.7406716015111933`*^9},
 CellLabel->
  "Out[1535]=",ExpressionUUID->"05510cc9-ccc8-49c9-a292-46a9a2f04659"],

Cell[BoxData[
 RowBox[{"meig1", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}], ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "a", " ", "b"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "b"}], ",", "  ", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]}], "}"}]}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", " ", 
         FractionBox[
          SqrtBox[
           RowBox[{"m", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["m", "2"], "+", 
              SuperscriptBox["n", "2"]}]]}]], 
          RowBox[{
           SqrtBox["2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["m", "2"], "+", 
              SuperscriptBox["n", "2"]}], ")"}], 
            RowBox[{"1", "/", "4"}]]}]]}], ",", 
        RowBox[{"b", "\[Rule]", 
         FractionBox[
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "m"}], "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["m", "2"], "+", 
               SuperscriptBox["n", "2"]}]]}]], " ", 
           RowBox[{"Sign", "[", "n", "]"}]}], 
          RowBox[{
           SqrtBox["2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["m", "2"], "+", 
              SuperscriptBox["n", "2"]}], ")"}], 
            RowBox[{"1", "/", "4"}]]}]]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sign", "[", "n", "]"}], "2"], "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{
           RowBox[{"-", "m"}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["m", "2"], "+", 
             SuperscriptBox["n", "2"]}]]}]], " ", 
         SqrtBox[
          RowBox[{"m", "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["m", "2"], "+", 
             SuperscriptBox["n", "2"]}]]}]]}], "\[Rule]", " ", 
        RowBox[{"Sqrt", "[", " ", 
         SuperscriptBox["n", "2"], " ", "]"}]}]}], "}"}]}], "/.", " ", 
    RowBox[{
     RowBox[{
      SqrtBox[
       SuperscriptBox["n", "2"]], " ", 
      RowBox[{"Sign", "[", "n", "]"}]}], "\[Rule]", " ", "n"}]}], "//", 
   "Together"}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.740339210048924*^9, 3.7403392179509478`*^9}, {
   3.7403392644212103`*^9, 3.7403394102059393`*^9}, {3.740340282504809*^9, 
   3.740340284185968*^9}, 3.740671601511991*^9},
 CellLabel->
  "In[1540]:=",ExpressionUUID->"a8595d36-47af-49f3-a3e1-c2023e63bddb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["m", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["m", "2"], "+", 
        SuperscriptBox["n", "2"]}]]], ",", 
     RowBox[{"-", 
      FractionBox["n", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["m", "2"], "+", 
         SuperscriptBox["n", "2"]}]]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["n", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["m", "2"], "+", 
        SuperscriptBox["n", "2"]}]]], ",", 
     FractionBox["m", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["m", "2"], "+", 
        SuperscriptBox["n", "2"]}]]]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.7403392211833897`*^9, {3.740339266338736*^9, 3.7403393142922983`*^9}, 
   3.74033937380933*^9, 3.7403394114868298`*^9, 3.740340284908774*^9, 
   3.740671601512784*^9},
 CellLabel->
  "Out[1540]=",ExpressionUUID->"3007bab5-5675-4029-af38-f48f279fc986"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"BOTH", " ", "WORK"}], " ", "*)"}], 
  RowBox[{"meig2", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"]}], ",", 
           RowBox[{
            RowBox[{"-", "2"}], " ", "a", " ", "b"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"2", " ", "a", " ", "b"}], ",", "  ", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"]}]}], "}"}]}], "}"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "\[Rule]", " ", 
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "m"}], "+", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["m", "2"], "+", 
                SuperscriptBox["n", "2"]}]]}]], 
            RowBox[{
             SqrtBox["2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m", "2"], "+", 
                SuperscriptBox["n", "2"]}], ")"}], 
              RowBox[{"1", "/", "4"}]]}]]}]}], ",", 
         RowBox[{"b", "\[Rule]", 
          FractionBox[
           RowBox[{
            SqrtBox[
             RowBox[{"m", "+", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["m", "2"], "+", 
                SuperscriptBox["n", "2"]}]]}]], " ", 
            RowBox[{"Sign", "[", "n", "]"}]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["m", "2"], "+", 
               SuperscriptBox["n", "2"]}], ")"}], 
             RowBox[{"1", "/", "4"}]]}]]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"Sign", "[", "n", "]"}], "2"], "\[Rule]", "1"}], ",", 
        RowBox[{
         RowBox[{
          SqrtBox[
           RowBox[{
            RowBox[{"-", "m"}], "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["m", "2"], "+", 
              SuperscriptBox["n", "2"]}]]}]], " ", 
          SqrtBox[
           RowBox[{"m", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["m", "2"], "+", 
              SuperscriptBox["n", "2"]}]]}]]}], "\[Rule]", " ", 
         RowBox[{"Sqrt", "[", " ", 
          SuperscriptBox["n", "2"], " ", "]"}]}]}], "}"}]}], "/.", " ", 
     RowBox[{
      RowBox[{
       SqrtBox[
        SuperscriptBox["n", "2"]], " ", 
       RowBox[{"Sign", "[", "n", "]"}]}], "\[Rule]", " ", "n"}]}], "//", 
    "Together"}]}]}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.740339962481702*^9, 3.74033996936117*^9}, {
   3.7403400538926363`*^9, 3.7403400597928257`*^9}, {3.7403402050906067`*^9, 
   3.740340274720873*^9}, 3.740671601513543*^9},
 CellLabel->
  "In[1539]:=",ExpressionUUID->"97e41bb5-dc45-4601-a58c-6c58fc8fedcf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["m", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["m", "2"], "+", 
         SuperscriptBox["n", "2"]}]]]}], ",", 
     FractionBox["n", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["m", "2"], "+", 
        SuperscriptBox["n", "2"]}]]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["n", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["m", "2"], "+", 
         SuperscriptBox["n", "2"]}]]]}], ",", 
     RowBox[{"-", 
      FractionBox["m", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["m", "2"], "+", 
         SuperscriptBox["n", "2"]}]]]}]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{
  3.740339971228266*^9, 3.740340061578403*^9, {3.7403402087328463`*^9, 
   3.740340234919663*^9}, 3.7403402760192204`*^9, 3.740671601514338*^9},
 CellLabel->
  "Out[1539]=",ExpressionUUID->"d7179bca-d9a1-4bb5-b801-6c683a150a8e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"meig2", ".", "meig1"}], "//", "Simplify"}]], "Input",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.740340289110284*^9, 3.740340333917445*^9}, 
   3.74067160151512*^9},
 CellLabel->
  "In[1542]:=",ExpressionUUID->"b023223b-d2de-456c-9a7a-64dfc43ed827"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["m", "2"]}], "+", 
       SuperscriptBox["n", "2"]}], 
      RowBox[{
       SuperscriptBox["m", "2"], "+", 
       SuperscriptBox["n", "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", "m", " ", "n"}], 
      RowBox[{
       SuperscriptBox["m", "2"], "+", 
       SuperscriptBox["n", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "m", " ", "n"}], 
       RowBox[{
        SuperscriptBox["m", "2"], "+", 
        SuperscriptBox["n", "2"]}]]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["m", "2"]}], "+", 
       SuperscriptBox["n", "2"]}], 
      RowBox[{
       SuperscriptBox["m", "2"], "+", 
       SuperscriptBox["n", "2"]}]]}], "}"}]}], "}"}]], "Output",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{3.7403402994605827`*^9, 3.7403403343180027`*^9, 
  3.7406716015159082`*^9},
 CellLabel->
  "Out[1542]=",ExpressionUUID->"61df1630-6bba-48dd-a299-271ec15611a3"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D:", "Subsubsection",
 CellChangeTimes->{{3.740670286775611*^9, 
  3.740670291831479*^9}},ExpressionUUID->"e8f79def-fc64-47ce-bdb0-\
ffa692049cf1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvals2D", "[", "mm2Dmat_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", ",", "lambda"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"lambda", " ", "=", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"lambda", ",", 
       RowBox[{"-", "lambda"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73981877786884*^9, 3.7398188864923077`*^9}, {
   3.7398189227555313`*^9, 3.739819016795796*^9}, 3.739819063406487*^9, {
   3.739819705347156*^9, 3.7398197188762703`*^9}, 
   3.740670347440897*^9},ExpressionUUID->"c9aca073-c0de-4cfd-a8e6-\
0ccfd0f9e8d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maxEigenval2D", "[", "mm2Dmat_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", ",", "lambda"}], "}"}],
     ",", "\[IndentingNewLine]", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}]]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73981877786884*^9, 3.7398188864923077`*^9}, {
   3.7398189227555313`*^9, 3.739819016795796*^9}, 3.739819063406487*^9, {
   3.739819705347156*^9, 3.7398197188762703`*^9}, 3.740670347440897*^9, {
   3.74067040611208*^9, 3.7406704313398848`*^9}, 
   3.7406713293279467`*^9},ExpressionUUID->"c048489e-5843-4888-87ba-\
6c362ddafdd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvecs2D", "[", "mm2Dmat_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", ",", "lambda"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"lambda", " ", "=", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        FractionBox["1", 
         SqrtBox[
          RowBox[{"2", "lambda"}]]], " ", 
        RowBox[{"{", 
         RowBox[{
          SqrtBox[
           RowBox[{"lambda", "+", "a"}]], ",", 
          RowBox[{
           RowBox[{"Sign", "[", "b", "]"}], 
           SqrtBox[
            RowBox[{" ", 
             RowBox[{"lambda", "-", "a"}]}]]}]}], "}"}]}], ",", 
       RowBox[{
        FractionBox["1", 
         SqrtBox[
          RowBox[{"2", "lambda"}]]], " ", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox[
            RowBox[{"lambda", "-", "a"}]]}], ",", 
          RowBox[{
           RowBox[{"Sign", "[", "b", "]"}], 
           SqrtBox[
            RowBox[{" ", 
             RowBox[{"lambda", "+", "a"}]}]]}]}], "}"}]}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73981877786884*^9, 3.7398188864923077`*^9}, {
   3.7398189227555313`*^9, 3.739819016795796*^9}, 3.739819063406487*^9, {
   3.740319285406335*^9, 3.740319299588518*^9}, {3.7403197943215313`*^9, 
   3.7403197980408792`*^9}, {3.7403316033598537`*^9, 3.740331641520644*^9}, {
   3.740332015166485*^9, 3.740332018742668*^9}, {3.740332093030027*^9, 
   3.740332100190097*^9}, {3.740333239992852*^9, 3.740333249868678*^9}, 
   3.74067043841896*^9},
 CellLabel->"In[69]:=",ExpressionUUID->"d961f2f8-902d-46a7-995b-89c7044a8d2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maxEigenvec2D", "[", "mm2Dmat_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", ",", "lambda"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"lambda", " ", "=", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ";", "\[IndentingNewLine]", " ", 
     RowBox[{
      FractionBox["1", 
       SqrtBox[
        RowBox[{"2", "lambda"}]]], " ", 
      RowBox[{"{", 
       RowBox[{
        SqrtBox[
         RowBox[{"lambda", "+", "a"}]], ",", 
        RowBox[{
         RowBox[{"Sign", "[", "b", "]"}], 
         SqrtBox[
          RowBox[{" ", 
           RowBox[{"lambda", "-", "a"}]}]]}]}], "}"}]}]}]}], "]"}]}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.73981877786884*^9, 3.7398188864923077`*^9}, {
   3.7398189227555313`*^9, 3.739819016795796*^9}, 3.739819063406487*^9, {
   3.740319285406335*^9, 3.740319299588518*^9}, {3.7403197943215313`*^9, 
   3.7403197980408792`*^9}, {3.7403316033598537`*^9, 3.740331641520644*^9}, {
   3.740332015166485*^9, 3.740332018742668*^9}, {3.740332093030027*^9, 
   3.740332100190097*^9}, {3.740333239992852*^9, 3.740333249868678*^9}, 
   3.74067043841896*^9, {3.74067132308873*^9, 
   3.740671355991754*^9}},ExpressionUUID->"86bd431b-6ab7-4d60-abf4-\
cd67fed72707"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Eigenvectors", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", 
        RowBox[{"-", "a"}]}], "}"}]}], "}"}], "]"}], "*", "b"}], " ", "//", 
  "Simplify"}]], "Input",
 CellLabel->"In[67]:=",ExpressionUUID->"8a8a0806-c502-440c-9fae-ab2d8883e6d7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ",", "b"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.74067092675498*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"8746067f-4da1-4408-a647-b8b3168cff59"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Normalize", "/@", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Eigenvectors", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a", ",", "b"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b", ",", 
             RowBox[{"-", "a"}]}], "}"}]}], "}"}], "]"}], "*", "b"}], " ", "//",
        "Simplify"}], ")"}]}], ")"}], "/.", " ", "\[IndentingNewLine]", "  ", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Abs", "[", "b", "]"}], "2"], "\[Rule]", " ", 
      SuperscriptBox["b", "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Abs", "[", 
        RowBox[{"a", "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]]}], "]"}], "2"], "\[Rule]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]]}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Abs", "[", 
        RowBox[{"a", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]]}], "]"}], "2"], "\[Rule]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]]}], ")"}], "2"]}]}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.740670466738071*^9, 3.7406704833981447`*^9}, {
  3.740670521792349*^9, 3.740670677278459*^9}, {3.740670839822344*^9, 
  3.740670883018641*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"be8998fe-47c3-4f9d-8773-7319c8351da8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"a", "-", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]]}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"]}]]}], ")"}], "2"]}]]], ",", 
     FractionBox["b", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"]}]]}], ")"}], "2"]}]]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"a", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]]}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"]}]]}], ")"}], "2"]}]]], ",", 
     FractionBox["b", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"]}]]}], ")"}], "2"]}]]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.740670483893715*^9, {3.740670525380006*^9, 3.740670565909045*^9}, 
   3.7406708119420633`*^9, 3.7406708543692713`*^9, 3.740670893740283*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"02ca4c67-4286-4ced-849d-74b3f994c98f"]
}, Open  ]],

Cell[TextData[StyleBox["Introduce the rest of the computation, and check that \
with/without Sign[b] versions OK",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7406715310924997`*^9, 
  3.740671559604595*^9}},ExpressionUUID->"462dd013-ea2c-4063-9aac-\
e00aab6e9d85"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvecs2DAlt", "[", "mm2Dmat_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", ",", "lambda"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"lambda", " ", "=", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"lambda", "+", "a"}], 
          SqrtBox[
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", "lambda"}], ")"}], "2"]}]]], ",", 
         FractionBox["b", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", "lambda"}], ")"}], "2"]}]]]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"lambda", "-", "a"}], 
           SqrtBox[
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"a", "-", "lambda"}], ")"}], "2"]}]]]}], ",", 
         FractionBox["b", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "lambda"}], ")"}], "2"]}]]]}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73981877786884*^9, 3.7398188864923077`*^9}, {
   3.7398189227555313`*^9, 3.739819016795796*^9}, 3.739819063406487*^9, {
   3.740319285406335*^9, 3.740319299588518*^9}, {3.7403197943215313`*^9, 
   3.7403197980408792`*^9}, {3.7403316033598537`*^9, 3.740331641520644*^9}, {
   3.740332015166485*^9, 3.740332018742668*^9}, {3.740332093030027*^9, 
   3.740332100190097*^9}, {3.740333239992852*^9, 3.740333249868678*^9}, {
   3.74067043841896*^9, 3.7406704579280567`*^9}, {3.740670991810809*^9, 
   3.740671086283828*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"e95233ca-5726-42ce-bb3f-092c54b0b7a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "mat"}], "}"}], ",", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}]}], ";", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}]}], ";", "  ", 
      RowBox[{"mat", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"b", ",", 
           RowBox[{"-", "a"}]}], "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Union", "[", 
       RowBox[{"Chop", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"eigenvecs2D", "[", "mat", "]"}], "-", 
          RowBox[{"eigenvecs2DAlt", "[", "mat", "]"}]}], "]"}], "]"}], 
       "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "100"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.74067110392922*^9, 3.7406711702647448`*^9}, {
  3.7406712779918537`*^9, 3.7406713008642282`*^9}, {3.740671375170082*^9, 
  3.740671493730713*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"ee124682-bb37-4e3f-a895-26c3d472ffb8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.740671489086228*^9, 3.740671494738883*^9}},
 CellLabel->"Out[71]=",ExpressionUUID->"c358c64f-dc0d-4b69-a497-386390359925"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D cost stuff", "Subsubsection",
 CellChangeTimes->{{3.7406716765798492`*^9, 
  3.740671680555114*^9}},ExpressionUUID->"65253d74-a922-44c8-b2a4-\
b30ab91aba7e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"chordRRRCost2D", "[", 
   RowBox[{"theta_", ",", "mm2Dmat_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a0", "=", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"theta", "/", "2"}], "]"}]}], ",", 
      RowBox[{"a1", "=", 
       RowBox[{"Sin", "[", 
        RowBox[{"theta", "/", "2"}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a0", ",", "a1"}], "}"}], ".", "mm2Dmat", ".", 
     RowBox[{"{", 
      RowBox[{"a0", ",", "a1"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.739724787932878*^9, 3.739724791668619*^9}, {
  3.739725538710827*^9, 3.739725619670326*^9}, {3.739808425633398*^9, 
  3.739808443981251*^9}, {3.7398171731215*^9, 3.739817333400206*^9}, {
  3.739820474930541*^9, 3.739820487967317*^9}, {3.7398205180588617`*^9, 
  3.739820528983531*^9}, {3.739820603014254*^9, 3.739820626060833*^9}},
 CellLabel->
  "In[999]:=",ExpressionUUID->"7a606635-d0a9-44bd-ada0-601140eec7f8"],

Cell[TextData[StyleBox[" Interesting when b=0, M is diagonal: that means that \
a>0 for the largest eigenvalue, so\n    Sqrt[Sqrt[a^2]+ a] = Sqrt[2 a], and \
reversed sign for the negative (lowest) eigenvalue,\n    Sqrt[a^2] - a = 2 \
Sqrt[a^2]> 0.",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7403382763825808`*^9, 3.740338368495037*^9}, {
  3.740338459983239*^9, 
  3.740338521469492*^9}},ExpressionUUID->"e729f671-bec8-42f2-a449-\
ff2f6ae2c6c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"chordOptAngle", "[", "mm2Dmat_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"mm2Dmat", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", "v0", ",", "v1"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"v0", ",", "v1"}], "}"}], "=", 
      RowBox[{
       FractionBox["1", 
        SqrtBox[
         RowBox[{"2", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}]]}]]], " ", 
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{" ", 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"]}]], "+", "a"}]}]], ",", 
         RowBox[{
          RowBox[{"Sign", "[", "b", "]"}], 
          SqrtBox[
           RowBox[{" ", 
            RowBox[{
             SqrtBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"]}]], "-", "a"}]}]]}]}], "}"}]}]}], ";",
      " ", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"v0", ",", 
       RowBox[{
        RowBox[{"v1", " ", "are", " ", "in", " ", "quaternion", " ", "half"}],
         "-", 
        RowBox[{"angle", " ", "coords"}]}]}], " ", "*)"}], " ", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["v0", "2"], "-", 
        SuperscriptBox["v1", "2"]}], ",", " ", 
       RowBox[{"2", " ", "v0", " ", "v1"}]}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7398173759078693`*^9, 3.739817537856061*^9}, {
   3.739818263105351*^9, 3.739818303160675*^9}, {3.739818462687995*^9, 
   3.7398184766638937`*^9}, 3.740319339747612*^9, 3.740319909856185*^9, {
   3.7403316155291862`*^9, 3.740331618165105*^9}},
 CellLabel->
  "In[1484]:=",ExpressionUUID->"521113ac-0f6e-40f3-aed6-270cc1728c88"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mm22test", "=", 
  RowBox[{"makeM2Dfrm", "[", 
   RowBox[{
    RowBox[{"data2DquatsTgt", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"data2Dquats", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.740319488701295*^9, 3.7403194919534616`*^9}},
 CellLabel->
  "In[1453]:=",ExpressionUUID->"b800e23a-8140-49bc-b40a-65ccfbb5287b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"90.2356529952429`", ",", 
     RowBox[{"-", "36.93596430895122`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36.93596430895122`"}], ",", 
     RowBox[{"-", "90.2356529952429`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.74031947627837*^9, 3.740319492505809*^9}},
 CellLabel->
  "Out[1453]=",ExpressionUUID->"dbd4d2a8-f2bf-4901-970f-47979669da59"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"mm22testC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"90.2356529952429`", ",", " ", "36.93596430895122`"}], "}"}], 
     ",", 
     RowBox[{"{", " ", 
      RowBox[{"36.93596430895122`", ",", 
       RowBox[{"-", "90.2356529952429`"}]}], "}"}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.7403316666254263`*^9, 3.740331689825618*^9}},
 CellLabel->
  "In[1481]:=",ExpressionUUID->"d2c76059-9a1a-4b1b-a82e-ca9481947c6c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"chordOptAngle", "[", "mm22test", "]"}], ",", 
   RowBox[{"chordOptAngle", "[", " ", "mm22testC", "]"}]}], "  ", 
  "}"}]], "Input",
 CellChangeTimes->{{3.740331785168436*^9, 3.7403318147837973`*^9}},
 CellLabel->
  "In[1485]:=",ExpressionUUID->"6a4f0210-07ca-402d-a4c0-77011968438b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.3885216592324799`"}], ",", "0.3885216592324799`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.740331816982354*^9},
 CellLabel->
  "Out[1485]=",ExpressionUUID->"21766c41-0d46-48c4-b299-e84d29cfc000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Eigensystem", "[", "mm22test", "]"}], ",", 
   RowBox[{"Eigensystem", "[", "mm22testC", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.740319501007161*^9, 3.740319512330058*^9}, {
  3.740331696261346*^9, 3.740331706184928*^9}},
 CellLabel->
  "In[1482]:=",ExpressionUUID->"f04b20aa-5cf7-402e-8a74-d716e8b41682"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "97.50250525453184`"}], ",", "97.50250525453184`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19304132071168373`"}], ",", 
         RowBox[{"-", "0.9811906280116462`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9811906280116462`"}], ",", "0.19304132071168373`"}], 
        "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "97.50250525453184`"}], ",", "97.50250525453184`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.19304132071168373`", ",", 
         RowBox[{"-", "0.9811906280116462`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9811906280116462`"}], ",", 
         RowBox[{"-", "0.19304132071168373`"}]}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.740319512944715*^9, 3.74033170848982*^9},
 CellLabel->
  "Out[1482]=",ExpressionUUID->"6e6937c7-ce16-404e-8b36-0e1a968cf6b9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"frmEigenvals2D", "[", "mm22test", "]"}]], "Input",
 CellChangeTimes->{{3.74031958201822*^9, 3.740319582488551*^9}},
 CellLabel->
  "In[1456]:=",ExpressionUUID->"ba63b517-fb03-4c54-bd1a-3d97cfa1e8bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"97.50250525453183`", ",", 
   RowBox[{"-", "97.50250525453183`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.740319583759816*^9},
 CellLabel->
  "Out[1456]=",ExpressionUUID->"bde8da90-567d-4c91-bdeb-1ad24415c219"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vv11A", ",", "vv22B"}], "}"}], " ", "=", " ", 
    RowBox[{"frmEigenvecs2D", "[", "mm22test", "]"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vv11AC", ",", "vv22BC"}], "}"}], " ", "=", " ", 
    RowBox[{"frmEigenvecs2D", "[", "mm22testC", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.740319525740843*^9, 3.740319563217142*^9}, 
   3.740319775771096*^9, {3.740331747491764*^9, 3.740331760489324*^9}},
 CellLabel->
  "In[1513]:=",ExpressionUUID->"fc37c4c5-18dd-4421-8b75-5538778db3f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9811906280116462`", ",", 
       RowBox[{"-", "0.19304132071168364`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.19304132071168364`"}], ",", 
       RowBox[{"-", "0.9811906280116462`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9811906280116462`", ",", "0.19304132071168364`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.19304132071168364`"}], ",", "0.9811906280116462`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.740319563836832*^9, 3.740319817654755*^9, 
  3.740331765066299*^9, 3.740332033670062*^9, 3.740332107319018*^9, 
  3.740333263102324*^9},
 CellLabel->
  "Out[1513]=",ExpressionUUID->"b4d6b3ee-7055-457f-ad32-b3b4bc61afe5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"vv11A", ".", "mm22test"}], ")"}], "/", "97.50250525453183`"}], 
   ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"vv22B", ".", "mm22test"}], ")"}]}], "/", 
    "97.50250525453183`"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.74031959117115*^9, 3.740319633016005*^9}, {
  3.740319856370282*^9, 3.740319879967607*^9}},
 CellLabel->
  "In[1514]:=",ExpressionUUID->"71678f7b-916a-47f3-984f-a58fa4aeea70"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9811906280116464`", ",", 
     RowBox[{"-", "0.19304132071168387`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.19304132071168387`"}], ",", 
     RowBox[{"-", "0.9811906280116464`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7403196033147783`*^9, 3.7403196339273376`*^9}, 
   3.7403198406621523`*^9, 3.740319881954577*^9, 3.7403319102798653`*^9, 
   3.7403320395186167`*^9, 3.740332112968153*^9, 3.740333313801566*^9},
 CellLabel->
  "Out[1514]=",ExpressionUUID->"66725eaf-19b9-4a0e-a077-dfd8f4ac7baa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"vv11AC", ".", "mm22testC"}], ")"}], "/", "97.50250525453183`"}],
    ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"vv22BC", ".", "mm22testC"}], ")"}]}], "/", 
    "97.50250525453183`"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.74031959117115*^9, 3.740319633016005*^9}, {
  3.740319856370282*^9, 3.740319879967607*^9}, {3.7403319484891148`*^9, 
  3.740331966598583*^9}},
 CellLabel->
  "In[1515]:=",ExpressionUUID->"d55a684f-6427-40bc-986b-d05c073ac1d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9811906280116464`", ",", "0.19304132071168387`"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.19304132071168387`"}], ",", "0.9811906280116464`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.740331968197122*^9, 3.7403320437414093`*^9, 
  3.740332118415614*^9, 3.7403333259460783`*^9},
 CellLabel->
  "Out[1515]=",ExpressionUUID->"8cb73733-e598-4731-b5cc-643252a2c948"]
}, Open  ]],

Cell[TextData[StyleBox["ABOVE CHECKS SUCCEED:  I had no idea this would need \
the Sign[b], good thing I tried\n    a strange case in the test step....",
 FontSize->18]], "Text",
 CellChangeTimes->{{3.7403381485286417`*^9, 
  3.7403381826720867`*^9}},ExpressionUUID->"36775ba2-04c1-4e03-a564-\
c7806e7367c5"],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"mmat", " ", "=", " ", 
      RowBox[{"makeM2Dfrm", "[", " ", 
       RowBox[{
        RowBox[{"data2DquatsTgt", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
        RowBox[{"data2Dquats", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ",", "maxCost"}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"maxCost", "=", 
     RowBox[{"chordRRRCost2D", "[", 
      RowBox[{"thedata2DQTheta", ",", "mmat"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"chordRRRCost2D", "[", 
       RowBox[{"th", ",", "mmat"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"th", ",", "0", ",", " ", 
        RowBox[{"2", " ", "thedata2DQTheta"}]}], "}"}], ",", 
      RowBox[{"Epilog", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", 
         RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"thedata2DQTheta", ",", "maxCost"}], "}"}], "]"}], ",", 
         "Red", ",", "Thick", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"thedata2DQTheta", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"thedata2DQTheta", ",", "maxCost"}], "}"}]}], "}"}], 
          "]"}]}], " ", "}"}]}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.739819192484618*^9, 3.739819212792898*^9}, {
  3.739820655180191*^9, 3.739820698924457*^9}, {3.7398246804005747`*^9, 
  3.739824807699745*^9}, {3.739824845328041*^9, 3.739824972354714*^9}, {
  3.739825007227419*^9, 3.739825015633933*^9}},
 CellLabel->
  "In[1006]:=",ExpressionUUID->"e0df8b1b-33cc-4589-a032-4450cd34d4fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Useful  2D  (and 3D -todo-)  Demos", "Section",
 CellChangeTimes->{{3.739841984269065*^9, 
  3.739842000374303*^9}},ExpressionUUID->"5914fc2c-cecf-4265-9889-\
11de1f33e16c"],

Cell[TextData[StyleBox["======================================================\
===\n SELFCONTAINED - transfer these data plus defs of  chordDistance2DV12  & \
 chordCost2D",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7397274446224117`*^9, 
  3.739727503150792*^9}},ExpressionUUID->"f975894f-541d-4052-a71f-\
9fb66c48e0f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Retrieve", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "Get", "[", 
    "\"\</home/hanson/Dropbox/Articles/Horn-soln-dir/000FIGURES/data2D100Ref.\
m\>\"", "]"}], ";", 
   RowBox[{
   "Get", "[", 
    "\"\</home/hanson/Dropbox/Articles/Horn-soln-dir/000FIGURES/data2D100Tgt.\
m\>\"", "]"}], ";", 
   RowBox[{"{", 
    RowBox[{"TheglobalRadP", " ", ",", " ", "TheglobalRadF"}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.739634221154203*^9, 3.7396343122614307`*^9}, {
  3.7396346246344843`*^9, 
  3.739634626265675*^9}},ExpressionUUID->"cb86dce3-0848-4d35-b8f3-\
e603690d732a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data2Dquats", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", 
    RowBox[{"1", ";;", "3"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.739842046124605*^9, 3.7398420602600813`*^9}},
 CellLabel->
  "In[1015]:=",ExpressionUUID->"5cd53975-cfc1-4e45-bb5f-1c66cfb2f621"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5386441507556552`"}], ",", 
     RowBox[{"-", "0.24880183909751175`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4640322132712664`", ",", 
     RowBox[{"-", "0.28441911960381283`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.13408288048471562`"}], ",", "0.014243667420032136`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.739842048498807*^9, 3.739842061199682*^9}},
 CellLabel->
  "Out[1015]=",ExpressionUUID->"dcd591e7-76e8-43dc-97ea-47d56827d917"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"theCostPlotF", " ", "=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"rot", ",", "rotTgt", ",", 
       RowBox[{"frmTgt", " ", "=", 
        RowBox[{"data2DquatsTgt", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", 
       RowBox[{"frmRef", "=", 
        RowBox[{"data2Dquats", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"rot", " ", "=", "  ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", "th", "]"}], ",", 
             RowBox[{"-", 
              RowBox[{"Sin", "[", "th", "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sin", "[", "th", "]"}], ",", 
             RowBox[{"Cos", "[", "th", "]"}]}], "}"}]}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"rotTgt", " ", "=", " ", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"rot", ".", "#"}], ")"}], "&"}], ",", "frmTgt"}], 
          "]"}]}], ";", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"th", " ", "/", "Degree"}], " ", ")"}], ",", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"rotTgt", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ")"}], ".", 
             RowBox[{"frmRef", "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "1", ",", 
              RowBox[{"Length", "[", "frmRef", "]"}]}], "}"}]}], "]"}]}], 
         "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"th", ",", 
         RowBox[{"-", "Pi"}], ",", "Pi", ",", ".2"}], "}"}]}], "]"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.73721016238546*^9, 3.7372101926575947`*^9}, {
  3.7372102283105907`*^9, 3.7372103834620867`*^9}, {3.737210433154332*^9, 
  3.737210449406316*^9}, {3.737210481568935*^9, 3.737210530325067*^9}, {
  3.739666940000959*^9, 3.739667026874363*^9}},
 CellLabel->
  "In[640]:=",ExpressionUUID->"41474c14-36ee-44a7-b4ec-050cdd3b1f62"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   RowBox[{
    StyleBox["the",
     FontSize->14,
     FontWeight->"Bold",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontSize->14,
     FontWeight->"Bold",
     FontSlant->"Italic"], 
    StyleBox["CHORD",
     FontSize->14,
     FontWeight->"Bold",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontSize->14,
     FontWeight->"Bold",
     FontSlant->"Italic"], 
    StyleBox["distance",
     FontSize->14,
     FontWeight->"Bold",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontSize->14,
     FontWeight->"Bold",
     FontSlant->"Italic"], 
    StyleBox["approx",
     FontSize->14,
     FontWeight->"Bold",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    RowBox[{
     StyleBox["to",
      FontSize->14,
      FontWeight->"Bold",
      FontSlant->"Italic"], 
     StyleBox[":",
      FontSize->14,
      FontWeight->"Bold",
      FontSlant->"Italic"], "  ", 
     RowBox[{"quaternion", "-", "reduced", "-", "to", "-", 
      RowBox[{"2", "D", " ", "data"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"frmTgt", " ", "=", 
       RowBox[{"data2DquatsTgt", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", 
      RowBox[{"frmRef", "=", 
       RowBox[{"data2Dquats", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
      RowBox[{"size", " ", "=", " ", "380"}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Chord", " ", "Soln"}], " ", "*)"}], " ", 
      RowBox[{"th0", "=", 
       RowBox[{"ArcTan", "@@", " ", 
        RowBox[{"Normalize", "[", 
         RowBox[{"chordDistance2DV12", "[", 
          RowBox[{
           RowBox[{"data2DquatsTgt", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"data2Dquats", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"DynamicModule", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"theAngle0", " ", "=", 
         RowBox[{"-", "0.2"}]}], ",", "rot0", ",", "rotTgt0", ",", 
        "deltaX0"}], "  ", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rot0", " ", "=", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", "th0", "]"}], ",", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", "th0", "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sin", "[", "th0", "]"}], ",", 
            RowBox[{"Cos", "[", "th0", "]"}]}], "}"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"rotTgt0", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"rot0", ".", "#"}], ")"}], "&"}], ",", "frmTgt"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "MAX", " ", "of", " ", "delta", " ", "is", " ", "at", " ", "th0"}], 
         ",", " ", 
         RowBox[{
         "this", " ", "is", " ", "optimal", " ", "chord", " ", "cost"}]}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"deltaX0", " ", "=", " ", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"rotTgt0", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ")"}], ".", 
           RowBox[{"frmRef", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", 
            RowBox[{"Length", "[", "frmRef", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Manipulate", "[", " ", 
        RowBox[{
         RowBox[{"Module", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "V1", ",", "V2", ",", "rot", ",", "rotTgt", ",", "deltaX"}], 
            "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rot", " ", "=", "  ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Cos", "[", "th", "]"}], ",", 
                 RowBox[{"-", 
                  RowBox[{"Sin", "[", "th", "]"}]}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Sin", "[", "th", "]"}], ",", 
                 RowBox[{"Cos", "[", "th", "]"}]}], "}"}]}], "}"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"rotTgt", " ", "=", " ", 
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"rot", ".", "#"}], ")"}], "&"}], ",", "frmTgt"}], 
              "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"deltaX", " ", "=", " ", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"rotTgt", "[", 
                  RowBox[{"[", "k", "]"}], "]"}], ")"}], ".", 
                RowBox[{"frmRef", "[", 
                 RowBox[{"[", "k", "]"}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"k", ",", "1", ",", 
                 RowBox[{"Length", "[", "frmRef", "]"}]}], "}"}]}], "]"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"V1", ",", "V2"}], "}"}], " ", "=", " ", 
             RowBox[{"chordDistance2DV12", "[", 
              RowBox[{"frmTgt", ",", "frmRef"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"GraphicsRow", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Graphics", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"Blue", ",", "Thick", ",", 
                   RowBox[{"Line", "[", " ", "theCostPlotF", "]"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
                   RowBox[{"Point", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"th0", "/", "Degree"}], ",", "deltaX0"}], "}"}], 
                    "]"}], ",", "\[IndentingNewLine]", "Red", ",", 
                   RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
                   RowBox[{"Point", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"th", "/", "Degree"}], ",", "deltaX"}], "}"}], 
                    "]"}], ",", "Red", ",", 
                   RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"th", "/", "Degree"}], ",", 
                    RowBox[{"-", "60"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"th", "/", "Degree"}], ",", "deltaX"}], "}"}]}], 
                    "}"}], "]"}], ",", "Black", ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"\"\<   Match fcn: \>\"", "<>", 
                    RowBox[{"ToString", "[", " ", "deltaX", " ", "]"}], "<>", 
                    "\"\<\\n \[Theta]=\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{
                    RowBox[{"th", "/", "Degree"}], "//", "N"}], "]"}], "<>", 
                    "\"\<\\n \!\(\*SubscriptBox[\(\[Theta]\), \(0\)]\)=\>\"", 
                    "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{
                    RowBox[{"th0", "/", "Degree"}], "//", "N"}], "]"}], "<>", 
                    "\"\<  \>\""}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Center", ",", 
                    RowBox[{"-", "100"}]}], "}"}]}], "]"}], ",", "Bold", ",", 
                    "16"}], "]"}]}], "}"}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "200"}], ",", "200"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "200"}], ",", "110"}], "}"}]}], "}"}]}]}], 
                "]"}], ",", " ", "\[IndentingNewLine]", 
               RowBox[{"Graphics", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"MapThread", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Red", ",", 
                    RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
                    RowBox[{"Point", "[", "#1", "]"}], ",", "Blue", ",", 
                    RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
                    RowBox[{"Point", "[", "#2", "]"}], ",", "Black", ",", 
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{"#1", ",", "#2"}], "}"}], "]"}]}], "}"}], "&"}], 
                    ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"frmRef", ",", 
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1.2", 
                    RowBox[{
                    RowBox[{"make2DRotation", "[", "th", "]"}], ".", "#"}]}], 
                    ")"}], "&"}], ",", "frmTgt"}], "]"}]}], "}"}]}], "]"}], 
                   ",", "\[IndentingNewLine]", 
                   RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{
                    "\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(0\)]\)= \>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{
                    RowBox[{"N", "[", 
                    RowBox[{"th0", ",", "4"}], "]"}], "/", "Degree"}], "]"}], 
                    "<>", "\"\<\\n \!\(\*SubscriptBox[\(\[CapitalDelta]\), \
\(0\)]\)= \>\"", "<>", 
                    RowBox[{"ToString", "[", " ", 
                    RowBox[{"chordCost2D", "[", 
                    RowBox[{"th0", ",", "frmTgt", ",", "frmRef"}], "]"}], 
                    "]"}]}], ",", "Black", ",", "Bold", ",", "20"}], "]"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], "  ", "}"}], 
                 ",", "\[IndentingNewLine]", 
                 RowBox[{"ImageSize", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "size"}], ",", "size"}], "}"}]}], "}"}]}]}], 
                "]"}]}], "}"}], "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"th", ",", "th0"}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "4"}], "-", 
            RowBox[{"Pi", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pi", "/", "8"}], "+", 
            RowBox[{"Pi", "/", "2"}]}], ",", 
           RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
        "]"}]}]}], "]"}]}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.739554630191571*^9, 3.739554660268139*^9}, {
   3.739555071444439*^9, 3.7395552585679007`*^9}, {3.7395553245397797`*^9, 
   3.739555330740857*^9}, {3.739560067829527*^9, 3.739560108763146*^9}, {
   3.739560160322522*^9, 3.7395602266421556`*^9}, {3.739560374796484*^9, 
   3.739560386449664*^9}, {3.7395604419890823`*^9, 3.7395604503449583`*^9}, {
   3.739635085488658*^9, 3.7396350904403057`*^9}, {3.739636327861002*^9, 
   3.739636386788987*^9}, {3.739636487412158*^9, 3.7396365515475492`*^9}, {
   3.7396365957790937`*^9, 3.739636634876978*^9}, {3.739636667227674*^9, 
   3.739636754422948*^9}, {3.739636816640935*^9, 3.739636861592784*^9}, {
   3.739636902477881*^9, 3.739636906209203*^9}, {3.7396369609576674`*^9, 
   3.739637022256543*^9}, {3.739637123815077*^9, 3.739637215390133*^9}, {
   3.739637287570877*^9, 3.739637288358466*^9}, {3.7396488691765213`*^9, 
   3.7396489573259563`*^9}, {3.739667099066554*^9, 3.739667211121928*^9}, {
   3.7396673278088303`*^9, 3.7396673990220423`*^9}, {3.7397210190419292`*^9, 
   3.739721067112602*^9}, {3.7397211050499*^9, 3.739721112213065*^9}, {
   3.739721188397382*^9, 3.73972121544659*^9}, {3.739721400345386*^9, 
   3.739721405960864*^9}, 3.739721575778161*^9, {3.7397217778932734`*^9, 
   3.7397218171900673`*^9}, {3.739721957334662*^9, 3.739721959597643*^9}, {
   3.739722001018134*^9, 3.739722057576086*^9}, {3.739722132280542*^9, 
   3.739722147371776*^9}, {3.739722190154913*^9, 3.73972228623518*^9}, {
   3.7397223998406353`*^9, 3.7397224293533297`*^9}, {3.7397225236422997`*^9, 
   3.739722534393478*^9}, {3.739722624756131*^9, 3.7397226544426117`*^9}, 
   3.7397226913347073`*^9, {3.7397258508839397`*^9, 3.7397258788419943`*^9}, 
   3.7397260320217953`*^9, {3.739726070941696*^9, 3.739726080112404*^9}, {
   3.739726123122411*^9, 3.739726199414091*^9}, {3.739726253441646*^9, 
   3.739726253920779*^9}, {3.7397263704353952`*^9, 3.739726412881997*^9}, {
   3.739726480074954*^9, 3.739726480511854*^9}, {3.7397265138251123`*^9, 
   3.739726516062057*^9}, {3.739726548563946*^9, 3.7397266558027983`*^9}, {
   3.739726704374578*^9, 3.739726761505712*^9}, {3.739727046153461*^9, 
   3.7397270763241663`*^9}},
 CellLabel->
  "In[685]:=",ExpressionUUID->"7c203554-6b31-43df-a9ed-86b8a52c05d1"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`theAngle0$$ = -0.2, $CellContext`rot0$$ = {{
  0.9811644805442578, 0.19317417559890585`}, {-0.19317417559890585`, 
  0.9811644805442578}}, $CellContext`rotTgt0$$ = CompressedData["
1:eJwVlGs8FPgextFtltokleWEVayGLeuY2I71o11n91C5tMu6Zlz2sGJ0Wbqg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  "], $CellContext`deltaX0$$ = 
  99.3719807870518}, 
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`th$$ = -0.18771016105199034`, 
     Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
     Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
     1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`th$$], -0.1943962331285196}, Rational[-3, 4] Pi, 
       Rational[5, 8] Pi}}, Typeset`size$$ = {823., {202., 208.}}, 
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
     True, $CellContext`th$321697$$ = 0}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, 
       "Variables" :> {$CellContext`th$$ = -0.1943962331285196}, 
       "ControllerVariables" :> {
         Hold[$CellContext`th$$, $CellContext`th$321697$$, 0]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> 
       Module[{$CellContext`V1$, $CellContext`V2$, $CellContext`rot$, \
$CellContext`rotTgt$, $CellContext`deltaX$}, $CellContext`rot$ = {{
             Cos[$CellContext`th$$], -Sin[$CellContext`th$$]}, {
             Sin[$CellContext`th$$], 
             Cos[$CellContext`th$$]}}; $CellContext`rotTgt$ = 
          Map[Dot[$CellContext`rot$, #]& , CompressedData["
1:eJwVVGlUk4cWpFKgWiVVzKtFo7YKslSjbJFCe4EDKAVpatWHrEZ4fRYVihWx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            "]]; $CellContext`deltaX$ = 
          Sum[
            Dot[
             Part[$CellContext`rotTgt$, $CellContext`k], 
             Part[CompressedData["
1:eJwV0vs/1PkewPHIJToPbald2pRZ65GSaTlLCb27iKwpiVxWLskYbZhW+9hI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              
              "], $CellContext`k]], {$CellContext`k, 1, 
             Length[CompressedData["
1:eJwV0vs/1PkewPHIJToPbald2pRZ65GSaTlLCb27iKwpiVxWLskYbZhW+9hI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              
              "]]}]; {$CellContext`V1$, $CellContext`V2$} = \
$CellContext`chordDistance2DV12[CompressedData["
1:eJwVVGlUk4cWpFKgWiVVzKtFo7YKslSjbJFCe4EDKAVpatWHrEZ4fRYVihWx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            "], CompressedData["
1:eJwV0vs/1PkewPHIJToPbald2pRZ65GSaTlLCb27iKwpiVxWLskYbZhW+9hI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            "]]; GraphicsRow[{
            Graphics[{Blue, Thick, 
              Line[$CellContext`theCostPlotF], 
              PointSize[0.05], 
              Point[{(-0.1943962331285196)/Degree, $CellContext`deltaX0$$}], 
              Red, 
              PointSize[0.02], 
              Point[{$CellContext`th$$/Degree, $CellContext`deltaX$}], Red, 
              
              Line[{{$CellContext`th$$/Degree, -60}, {$CellContext`th$$/
                 Degree, $CellContext`deltaX$}}], Black, 
              Style[
               Text[
                StringJoin["   Match fcn: ", 
                 ToString[$CellContext`deltaX$], "\n \[Theta]=", 
                 ToString[
                  N[$CellContext`th$$/Degree]], 
                 "\n \!\(\*SubscriptBox[\(\[Theta]\), \(0\)]\)=", 
                 ToString[
                  N[(-0.1943962331285196)/Degree]], "  "], {Center, -100}], 
               Bold, 16]}, PlotRange -> {{-200, 200}, {-200, 110}}], 
            Graphics[{
              MapThread[{Red, 
                PointSize[0.02], 
                Point[#], Blue, 
                PointSize[0.015], 
                Point[#2], Black, 
                Line[{#, #2}]}& , {CompressedData["
1:eJwV0vs/1PkewPHIJToPbald2pRZ65GSaTlLCb27iKwpiVxWLskYbZhW+9hI
GmvtuqRNuWSNSy4VFU32gnK8kVtGMSM2l8YwM5kZM9+PSMqis/vD6/H8B160
UPZRpuayZcvC/ulfXULpoewWgrvMP/ou1QvhP7WieL8Lk2iQtLxu7UkxHC/U
OP7ZDyJoar2OBTQV5jue7s4SIx75vZ5yaiK4e2q5KmF3LzB3rs5omKFA9YnY
xi52DJ55Zh1L71HCBqdER6OmF+Brc6K6OEkNlOFf31dq9cO6Sl5AqT2F2art
ZqPZ2Vh4nhvgt0TgD4/aw5abJ3HF7J6cZkoMPT+YGBkbqZC7yVWXVi4CbpLr
wdR3BLmmtavch2/iii9US8+DCdwwuAlL259ATXFUtpWtEtaKobPw+Dh4BS2Z
sapz4dqhQ5zFRYKsjM8f1noQ2CsUONif6oL3dQNhzYYT6Oz73SVzy1c4pdV0
VRY5AU3dV3xE3TL0vS18+rODAk09/GysqyXIua02+O+vBL6urrCV2LWCZDfn
/so9PDQZ4ZSfJwSMudwWl1YKHcoNXerzBBifmnEvASl877vTaNVDAYQ6Gn64
l6uAjlM+dUY7JHjGPGfK5d0k7l8f/q7uk1FInn4V3Xh4AjPL03YZqWUoNk2K
aH3wAlq8NWqLf1JD6/MSfQu9Lri2SXGj0ZtAfaY6sWEHwfUDubGmtG5kzc3H
rD1LEIMMZhrLOnDIcUbEruzE/toBblI4QbO0uyUbdNXomFVuW0qGoIpxM3q2
YRITD5nTkxWjsIHJz1q5eRwFmjuVYV8rwWnRs60aSkC0xT3H/2+CH9WOyuIo
BSTcTSqaxnH8eM9RYYRcif0+Xtd7PMeQ8CO8jJ0mYCvv7EjXBxmwJRk6v92h
4GrQgTC5qxB/+Y2lQz+hxlCtwVPugYN4dkbbm818irkcQx19cwJ/prU7ZYZL
0GXXsectMQrYMmpgWlolRf4iK3PitBzTrkymWwzLUEfq8yEzeAIz/ILnnO+M
YHBeBCOwQAXujvyXdUY9OH5tziBLnyD9SlvIFt1OqOkYKgmKJtiXZ3VBjyOB
Va0hfbohCqR/G89c8ldj8S7nhQsXB1E/tyEw7rgKtsT62i+UvQRLJvtAZgjB
F2q9KCbtCYpmNcz4v1OQ/7pPu3S5EKc3Vf19eX0nDHO/0f82iqAgPSWs8e49
OLSzyNd8hsD+T5sqLqePYZKJmejyYyUK66W9Zwbk+PiiVhDdSorGdrsNy55R
aGg8klDsIcArgwVtp/uacdnqgBpLHkEDedE+L6kczc4t1epvkILrK09akG0v
uNXP3qLeUKDn/ZZ1MliFbrf+94Uw7yVmvM1zmvqZQg5/bj7Bug/7TxbR1/3z
Q2H8O7/7ZR3QecLk2MIqPvi7pxv1uhCwcCs/0LdvErL3K+s/bhEjI+W+dmdl
F0Z+vsaEwSAQto2ZkqotA03GLwEsUzmyH3NiJrg9aKxLzbtpEpwtWr1O4tqJ
vFcrS/adJrDx0usy/ZlW0Cu2dkq7SmCNT4RH2uF2fF3Wm1aeRDDkjPNfoz3D
8Gur2N9AqALJ0IN8+jyB5w8jaxe+KsNSn29qmBlSCJsxtpalyCG83Sr9RqIS
lfnRt1eSMfRq03efGyKo4l2KyDxSh5e0ezWzWigs264TW1AuwGvPqmz6Ygg8
ecN2sqzsAIYwtv17wTiwtjbnt48pIKU/MKBROgGMBno1uMngUba9P2dQhZyE
jQHTvGFYbXcuda2PAO0aRu49fEpB7tFblnsEFHYuXK157ygAb1qhheqiFBv1
j7ItsuTQOxvlsvCVGnN/3Fa27fEgFPbmPlJ2iKEtodTBCSYh7mCzhvwzCWps
Y8uf3FRgZEPoT0fsFRAeoyPXeSDBkRznaeEzgpvP+6YYajagtXc1I7qmC1yF
pmYD7gT3r+AHuayhgEcJLafG+sEqvmLgRz0xcL4MZM7zJsF4vnjNjiEVJhw8
l/ymahjfXm7besx1FBwXaKwl5SR4ztkert/Yjp15cS2YTCDwRGaOtoSCgiOa
opFHvTAkGioJ1XoBT4v3djAq1fA2stHmzqcDsNiavONPXQosK66P3v6SYHqX
OrLAtxujttrRKviJSHeYiqv/QPD/kuNrfA==
                "], 
                Map[1.2 Dot[
                   $CellContext`make2DRotation[$CellContext`th$$], #]& , \
CompressedData["
1:eJwVVGlUk4cWpFKgWiVVzKtFo7YKslSjbJFCe4EDKAVpatWHrEZ4fRYVihWx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                 "]]}], 
              Text[
               Style[
                StringJoin["\!\(\*SubscriptBox[\(\[Theta]\), \(0\)]\)= ", 
                 ToString[N[-0.1943962331285196, 4]/Degree], 
                 "\n \!\(\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\)= ", 
                 ToString[
                  $CellContext`chordCost2D[-0.1943962331285196, \
CompressedData["
1:eJwVVGlUk4cWpFKgWiVVzKtFo7YKslSjbJFCe4EDKAVpatWHrEZ4fRYVihWx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                   "], CompressedData["
1:eJwV0vs/1PkewPHIJToPbald2pRZ65GSaTlLCb27iKwpiVxWLskYbZhW+9hI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                   "]]]], Black, Bold, 
                20], {0, 0}]}, ImageSize -> {{-380, 380}, {-380, 380}}]}]], 
       "Specifications" :> {{{$CellContext`th$$, -0.1943962331285196}, 
          Rational[-3, 4] Pi, Rational[5, 8] Pi, Appearance -> "Labeled"}}, 
       "Options" :> {}, "DefaultOptions" :> {}],
      ImageSizeCache->{870., {246., 253.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]],
  DynamicModuleValues:>{}]], "Output",
 CellChangeTimes->{
  3.7397211169066963`*^9, 3.7397212183910713`*^9, 3.739721407108964*^9, 
   3.739721496620619*^9, 3.739721578928544*^9, 3.7397218192631893`*^9, 
   3.739721961792883*^9, 3.739722060982723*^9, 3.739722148177023*^9, 
   3.739722192145434*^9, 3.739722274019656*^9, 3.739722431149393*^9, {
   3.739722526699133*^9, 3.7397225354473047`*^9}, 3.739722655249037*^9, {
   3.739726344668971*^9, 3.739726413687681*^9}, 3.739726481654909*^9, 
   3.739726516981729*^9, {3.739726550788741*^9, 3.739726568217969*^9}, 
   3.739726602588994*^9, {3.739726641319916*^9, 3.739726657377852*^9}, {
   3.739726710008267*^9, 3.739726721588503*^9}, 3.739726762950605*^9, {
   3.739727061945491*^9, 3.739727077152457*^9}},
 CellLabel->
  "Out[685]=",ExpressionUUID->"01b10f25-e59b-425d-8d4e-c6f36f28d4d6"],

Cell[BoxData[
 TemplateBox[{
  "Set","shape",
   "\"Lists \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"V1$8028\\\", \\\",\\\", \
\\\"V2$8028\\\"}], \\\"}\\\"}]\\) and \\!\\(\\*RowBox[{\\\"chordDistance2DV12\
\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.9958233511453108`\\\"}], \\\",\\\", RowBox[{\
\\\"-\\\", \\\"0.09130089437526231`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\
\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.93324694643938`\\\"}], \\\",\\\", \
\\\"0.35923548956300666`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"0.7090731891584553`\\\", \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.7051348895187768`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.04786618411190635`\\\"}], \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.998853757273088`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"\[LeftSkeleton]\\\", \\\"43\\\", \\\"\[RightSkeleton]\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.6125524066178577`\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.7904299773836205`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.7091532020458046`\\\"}], \
\\\",\\\", RowBox[{\\\"-\\\", \\\"0.705054420614595`\\\"}]}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.7326007045670933`\\\", \\\",\\\", \
\\\"0.6806586572341518`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"\
\[LeftSkeleton]\\\", \\\"50\\\", \\\"\[RightSkeleton]\\\"}]}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.9924847524262723`\\\"}], \\\",\\\", RowBox[{\
\\\"\[LeftSkeleton]\\\", \\\"20\\\", \\\"\[RightSkeleton]\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \\\"49\\\", \\\"\
\[RightSkeleton]\\\"}], \\\",\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \
\\\"50\\\", \\\"\[RightSkeleton]\\\"}]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) are \
not the same shape.\"",2,11,1,27320936865651559573,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7405921823163233`*^9},
 CellLabel->"",ExpressionUUID->"6dcb44cb-cfd8-40f6-af0a-ef1ed27ee1ad"],

Cell[BoxData[
 TemplateBox[{
  "Set","shape",
   "\"Lists \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"V1$8077\\\", \\\",\\\", \
\\\"V2$8077\\\"}], \\\"}\\\"}]\\) and \\!\\(\\*RowBox[{\\\"chordDistance2DV12\
\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.9958233511453108`\\\"}], \\\",\\\", RowBox[{\
\\\"-\\\", \\\"0.09130089437526231`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\
\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.93324694643938`\\\"}], \\\",\\\", \
\\\"0.35923548956300666`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"0.7090731891584553`\\\", \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.7051348895187768`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.04786618411190635`\\\"}], \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.998853757273088`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"\[LeftSkeleton]\\\", \\\"43\\\", \\\"\[RightSkeleton]\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.6125524066178577`\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.7904299773836205`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.7091532020458046`\\\"}], \
\\\",\\\", RowBox[{\\\"-\\\", \\\"0.705054420614595`\\\"}]}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.7326007045670933`\\\", \\\",\\\", \
\\\"0.6806586572341518`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"\
\[LeftSkeleton]\\\", \\\"50\\\", \\\"\[RightSkeleton]\\\"}]}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.9924847524262723`\\\"}], \\\",\\\", RowBox[{\
\\\"\[LeftSkeleton]\\\", \\\"20\\\", \\\"\[RightSkeleton]\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \\\"49\\\", \\\"\
\[RightSkeleton]\\\"}], \\\",\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \
\\\"50\\\", \\\"\[RightSkeleton]\\\"}]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) are \
not the same shape.\"",2,11,2,27320936865651559573,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7405921827581367`*^9},
 CellLabel->"",ExpressionUUID->"e5f0461e-8eb8-48e5-ac9e-f6b3e6ca60f8"],

Cell[BoxData[
 TemplateBox[{
  "Set","shape",
   "\"Lists \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"V1$12781\\\", \\\",\\\", \
\\\"V2$12781\\\"}], \\\"}\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"chordDistance2DV12\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \
\\\"0.9958233511453108`\\\"}], \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.09130089437526231`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.93324694643938`\\\"}], \\\",\\\", \
\\\"0.35923548956300666`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"0.7090731891584553`\\\", \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.7051348895187768`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.04786618411190635`\\\"}], \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.998853757273088`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"\[LeftSkeleton]\\\", \\\"43\\\", \\\"\[RightSkeleton]\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.6125524066178577`\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.7904299773836205`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.7091532020458046`\\\"}], \
\\\",\\\", RowBox[{\\\"-\\\", \\\"0.705054420614595`\\\"}]}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.7326007045670933`\\\", \\\",\\\", \
\\\"0.6806586572341518`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"\
\[LeftSkeleton]\\\", \\\"50\\\", \\\"\[RightSkeleton]\\\"}]}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \\\"1\\\", \
\\\"\[RightSkeleton]\\\"}], \\\"}\\\"}]}], \\\"]\\\"}]\\) are not the same \
shape.\"",2,35,5,27320936865651559573,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7405965102470837`*^9},
 CellLabel->"",ExpressionUUID->"dc12dac2-fdb8-4805-a79f-3c5833457070"],

Cell[BoxData[
 TemplateBox[{
  "Set","shape",
   "\"Lists \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"V1$58067\\\", \\\",\\\", \
\\\"V2$58067\\\"}], \\\"}\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"chordDistance2DV12\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \
\\\"0.9958233511453108`\\\"}], \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.09130089437526231`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.93324694643938`\\\"}], \\\",\\\", \
\\\"0.35923548956300666`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"0.7090731891584553`\\\", \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.7051348895187768`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.04786618411190635`\\\"}], \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.998853757273088`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"\[LeftSkeleton]\\\", \\\"43\\\", \\\"\[RightSkeleton]\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.6125524066178577`\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.7904299773836205`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.7091532020458046`\\\"}], \
\\\",\\\", RowBox[{\\\"-\\\", \\\"0.705054420614595`\\\"}]}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.7326007045670933`\\\", \\\",\\\", \
\\\"0.6806586572341518`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"\
\[LeftSkeleton]\\\", \\\"50\\\", \\\"\[RightSkeleton]\\\"}]}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.9924847524262723`\\\"}], \\\",\\\", RowBox[{\
\\\"\[LeftSkeleton]\\\", \\\"20\\\", \\\"\[RightSkeleton]\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \\\"50\\\", \\\"\
\[RightSkeleton]\\\"}]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) are not the same \
shape.\"",2,208,42,27320936865651559573,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.740751243741227*^9},
 CellLabel->"",ExpressionUUID->"212b660d-ffaa-420b-9878-629e5cef5968"],

Cell[BoxData[
 TemplateBox[{
  "Set","shape",
   "\"Lists \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"V1$40223\\\", \\\",\\\", \
\\\"V2$40223\\\"}], \\\"}\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"chordDistance2DV12\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \
\\\"0.9958233511453108`\\\"}], \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.09130089437526231`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.93324694643938`\\\"}], \\\",\\\", \
\\\"0.35923548956300666`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"0.7090731891584553`\\\", \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.7051348895187768`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.04786618411190635`\\\"}], \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.998853757273088`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"\[LeftSkeleton]\\\", \\\"43\\\", \\\"\[RightSkeleton]\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.6125524066178577`\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.7904299773836205`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.7091532020458046`\\\"}], \
\\\",\\\", RowBox[{\\\"-\\\", \\\"0.705054420614595`\\\"}]}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.7326007045670933`\\\", \\\",\\\", \
\\\"0.6806586572341518`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"\
\[LeftSkeleton]\\\", \\\"50\\\", \\\"\[RightSkeleton]\\\"}]}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \\\"1\\\", \
\\\"\[RightSkeleton]\\\"}], \\\"}\\\"}]}], \\\"]\\\"}]\\) are not the same \
shape.\"",2,27,22,27330770613124539526,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.742080985909355*^9},
 CellLabel->"",ExpressionUUID->"663f9e84-a467-4fa7-8d48-141f117088b1"],

Cell[BoxData[
 TemplateBox[{
  "Set","shape",
   "\"Lists \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"V1$44395\\\", \\\",\\\", \
\\\"V2$44395\\\"}], \\\"}\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"chordDistance2DV12\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \
\\\"0.9958233511453108`\\\"}], \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.09130089437526231`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.93324694643938`\\\"}], \\\",\\\", \
\\\"0.35923548956300666`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"0.7090731891584553`\\\", \\\",\\\", RowBox[{\\\"-\\\", \
\\\"0.7051348895187768`\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.04786618411190635`\\\"}], \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.998853757273088`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"\[LeftSkeleton]\\\", \\\"43\\\", \\\"\[RightSkeleton]\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.6125524066178577`\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"0.7904299773836205`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.7091532020458046`\\\"}], \
\\\",\\\", RowBox[{\\\"-\\\", \\\"0.705054420614595`\\\"}]}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"0.7326007045670933`\\\", \\\",\\\", \
\\\"0.6806586572341518`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"\
\[LeftSkeleton]\\\", \\\"50\\\", \\\"\[RightSkeleton]\\\"}]}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"\[LeftSkeleton]\\\", \\\"1\\\", \
\\\"\[RightSkeleton]\\\"}], \\\"}\\\"}]}], \\\"]\\\"}]\\) are not the same \
shape.\"",2,51,24,27330770613124539526,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.742082450436019*^9},
 CellLabel->"",ExpressionUUID->"ef408fe5-ccd6-4160-ab8c-4947e57b9cb1"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "xxx  These are the elements of the 3D Figure library\n  coming from  \
analogies to  ",
 StyleBox["TransRot-2D-demo-1.nb",
  FontSize->24,
  FontWeight->"Bold"],
 "\n in the  ",
 StyleBox["Horn-soln-dir/00plosCB-submit/mathka/",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox["  folder.",
  FontSize->24]
}], "Subchapter",
 CellChangeTimes->{{3.7398414046102543`*^9, 3.7398414434924088`*^9}, {
  3.739844341408534*^9, 3.739844341803158*^9}, {3.740162212788142*^9, 
  3.74016221580375*^9}},ExpressionUUID->"56619930-cd94-434b-813c-\
b59c824571ed"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Generate 3D pnt and frm data- Use Normal, not FLAT, \
error models.",
 FontWeight->"Bold"]], "Subsection",
 CellChangeTimes->{{3.739443294148787*^9, 3.7394433050526257`*^9}, {
  3.740162222771244*^9, 
  3.740162240915092*^9}},ExpressionUUID->"127972be-1820-4235-afcd-\
d754a7424828"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Gaussian", "!!"}], " ", "*)"}], 
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AbsolutePointSize", "[", "1", "]"}], ",", 
     RowBox[{"Point", "[", 
      RowBox[{"RandomVariate", "[", 
       RowBox[{
        RowBox[{"NormalDistribution", "[", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"10", "^", "4"}], ",", "3"}], "}"}]}], "]"}], "]"}]}], 
    "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7401618532630043`*^9, 
  3.74016188169494*^9}},ExpressionUUID->"648e848c-6dc2-4717-8547-\
b5b5d8267bdf"],

Cell[TextData[StyleBox["  This is for randomizing the nhat direction in \
random quaternion, either totally random,\nor centered about  q0=1 (Cos[th/2] \
with th near zero).",
 FontSize->16,
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.740242759565098*^9, 
  3.740242818973714*^9}},ExpressionUUID->"2cf2422d-5870-4578-8fc2-\
da15f3df3f69"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"randomSphere2", "[", "n_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"0.2", "\[LessEqual]", " ", 
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "1.0"}], ",", 
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", 
             RowBox[{"Normalize", "[", "test", "]"}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", "out"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{" "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725126678664934*^9, 3.725126747221231*^9}, {
  3.725126784293984*^9, 3.7251268188772497`*^9}, {3.725136303100024*^9, 
  3.725136377027377*^9}, {3.72513641438743*^9, 3.7251365562100897`*^9}, {
  3.739443213984022*^9, 3.7394432207027283`*^9}, {3.7394433159424953`*^9, 
  3.739443319942561*^9}, {3.740242726503377*^9, 3.740242739855081*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"60fd37ac-cc30-4fc6-8676-1fd098cf3943"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"randomSphere3", "[", "n_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "4"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"0.2", "\[LessEqual]", " ", 
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "1.0"}], ",", 
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", 
             RowBox[{"Normalize", "[", "test", "]"}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", "out"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{" "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725126678664934*^9, 3.725126747221231*^9}, {
  3.725126784293984*^9, 3.7251268188772497`*^9}, {3.725136303100024*^9, 
  3.725136377027377*^9}, {3.72513641438743*^9, 3.7251365562100897`*^9}, {
  3.739443213984022*^9, 3.7394432207027283`*^9}, {3.7394433159424953`*^9, 
  3.739443319942561*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"fb4d3498-7e31-41d5-a663-412bf33f5bfb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomBall3", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"size_:", "1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", "3"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "size"}], ",", 
          
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", "test"}], "]"}]}]}], "]"}]}]}], "]"}], 
     ";", "out"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73944076443102*^9, 3.739440786763439*^9}, {
   3.7394408424202747`*^9, 3.739440857523859*^9}, {3.739460952836001*^9, 
   3.73946101596912*^9}, {3.7395528751223373`*^9, 3.73955287646989*^9}, {
   3.7401620552648067`*^9, 3.7401620559335833`*^9}, 3.740162091029406*^9},
 CellLabel->"In[63]:=",ExpressionUUID->"64bd816f-425e-488d-b4ca-cf7f7b161112"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomBall3CM", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"size_:", "1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test", ",", "cm"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", "3"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "size"}], ",", 
          
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", "test"}], "]"}]}]}], "]"}]}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"cm", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Plus", "@@", "out"}], ")"}], "/", "n"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", "-", "cm"}], "&"}], ")"}], "/@", "out"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73944076443102*^9, 3.739440786763439*^9}, {
  3.7394408424202747`*^9, 3.739440857523859*^9}, {3.739460952836001*^9, 
  3.73946101596912*^9}, {3.739473446919948*^9, 3.7394735330063257`*^9}, {
  3.7395528860575743`*^9, 3.739552887102167*^9}, {3.7401621003782663`*^9, 
  3.740162105565789*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"84a74ea7-8e5b-4a53-b453-af646d2dc212"],

Cell[TextData[StyleBox["Four 4D Euclidean data sets:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.740322459014062*^9, 
  3.7403224659026337`*^9}},ExpressionUUID->"4e8e687c-15ad-426c-99de-\
f8aca5e0f451"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomBall4", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"size_:", "1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", "4"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "size"}], ",", 
          
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", "test"}], "]"}]}]}], "]"}]}]}], "]"}], 
     ";", "out"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73944076443102*^9, 3.739440786763439*^9}, {
   3.7394408424202747`*^9, 3.739440857523859*^9}, {3.739460952836001*^9, 
   3.73946101596912*^9}, {3.7395528751223373`*^9, 3.73955287646989*^9}, {
   3.7401620552648067`*^9, 3.7401620559335833`*^9}, 3.740162091029406*^9, {
   3.740322449832139*^9, 3.740322471727456*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"42e29011-7da9-4e77-886e-7240e30f56ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomBall4CM", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"size_:", "1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"out", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"num", "=", "0"}], ",", "test", ",", "cm"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"num", "<", "n"}], ",", 
       RowBox[{
        RowBox[{"test", "=", "   ", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "size"}], ",", "size"}], "}"}], ",", "4"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "test", "]"}], "\[LessEqual]", "size"}], ",", 
          
          RowBox[{
           RowBox[{"num", "++"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"out", ",", " ", "test"}], "]"}]}]}], "]"}]}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"cm", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Plus", "@@", "out"}], ")"}], "/", "n"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", "-", "cm"}], "&"}], ")"}], "/@", "out"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.73944076443102*^9, 3.739440786763439*^9}, {
  3.7394408424202747`*^9, 3.739440857523859*^9}, {3.739460952836001*^9, 
  3.73946101596912*^9}, {3.739473446919948*^9, 3.7394735330063257`*^9}, {
  3.7395528860575743`*^9, 3.739552887102167*^9}, {3.7401621003782663`*^9, 
  3.740162105565789*^9}, {3.740322452231859*^9, 3.7403224774320707`*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"b17ce309-5bab-46b1-91c7-5b672a35a160"],

Cell[TextData[StyleBox["Build the 3D point and frame data sets",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.740322510573628*^9, 
  3.740322520894145*^9}},ExpressionUUID->"bf332579-aa88-4d6d-92d3-\
a5b837520423"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeRotation", "[", 
   RowBox[{
    RowBox[{"angle_:", "0"}], ",", 
    RowBox[{"n_List:", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", " ", "=", " ", 
       RowBox[{
        RowBox[{"Cos", "[", "angle", "]"}], "//", "N"}]}], ",", " ", 
      RowBox[{"s", " ", "=", " ", 
       RowBox[{
        RowBox[{"Sin", "[", "angle", "]"}], "//", "N"}]}], ",", " ", "cm"}], 
     "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"cm", " ", "=", " ", 
      RowBox[{"1", " ", "-", " ", "c"}]}], ";", "\n", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"c", " ", "+", " ", 
           RowBox[{"cm", "*", 
            RowBox[{
             RowBox[{"n", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}]}], ",", " ", 
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], " ", "-", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}]}], ",", " ", 
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}]}], "}"}], ",", "\n", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "+", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}]}], ",", " ", 
          RowBox[{"c", " ", "+", " ", 
           RowBox[{"cm", "*", 
            RowBox[{
             RowBox[{"n", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}]}], ",", "  ", 
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}]}], "}"}], ",", "\n", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], " ", "-", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], ",", " ", "\n", 
          "              ", 
          RowBox[{
           RowBox[{"cm", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], " ", "+", " ", 
           RowBox[{"s", "*", 
            RowBox[{"n", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], ",", " ", 
          RowBox[{"c", " ", "+", " ", 
           RowBox[{"cm", "*", 
            RowBox[{
             RowBox[{"n", "[", 
              RowBox[{"[", "3", "]"}], "]"}], "^", "2"}]}]}]}], "}"}]}], 
       "}"}], "//", "N"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.584375852951816*^9, 3.58437587259674*^9}, {
  3.584375910037079*^9, 3.584375911589164*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"df76ce66-0490-4857-a7ed-2c387e1d9b2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Match", " ", "order", " ", "of", " ", "makeExxmat"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
     "REMEMBER", " ", "move", " ", "to", " ", "center", " ", "of", " ", 
      "mass", " ", "\[IndentingNewLine]", "REMEMBER", " ", "the", " ", "DATA",
       " ", "are", " ", "uniform"}]}], ",", " ", 
    RowBox[{
    "but", " ", "the", " ", "NOISE", " ", "should", " ", "be", " ", 
     "Gaussian"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"build3DPntdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"quat_:", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"Pi", "/", "8"}], "]"}], ",", "0", ",", "0", ",", 
        RowBox[{"Sin", "[", 
         RowBox[{"Pi", "/", "8"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"size_:", "1"}], ",", 
     RowBox[{"rmax_:", "0.05"}]}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xRef", " ", "=", "  ", 
        RowBox[{"randomBall3CM", "[", 
         RowBox[{"npts", ",", "size"}], "]"}]}], ",", "xRefCtr", ",", 
       "xTgtCtr", ",", " ", "quatForRot", ",", "\[IndentingNewLine]", 
       RowBox[{"xJitter", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", ",", "rmax"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"npts", ",", "3"}], "}"}]}], "]"}]}], ",", "xTgt", ",", 
       "xTgtInit", ",", "th", ",", "rotTgt"}], "}"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"checkJitter", "=", "xJitter"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
          RowBox[{"xJitter", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"to", " ", "ctr", " ", "of", " ", "mass", "  ", "xRefCtr"}], 
         "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Plus", "@@", "xRef"}], ")"}], "/", "npts"}]}], ";", " ", 
        RowBox[{"xRef", " ", "=", " ", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"#", "-", "xRefCtr"}], " ", ")"}], "&"}], ",", "xRef"}], 
          "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xTgtCtr", "=", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"Plus", "@@", "xTgtInit"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xTgtInit", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xTgtCtr"}], ")"}], " ", "&"}], ",", 
         "xTgtInit"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"quatForRot", " ", "=", " ", 
       RowBox[{"quat", "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotTgt", " ", "=", 
       RowBox[{"QuatToRot", "[", "quatForRot", "]"}]}], ";", "  ", 
      RowBox[{"xTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotTgt", ".", "#"}], ")"}], "&"}], ",", "xTgtInit"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"xTgt", ",", "xRef", ",", " ", "xTgtInit", ",", "quatForRot"}],
        "}"}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7401566126087313`*^9, 3.740156637764062*^9}, {
   3.740156733131111*^9, 3.740156737806591*^9}, {3.740157022119525*^9, 
   3.740157030000266*^9}, {3.740157367687036*^9, 3.740157392800632*^9}, 
   3.740157437040656*^9, {3.740158070725053*^9, 3.740158089235664*^9}, 
   3.740159586840007*^9, {3.740159642514539*^9, 3.740159690146283*^9}, 
   3.740160005070737*^9, {3.740160196850152*^9, 3.740160199330799*^9}, {
   3.7401602613260727`*^9, 3.74016032610748*^9}, {3.740160486288015*^9, 
   3.7401604871031847`*^9}, {3.740160673001334*^9, 3.740160701017693*^9}, {
   3.740160922060377*^9, 3.740160922258162*^9}, {3.740161414698333*^9, 
   3.7401614169393044`*^9}, {3.740161536127232*^9, 3.740161542060059*^9}, {
   3.740161709918662*^9, 3.740161716226707*^9}, {3.740161908329082*^9, 
   3.740161950137549*^9}, {3.7401621418305063`*^9, 3.740162147535569*^9}, {
   3.740162577812636*^9, 3.7401626889393873`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"49fcec19-76df-4888-a426-c36ce56f4bad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "Gaussian", " ", "distribution", " ", "of", " ",
     "rotation", " ", "angles"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"setsOf3DPntData", " ", "[", 
     RowBox[{
      RowBox[{"npts_:", "100"}], ",", 
      RowBox[{"nsets_:", "1000"}]}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"q0th", " ", "=", " ", 
         RowBox[{"RandomVariate", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{
             RowBox[{"Pi", "/", "8"}], ",", 
             RowBox[{"Pi", "/", "32."}]}], "]"}], ",", "nsets"}], "]"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"nhat", " ", "=", " ", 
         RowBox[{"randomSphere2", "[", "nsets", "]"}]}], ",", "quats"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"quats", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Cos", "[", 
              RowBox[{"q0th", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}], ",", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"q0th", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "*", 
             RowBox[{"nhat", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"build3DPntdataset", "[", 
          RowBox[{"npts", ",", 
           RowBox[{"quats", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}]}], "]"}]}], 
   ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740270743390102*^9, 3.7402708426953087`*^9}, {
   3.740270898742909*^9, 3.740270940293716*^9}, 3.740659216120525*^9, 
   3.743088333474091*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"aeb26364-3a83-46ef-be25-44f351d8f063"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pi", "/", "32."}]], "Input",
 CellChangeTimes->{{3.742236100555193*^9, 3.742236102348666*^9}},
 CellLabel->
  "In[280]:=",ExpressionUUID->"c58ac530-e7d8-4b6e-8ddc-c7744728295f"],

Cell[BoxData["0.09817477042468103`"], "Output",
 CellChangeTimes->{3.742236103147449*^9},
 CellLabel->
  "Out[280]=",ExpressionUUID->"738f9f1a-ce5a-4c59-b3fe-bcc5bff822b4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"build3DFrmdataset", "[", 
   RowBox[{"npts_", ",", 
    RowBox[{"baseQuat_:", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"Pi", "/", "16"}], "]"}], ",", "0", ",", "0", ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"Pi", "/", "16"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"thmax_:", 
     RowBox[{"Pi", "/", "32."}]}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fRef", " ", "=", "  ", 
       RowBox[{"randomSphere3", "[", "npts", "]"}]}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"These", " ", "are", " ", "unit", " ", "2"}], "-", 
         "vectors"}], ",", " ", 
        RowBox[{
        "theoretically", " ", "on", " ", "a", " ", "4", " ", "Pi", " ", 
         "circle"}], ",", " ", 
        RowBox[{"not", " ", "a", " ", "2", " ", "Pi", " ", "circle"}]}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"q0th", " ", "=", " ", 
       RowBox[{"RandomVariate", "[", 
        RowBox[{
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "thmax"}], "]"}], ",", "npts"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"nhat", " ", "=", " ", 
       RowBox[{"randomSphere2", "[", "npts", "]"}]}], ",", "fJitter", ",", 
      "fTgt", ",", "fTgtInit", ",", "qglobalRot", ",", "rotTgt"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "The", " ", "idea", " ", "is", " ", "that", " ", "this", " ", "is", " ", 
      "Gaussian", " ", "distributed", " ", "around", " ", "identity", " ", 
      "quaternion"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fJitter", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", 
            RowBox[{"q0th", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"q0th", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "*", 
           RowBox[{"nhat", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"checkJitter", " ", "=", " ", "fJitter"}], ";"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"fTgtInit", " ", "=", "  ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"qprod", "[", 
         RowBox[{
          RowBox[{"fJitter", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"fRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qglobalRot", "=", 
      RowBox[{"baseQuat", "//", "N"}]}], ";", "\[IndentingNewLine]", " ", 
     RowBox[{"fTgt", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"qprod", "[", 
          RowBox[{"qglobalRot", ",", "#"}], "]"}], "&"}], ",", "fTgtInit"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"fTgt", ",", "fRef", ",", " ", "fTgtInit", ",", "qglobalRot"}], 
      "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.740180814514526*^9, {3.7402434529747868`*^9, 3.740243514920508*^9}, {
   3.740243552778117*^9, 3.740243984940943*^9}, {3.740244034336215*^9, 
   3.740244039149988*^9}, {3.740244125782045*^9, 3.740244164398611*^9}, 
   3.7402441960187407`*^9, {3.742236111371264*^9, 3.742236126680175*^9}},
 CellLabel->
  "In[281]:=",ExpressionUUID->"d4ca227a-a38b-4598-9b9b-173f967b7d41"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "Gaussian", " ", "distribution", " ", "of", " ",
     "rotation", " ", "angles"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"setsOf3DFrmData", "[", 
     RowBox[{
      RowBox[{"npts_:", "100"}], ",", 
      RowBox[{"nsets_:", "1000"}]}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"q0th", " ", "=", " ", 
         RowBox[{"RandomVariate", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{
             RowBox[{"Pi", "/", "8"}], ",", 
             RowBox[{"Pi", "/", "32."}]}], "]"}], ",", "nsets"}], "]"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"nhat", " ", "=", " ", 
         RowBox[{"randomSphere2", "[", "nsets", "]"}]}], ",", "quats"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"quats", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Cos", "[", 
              RowBox[{"q0th", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}], ",", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"q0th", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "*", 
             RowBox[{"nhat", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"build3DFrmdataset", "[", 
          RowBox[{"npts", ",", 
           RowBox[{"quats", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}]}], "]"}]}], 
   ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740162994297964*^9, 3.740163047317624*^9}, {
   3.740163147428155*^9, 3.740163349971508*^9}, {3.7402432449071074`*^9, 
   3.74024331869864*^9}, {3.740243390264056*^9, 3.740243400254286*^9}, 
   3.740247245626575*^9, {3.740247416473744*^9, 3.740247423745777*^9}, {
   3.740248208714072*^9, 3.7402482122102203`*^9}, {3.740248275138362*^9, 
   3.740248331899119*^9}, {3.740248371825974*^9, 3.740248376585971*^9}, {
   3.740270893120902*^9, 3.740270893981084*^9}, 3.7406592082152967`*^9, 
   3.741707757247739*^9},
 CellLabel->"In[71]:=",ExpressionUUID->"29613bcb-cefe-4cde-aae8-b9096f7534d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Match", " ", "order", " ", "of", " ", "makeExxmat"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
     "REMEMBER", " ", "move", " ", "to", " ", "center", " ", "of", " ", 
      "mass"}], ";", "  ", 
     RowBox[{
      RowBox[{"And", " ", "you", " ", "need", " ", "SO4", " ", "Global"}], 
      " ", "\[Rule]", " ", 
      RowBox[{"2", " ", 
       RowBox[{"quaternions", ".", "\[IndentingNewLine]", 
        RowBox[{"--", "how"}]}], " ", "do", " ", "you", " ", "randomize", " ", 
       RowBox[{"that", "?", "\[IndentingNewLine]", "REMEMBER"}], " ", "the", 
       " ", "DATA", " ", "are", " ", "uniform"}]}]}], ",", " ", 
    RowBox[{
    "but", " ", "the", " ", "NOISE", " ", "should", " ", "be", " ", 
     "Gaussian"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"build4DPntdataset", "[", 
    RowBox[{"npts_", ",", 
     RowBox[{"pqquats_:", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"Pi", "/", "8"}], "]"}], ",", "0", ",", "0", ",", 
          RowBox[{"Sin", "[", 
           RowBox[{"Pi", "/", "8"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"Pi", "/", "8"}], "]"}], ",", "0", ",", "0", ",", 
          RowBox[{"Sin", "[", 
           RowBox[{"Pi", "/", "8"}], "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"size_:", "1"}], ",", 
     RowBox[{"rmax_:", "0.05"}]}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xRef", " ", "=", "  ", 
        RowBox[{"randomBall4CM", "[", 
         RowBox[{"npts", ",", "size"}], "]"}]}], ",", "xRefCtr", ",", 
       "xTgtCtr", ",", " ", "pquat", ",", "qquat", ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"xJitter", " ", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", ",", "rmax"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"npts", ",", "4"}], "}"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", "xTgt", ",", "xTgtInit", ",", "th", ",", 
       "rotTgt"}], "}"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"checkJitter", "=", "xJitter"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xTgtInit", " ", "=", "  ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xRef", " ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
          RowBox[{"xJitter", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"to", " ", "ctr", " ", "of", " ", "mass", "  ", "xRefCtr"}], 
         "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Plus", "@@", "xRef"}], ")"}], "/", "npts"}]}], ";", " ", 
        RowBox[{"xRef", " ", "=", " ", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"#", "-", "xRefCtr"}], " ", ")"}], "&"}], ",", "xRef"}], 
          "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
      RowBox[{"xTgtCtr", "=", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"Plus", "@@", "xTgtInit"}], ")"}], "/", "npts"}]}], ";", " ", 
      RowBox[{"xTgtInit", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "-", "xTgtCtr"}], ")"}], " ", "&"}], ",", 
         "xTgtInit"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pquat", ",", "qquat"}], "}"}], "=", 
       RowBox[{"pqquats", "//", "N"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rotTgt", " ", "=", 
       RowBox[{"PQbTo4DRot", "[", 
        RowBox[{"pquat", ",", "qquat"}], "]"}]}], ";", "  ", 
      RowBox[{"xTgt", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotTgt", ".", "#"}], ")"}], "&"}], ",", "xTgtInit"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"xTgt", ",", "xRef", ",", " ", "xTgtInit", ",", 
        RowBox[{"{", 
         RowBox[{"pquat", ",", "qquat"}], "}"}]}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7401566126087313`*^9, 3.740156637764062*^9}, {
   3.740156733131111*^9, 3.740156737806591*^9}, {3.740157022119525*^9, 
   3.740157030000266*^9}, {3.740157367687036*^9, 3.740157392800632*^9}, 
   3.740157437040656*^9, {3.740158070725053*^9, 3.740158089235664*^9}, 
   3.740159586840007*^9, {3.740159642514539*^9, 3.740159690146283*^9}, 
   3.740160005070737*^9, {3.740160196850152*^9, 3.740160199330799*^9}, {
   3.7401602613260727`*^9, 3.74016032610748*^9}, {3.740160486288015*^9, 
   3.7401604871031847`*^9}, {3.740160673001334*^9, 3.740160701017693*^9}, {
   3.740160922060377*^9, 3.740160922258162*^9}, {3.740161414698333*^9, 
   3.7401614169393044`*^9}, {3.740161536127232*^9, 3.740161542060059*^9}, {
   3.740161709918662*^9, 3.740161716226707*^9}, {3.740161908329082*^9, 
   3.740161950137549*^9}, {3.7401621418305063`*^9, 3.740162147535569*^9}, {
   3.740162577812636*^9, 3.7401626889393873`*^9}, {3.74070578348046*^9, 
   3.740705810718364*^9}, {3.740705989108055*^9, 3.740706033659021*^9}, {
   3.740706199593499*^9, 3.740706215025917*^9}, {3.740706256882056*^9, 
   3.740706262817651*^9}, {3.7407062956491413`*^9, 3.740706480818746*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"a67936f7-86fc-44f0-8cde-c15376a2dfe1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "Gaussian", " ", "distribution", " ", "of", " ",
     "rotation", " ", "angles"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"setsOf4DPntData", " ", "[", 
     RowBox[{
      RowBox[{"npts_:", "100"}], ",", 
      RowBox[{"nsets_:", "1000"}]}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"p0th", " ", "=", " ", 
         RowBox[{"RandomVariate", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{
             RowBox[{"Pi", "/", "8"}], ",", 
             RowBox[{"Pi", "/", "32."}]}], "]"}], ",", "nsets"}], "]"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"q0th", " ", "=", " ", 
         RowBox[{"RandomVariate", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{
             RowBox[{"Pi", "/", "8"}], ",", 
             RowBox[{"Pi", "/", "32."}]}], "]"}], ",", "nsets"}], "]"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"nhatp", " ", "=", " ", 
         RowBox[{"randomSphere2", "[", "nsets", "]"}]}], ",", 
        RowBox[{"nhatq", " ", "=", " ", 
         RowBox[{"randomSphere2", "[", "nsets", "]"}]}], ",", "pquats", ",", 
        "qquats"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pquats", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Cos", "[", 
              RowBox[{"p0th", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}], ",", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"p0th", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "*", 
             RowBox[{"nhatp", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"qquats", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Cos", "[", 
              RowBox[{"q0th", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}], ",", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"q0th", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "*", 
             RowBox[{"nhatq", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"build4DPntdataset", "[", 
          RowBox[{"npts", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"pquats", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"qquats", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}]}], "]"}]}], 
   ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.740270743390102*^9, 3.7402708426953087`*^9}, {
   3.740270898742909*^9, 3.740270940293716*^9}, 3.740659216120525*^9, {
   3.740705786923853*^9, 3.74070579137286*^9}, {3.7407065275901623`*^9, 
   3.740706667348823*^9}, 3.741707774500991*^9},
 CellLabel->"In[73]:=",ExpressionUUID->"dd08feaa-5144-4235-aa2f-e98d0510e169"],

Cell[BoxData[
 RowBox[{"Clear", "[", "build4DFrmUmat", "]"}]], "Input",
 CellChangeTimes->{{3.744158558393773*^9, 3.744158570164554*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"c752cd48-dd09-4df5-876e-79193c438b58"],

Cell[BoxData[
 RowBox[{
  RowBox[{"build4DFrmSmat", "[", 
   RowBox[{"npts_", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"baseQuatL_:", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["\[Pi]", "16"], "]"}], ",", "0", ",", " ", 
         RowBox[{"Sin", "[", 
          FractionBox["\[Pi]", "16"], "]"}], ",", "0"}], "}"}]}], ",", 
      RowBox[{"baseQuatR_:", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["\[Pi]", "16"], "]"}], ",", "0", ",", "0", ",", 
         RowBox[{"Sin", "[", 
          FractionBox["\[Pi]", "16"], "]"}]}], "}"}]}]}], "}"}], ",", 
    RowBox[{"thmax_:", "0.09817477042468103`"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fRefL", "=", 
       RowBox[{"randomSphere3", "[", "npts", "]"}]}], ",", 
      RowBox[{"fRefR", "=", 
       RowBox[{"randomSphere3", "[", "npts", "]"}]}], ",", "fRefRot4", ",", 
      "fTgtInitRot4", ",", 
      RowBox[{"q0thL", "=", 
       RowBox[{"RandomVariate", "[", 
        RowBox[{
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "thmax"}], "]"}], ",", "npts"}], "]"}]}], ",", 
      RowBox[{"nhatL", "=", 
       RowBox[{"randomSphere2", "[", "npts", "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"q0thR", "=", 
       RowBox[{"RandomVariate", "[", 
        RowBox[{
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "thmax"}], "]"}], ",", "npts"}], "]"}]}], ",", 
      RowBox[{"nhatR", "=", 
       RowBox[{"randomSphere2", "[", "npts", "]"}]}], ",", "fJitterL", ",", 
      " ", "fJitterR", ",", "fTgtRot4", ",", "qglobalRotL", ",", 
      "qglobalRotR", ",", "globalRot4", ",", "SMat4"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     StyleBox["(*",
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"Ref", " ", "SO4", " ", "mat"}],
      FontWeight->"Bold"], 
     StyleBox[" ",
      FontWeight->"Bold"], 
     StyleBox["*)",
      FontWeight->"Plain"]}], 
    StyleBox[" ",
     FontWeight->"Plain"], 
    RowBox[{
     RowBox[{"fRefRot4", " ", "=", " ", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"PQbTo4DRot", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{"fRefL", ",", "fRefR"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Jitter", " ", "in", " ", "p", " ", "and", " ", "q", " ", "both"}], " ",
       "*)"}], "\[IndentingNewLine]", 
     RowBox[{"fJitterL", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", 
            RowBox[{
            "q0thL", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
            "q0thL", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "]"}], " ", 
           RowBox[{
           "nhatL", "\[LeftDoubleBracket]", "i", 
            "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fJitterR", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cos", "[", 
            RowBox[{
            "q0thR", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "]"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
            "q0thR", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "]"}], " ", 
           RowBox[{
           "nhatR", "\[LeftDoubleBracket]", "i", 
            "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"fTgtInitRot4", " ", "=", 
      RowBox[{"Table", "[", "  ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"PQbTo4DRot", "[", 
           RowBox[{
            RowBox[{"fJitterL", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", 
            RowBox[{"fJitterR", "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ".", 
          RowBox[{"fRefRot4", "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], ")"}], " ", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "npts"}], "}"}]}], " ", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"qglobalRotL", "=", 
      RowBox[{"N", "[", "baseQuatL", "]"}]}], ";", 
     RowBox[{"qglobalRotR", "=", 
      RowBox[{"N", "[", "baseQuatR", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"globalRot4", " ", "=", " ", 
      RowBox[{"PQbTo4DRot", "[", 
       RowBox[{"qglobalRotL", ",", "qglobalRotR"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"fTgtRot4", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"globalRot4", " ", ".", "#"}], ")"}], "&"}], ")"}], "/@", 
       "fTgtInitRot4"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Now", " ", "build", " ", "the", " ", "Smat", " ", "from", " ", "Sums", 
       " ", "of", " ", 
       RowBox[{"P", ".", "Rinverse"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"SMat4", "=", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fTgtRot4", "[", 
          RowBox[{"[", "k", "]"}], "]"}], ".", 
         RowBox[{"Transpose", "[", 
          RowBox[{"fRefRot4", "[", 
           RowBox[{"[", "k", "]"}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], " ", ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "SMat4", ",", "fTgtRot4", ",", "fRefRot4", ",", "fTgtInitRot4", ",", 
       RowBox[{"{", 
        RowBox[{"qglobalRotL", ",", "qglobalRotR"}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.743701077674583*^9, 3.743701082446232*^9}, {
   3.743701122974497*^9, 3.743701139310562*^9}, {3.743701241620919*^9, 
   3.743701253876624*^9}, {3.7437015748024483`*^9, 3.7437016970899563`*^9}, {
   3.7437017520256453`*^9, 3.7437019328087473`*^9}, {3.743702013007176*^9, 
   3.743702024599123*^9}, {3.743702089686983*^9, 3.7437022832864037`*^9}, {
   3.7437048783707314`*^9, 3.7437049060850897`*^9}, {3.7437055701652727`*^9, 
   3.7437055711268797`*^9}, {3.743705642181325*^9, 3.743705671603883*^9}, {
   3.743705714111507*^9, 3.743705756952504*^9}, {3.7437058251006927`*^9, 
   3.743705828522233*^9}, {3.743705867909216*^9, 3.743706006665702*^9}, {
   3.743721851003179*^9, 3.743721898240999*^9}, {3.743721954850933*^9, 
   3.743722051721287*^9}, {3.743722140049726*^9, 3.743722165954822*^9}, {
   3.7437222093771067`*^9, 3.743722241040317*^9}, {3.743722276382243*^9, 
   3.743722314280683*^9}, {3.74372370942704*^9, 3.743723736188209*^9}, {
   3.743724061583494*^9, 3.743724123030529*^9}, {3.743724229763873*^9, 
   3.743724340881013*^9}, 3.743724379312354*^9, {3.74372925015096*^9, 
   3.743729298675962*^9}, {3.7441563262096357`*^9, 3.744156332111383*^9}, {
   3.744156803202732*^9, 3.744156811858735*^9}, {3.744158545874333*^9, 
   3.744158552521237*^9}, {3.7441588389690113`*^9, 3.7441588449911823`*^9}, {
   3.744162709132386*^9, 3.744162736017488*^9}, {3.7449954800110064`*^9, 
   3.744995480191369*^9}},ExpressionUUID->"c4b1cfc4-52e6-4e44-aa9e-\
a5aa9f3a17d9"],

Cell[TextData[StyleBox["Attempting to verify that this sum of matrices \
R[p*rbar] = R[s] is the S_{ab}\n   frame-based cross-covariance, and how to \
compute the maximal similarity\n   measure, and have it agree with something \
we can COMPUTE without SVD...",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.744159970902843*^9, 3.744160050197937*^9}, {
  3.744162803838409*^9, 
  3.744162815317936*^9}},ExpressionUUID->"45cbf9be-0171-4b92-9c64-\
911190c66844"],

Cell[BoxData[
 RowBox[{
  RowBox[{"test4Dfrm", " ", "=", " ", 
   RowBox[{"build4DFrmSmat", "[", 
    RowBox[{"10", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     ".1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.744156346635483*^9, 3.744156409406075*^9}, {
   3.744156758917757*^9, 3.744156759029645*^9}, 3.744156849937792*^9, {
   3.744158859608316*^9, 3.744158866638103*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"11b915a9-7f21-4c01-9d80-131d384e2209"],

Cell[BoxData["."], "Input",
 CellChangeTimes->{
  3.744849023087667*^9},ExpressionUUID->"97a47a3c-8a18-49a4-99f2-\
efad95d58712"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"test4Dfrm", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.74415678253461*^9, 3.744156784126092*^9}, {
  3.744159592581476*^9, 3.744159597347458*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"a59e4bff-045c-43c2-b214-2e36dd7a4e34"],

Cell[BoxData["9607.518780351991`"], "Output",
 CellChangeTimes->{
  3.744156785238731*^9, 3.744156862374928*^9, 3.744158878732128*^9, 
   3.744159597819253*^9, {3.744849038129702*^9, 3.744849053909273*^9}},
 CellLabel->"Out[14]=",ExpressionUUID->"a989f0be-68d0-4bfc-807b-b7fff611ec11"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"makeMwwmat", "[", "hornE4mat", "]"}]}]], "Input",
 CellChangeTimes->{{3.744160135251747*^9, 3.744160137560294*^9}, {
  3.744160276240304*^9, 3.744160283164308*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"58291052-a463-4db6-b5e9-16a6b6218b94"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Eww", "+", "Exx", "+", "Eyy", "+", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "+", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "-", "Exz", "+", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "-", "Eyx", "+", "Ezw"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewx", "-", "Exw", "+", "Eyz", "-", "Ezy"}], ",", 
     RowBox[{"Eww", "+", "Exx", "-", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewz"}], "+", "Exy", "+", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{"Ewy", "+", "Exz", "+", "Eyw", "+", "Ezx"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewy", "-", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewz", "+", "Exy", "+", "Eyx", "+", "Ezw"}], ",", 
     RowBox[{"Eww", "-", "Exx", "+", "Eyy", "-", "Ezz"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewx"}], "-", "Exw", "+", "Eyz", "+", "Ezy"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ewz", "+", "Exy", "-", "Eyx", "-", "Ezw"}], ",", 
     RowBox[{
      RowBox[{"-", "Ewy"}], "+", "Exz", "-", "Eyw", "+", "Ezx"}], ",", 
     RowBox[{"Ewx", "+", "Exw", "+", "Eyz", "+", "Ezy"}], ",", 
     RowBox[{"Eww", "-", "Exx", "-", "Eyy", "+", "Ezz"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.744160283709394*^9, 3.744849044824286*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"291e0dc4-cdb2-4394-a3ea-af6dd41b2a56"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"test4DfrmSmat", " ", "=", " ", 
     RowBox[{"test4Dfrm", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ",", 
    RowBox[{"test4DfrmUmat", "=", 
     RowBox[{"makeMwwmat", "[", "test4DfrmSmat", "]"}]}]}], "}"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.744160073643375*^9, 3.744160128149816*^9}, 
   3.7441603115822268`*^9},
 CellLabel->"In[70]:=",ExpressionUUID->"fee65cfd-3a7b-46e8-a6d7-f3bd02a46c28"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.744160545253626*^9},ExpressionUUID->"c4955aef-3f91-4484-b0df-\
bc7097593b86"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"This", " ", "works"}], " ", "*)"}], 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.021338049062173098`", " ", "q2", " ", "qq0"}], "-", 
       RowBox[{"0.023022354596369837`", " ", "q3", " ", "qq0"}], "+", 
       RowBox[{"0.1800534016882655`", " ", "q2", " ", "qq1"}], "+", 
       RowBox[{"0.08066883277383904`", " ", "q3", " ", "qq1"}], "+", 
       RowBox[{"0.023287798056841252`", " ", "q2", " ", "qq2"}], "+", 
       RowBox[{"0.012949547631423643`", " ", "q3", " ", "qq2"}], "+", 
       RowBox[{"q0", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.25717047364979884`"}], " ", "qq0"}], "-", 
          RowBox[{"39.68261346540095`", " ", "qq1"}], "+", 
          RowBox[{"0.48709894810077276`", " ", "qq2"}], "-", 
          RowBox[{"0.8969194236144575`", " ", "qq3"}]}], ")"}]}], "+", 
       RowBox[{"q1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.00020917934211084344`", " ", "qq0"}], "+", 
          RowBox[{"0.868300604240739`", " ", "qq1"}], "-", 
          RowBox[{"0.013320027162771834`", " ", "qq2"}], "-", 
          RowBox[{"0.00014564455414417535`", " ", "qq3"}]}], ")"}]}], "-", 
       RowBox[{"0.0029306641720712174`", " ", "q2", " ", "qq3"}], "+", 
       RowBox[{"0.0420994567571005`", " ", "q3", " ", "qq3"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["q0", "2"], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}]], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["qq0", "2"], "+", 
         SuperscriptBox["qq1", "2"], "+", 
         SuperscriptBox["qq2", "2"], "+", 
         SuperscriptBox["qq3", "2"]}]]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q3", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"qq0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"qq1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"qq2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"qq3", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.744161881872319*^9, 
  3.744161888733575*^9}},ExpressionUUID->"d5f8df1f-1c96-42a8-966d-\
5828dafba634"],

Cell[TextData[StyleBox["Check on a weird thing - is the BarItzhack  3D, 4D \
maximal or not?",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7441945471126413`*^9, 3.744194578504171*^9}, {
  3.744194667895926*^9, 
  3.744194669543223*^9}},ExpressionUUID->"5f54b0bb-3fc8-46e4-9809-\
a4e5baf9bddc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testBI3D", "=", 
  RowBox[{
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"QuatToRot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox["q0", "2"], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"], "+", 
         SuperscriptBox["q3", "2"]}], "]"}]}], "]"}], ".", 
     RowBox[{"QuatToRot", "[", 
      RowBox[{"{", 
       RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "]"}]}], "]"}],
    "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.744194857309637*^9, 3.74419486550175*^9}, {
  3.744195141501854*^9, 3.744195144731827*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"982c0389-7e33-466f-b859-c1a09d227f3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["p0", "2"]}], "-", 
  SuperscriptBox["p1", "2"], "-", 
  SuperscriptBox["p2", "2"], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["p3", "2"]}], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["p0", "2"], " ", 
       SuperscriptBox["q0", "2"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "q1"}], "+", 
         RowBox[{"p2", " ", "q2"}]}], ")"}], "2"], "-", 
      RowBox[{
       SuperscriptBox["p3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q0", "2"], "+", 
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"]}], ")"}]}], "+", 
      RowBox[{"2", " ", "p3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "q1"}], "+", 
         RowBox[{"p2", " ", "q2"}]}], ")"}], " ", "q3"}], "-", 
      RowBox[{"2", " ", "p0", " ", "q0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "q1"}], "+", 
         RowBox[{"p2", " ", "q2"}], "+", 
         RowBox[{"p3", " ", "q3"}]}], ")"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["q0", "2"], "+", 
    SuperscriptBox["q1", "2"], "+", 
    SuperscriptBox["q2", "2"], "+", 
    SuperscriptBox["q3", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.744194858455368*^9, 3.744194867473434*^9}, 
   3.744195147612578*^9},
 CellLabel->
  "Out[123]=",ExpressionUUID->"b96882cc-b248-40cd-80e1-017db029cbcb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArgMax", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{
      RowBox[{"QuatToRot", "[", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "]"}], ".", 
      RowBox[{"QuatToRot", "[", 
       RowBox[{"{", 
        RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "]"}]}], 
     "]"}], "//", "FullSimplify"}], ",", 
   RowBox[{"{", 
    RowBox[{"q0", ",", " ", "q1", ",", "q2", ",", "q3"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.744195321730585*^9, 3.744195379896785*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"067d9e27-814b-4dda-99e0-4244397c4951"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.744195412898036*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"a66feb59-2a56-47aa-a48d-cbb01598244c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qLtest", " ", "=", " ", 
  RowBox[{"Normalize", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7441954711202593`*^9, 3.744195490279621*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"5fd914cc-64ef-4486-b085-3f66529a6556"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   FractionBox["1", "2"], ",", 
   FractionBox["1", "2"], ",", 
   FractionBox["1", "2"]}], "}"}]], "Output",
 CellChangeTimes->{3.7441954923928957`*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"fb0d7955-4faa-4cfe-9936-afe969a9bf4e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testBI3D", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{
       RowBox[{"QuatToRot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SuperscriptBox["q0", "2"], "+", 
           SuperscriptBox["q1", "2"], "+", 
           SuperscriptBox["q2", "2"], "+", 
           SuperscriptBox["q3", "2"]}], "]"}]}], "]"}], ".", 
       RowBox[{"QuatToRot", "[", "qLtest", "]"}]}], "]"}], "//", 
     "FullSimplify"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q3", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7441954241613817`*^9, 3.744195452873085*^9}, {
  3.744195503816679*^9, 3.744195583744298*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"1718d140-9e24-4cea-9cf5-399f75914fd4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.0000000000000004`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q0", "\[Rule]", "0.9924643888718337`"}], ",", 
     RowBox[{"q1", "\[Rule]", 
      RowBox[{"-", "0.9924643888701845`"}]}], ",", 
     RowBox[{"q2", "\[Rule]", 
      RowBox[{"-", "0.992464388870184`"}]}], ",", 
     RowBox[{"q3", "\[Rule]", 
      RowBox[{"-", "0.992464388870184`"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7441955151274014`*^9, 3.744195584578807*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"ed8f8210-c80d-4821-b3a6-b9897ccab527"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qltestmax", " ", "=", " ", 
  RowBox[{"Normalize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/.", 
    RowBox[{"testBI3D", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.744195635172996*^9, 3.7441956744708567`*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"527780b8-78e0-4202-9ab4-057a57e4ed15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5000000000006232`", ",", 
   RowBox[{"-", "0.49999999999979233`"}], ",", 
   RowBox[{"-", "0.49999999999979206`"}], ",", 
   RowBox[{"-", "0.49999999999979206`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744195675276966*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"5fa979d5-2e2c-4bbd-aedc-86f2899415de"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Eigenvalues", "[", 
     RowBox[{"QuatToRot", "[", "qLtest", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"Eigenvectors", "[", 
     RowBox[{"QuatToRot", "[", "qLtest", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"Eigenvectors", "[", 
     RowBox[{"QuatToRot", "[", "qLtest", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.74419599565163*^9, 3.744196002715506*^9}, {
  3.744196036176258*^9, 3.7441960775624437`*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"6150a6b0-0339-4b59-931a-74f896be408c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7441960031710777`*^9, 3.744196078091976*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"2db55257-6395-42d7-a6d3-5c6b58062d81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"qLtest", ".", "qltestmax"}], ",", 
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"QuatToRot", "[", "qltestmax", "]"}], ".", 
     RowBox[{"QuatToRot", "[", "qLtest", "]"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.744195681874971*^9, 3.744195695346386*^9}, {
  3.744195908097736*^9, 3.74419593753196*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"8c4a4b0b-07c9-4205-a292-7971fd708746"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.4999999999993766`"}], ",", "2.9999999999999987`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.744195696104329*^9, 3.744195937976499*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"55dd5d98-1a83-4a7c-a44e-13ee2cfc007f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArgMax", "[", 
  RowBox[{
   RowBox[{"testBI3D", "/.", 
    RowBox[{"q0", "\[Rule]", "1"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"q1", ",", "q2", ",", "q3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.74419507630056*^9, 3.744195098459721*^9}, {
  3.744195133849584*^9, 3.744195162211192*^9}, {3.744195223526771*^9, 
  3.744195281482273*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"24eccf4b-8038-49fc-8cd5-813d7b9b2c9f"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{{3.74419521331618*^9, 3.744195229301106*^9}, 
   3.7441953145209427`*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"7854038b-7f2d-40dc-ac32-2bda60a66dee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"quat", ",", "out", ",", "rules"}], "}"}], ",", 
    RowBox[{
     RowBox[{"out", "=", 
      RowBox[{"FindMaximum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["p0", "2"]}], "-", 
         SuperscriptBox["p1", "2"], "-", 
         SuperscriptBox["p2", "2"], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["p3", "2"]}], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            SuperscriptBox["q0", "2"], "+", 
            SuperscriptBox["q1", "2"], "+", 
            SuperscriptBox["q2", "2"], "+", 
            SuperscriptBox["q3", "2"]}]], "4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["p0", "2"], " ", 
             SuperscriptBox["q0", "2"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"p1", " ", "q1"}], "+", 
               RowBox[{"p2", " ", "q2"}]}], ")"}], "2"], "-", 
            RowBox[{
             SuperscriptBox["p3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["q0", "2"], "+", 
               SuperscriptBox["q1", "2"], "+", 
               SuperscriptBox["q2", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", "p3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"p1", " ", "q1"}], "+", 
               RowBox[{"p2", " ", "q2"}]}], ")"}], " ", "q3"}], "-", 
            RowBox[{"2", " ", "p0", " ", "q0", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"p1", " ", "q1"}], "+", 
               RowBox[{"p2", " ", "q2"}], "+", 
               RowBox[{"p3", " ", "q3"}]}], ")"}]}]}], ")"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"q0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"q1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"q2", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"q3", ",", "0"}], "}"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "out"}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"rules", "  ", "=", 
      RowBox[{"out", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", "  ", 
     RowBox[{"Normalize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/.", " ", 
       "rules"}], "]"}]}], "*)"}], "]"}], "//", "Quiet"}]], "Input",
 CellChangeTimes->{{3.7441946781390247`*^9, 3.7441947286169643`*^9}, {
   3.744194770752533*^9, 3.744194792008697*^9}, 3.744194932384241*^9, {
   3.7441949771627703`*^9, 3.744195004183782*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"97671d7f-3803-4c88-bb2f-8055a83d631c"],

Cell[BoxData[
 TemplateBox[{
  "FindMaximum","nrnum",
   "\"The function value \\!\\(\\*RowBox[{SuperscriptBox[\\\"p0\\\", \
\\\"2\\\"], \\\"+\\\", SuperscriptBox[\\\"p1\\\", \\\"2\\\"], \\\"+\\\", \
SuperscriptBox[\\\"p2\\\", \\\"2\\\"], \\\"-\\\", RowBox[{\\\"3\\\", \\\" \
\\\", SuperscriptBox[\\\"p3\\\", \\\"2\\\"]}], \\\"-\\\", \
RowBox[{\\\"4.`\\\", \\\" \\\", RowBox[{\\\"(\\\", \
RowBox[{RowBox[{\\\"0.`\\\", \\\"\[VeryThinSpace]\\\"}], \\\"+\\\", \
RowBox[{\\\"1.`\\\", \\\" \\\", SuperscriptBox[\\\"p0\\\", \\\"2\\\"]}], \
\\\"-\\\", RowBox[{\\\"1.`\\\", \\\" \\\", SuperscriptBox[\\\"p3\\\", \\\"2\\\
\"]}]}], \\\")\\\"}]}]}]\\) is not a real number at \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"q0\\\", \\\",\\\", \\\"q1\\\", \
\\\",\\\", \\\"q2\\\", \\\",\\\", \\\"q3\\\"}], \\\"}\\\"}]\\) = \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"1.`\\\", \\\",\\\", \\\"0.`\\\", \
\\\",\\\", \\\"0.`\\\", \\\",\\\", \\\"0.`\\\"}], \\\"}\\\"}]\\).\"",2,119,16,
   27344378750003428142,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.744195006563826*^9},
 CellLabel->
  "During evaluation of \
In[119]:=",ExpressionUUID->"fe6b80f7-1751-4549-b893-ca67df31cfa5"],

Cell[BoxData[
 RowBox[{"FindMaximum", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["p0", "2"]}], "-", 
    SuperscriptBox["p1", "2"], "-", 
    SuperscriptBox["p2", "2"], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["p3", "2"]}], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["p0", "2"], " ", 
         SuperscriptBox["q0", "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "q1"}], "+", 
           RowBox[{"p2", " ", "q2"}]}], ")"}], "2"], "-", 
        RowBox[{
         SuperscriptBox["p3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["q0", "2"], "+", 
           SuperscriptBox["q1", "2"], "+", 
           SuperscriptBox["q2", "2"]}], ")"}]}], "+", 
        RowBox[{"2", " ", "p3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "q1"}], "+", 
           RowBox[{"p2", " ", "q2"}]}], ")"}], " ", "q3"}], "-", 
        RowBox[{"2", " ", "p0", " ", "q0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p1", " ", "q1"}], "+", 
           RowBox[{"p2", " ", "q2"}], "+", 
           RowBox[{"p3", " ", "q3"}]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["q0", "2"], "+", 
      SuperscriptBox["q1", "2"], "+", 
      SuperscriptBox["q2", "2"], "+", 
      SuperscriptBox["q3", "2"]}]]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q2", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q3", ",", "0"}], "}"}]}], "}"}]}], "]"}]], "Output",
 CellChangeTimes->{
  3.744194806189015*^9, {3.7441949788661213`*^9, 3.744195006570097*^9}},
 CellLabel->
  "Out[119]=",ExpressionUUID->"9e5f636a-a7d2-449b-9ed1-49d3869fc2c4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"quat", ",", "out", ",", "rules"}], "}"}], ",", 
   RowBox[{"out", "=", 
    RowBox[{
     RowBox[{"FindMaximum", "[", 
      RowBox[{
       RowBox[{"Tr", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PQbTo4DRot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/", 
              RowBox[{"Sqrt", "[", 
               RowBox[{
                SuperscriptBox["q0", "2"], "+", 
                SuperscriptBox["q1", "2"], "+", 
                SuperscriptBox["q2", "2"], "+", 
                SuperscriptBox["q3", "2"]}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"qq0", ",", "qq1", ",", "qq2", ",", "qq3"}], "}"}], 
              "/", 
              RowBox[{"Sqrt", "[", 
               RowBox[{
                SuperscriptBox["qq0", "2"], "+", 
                SuperscriptBox["qq1", "2"], "+", 
                SuperscriptBox["qq2", "2"], "+", 
                SuperscriptBox["qq3", "2"]}], "]"}]}]}], "]"}], ".", " ", 
           RowBox[{"PQbTo4DRot", "[", 
            RowBox[{"{", 
             RowBox[{"p0", ",", "p1", ",", "p2", ",", "p3"}], "}"}], "]"}]}], 
          "//", "Simplify"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"q1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"q2", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"q3", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"qq0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"qq1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"qq2", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"qq3", ",", "0"}], "}"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"rules", " ", "=", 
        RowBox[{"out", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/.", " ",
            "rules"}], "]"}], ",", 
         RowBox[{"Normalize", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"qq0", ",", "qq1", ",", "qq2", ",", "qq3"}], "}"}], "/.", 
           "rules"}], "]"}]}], "}"}]}], "]"}], "//", "Quiet"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.744194612066751*^9, 
  3.744194634755452*^9}},ExpressionUUID->"7bbac4c9-3af3-40b7-a176-\
ab068f824aa7"],

Cell[TextData[StyleBox["Now get the whole optimum, and YES, it agrees exactly \
with SVD,\n   so SVD is the optimal rotation (either as R or optimal qL,qR)",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.744194479016864*^9, 
  3.744194533097019*^9}},ExpressionUUID->"86e12368-7700-43f6-b31b-\
e68045c4c9c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"evecLefttst", ",", "evecRgttst"}], "}"}], "=", "   ", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"quat", ",", "out", ",", "rules"}], "}"}], ",", 
     RowBox[{
      RowBox[{"out", "=", 
       RowBox[{"FindMaximum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Tr", "[", 
           RowBox[{
            RowBox[{"PQbTo4DRot", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 SuperscriptBox["q0", "2"], "+", 
                 SuperscriptBox["q1", "2"], "+", 
                 SuperscriptBox["q2", "2"], "+", 
                 SuperscriptBox["q3", "2"]}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"qq0", ",", "qq1", ",", "qq2", ",", "qq3"}], "}"}], 
               "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 SuperscriptBox["qq0", "2"], "+", 
                 SuperscriptBox["qq1", "2"], "+", 
                 SuperscriptBox["qq2", "2"], "+", 
                 SuperscriptBox["qq3", "2"]}], "]"}]}]}], "]"}], ".", " ", 
            "test4DfrmSmat"}], "]"}], "//", "Simplify"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"q0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"q1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"q2", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"q3", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"qq0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"qq1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"qq2", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"qq3", ",", "0"}], "}"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"rules", " ", "=", 
       RowBox[{"out", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"Normalize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"q0", ",", "q1", ",", "q2", ",", "q3"}], "}"}], "/.", " ", 
          "rules"}], "]"}], ",", 
        RowBox[{"Normalize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"qq0", ",", "qq1", ",", "qq2", ",", "qq3"}], "}"}], "/.", 
          "rules"}], "]"}]}], "}"}]}]}], "]"}], "//", "Quiet"}]}]], "Input",
 CellChangeTimes->{{3.7441617618609533`*^9, 3.74416181638483*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"20f2a09b-95c3-4d65-9b52-a59c01b565d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9997485989771879`", ",", 
     RowBox[{"-", "0.0218643278514802`"}], ",", 
     RowBox[{"-", "0.004527622995655106`"}], ",", 
     RowBox[{"-", "0.0020471054594052534`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.006476508987022818`"}], ",", 
     RowBox[{"-", "0.999648672919322`"}], ",", "0.01226839679949147`", ",", 
     RowBox[{"-", "0.022584773674962626`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744161833673437*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"f1dadec2-f48f-4042-b5e7-e80692b84525"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Test of maximization of the 4D profile system: the by-hand numerical
maximization works, and matches the SVD:\
\>", "Subsubsection",
 CellChangeTimes->{{3.744162398529223*^9, 
  3.744162439521093*^9}},ExpressionUUID->"6251c880-2efe-4810-b507-\
5b3ad3c331f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Nope", ",", " ", 
    RowBox[{"these", " ", "are", " ", "backwards"}]}], " ", "*)"}], 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{
      RowBox[{"PQbTo4DRot", "[", 
       RowBox[{"evecRgttst", ",", "evecLefttst"}], "]"}], ".", 
      "test4DfrmSmat"}], "]"}], ",", 
    RowBox[{"evecRgttst", ".", "test4DfrmUmat", " ", ".", "evecLefttst"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.744161548400866*^9, 3.7441616178247547`*^9}, {
  3.744161669591195*^9, 3.744161680056183*^9}, {3.7441624525812597`*^9, 
  3.7441624603695917`*^9}},ExpressionUUID->"d2452fe5-0a49-40c6-84b2-\
653b7a669c26"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.015531932917907554`", ",", "0.015531932917911547`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.744161619018792*^9, 3.744161689086384*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"7bdfe793-253c-408b-a88a-2616d880cfb9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"both", " ", 
    RowBox[{"Tr", "[", " ", 
     RowBox[{
      RowBox[{"R", "[", 
       RowBox[{"qL", ",", "qR"}], "]"}], ".", "S"}], "]"}], " ", "and", " ", 
    RowBox[{"qL", ".", "U", ".", "qR"}], "  ", "match", " ", "the", " ", 
    RowBox[{"Tr", "[", 
     RowBox[{"SVD", ".", "S"}], "]"}]}], " ", "*)"}], 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{
      RowBox[{"PQbTo4DRot", "[", 
       RowBox[{"evecLefttst", ",", "evecRgttst"}], "]"}], ".", 
      "test4DfrmSmat"}], "]"}], ",", 
    RowBox[{"evecLefttst", ".", "test4DfrmUmat", ".", "evecRgttst"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.744161548400866*^9, 3.7441616178247547`*^9}, {
  3.744161669591195*^9, 3.744161680056183*^9}, {3.7441619189780617`*^9, 
  3.744161953928975*^9}, {3.744162467645743*^9, 
  3.7441625457599897`*^9}},ExpressionUUID->"e3c1e0ce-3ba2-43d4-8fe1-\
1cdba12d2b7b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"39.70655236797032`", ",", "39.70655236797032`"}], "}"}]], "Output",\

 CellChangeTimes->{3.744161956638377*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"7f67fe3a-b2bd-44b2-9f80-fac5a33635ee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"eMat", "=", "test4DfrmSmat"}], ",", 
     RowBox[{"mMat", "=", "test4DfrmUmat"}], ",", "U4D", ",", "S4D", ",", 
     "V4D"}], " ", "}"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"U4D", ",", "S4D", ",", "V4D"}], "}"}], "=", " ", 
     RowBox[{"SingularValueDecomposition", "[", "eMat", "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"testjustS4D", "=", "S4D"}], ";", "\[IndentingNewLine]", 
    RowBox[{"svdRot4", "=", 
     RowBox[{"V4D", ".", 
      RowBox[{"Transpose", "[", "U4D", "]"}]}]}], ";", " ", 
    RowBox[{"Tr", "[", 
     RowBox[{"svdRot4", ".", "eMat"}], "]"}]}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.744161985541411*^9, 3.744162086820221*^9}, {
  3.7441622152716722`*^9, 3.744162257882668*^9}, {3.744163828128874*^9, 
  3.744163840725775*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"bd431e70-b196-405d-b083-0820d2ae1cc3"],

Cell[BoxData["39.70655236797033`"], "Output",
 CellChangeTimes->{
  3.744162087586568*^9, {3.744162235789535*^9, 3.744162260459202*^9}, 
   3.744163843402068*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"9e85e002-f956-419f-b599-0996b330b891"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigenvectors", "[", 
   RowBox[{"makeMwwmat", "[", "svdRot4", "]"}], "]"}], "//", 
  "Chop"}]], "Input",
 CellChangeTimes->{{3.744163325238825*^9, 3.744163326976016*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"ac8b130e-62c7-4a82-b4ff-eb35ef2f6a24"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9997485989976951`"}], ",", 
     RowBox[{"-", "0.02186432655685918`"}], ",", 
     RowBox[{"-", "0.004527626727245742`"}], ",", 
     RowBox[{"-", "0.0020471010184785004`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9993873185377787`"}], ",", 
     RowBox[{"-", "0.007152411735259197`"}], ",", "0.006657427535268658`", 
     ",", "0.033608171786793824`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6965668059176318`", ",", 
     RowBox[{
      RowBox[{"-", "0.006581157259965203`"}], "-", 
      RowBox[{"0.002724792049540379`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.26044506783472965`"}], "+", 
      RowBox[{"0.4414050899613516`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.3495683347203128`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.3603829093183472`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6965668059176318`", ",", 
     RowBox[{
      RowBox[{"-", "0.006581157259965203`"}], "+", 
      RowBox[{"0.002724792049540379`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.26044506783472965`"}], "-", 
      RowBox[{"0.4414050899613516`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.3495683347203128`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.3603829093183472`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744163321903104*^9, 3.7441633274271*^9}},
 CellLabel->"Out[99]=",ExpressionUUID->"869020a6-afc2-4271-a944-b1f31f2601f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Eigenvectors", " ", "of", " ", "the", " ", 
    RowBox[{"Mww", "[", "SVDrotation", "]"}], " ", "also", " ", "match", " ", 
    "the", " ", "numerical", " ", "optimization"}], " ", "*)"}], 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Normalize", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Eigenvectors", "[", 
        RowBox[{"makeMwwmat", "[", "svdRot4", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "//", "Chop"}], "]"}], ",", 
    RowBox[{"Normalize", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Eigenvectors", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"makeMwwmat", "[", "svdRot4", "]"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "//", "Chop"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.744162264481616*^9, 3.744162356906254*^9}, {
  3.7441625790268297`*^9, 
  3.744162622096115*^9}},ExpressionUUID->"58722332-f0fd-4c4e-b4b9-\
063540bb59ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9997485989976951`"}], ",", 
     RowBox[{"-", "0.02186432655685918`"}], ",", 
     RowBox[{"-", "0.004527626727245742`"}], ",", 
     RowBox[{"-", "0.0020471010184785004`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00647650981009423`"}], ",", "0.9996486728075705`", ",", 
     RowBox[{"-", "0.01226839772834648`"}], ",", "0.022584777880718793`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744162309194059*^9, 3.74416235737475*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"95f43e4b-7c67-4dcc-9bde-c4291b95b9cb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"evecLefttst", ",", "evecRgttst"}], "}"}]], "Input",
 CellLabel->"In[95]:=",ExpressionUUID->"faa457d2-6988-4d60-bfc7-d56f2b48a36c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9997485989771879`", ",", 
     RowBox[{"-", "0.0218643278514802`"}], ",", 
     RowBox[{"-", "0.004527622995655106`"}], ",", 
     RowBox[{"-", "0.0020471054594052534`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.006476508987022818`"}], ",", 
     RowBox[{"-", "0.999648672919322`"}], ",", "0.01226839679949147`", ",", 
     RowBox[{"-", "0.022584773674962626`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744162381973094*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"c093ebe9-5793-40af-970d-924685f91dde"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Puzzle:  I cannot assume direct optimization over the field q,qq;
                 I cannot assume I have the SVD decomposition.
                 I know that in the Emat = SO4[p,p\[CloseCurlyQuote]] case \
that  (pRgt.Mmat.pLft)
                     gives eigenmeasure = 1, and (pLft.Mmat.pRgt) = \
(pRgt.pLft)^2 << 1.
             WHAT can I get out of Emat or Mmat=buildM[Emat] that matches
                      Tr[svdRot4.eMat] = 39.7066 for these data?\
\>", "Subsubsection",
 CellChangeTimes->{{3.744163442728355*^9, 
  3.744163715014228*^9}},ExpressionUUID->"bbaa7410-f06c-40fa-9337-\
16ea985a56e6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Eigenvalues", "[", "test4DfrmUmat", "]"}], ",", 
   RowBox[{"Tr", "@", "testjustS4D"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.744163781070304*^9, 3.7441638046690807`*^9}, {
  3.744163855065989*^9, 3.744163855264873*^9}, {3.744163912177672*^9, 
  3.744163976348454*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"5b7bd617-1726-48d8-9f65-67a87d09739a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.869962097731742`", ",", 
     RowBox[{"-", "0.3132736051360927`"}], ",", "0.08030649599185656`", ",", 
     "0.03952239681737705`"}], "}"}], ",", "39.706552367970346`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.744163805024461*^9, 3.7441638560546083`*^9, {3.7441639158687363`*^9, 
   3.744163977573152*^9}},
 CellLabel->
  "Out[106]=",ExpressionUUID->"f733aeca-b63d-4cde-8ec6-9620d185dfe9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"evML", " ", "=", " ", 
    RowBox[{"Eigenvectors", "[", 
     RowBox[{"Transpose", "[", "test4DfrmUmat", "]"}], "]"}]}], ",", 
   RowBox[{"evMR", " ", "=", " ", 
    RowBox[{"Eigenvectors", "[", "test4DfrmUmat", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.744163735694655*^9, 3.74416376388599*^9}, {
  3.7441640044757643`*^9, 3.744164041211813*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"5ca9e8d5-16f6-48e6-9ffa-cc1151412a34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.0001135276328863115`", ",", 
       RowBox[{"-", "0.9998752372003613`"}], ",", "0.01579547833880158`", ",", 
       RowBox[{"-", "3.0077433814541174`*^-6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.029800274712776742`"}], ",", 
       RowBox[{"-", "0.9966735683576828`"}], ",", "0.006591709631740417`", 
       ",", 
       RowBox[{"-", "0.07556646828016321`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.016598482976348347`"}], ",", 
       RowBox[{"-", "0.9108869572488459`"}], ",", "0.15753182683508413`", ",",
        "0.38104220896224106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00038329370863692517`", ",", "0.2372602801855572`", ",", 
       RowBox[{"-", "0.7110945070664799`"}], ",", 
       RowBox[{"-", "0.6618549800009695`"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9989790257023099`", ",", 
       RowBox[{"-", "0.02745452824273775`"}], ",", "0.01944236168690679`", 
       ",", 
       RowBox[{"-", "0.030152108680291695`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9958208028213399`", ",", 
       RowBox[{"-", "0.0008679613211831741`"}], ",", 
       RowBox[{"-", "0.06208769077974818`"}], ",", "0.0669723373120999`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.8529487672548375`", ",", "0.005735911654023879`", ",", 
       "0.3568880304738009`", ",", 
       RowBox[{"-", "0.38088900412125515`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.47938795255244426`", ",", "0.013138224299135236`", ",", 
       "0.8281666784062557`", ",", 
       RowBox[{"-", "0.2900940033633765`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.744164041763577*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"a148d6e3-c12f-44f9-a715-6c5a68146174"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"evML", "  ", "=", 
    RowBox[{"evML", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ",", 
   RowBox[{"evMR", "=", " ", 
    RowBox[{"evMR", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.744164169881756*^9, 3.7441641933387527`*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"bff49646-2a47-4cf5-8615-24eaf5a0e84c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.0001135276328863115`", ",", 
     RowBox[{"-", "0.9998752372003613`"}], ",", "0.01579547833880158`", ",", 
     RowBox[{"-", "3.0077433814541174`*^-6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9989790257023099`", ",", 
     RowBox[{"-", "0.02745452824273775`"}], ",", "0.01944236168690679`", ",", 
     
     RowBox[{"-", "0.030152108680291695`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744164193803719*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"48f699d3-d799-4082-99d5-63a64b6306cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Check", " ", "against", " ", "SVD", " ", "and", " ", "brute", " ", 
    "force", " ", 
    RowBox[{"numerical", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", " ", 
  RowBox[{"Tr", "[", 
   RowBox[{"svdRot4", ".", "test4DfrmSmat"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.744164273832445*^9, 3.744164312762322*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"267d560f-6485-41ec-807d-dd15ae33028f"],

Cell[BoxData["39.70655236797033`"], "Output",
 CellChangeTimes->{3.7441643140033693`*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"3cb19615-2acd-48a7-9728-a0992bc380b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"evML", ".", " ", "test4DfrmUmat", ".", "evMR"}], " ", "+", 
  RowBox[{
  "evMR", " ", ".", " ", "test4DfrmUmat", " ", ".", " ", "evML"}]}]], "Input",\

 CellChangeTimes->{{3.744194288259698*^9, 3.744194294496179*^9}, 
   3.7441943347619543`*^9},
 CellLabel->
  "In[113]:=",ExpressionUUID->"4e137a18-bd79-45c4-8539-3684ca08b96f"],

Cell[BoxData["39.69183414506103`"], "Output",
 CellChangeTimes->{3.74419429592339*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"f1975762-5e81-45f1-9786-427de9b03877"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"evML", ".", "evMR"}], ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"evML", ".", "evMR"}], ")"}], "2"]}], "}"}]], "Input",
 CellChangeTimes->{{3.744194341919497*^9, 3.74419437197058*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"36abfddf-d9df-4cf3-a80c-0d65af7a4269"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.027871706755708485`", ",", "0.000776832037476206`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7441943728249407`*^9},
 CellLabel->
  "Out[114]=",ExpressionUUID->"4c6c2fa4-8bd1-466d-9806-7b449b1ba6d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", " ", 
  RowBox[{
   RowBox[{"evML", ".", " ", "test4DfrmUmat", ".", "evMR"}], " ", ",", 
   RowBox[{"evMR", " ", ".", " ", "test4DfrmUmat", " ", ".", " ", "evML"}], 
   ",", " ", 
   RowBox[{"evML", ".", " ", 
    RowBox[{"Transpose", "[", "test4DfrmUmat", "]"}], " ", ".", " ", "evMR"}],
    ",", 
   RowBox[{"evMR", ".", " ", 
    RowBox[{"Transpose", "[", "test4DfrmUmat", "]"}], ".", " ", "evML"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.744164118059918*^9, 3.744164160547308*^9}, {
  3.7441642030627813`*^9, 3.744164239197056*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"dcf2e6ea-8492-4dfa-bfde-d06d381abba3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.024247328476560095`", ",", "39.66758681658447`", ",", 
   "39.66758681658446`", ",", "0.024247328476560095`"}], "}"}]], "Output",
 CellChangeTimes->{3.744164318434613*^9},
 CellLabel->
  "Out[110]=",ExpressionUUID->"46149735-15d8-44ff-82bb-e043f668d639"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"39.70655236797033`", "-", "39.66758681658447`"}]], "Input",
 CellChangeTimes->{{3.7441645948961773`*^9, 3.744164595855919*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"c0571139-af89-4eb6-acfd-a8a1a8c96faa"],

Cell[BoxData["0.03896555138586422`"], "Output",
 CellChangeTimes->{3.744164596997716*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"c45045af-bb76-4078-adc1-bb7e9da0f6d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"0.03896555138586422`", "/", "39.70655236797033`"}]], "Input",
 CellChangeTimes->{{3.744164712934718*^9, 3.744164720570722*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"eb9f582c-403a-406a-821a-82c172984114"],

Cell[BoxData["0.000981338067953141`"], "Output",
 CellChangeTimes->{3.7441647216369057`*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"a35c26a3-6718-40b3-8923-225a9efcde53"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["WHAT?  I cannot get the MAX = 39.7066 out of Umat, \
just 39.6676.\nIs this wrong, or is this, say, an ArcLength vs ChordLength \
issue --\nI am EXACTLY optimizing when  I do the SVD?  Is that different?",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.744164534872493*^9, 3.7441645778237877`*^9}, {
  3.7441646214796257`*^9, 3.7441646517193413`*^9}, {3.744164686399744*^9, 
  3.744164700966461*^9}},ExpressionUUID->"9d97b5e5-f742-4b00-a166-\
aba42d5fea4c"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.7441604882184143`*^9},ExpressionUUID->"cd321480-e1c6-49f6-b64f-\
dec2d9758487"]
}, Open  ]],

Cell[CellGroupData[{

Cell["=========================================", "Subsubsection",
 CellChangeTimes->{{3.744163435983982*^9, 
  3.744163437781846*^9}},ExpressionUUID->"ef1ac928-0274-4f41-aec6-\
fb317232b6a8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qID", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"eMat", " ", "=", " ", 
      RowBox[{
       RowBox[{"test4Dfrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "//", "Chop"}]}], ",", 
     RowBox[{"uMat", " ", "=", " ", 
      RowBox[{"makeMwwmat", "[", 
       RowBox[{"test4Dfrm", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", "qL", ",", "qR", ",", 
     "qqRot4", ",", "qqRot4x", ",", "U4D", ",", "S4D", ",", "V4D", ",", 
     "svdRot4"}], "}"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"qR", "=", 
     RowBox[{
      RowBox[{"Normalize", "[", 
       RowBox[{
        RowBox[{"Eigenvectors", "[", "uMat", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], "//", "Chop"}]}], ";", 
    RowBox[{"qL", "=", 
     RowBox[{
      RowBox[{"Normalize", "[", 
       RowBox[{
        RowBox[{"Eigenvectors", "[", 
         RowBox[{"Transpose", "[", "uMat", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], "//", "Chop"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"qqRot4", "=", 
     RowBox[{"PQbTo4DRot", "[", 
      RowBox[{"qR", ",", "qL"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
    RowBox[{"qqRot4x", "=", 
     RowBox[{"PQbTo4DRot", "[", 
      RowBox[{"qL", ",", "qR"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"U4D", ",", "S4D", ",", "V4D"}], "}"}], "=", " ", 
     RowBox[{"SingularValueDecomposition", "[", "eMat", "]"}]}], ";", 
    RowBox[{"svdRot4", "=", 
     RowBox[{"V4D", ".", 
      RowBox[{"Transpose", "[", "U4D", "]"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qID", ".", "uMat", ".", "qID"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"qR", ".", "uMat", ".", "qL"}], ",", 
        RowBox[{"Tr", "[", 
         RowBox[{"qqRot4", ".", "eMat"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"qL", ".", "uMat", ".", "qR"}], ",", 
        RowBox[{"Tr", "[", 
         RowBox[{"qqRot4x", ".", "eMat"}], "]"}]}], "}"}], ",", 
      RowBox[{"Tr", "[", 
       RowBox[{"svdRot4", ".", "eMat"}], "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7441588832533283`*^9, 3.744159024049308*^9}, {
  3.74415909247753*^9, 3.744159344135255*^9}, {3.7441593753745203`*^9, 
  3.744159420516459*^9}, {3.7441596423036213`*^9, 3.7441597097802353`*^9}, {
  3.7441597448601313`*^9, 3.744159783370914*^9}, {3.744159856079123*^9, 
  3.744159879042367*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"fda7f338-ad3c-417c-ad55-4e52a83e5de7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.2571704736497987`"}], ",", 
   RowBox[{"{", 
    RowBox[{"39.66758681658446`", ",", "39.66758681658445`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.024247328476560092`", ",", "0.024247328476560526`"}], "}"}], 
   ",", "39.70655236797033`"}], "}"}]], "Output",
 CellChangeTimes->{3.744159027046186*^9, 3.74415942435458*^9, 
  3.744159785843342*^9, 3.744159880289789*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"88fe08bc-39cd-4bae-aa9e-c55a03ccd65e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "/@", " ", "test4Dfrm", " "}]], "Input",
 CellChangeTimes->{{3.7441564287919607`*^9, 3.744156450169249*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"269e5cbf-1844-4b4d-81eb-755987ff4a33"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744156451297324*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"5a2d1101-3c71-4765-bf4c-d27ea443d077"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"setsOf4DFrmSmatData", " ", "[", 
    RowBox[{
     RowBox[{"npts_:", "100"}], ",", 
     RowBox[{"nsets_:", "1000"}]}], "]"}], " ", ":=", "\[IndentingNewLine]", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p0th", " ", "=", " ", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{
            RowBox[{"Pi", "/", "8"}], ",", 
            RowBox[{"Pi", "/", "32."}]}], "]"}], ",", "nsets"}], "]"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"q0th", " ", "=", " ", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{
            RowBox[{"Pi", "/", "8"}], ",", 
            RowBox[{"Pi", "/", "32."}]}], "]"}], ",", "nsets"}], "]"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"nhatp", " ", "=", " ", 
        RowBox[{"randomSphere2", "[", "nsets", "]"}]}], ",", 
       RowBox[{"nhatq", " ", "=", " ", 
        RowBox[{"randomSphere2", "[", "nsets", "]"}]}], ",", "pquats", ",", 
       "qquats"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pquats", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Cos", "[", 
             RowBox[{"p0th", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}], ",", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"p0th", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "*", 
            RowBox[{"nhatp", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"qquats", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Cos", "[", 
             RowBox[{"q0th", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}], ",", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"q0th", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "*", 
            RowBox[{"nhatq", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"build4DFrmSmat", "[", 
         RowBox[{"npts", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"pquats", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"qquats", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "nsets"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.744156137335711*^9, 3.744156138230504*^9}, 
   3.744156182668971*^9, {3.744162651310503*^9, 
   3.7441626877854757`*^9}},ExpressionUUID->"c5f40806-0e1a-4a12-8042-\
e370a9efe4c5"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"test3DPnt", " ", "=", " ", 
    RowBox[{"build3DPntdataset", "[", "200", "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.740162424497295*^9, 3.740162452857421*^9}},
 CellLabel->
  "In[1248]:=",ExpressionUUID->"7298bdbd-3b3f-4e45-8b2b-47c264b2a2d2"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"test3DPnt", " ", "=", " ", 
    RowBox[{"build3DPntdataset", "[", 
     RowBox[{"200", ",", " ", 
      RowBox[{"Normalize", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", ".2", ",", ".5", ",", ".6"}], "}"}], "]"}]}], 
     "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.740164005152687*^9, 3.740164014141548*^9}},
 CellLabel->
  "In[1256]:=",ExpressionUUID->"bcfe0b5d-9ec9-430c-ae7f-1d22abdd16de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"{", 
   RowBox[{"Red", ",", 
    RowBox[{"Point", "[", 
     RowBox[{"test3DPnt", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", "Blue", ",", 
    RowBox[{"Point", "[", 
     RowBox[{"test3DPnt", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", " ", "Green", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Point", "[", 
     RowBox[{"test3DPnt", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "]"}], ",", 
    RowBox[{"Darker", "@", "Green"}], ",", 
    RowBox[{"Line", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"test3DPnt", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"test3DPnt", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "200"}], "}"}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", "Blue", ",", 
    RowBox[{"Line", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"test3DPnt", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"test3DPnt", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "200"}], "}"}]}], "]"}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7401624333299637`*^9, 3.7401624342595167`*^9}, {
  3.7401624709831123`*^9, 3.740162501217175*^9}, {3.740162845532135*^9, 
  3.740162847616014*^9}},
 CellLabel->
  "In[1257]:=",ExpressionUUID->"cee325b5-45e5-4b40-90b5-2c75dbce87e7"],

Cell[BoxData[
 Graphics3DBox[{
   {RGBColor[1, 0, 0], Point3DBox[CompressedData["
1:eJwNV2k4FGwUlconfSJFqRSyRaRNst1KJbSIkAiVbFkTLUh9orKVJbJkmSJL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     "]]}, 
   {RGBColor[0, 0, 1], Point3DBox[CompressedData["
1:eJwNV/cjFAwYNktRRtLSLi2pZKXxihJSqaSBSEr6SsuojMhKiYxskuyWkWwv
sp15zp1z2905l1Uqs3x+eP6CZ6+3u3PmmpiIiEjDHMTnUDn5+OybL714OH74
ValKJbq79P6IOzIKWs+7Oi7fJoHIiZSjS+UHwVt5l8310m/wYva/MIdVPDxV
2plZcIAKqxO6pYZ0Obhu1G7jCyodDrJmD3Hd+3DYX3X7yeEy9MwyOrvZpgsF
aptqF4t24S2rowdFJTtw5eZXsznLaXjseUo527YT+Meu+SwkkbDhxbqJ919r
UGvfict8EhXN4uPZl936kKRUGX34RAvGbGcndpzmwOjSZW5FRiy4Vj87qvWk
E6VMB01JW9sxqohoWG3Rid7td/RM9pHg4/SelIOFjSinmfgpMqUL/7C+XbVT
YWFE6JG2w2Z0LPervvUpiY0lrVvDxEza4On7PCqVPQL2JStNo2ey8YzwWEei
2jBsIkdqKyl+BO9NnhuW53aAks+Jon3OjXhTfpXc4sBstM1adnErtwTnMeqf
PXH8iOIzGcrFQ6M4qlyjmbbJGzoviK6xuteD7/c1q3rmfkIPhna46ysWNNat
XxWjUAWMM78XTa4fxlRHRoXj7i6sSO+Osb9HwZnPRv4y1VwwMjlfyLGJgJUy
f04ez6gBjW3mx5ZSOHjd5MGzz6Y9+J/+2tjFGg3oXB6UnG3Kh7VpV1x8tnRg
a9qtToctffhYS6lwcKgLzbUPu0SspaBq/CqD+Npc8AqWvRP9i4xT848YagTx
Uf3+iuSHUmw846ATS9tOBlPysF9dAhP+4iX3QEUSVqX83nJoSQuYxG1YZuWZ
Cc92dnMMthOgZDd/snQwGU5odpzuMOpB/bVuZ5aRe2Gg6fcPj/wBYO2lh/bP
JoHeUnWjM8ubwMxyJujogUcQuv2ybtryQaCWhicE3PqG1wt9HWsobHh6CTZO
+lTjuOzsj/LURhjWPuRvEUzFJbWHdEY/EJH6cm9Bxz4iPsmpamuN44KQcnJt
dB0d9X/PDLktEULp1PMfGjNUSG/qled6EXGDGCEmZDEF4ho8NZ6YdcJSXZHg
/Yn1mP0zJMjSlgyECPG43okApJz1n1D3yMPxeQ9zTK2F6OJooNa9+D0+/88o
/fs1JqrqP11V7dyCHT1lasunWiE19Wd41vNeLLpgtDRi8g0O9QdGyO4k4Zjp
V91HjDYszukXcz7RCi9Z1N+ZT9vR+9T6U+MNbrBNRr/YSI4JhrrS65V8mXgj
rdQncSMTuxeZXOElMyHPmbgh7Fwvuq49smD4YSFqsZ69uMVh47+Vuh7qkfno
QfNXtG6kQMOuwofW2QJMrPplv43MgcH6AUPW5Rb4s37nmvQ8FkpbdZP1uqpR
mhyqFdstxOL9XUv3NTTjdGib6sgADd+ev6M5r6EThbXhUdYVROxmZa4r8Gdj
q8vVNZ1VZPDTVH8gfMiGor9heUpEGuTVOyekadTA1inJ7FBmHdyXrnhuFpSB
apLRRHuz7xD+jhjStIMDxQ8ELztyCnBMI9LKyYyP3KQS15/kbmAIZCP1PUsg
dcFZ0+4XLPBx0JHQwCr01lGtUN/RDoJnu1i+dq2QvXYJY0TQhafiF0WWvedC
6NgCjfHNVThlSy2tkE2FJHvDHdgsABvmnpEIdi56avx6o27IRjWhs1sGqQEm
/xBsO85SsVf9ZpnYnE83he1OPHSSC1/+bKH9Y6Zjg5fLugV+VChwXrPgtd8A
iM0eJCjld8Gv/CcjJnbdGBM3PdkhLUQN22tqF8UIsMX7thtTiQw728WZ7hV0
XKbml0AZbEerkcg9I9YVaLBtRjvlIg1/Gr6NaXEdQpryqt7FEj144CC7q7ik
DVKLb3vqnhoEXaZ+b9n+IpQQMZJ5fJkLrrerMwM3tQGxrmfpvv84eOzY/nzK
KAFy8hbHHC5igIHfnfLIrTxU/n5YXab5AW4ln18tbc+FRDXJL617qnCpWhvr
irEAzReefLvc/wPG/hS1vEigQu4i43/yTgL02Vs0kqr9FU9vrXBVzabhpQ0G
IX9OU7Hn2dW24CV9uOa1o/ojEzaOjd3KCHldi7R31q5L9peD789s1UOVNBhq
dk3+97QQ5eY3DH4cbAW5lUk90Sbfcet96aC0LRSgJmXS3tO74VYDO3TLwz4Q
2Rqf6iSXDH8pCu06bs1o6HhKqkyDCO2Cz42ByhyYbAxTbSmtx+SjFqfP36Sj
9AbNlC9t33Dm5tYbYisYcP2jd4PRExIe9JckCL8w4G6opBwvJRcHDmU7PU4j
w607LJndWuGYZ15rzc0Wwoe9IrkJSdlIeF27avwdF3MefNnwc38fzLu1puxP
BBFI826uL9OtAj/Grzsvb39BY/afzRn7KlH5XOb05tUMdDrvrMb/SYT8zPSa
u4594HGK1bwiPxws/3ldfd7EAedTIvo0814kG/wgyD7k47GdVYrHqQ1gNfvp
plTgMKbIOiX16L6FZCU/rSHlSuxXSsOipz1oPjOQOnwqBpxlklGbN5fn2gM+
ORF9YEE5ulxxUy6s9Lzd2E1kwIcCrSBJRg92WtuuMPrFwUqni9mGJ3pA7LnQ
hyxko+rGl8+IvwpAwWS+hZEWD5pvVjLXaDMRt0XcOxlCwR2ExsiWgQEs6Vrn
wgjpg78KFZ8ZwwP4gzA79cO+C05u0JnPCapEeuXt1cdGGDCVfkmnb3cj1pBP
+FcfJiM35JiqrWQ5njtm6CKuQcYi40A3tWtcCLH8HSbRQceAHwJjiOYBt97b
4/KGXMzT50vdbW6EVxVLPKJcCRjXdfz35nm9uOnL6s4R105UKX43c6RcCBcC
xD6tP96FHQ0SlefffIMArU/hVguFQBmwUN9omgUfWPFB9swUzBf4vDImcaDS
y6qHWcKC9PKMiLtCLgqNXlh3iuZB8KtEcokNA9nlMoKv5TTcHAnOLfYDuNhw
8MTbXhaQF6WnspvJ6PPAa3hWiYFmMva8BaWt8F2Nnh1/jYr+JkPrSoO/w7Pr
1KbCqz04sSDakRLUi+Y7wlbNfObgzIKpfsv5rei3sGQiPJ8Ir+5URU1XCDHE
KXpZRBsLsiPIXXTNLlC4cjpa37YMN609kJoy3gk79eoftbdxQQ926Chv54Ba
rPmO+H+9MKWc+YEYWAndtSGqUrk8SCJkg1YJD69lBWWq8qhYmd7/yVmrFrOW
03fff8qCp8fNVH894cK+F6HyH43YqJ+5SdkwsQWmPxF22yuTgFqivnrxVRLG
2O/p+kKowQEFdhY7gArcWEbb1iEmpvz87279oADmOYzrUdQSsdXrXCV1fxOO
5vhzk8dYGOcvm2twmwz6av6e22RZ0NVaV1/TKIBnXN8Goh4d7x4fFwnY0QsH
kkVNTGX6YMLy6qHAfh7+ekywlL9DBL2RnXt35gvx6wGnjX2ijXi/35EqL84B
qRqDLrsgBgSD9L0FIX2YkGD2lXGfAfa97XcfV7OBY/qB5bK3AxMU3Q7bPGah
Y0TaakkNAvQoF3/LOdcDAjmt4utenUgIblE4uJuMxx6ceuBWOecPhb/KPa8p
qAM1Xk4VPFDNDlbrlCbjy7sd/Sy1fri52k7cP42Ni5q0Lzq/6ADwUIp0D+fi
zEXFEWO/Eny7Zv+uzqd8CL09bO6dQcIbygGG4xczYLtEwL/wglaUefE65WaU
ECI9zz18Qi5DHbuAZn8uCZNSVLZO/hYCa8J7Tds4CyR/nfOL2FIDqepFUo8J
HHTSs9lOpfVjZYtmT9h1BtbwHnVGtdRBpcu3EJEVb8DC4nTqjx8k4G/Z9eVv
eR+G+9u273zJRIb3BYUzbrngfink8jcJPphMKa0LoNeDkXl39sKztaguPr/K
MGgAqt2DNeSKu2EMozXGJrk4Evf2wtoaHsg3WYwvmOP7gOJp4p5lVKy1f9S3
slmA68ZMy1qGSKBZ/2qbWeMglj2nvpWJykKp8bBPCpM1cMEyTdFmtxBsI50f
zXYUQwDhb7aOazukRS7z+WjThjMrm6+EVLMxc727yvb5LKg4rEgbWyZAWmeu
1HRjC+6etogVu5qDCQZr/2j//Ap7s9CxJZ0PEqL3b5EtvqFM0gZvHqsBe98X
cyxoXNC2Pq1ZMlsM9JH99W9GqEBTzNyl11QPdUWaB7y8evCWb/wRKTk+8K6c
e+6n1obliypCNKvb4VEE3/NNDB8Kuq5uOJ1MgxgvxS3f7cNRnK9SkulLAMp9
FdHeud2e9y7ZarlDFji2fLgeXCZAu8eW4g71lZiup19evIaJcXK8whNebMxS
EqU/TOvE0eoHrgJbOpyNjDN+wmKhn3lU6mUYgHzrYbnS8FZknGpeHvVcAHy1
e5NJLdU47bqizkalBEabbrKWzOkp4c/PmkOVdHg5Fqz8r6YJHf0jVi6f/IYn
Bh3HF60rR7Oy2l9x2fVgzHVwqjk2hEkeTcXb+C2YH08j0vW4KHVGpTy5kgmd
j5/uVTRuheqTvx9/DuSj7RvfxP2KdBzVYhbehQTwWz1e92ysFQtVJ8WKS/pw
vQtd1Gd7HZ63v2+n7FyN2f/9OyBgfoeJpI9PGUXtONOgfdrp2ndIyFjI3J4R
iUax9rbvC2uRkPJ1lTyDi6Pe0gcOjuQjt6W55lB8OzitkhPUjXLwSNfGGzfL
aEALq85jnctA+Z68QN2nTBBr/NAbcZ+KcG6FZYw8HzgG/Hrt2bnf4P73Nv0w
B95FCCRdOdWY8Do+pKiiD+msqoDk1nI4uDBZ1PwfD0vKxa/HDhagtpJUcFck
H3Ulo5uXubxDCbfCdut9X2APZaX2NY1anHkkY7B9xSDekKJqHL/VApJynW+X
zesAN5P804IVLMy5cvb04YWxmNLmtsTNpBAfJNIXubhwUKd0qOjkbyaUVgxL
jRCJmLN5iOqhNYiKFmvajaeKgHe70c15og+cFKvDF8704p4ymsEebwomiJvZ
/N5UiREKFn5N19vgz+rKG3CtBS4XkeOGj7eBHd9OOnfjIBQkfJLYJcuDQ1lM
dUZmHxwwTtHdNd6Igyvu/ZN+xkA5e8sFdpk8YAW/uMDPSUSSUSGF5FkKEiyb
ztgDNIT+D60PFfPhm4qz3pX9dByuJnAO7/0OB9xGr0zfSIYN1Na0yLIeENGR
9S0Oq8I+ozD8K9EAcf25jgHpxaDi4x/YN68BVOK1hcetWuGku47xlW99MLyH
QmSmkKGeFBk4spEF96eLxaeDu6B0xtg3ljnXswW+TjO3G3DKfU/sr8+V8NnU
ft1yHgsm3jMOi63nYHOQAtlGX4Dpkm5qiVtagW+2ttFeby5fj19SZvlWoriY
ZS1jEw2FUYMRD9d342N9OLRfkgSxmVpBM8kC+DY5nCZyh4RKRu2qtKffMVnP
Lu7ekAN6bCS5LZL5ivHDdYPPtjSDd6Mc/YRVEfiTml/p7uLjmVxNctXzJqhK
MzeTvSDA6qPGNs9K+2DZQXmC+J520DibFiGQ52FDl3kLBrPQ+e3YJffydvww
pBn6QqcdJK6zlbQKK0HiikbFua9ElBbz7c8tJM/lcGpWh1EcrNlG/hvR9BnC
097VO4WVQvpapcWv7AphXTwH2NN8OONnKuzRr8OTyhtWzQthAaXVYVhSdhBF
QmSJbYQCVPrdGjTtRceh0smoqOi5noq2OvMrdW5O+Rn8FJnTd6bDPIcppWqI
fNntTJzj3TzhreDlYjrE+EjS7igjZptYx1tfLUA35d/yBms6wZI/NLWwigbK
F0Q+MIm1cHntZ7ELlEpoF4/tM6LmQ9qojENPZB1o6U1Tiq0JqNiZGkS9WQ4W
OTtTbm2cyyn9WDYtsB+H31tmGao0wvd7o6P3E6i4zF50W49lI1yxcm4xe10O
f1vyJ3i9A0ApXV49NELE3Z5+wrJ5DLhn29209C4FvG/63W2n96GHZJrYl208
3GfSdClGn42jO93fuu8KA1eKd/78VZ04cn2fh4IqGybeZclEGfOBNesykxFF
he8vytvTMl/BRopJhuGquR862+XBWN0Hz6+17qsuTkGyeHD9hH8zWFxYuUhh
XS5GvQ9byNrOhBi9za/HqjmYc+fFyrNSHHhVH3lOczADLxio6H7ezAWt5qzc
YpkBiBKtPfTRtxx2kf6t27GzD8cdhCfzWrkQnqvykyVNAb3QKcJOexpM5H8J
chkggRdPa0u4Gwv1Eu5rx11NhOTw8x393Y/xT6j2BaO9Qrh6tF3p3epu+B8H
gjsc
     "]]}, 
   {RGBColor[0, 1, 0], Point3DBox[CompressedData["
1:eJwNlvk7FAwbhSUKhUpIyF6EJvGqpuVBIUspkkiWoqxpo1JpISQllYq+FiQp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     "]]}, 
   {RGBColor[0, 
     NCache[
      Rational[2, 3], 0.6666666666666666], 0], Line3DBox[CompressedData["
1:eJwVV3c4Fd4blxAKLSQpe0uqr4S8IoSKCJGMsjMq0SAqUklEUjSRPbKyee29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     "]]}, 
   {RGBColor[0, 0, 1], Line3DBox[CompressedData["
1:eJwVl3c81d8fxyVKZkNUVFZFGSkRlbdUViopWgpFIaNhlErKaoiMFI2vjIxS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     "]]}},
  ImageSize->{395.29340012648566`, 376.4302822628003},
  ImageSizeRaw->Automatic,
  ViewAngle->0.4187487826521287,
  ViewCenter->{{0.5, 0.5, 0.5}, {0.5088450328710207, 0.5516896244937195}},
  ViewPoint->{0.5929971028440417, 2.8899712856471744`, -1.6572327549723922`},
  ViewVertical->{0.2718580746422115, 
   0.07813778478001045, -0.9985771890099859}]], "Output",
 CellChangeTimes->{3.7401628079247847`*^9, 3.740162848163951*^9, 
  3.740164017909853*^9},
 CellLabel->
  "Out[1257]=",ExpressionUUID->"a6c24e9b-e317-4c42-a2c1-b0edf86d9d03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Normalize", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", ".2", ",", ".5", ",", ".6"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7401635786525793`*^9, 3.740163595337639*^9}, {
  3.7401637166769753`*^9, 3.7401637437799892`*^9}},
 CellLabel->
  "In[1255]:=",ExpressionUUID->"5710a258-370d-4130-86cf-46583980cae8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.778498944161523`", ",", "0.15569978883230462`", ",", 
   "0.3892494720807615`", ",", "0.46709936649691375`"}], "}"}]], "Output",
 CellChangeTimes->{{3.7401637113029346`*^9, 3.7401637440903997`*^9}},
 CellLabel->
  "Out[1255]=",ExpressionUUID->"db9b807a-038c-4bce-be70-af0098775adb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "Gaussian", " ", "distribution", " ", "of", " ",
     "quaternino", " ", "rotations", " ", "based", " ", "around", " ", "a", 
    " ", "fixed", " ", "quat"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"setsOf3DPntDatax", " ", "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"npts", "=", "200"}], ",", 
        RowBox[{"samples", "=", "4"}], ",", 
        RowBox[{"initQuat", " ", "=", " ", 
         RowBox[{"Normalize", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", ".2", ",", ".5", ",", ".6"}], "}"}], "]"}]}], 
        ",", "qjitter", ",", "quats"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"qjitter", " ", "=", " ", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", ",", " ", ".1"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"samples", ",", "4"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"quats", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Normalize", "[", 
           RowBox[{"initQuat", "+", 
            RowBox[{"qjitter", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "samples"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"build3DPntdataset", "[", 
          RowBox[{"npts", ",", 
           RowBox[{"quats", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "samples"}], "}"}]}], "]"}]}]}], 
     "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.740162994297964*^9, 3.740163047317624*^9}, {
   3.740163147428155*^9, 3.740163349971508*^9}, {3.7401634799459333`*^9, 
   3.740163492483089*^9}, {3.7401635575143147`*^9, 3.740163564889941*^9}, {
   3.740163621025481*^9, 3.74016367033775*^9}, 3.740163731356455*^9, {
   3.7401638193280497`*^9, 3.7401638715283546`*^9}, {3.740163952055122*^9, 
   3.740163952391163*^9}, {3.7401640350673103`*^9, 3.74016417998904*^9}, 
   3.7417077964529123`*^9},ExpressionUUID->"4b32aee0-2e99-4494-a42e-\
40beab315e40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "Gaussian", " ", "distribution", " ", "of", " ",
     "quaternion", " ", "rotations", " ", "with", " ", "no", " ", "fixed", 
    " ", "base"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"setsOf3DPntDataRandom", " ", "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"npts", "=", "200"}], ",", 
        RowBox[{"samples", "=", "4"}], ",", "quats"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"quats", " ", "=", " ", 
         RowBox[{"RandomVariate", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", " ", ".1"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"samples", ",", "4"}], "}"}]}], "]"}]}], ";"}], "*)"}], 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"quats", " ", "=", " ", 
        RowBox[{"randomSphere3", "[", "samples", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"build3DPntdataset", "[", 
          RowBox[{"npts", ",", 
           RowBox[{"quats", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "samples"}], "}"}]}], "]"}]}]}], 
     "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.740162994297964*^9, 3.740163047317624*^9}, {
   3.740163147428155*^9, 3.740163349971508*^9}, {3.7401634799459333`*^9, 
   3.740163492483089*^9}, {3.7401635575143147`*^9, 3.740163564889941*^9}, {
   3.740163621025481*^9, 3.74016367033775*^9}, 3.740163731356455*^9, {
   3.7401638193280497`*^9, 3.7401638715283546`*^9}, {3.740163952055122*^9, 
   3.740163952391163*^9}, {3.7401640350673103`*^9, 3.74016417998904*^9}, {
   3.740164242260447*^9, 3.740164289044242*^9}, {3.7401643772581797`*^9, 
   3.740164415275259*^9}, {3.740164460681073*^9, 
   3.740164464545055*^9}},ExpressionUUID->"e7f6555b-2ad3-4a0f-be01-\
ce5e04f715ad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NotebookDirectory", "[", "]"}]], "Input",
 CellChangeTimes->{{3.740218695752655*^9, 3.7402187001481953`*^9}},
 CellLabel->
  "In[1260]:=",ExpressionUUID->"028e95bd-0142-4f1e-bb8c-e3f10d7a798a"],

Cell[BoxData["\<\"/home/hanson/Dropbox/Articles/Horn-soln-dir/000MAKE-FIGURES/\
\"\>"], "Output",
 CellChangeTimes->{3.740218701311553*^9},
 CellLabel->
  "Out[1260]=",ExpressionUUID->"665c8cbc-3af6-418b-afd0-203c90e797e7"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Review -- Old large3D,  large4D case with trace !=0", "Section",
 CellChangeTimes->{{3.7422390983229647`*^9, 3.7422391145550537`*^9}, {
  3.742241260360745*^9, 
  3.74224127741647*^9}},ExpressionUUID->"0c05b5bf-8bf9-4f67-8711-\
640013474e3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"test3DPFrmSets", " ", "=", " ", 
        RowBox[{"setsOf3DFrmData", "[", 
         RowBox[{"100", ",", "1000"}], "]"}]}], ",", "test", ",", "ref"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"large3DFrmmats", " ", "=", " ", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"test", "=", 
           RowBox[{
            RowBox[{"test3DPFrmSets", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", 
          RowBox[{"ref", "=", 
           RowBox[{
            RowBox[{"test3DPFrmSets", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ";", 
          RowBox[{"makeMxxmat", "[", 
           RowBox[{"makeSxxmat", "[", 
            RowBox[{"test", ",", "ref"}], "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "test3DPFrmSets", "]"}]}], "}"}]}], "]"}]}],
       ";", 
      RowBox[{"large3DFrmPnrules", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"makePnNumRule", "[", 
          RowBox[{"makeXYZnumRule", "[", 
           RowBox[{"large3DFrmmats", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "test3DPFrmSets", "]"}]}], "}"}]}], "]"}]}],
       ";"}]}], "]"}], " ", "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7417054321894417`*^9, 3.741705450529546*^9}, {
  3.7417090894001207`*^9, 3.741709118941474*^9}, {3.741709233760467*^9, 
  3.741709260850483*^9}},
 CellLabel->
  "In[140]:=",ExpressionUUID->"dc8537ec-eea1-4da2-8414-6b7dd2e0be06"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"large4Dmats", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"makeMwwmat", "[", 
        RowBox[{"makeEwwmat", "@@", 
         RowBox[{
          RowBox[{"buildX4DRMSDdataset", "[", "100", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "]"}], ",", "1000"}], 
      "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"large4DPnrules", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"makePn4NumRule", "[", 
        RowBox[{"makeWXYZnumRule", "[", 
         RowBox[{"large4Dmats", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "large4Dmats", "]"}]}], "}"}]}], "]"}]}]}], 
   "}"}], ";"}]], "Input",
 CellChangeTimes->{{3.728827714768053*^9, 3.728827748133671*^9}, {
  3.728827792313651*^9, 3.7288278254090567`*^9}, {3.728828235973421*^9, 
  3.728828304896839*^9}, {3.7288283507320213`*^9, 3.7288284023085527`*^9}, {
  3.729013548698675*^9, 
  3.729013556170617*^9}},ExpressionUUID->"a657c39c-7ade-4b9c-b853-\
202bba8f451d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AbsoluteTiming", "[", 
   RowBox[{"algebraicEpsEigVal3Frmlist", " ", "=", " ", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"xyzEpsN", "[", 
        RowBox[{"k", ",", "0", ",", "p2", ",", "p3", ",", "p4"}], "]"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
     "large3DFrmPnrules"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7290974676372137`*^9, 3.729097578042824*^9}, {
   3.729097895016704*^9, 3.729097981162187*^9}, {3.740741354247929*^9, 
   3.7407413582240067`*^9}, {3.740789959922978*^9, 3.74078996321883*^9}, {
   3.74170548160902*^9, 3.7417055048104963`*^9}, 3.741709302338789*^9, {
   3.7417095637525463`*^9, 3.7417095699159613`*^9}},
 CellLabel->
  "In[143]:=",ExpressionUUID->"2987a17c-2cdf-48bc-bfce-f282d00395d5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "for", "  ", "Trace", " ", "not", "  ", "zero"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"oneFrmRRWPnRules", " ", "=", 
   RowBox[{"Chop", "[", " ", 
    RowBox[{"makePn4NumRule", "[", 
     RowBox[{"makeWXYZnumRule", "[", " ", 
      RowBox[{"oneFrmRRRWmat", "+", " ", 
       RowBox[{".2", " ", 
        RowBox[{"IdentityMatrix", "[", "4", "]"}]}]}], "]"}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.742239250081716*^9, 3.742239291537552*^9}, {
  3.742239328065095*^9, 3.7422393331805763`*^9}, {3.742239367225281*^9, 
  3.74223939867301*^9}, {3.74224120539546*^9, 
  3.742241237217342*^9}},ExpressionUUID->"88cd970b-33a4-4938-8bb9-\
3a8cd85f0064"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", 
    RowBox[{"-", "0.799999999999983`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{"-", "58312.888171941864`"}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "7.64164393967073`*^6"}]}], ",", 
   RowBox[{"p4", "\[Rule]", 
    RowBox[{"-", "2.818339031055976`*^8"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.74223933399095*^9, 3.742239381326388*^9, 
  3.742241216159786*^9},
 CellLabel->
  "Out[324]=",ExpressionUUID->"8d9c194a-5ea6-430c-8692-49f37e36be01"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optimalEigvalEigvecFromProfile", "[", "oneFrmRRRWmat", 
  "]"}]], "Input",
 CellChangeTimes->{{3.742239427774167*^9, 3.742239454211824*^9}},
 CellLabel->
  "In[305]:=",ExpressionUUID->"d24dccfb-a6c0-4756-ad45-1ddc054e9317"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"295.7525045406323`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9815495008055491`"}], ",", 
     RowBox[{"-", "0.004990494915221991`"}], ",", 
     RowBox[{"-", "0.0014942938000456704`"}], ",", "0.19113722692065377`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.74223945230711*^9, 3.742239455329685*^9}},
 CellLabel->
  "Out[305]=",ExpressionUUID->"79fa975a-86cf-4f48-acb6-499eaf939f12"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ee", "=", 
     RowBox[{"Eigensystem", "[", "oneFrmRRRWmat", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ee", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"Normalize", "[", 
      RowBox[{"ee", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.742239460642418*^9, 3.742239539839772*^9}},
 CellLabel->
  "In[308]:=",ExpressionUUID->"d48b9751-c3eb-4921-b030-cf9104f80d3b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"295.7525045406321`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.981549500805549`"}], ",", 
     RowBox[{"-", "0.00499049491522199`"}], ",", 
     RowBox[{"-", "0.0014942938000457313`"}], ",", "0.1911372269206539`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.742239473309658*^9, 3.742239496487171*^9}, 
   3.7422395403211727`*^9},
 CellLabel->
  "Out[308]=",ExpressionUUID->"a996cc54-0ad9-44f2-a706-c74278c9f559"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.7422395935848637`*^9},ExpressionUUID->"711d3e7c-7e2e-4574-9d5b-\
560f0362b3bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Footnote - Euclidean Einstein metrics, real symmetric, 
   nonvanishing trace: construct the vierbein:\
\>", "Section",
 CellChangeTimes->{{3.7424006166832952`*^9, 
  3.742400662155596*^9}},ExpressionUUID->"9f5fb824-db21-4173-af59-\
70d1e5db8c17"],

Cell[CellGroupData[{

Cell["\<\
Build random metric - Just use Randoms, build4DPnt has other purposes...\
\>", "Subsubsection",
 CellChangeTimes->{{3.742401114423617*^9, 3.7424011180124617`*^9}, {
  3.742407251846385*^9, 
  3.742407276725583*^9}},ExpressionUUID->"f4ab5fcf-968b-4bca-8e11-\
a5cb2c4d42a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"build4DPntdataset", "[", 
   RowBox[{"npts_", ",", 
    RowBox[{"pqquats_:", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"Pi", "/", "8"}], "]"}], ",", "0", ",", "0", ",", 
         RowBox[{"Sin", "[", 
          RowBox[{"Pi", "/", "8"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"Pi", "/", "8"}], "]"}], ",", "0", ",", "0", ",", 
         RowBox[{"Sin", "[", 
          RowBox[{"Pi", "/", "8"}], "]"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"size_:", "1"}], ",", 
    RowBox[{"rmax_:", "0.05"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xRef", " ", "=", "  ", 
       RowBox[{"randomBall4CM", "[", 
        RowBox[{"npts", ",", "size"}], "]"}]}], ",", "xRefCtr", ",", 
      "xTgtCtr", ",", " ", "pquat", ",", "qquat", ",", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"xJitter", " ", "=", 
       RowBox[{"RandomVariate", "[", 
        RowBox[{
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "rmax"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"npts", ",", "4"}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", "xTgt", ",", "xTgtInit", ",", "th", ",", 
      "rotTgt"}], "}"}], ",", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"checkJitter", "=", "xJitter"}], ";"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xTgtInit", " ", "=", "  ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"xRef", " ", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "+", " ", 
         RowBox[{"xJitter", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "npts"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"to", " ", "ctr", " ", "of", " ", "mass", "  ", "xRefCtr"}], 
        "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Plus", "@@", "xRef"}], ")"}], "/", "npts"}]}], ";", " ", 
       RowBox[{"xRef", " ", "=", " ", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"#", "-", "xRefCtr"}], " ", ")"}], "&"}], ",", "xRef"}], 
         "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"to", " ", "ctr", " ", "of", " ", "mass"}], " ", "*)"}], " ", 
     RowBox[{"xTgtCtr", "=", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{"Plus", "@@", "xTgtInit"}], ")"}], "/", "npts"}]}], ";", " ", 
     
     RowBox[{"xTgtInit", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"#", "-", "xTgtCtr"}], ")"}], " ", "&"}], ",", "xTgtInit"}],
        "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pquat", ",", "qquat"}], "}"}], "=", 
      RowBox[{"pqquats", "//", "N"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rotTgt", " ", "=", 
      RowBox[{"PQbTo4DRot", "[", 
       RowBox[{"pquat", ",", "qquat"}], "]"}]}], ";", "  ", 
     RowBox[{"xTgt", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"rotTgt", ".", "#"}], ")"}], "&"}], ",", "xTgtInit"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"xTgt", ",", "xRef", ",", " ", "xTgtInit", ",", 
       RowBox[{"{", 
        RowBox[{"pquat", ",", "qquat"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.742407178130167*^9, 3.7424071834655943`*^9}, {
  3.742407239280836*^9, 
  3.7424072447545156`*^9}},ExpressionUUID->"04299289-4fda-46b7-ada0-\
45797e6099aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testggMat", " ", "=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"init", "=", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"init", "+", 
       RowBox[{"Transpose", "[", "init", "]"}]}], ")"}], "/", "2"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.742407163584638*^9, 3.742407199039626*^9}, {
  3.742407298305385*^9, 3.742407422645681*^9}},
 CellLabel->
  "In[668]:=",ExpressionUUID->"17106221-5cb3-4aea-890a-91cc7a928f3f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.642379459600967`", ",", 
     RowBox[{"-", "0.1368645733705236`"}], ",", 
     RowBox[{"-", "5.616309253481878`"}], ",", "1.4123557333593393`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.1368645733705236`"}], ",", "4.437058815261686`", ",", 
     "3.3938302202961754`", ",", "3.4197574670865496`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.616309253481878`"}], ",", "3.3938302202961754`", ",", 
     "9.056791183165046`", ",", "4.8462524230876625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.4123557333593393`", ",", "3.4197574670865496`", ",", 
     "4.8462524230876625`", ",", "7.715433718972456`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.74240742414121*^9},
 CellLabel->
  "Out[668]=",ExpressionUUID->"5925b092-473d-4932-8ec7-ffda31daeb4b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Remember that we DO have full 4D eigenvalues:", "Subsubsection",
 CellChangeTimes->{{3.742401123783752*^9, 
  3.74240113639192*^9}},ExpressionUUID->"4da445a3-b020-404c-a55f-\
12b3f7c16ef9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"the4DeigVals", "[", 
   RowBox[{"rootNum_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], 
   "]"}], ":"}]], "Input",ExpressionUUID->"cd2d8707-0d3a-44c3-afeb-\
4519dc86bf4e"],

Cell[TextData[StyleBox[" And we have the special case of real symmetric with \
no trace as well:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.742401159782987*^9, 
  3.742401175279525*^9}},ExpressionUUID->"267bbbe8-a140-4be4-aa37-\
024bde5db8e7"],

Cell[BoxData[
 RowBox[{"xyzEpsN", "[", 
  RowBox[{
   RowBox[{"k", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], ",", "p1", ",", 
   "p2", ",", "p3", ",", "p4"}], "]"}]], "Input",
 CellChangeTimes->{{3.7424012138248568`*^9, 
  3.742401243783558*^9}},ExpressionUUID->"cb8d2d0b-f6f5-4b42-bf61-\
46a859a51c23"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["<NEED to do this for general 4D, not done yet >\n   \
Build the traceful eigenvectors from the eigenvalues:\n        ALL DONE HERE \
--  and a copy earlier...",
 FontWeight->"Bold"]], "Subsubsection",
 CellChangeTimes->{{3.726073125942054*^9, 3.7260731341658707`*^9}, {
  3.7260747973918056`*^9, 3.7260748086474237`*^9}, {3.741104355022315*^9, 
  3.741104357079178*^9}, {3.742401715475638*^9, 3.74240172502776*^9}, {
  3.742401855372117*^9, 
  3.742401873363142*^9}},ExpressionUUID->"e91dd595-1ed8-4162-87c2-\
00b45a8ec09b"],

Cell[CellGroupData[{

Cell[BoxData["hornA4mat"], "Input",
 CellChangeTimes->{{3.741104380982201*^9, 3.741104383770585*^9}},
 CellLabel->
  "In[603]:=",ExpressionUUID->"c139dbc0-70dd-4ce6-a519-b21d54c54c55"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", 
     RowBox[{"a", "+", "aw"}], ",", 
     RowBox[{"b", "+", "bw"}], ",", 
     RowBox[{"c", "+", "cw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", "aw"}], ",", 
     RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", 
     RowBox[{"cc", "+", "ccw"}], ",", 
     RowBox[{"bb", "-", "bbw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", "-", "bw"}], ",", 
     RowBox[{"cc", "-", "ccw"}], ",", 
     RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", 
     RowBox[{"aa", "+", "aaw"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "-", "cw"}], ",", 
     RowBox[{"bb", "+", "bbw"}], ",", 
     RowBox[{"aa", "-", "aaw"}], ",", 
     RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.741104384461095*^9},
 CellLabel->
  "Out[603]=",ExpressionUUID->"4756678b-22fb-4175-bbf5-ecdb8e93dea3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hornA4SymMat", "=", 
  RowBox[{"hornA4mat", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"aw", "\[Rule]", "0"}], ",", 
     RowBox[{"bw", "\[Rule]", "0"}], ",", 
     RowBox[{"cw", "\[Rule]", "0"}], ",", 
     RowBox[{"aaw", "\[Rule]", "0"}], ",", 
     RowBox[{"bbw", "\[Rule]", "0"}], ",", 
     RowBox[{"ccw", "\[Rule]", "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.7411043947981453`*^9, 3.741104453249879*^9}},
 CellLabel->
  "In[604]:=",ExpressionUUID->"2417d4fe-c9fb-4dfd-a8d8-816f69fa02c2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "+", "x", "+", "y", "+", "z"}], ",", "a", ",", "b", ",", 
     "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"w", "+", "x", "-", "y", "-", "z"}], ",", "cc", ",", "bb"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "cc", ",", 
     RowBox[{"w", "-", "x", "+", "y", "-", "z"}], ",", "aa"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "bb", ",", "aa", ",", 
     RowBox[{"w", "-", "x", "-", "y", "+", "z"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.741104457798039*^9},
 CellLabel->
  "Out[604]=",ExpressionUUID->"bf1970c4-0f1a-46c8-b445-70aa595dc36d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"optSolvep1", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"hornA4SymMat", "[", 
            RowBox[{"[", 
             RowBox[{"i", "+", "1"}], "]"}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{"1", ",", "vx", ",", "vy", ",", "vz"}], "}"}]}], " ", "-",
           " ", 
          RowBox[{"e", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"vx", ",", "vy", ",", "vz"}], "}"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"vx", ",", "vy", ",", "vz"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.725305187567337*^9, 3.725305291481596*^9}, {
  3.725305341705224*^9, 3.7253054026085243`*^9}, {3.725305527708928*^9, 
  3.725305548367922*^9}, {3.7411046468447*^9, 3.741104658202479*^9}},
 CellLabel->
  "In[607]:=",ExpressionUUID->"fabc4f43-a0f0-477d-b89e-b45e25bdc35f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"vx", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", "aa"}], "-", 
          RowBox[{"b", " ", "bb"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "bb"}], "+", 
          RowBox[{"cc", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bb", " ", "c"}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "aa"}], " ", "cc"}], "-", 
          RowBox[{"bb", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"bb", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
         RowBox[{
          SuperscriptBox["bb", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox["aa", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
          
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["cc", "2"], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], 
              ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], ",", 
   RowBox[{"vy", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "bb"}], "+", 
          RowBox[{"cc", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bb", " ", "cc"}], "+", 
          RowBox[{"aa", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["bb", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
       
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
       
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["cc", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{"vz", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"aa", " ", "cc"}], "+", 
          RowBox[{"bb", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bb", " ", "cc"}], "+", 
          RowBox[{"aa", " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["cc", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
       RowBox[{
        SuperscriptBox["bb", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
       
       RowBox[{
        SuperscriptBox["aa", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], "+", 
       
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["cc", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.741104669641706*^9},
 CellLabel->
  "Out[607]=",ExpressionUUID->"e1e58965-32d2-41d2-a0b3-4354191a9d41"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Factor", " ", "out", " ", "denominator"}], " ", "*)"}], 
  RowBox[{"optQuatBarep1", " ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
           RowBox[{
            SuperscriptBox["bb", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["aa", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"e", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["cc", "2"], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"e", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], 
               " ", 
               RowBox[{"(", 
                RowBox[{"e", "-", "w", "-", "x", "+", "y", "+", "z"}], 
                ")"}]}]}], ")"}]}]}], ")"}], 
         RowBox[{"{", 
          RowBox[{"1", ",", "vx", ",", "vy", ",", "vz"}], "}"}]}], "/.", 
        "optSolvep1"}], "//", "Expand"}], "//", "FullSimplify"}], ")"}], "/.", 
    RowBox[{"e", "\[Rule]", "eigval"}]}]}]}]], "Input",
 CellChangeTimes->{{3.725305617235581*^9, 3.725305668680132*^9}, {
  3.725584365937842*^9, 3.725584373803894*^9}, {3.726074846897582*^9, 
  3.7260748600242662`*^9}, {3.7411046855899143`*^9, 3.741104687559293*^9}, {
  3.741104829148344*^9, 3.741104882236814*^9}, {3.741105006542178*^9, 
  3.741105029603405*^9}},
 CellLabel->
  "In[614]:=",ExpressionUUID->"3d1087fe-da16-439f-ac9d-d0d6a1e0d1e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
    RowBox[{
     SuperscriptBox["bb", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}], 
    "+", 
    RowBox[{
     SuperscriptBox["aa", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
     
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["cc", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "aa"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "bb"}], "+", 
       RowBox[{"c", " ", "cc"}]}], ")"}]}], "-", 
    RowBox[{"bb", " ", "c", " ", "eigval"}], "-", 
    RowBox[{"b", " ", "cc", " ", "eigval"}], "+", 
    RowBox[{"bb", " ", "c", " ", "w"}], "+", 
    RowBox[{"b", " ", "cc", " ", "w"}], "-", 
    RowBox[{"bb", " ", "c", " ", "x"}], "-", 
    RowBox[{"b", " ", "cc", " ", "x"}], "+", 
    RowBox[{"bb", " ", "c", " ", "y"}], "-", 
    RowBox[{"b", " ", "cc", " ", "y"}], "-", 
    RowBox[{"bb", " ", "c", " ", "z"}], "+", 
    RowBox[{"b", " ", "cc", " ", "z"}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["aa", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", "bb"}], "+", 
       RowBox[{"cc", " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
         ")"}]}]}], ")"}]}], "-", 
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bb", " ", "cc"}], "+", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["bb", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"aa", " ", "cc"}], "+", 
       RowBox[{"bb", " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}], "-", 
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bb", " ", "cc"}], "+", 
       RowBox[{"aa", " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["cc", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
         ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7411048322839403`*^9, 3.7411048837435102`*^9}, {
  3.74110500850177*^9, 3.741105031722686*^9}},
 CellLabel->
  "Out[614]=",ExpressionUUID->"7b3655f0-d5cd-4370-9f24-3f40761228dd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvecRMSDp1", "[", 
   RowBox[{
   "eigval_", ",", "w_", ",", "x_", ",", "y_", ",", "z_", ",", "a_", ",", 
    "b_", ",", "c_", ",", "aa_", ",", "bb_", ",", "cc_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qbare", " ", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
          RowBox[{
           SuperscriptBox["bb", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
            ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["aa", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
            ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}],
            " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["cc", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "aa"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"b", " ", "bb"}], "+", 
             RowBox[{"c", " ", "cc"}]}], ")"}]}], "-", 
          RowBox[{"bb", " ", "c", " ", "eigval"}], "-", 
          RowBox[{"b", " ", "cc", " ", "eigval"}], "+", 
          RowBox[{"bb", " ", "c", " ", "w"}], "+", 
          RowBox[{"b", " ", "cc", " ", "w"}], "-", 
          RowBox[{"bb", " ", "c", " ", "x"}], "-", 
          RowBox[{"b", " ", "cc", " ", "x"}], "+", 
          RowBox[{"bb", " ", "c", " ", "y"}], "-", 
          RowBox[{"b", " ", "cc", " ", "y"}], "-", 
          RowBox[{"bb", " ", "c", " ", "z"}], "+", 
          RowBox[{"b", " ", "cc", " ", "z"}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["aa", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"aa", " ", "bb"}], "+", 
             RowBox[{"cc", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}]}]}], ")"}]}], "-", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"bb", " ", "cc"}], "+", 
             RowBox[{"aa", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["bb", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"aa", " ", "cc"}], "+", 
             RowBox[{"bb", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "-", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"bb", " ", "cc"}], "+", 
             RowBox[{"aa", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["cc", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}]}], "}"}]}], ",", "norm"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"norm", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"qbare", ".", "qbare"}], "]"}]}], ";", " ", 
     RowBox[{"qbare", "/", "norm"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.725575612366349*^9, 3.72557570949866*^9}, {
   3.7255842445435457`*^9, 3.725584257559821*^9}, {3.72558430173621*^9, 
   3.725584313739051*^9}, {3.7255849796150427`*^9, 3.7255850062316008`*^9}, {
   3.725585037682225*^9, 3.725585073930138*^9}, {3.725585120799941*^9, 
   3.725585123871475*^9}, {3.725585158541409*^9, 3.72558516776853*^9}, {
   3.741104614930942*^9, 3.741104623066741*^9}, {3.7411049544875793`*^9, 
   3.7411049628311777`*^9}, 3.741105089140779*^9},
 CellLabel->
  "In[615]:=",ExpressionUUID->"45419f6b-8814-4409-bfed-7ac7277d9cbb"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["And we  DO HAVE the  Metric Eigenvector routine:",
 FontSlant->"Italic",
 FontVariations->{"Underline"->True}]], "Subsubsection",
 CellChangeTimes->{{3.7424011810390577`*^9, 3.742401197015031*^9}, 
   3.742401739643125*^9, {3.742401773244048*^9, 
   3.742401777571488*^9}},ExpressionUUID->"58a3bd17-dd25-4a13-a459-\
f16e38edf439"],

Cell[TextData[StyleBox["\nLook here in the morning, does W make a \
difference... EXACTLY THE SAME!!",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.741055192751833*^9, 3.741055222696074*^9}, {
  3.741055275991503*^9, 3.7410552994473877`*^9}, {3.7411074084124527`*^9, 
  3.741107416117083*^9}, {3.7424017987152*^9, 
  3.742401802419571*^9}},ExpressionUUID->"1b1c9abe-6125-42de-a493-\
13d99a2cb15c"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"eigenvecRMSDp1", "[", 
    RowBox[{
    "98.9712467004448`", ",", "w", ",", "x", ",", "y", ",", "z", ",", "a", 
     ",", "b", ",", "c", ",", "aa", ",", "bb", ",", "cc"}], "]"}], " ", "/.", 
   "testqqRule"}]}]], "Input",
 CellChangeTimes->{{3.741055031057543*^9, 3.7410550605254993`*^9}, {
  3.74105523925893*^9, 3.741055269211606*^9}, {3.741107365540019*^9, 
  3.74110739341429*^9}},
 CellLabel->
  "In[624]:=",ExpressionUUID->"86e23ef4-a188-4787-b314-c99cc6e6eb5b"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "0.9792171403627875`"}], ",", 
    RowBox[{"-", "0.003592334333214316`"}], ",", 
    RowBox[{"-", "0.0003948989172451336`"}], ",", "0.20278247263658802`"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.741107605803856*^9, 3.741107611495099*^9}},
 CellLabel->
  "In[627]:=",ExpressionUUID->"9c798536-07f7-4892-bcc4-b2342bfa2559"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvecRMSD", "[", 
   RowBox[{
   "eigval_", ",", "x_", ",", "y_", ",", "z_", ",", "a_", ",", "b_", ",", 
    "c_", ",", "aa_", ",", "bb_", ",", "cc_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qbare", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
          RowBox[{
           SuperscriptBox["cc", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["bb", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["aa", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ",", 
         
         RowBox[{
          RowBox[{"a", " ", 
           SuperscriptBox["aa", "2"]}], "-", 
          RowBox[{"aa", " ", "b", " ", "bb"}], "-", 
          RowBox[{"aa", " ", "c", " ", "cc"}], "-", 
          RowBox[{"b", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
          RowBox[{"bb", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}]}]}], ",", 
         
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "aa", " ", "bb"}], "+", 
          RowBox[{"b", " ", 
           SuperscriptBox["bb", "2"]}], "-", 
          RowBox[{"bb", " ", "c", " ", "cc"}], "-", 
          RowBox[{"a", " ", "cc", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}]}], "-", 
          RowBox[{"aa", "  ", "c", 
           RowBox[{"(", " ", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "+", "y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}]}], ",", 
         
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "aa", " ", "cc"}], "-", 
          RowBox[{"b", " ", "bb", " ", "cc"}], "+", 
          RowBox[{"c", " ", 
           SuperscriptBox["cc", "2"]}], "-", 
          RowBox[{"a", " ", "bb", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{"aa", " ", "b", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}], "-", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "+", "x", "-", "y", "+", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "x", "+", "y", "+", "z"}], ")"}]}]}]}], 
        "}"}]}], ",", "norm"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"norm", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"qbare", ".", "qbare"}], "]"}]}], ";", " ", 
     RowBox[{"qbare", "/", "norm"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.725575612366349*^9, 3.72557570949866*^9}, {
  3.7255842445435457`*^9, 3.725584257559821*^9}, {3.72558430173621*^9, 
  3.725584313739051*^9}, {3.7255849796150427`*^9, 3.7255850062316008`*^9}, {
  3.725585037682225*^9, 3.725585073930138*^9}, {3.725585120799941*^9, 
  3.725585123871475*^9}, {3.725585158541409*^9, 3.72558516776853*^9}},
 CellLabel->
  "In[283]:=",ExpressionUUID->"fbdc31cd-dc45-43a9-89d3-dd78f2213d3b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvecRMSDp1", "[", 
   RowBox[{
   "eigval_", ",", "w_", ",", "x_", ",", "y_", ",", "z_", ",", "a_", ",", 
    "b_", ",", "c_", ",", "aa_", ",", "bb_", ",", "cc_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qbare", " ", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
          RowBox[{
           SuperscriptBox["bb", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
            ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["aa", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
            ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}],
            " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["cc", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "aa"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"b", " ", "bb"}], "+", 
             RowBox[{"c", " ", "cc"}]}], ")"}]}], "-", 
          RowBox[{"bb", " ", "c", " ", "eigval"}], "-", 
          RowBox[{"b", " ", "cc", " ", "eigval"}], "+", 
          RowBox[{"bb", " ", "c", " ", "w"}], "+", 
          RowBox[{"b", " ", "cc", " ", "w"}], "-", 
          RowBox[{"bb", " ", "c", " ", "x"}], "-", 
          RowBox[{"b", " ", "cc", " ", "x"}], "+", 
          RowBox[{"bb", " ", "c", " ", "y"}], "-", 
          RowBox[{"b", " ", "cc", " ", "y"}], "-", 
          RowBox[{"bb", " ", "c", " ", "z"}], "+", 
          RowBox[{"b", " ", "cc", " ", "z"}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["aa", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"aa", " ", "bb"}], "+", 
             RowBox[{"cc", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}]}]}], ")"}]}], "-", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"bb", " ", "cc"}], "+", 
             RowBox[{"aa", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["bb", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"aa", " ", "cc"}], "+", 
             RowBox[{"bb", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "-", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"bb", " ", "cc"}], "+", 
             RowBox[{"aa", " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["cc", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
               ")"}]}]}], ")"}]}]}]}], "}"}]}], ",", "norm"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"norm", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"qbare", ".", "qbare"}], "]"}]}], ";", " ", 
     RowBox[{"qbare", "/", "norm"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.725575612366349*^9, 3.72557570949866*^9}, {
   3.7255842445435457`*^9, 3.725584257559821*^9}, {3.72558430173621*^9, 
   3.725584313739051*^9}, {3.7255849796150427`*^9, 3.7255850062316008`*^9}, {
   3.725585037682225*^9, 3.725585073930138*^9}, {3.725585120799941*^9, 
   3.725585123871475*^9}, {3.725585158541409*^9, 3.72558516776853*^9}, {
   3.741104614930942*^9, 3.741104623066741*^9}, {3.7411049544875793`*^9, 
   3.7411049628311777`*^9}, 3.741105089140779*^9},
 CellLabel->
  "In[694]:=",ExpressionUUID->"f78ee2e3-826a-4479-b8ee-eb835575c1d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"wxyzToggRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"gg11", "+", "gg22", "+", "gg33", "+", "gg44"}], ")"}]}]}], 
     ",", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"gg11", "+", "gg22", "-", "gg33", "-", "gg44"}], ")"}]}]}], 
     ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"gg11", "-", "gg22", "+", "gg33", "-", "gg44"}], ")"}]}]}], 
     ",", 
     RowBox[{"z", "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"gg11", "-", "gg22", "-", "gg33", "+", "gg44"}], ")"}]}]}], 
     ",", 
     RowBox[{"a", "\[Rule]", "gg12"}], ",", 
     RowBox[{"aw", "\[Rule]", "0"}], ",", 
     RowBox[{"b", "\[Rule]", "gg13"}], ",", 
     RowBox[{"bw", "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", "gg14"}], ",", 
     RowBox[{"cw", "\[Rule]", "0"}], ",", 
     RowBox[{"aa", "\[Rule]", "gg34"}], ",", 
     RowBox[{"aaw", "\[Rule]", "0"}], ",", 
     RowBox[{"bb", "\[Rule]", "gg24"}], ",", 
     RowBox[{"bbw", "\[Rule]", "0"}], ",", 
     RowBox[{"cc", "\[Rule]", "gg23"}], ",", 
     RowBox[{"ccw", "\[Rule]", "0"}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742472061738214*^9, 3.742472091643043*^9}},
 CellLabel->
  "In[714]:=",ExpressionUUID->"fa916e5e-0dd3-4c08-9536-88b51038eaf0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"qbaregg", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "aa", " ", "bb", " ", "cc"}], "+", 
        RowBox[{
         SuperscriptBox["bb", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], ")"}]}],
         "+", 
        RowBox[{
         SuperscriptBox["aa", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], ")"}]}],
         "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], ")"}], 
         " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["cc", "2"], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
             ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
             ")"}]}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "aa"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"b", " ", "bb"}], "+", 
           RowBox[{"c", " ", "cc"}]}], ")"}]}], "-", 
        RowBox[{"bb", " ", "c", " ", "eigval"}], "-", 
        RowBox[{"b", " ", "cc", " ", "eigval"}], "+", 
        RowBox[{"bb", " ", "c", " ", "w"}], "+", 
        RowBox[{"b", " ", "cc", " ", "w"}], "-", 
        RowBox[{"bb", " ", "c", " ", "x"}], "-", 
        RowBox[{"b", " ", "cc", " ", "x"}], "+", 
        RowBox[{"bb", " ", "c", " ", "y"}], "-", 
        RowBox[{"b", " ", "cc", " ", "y"}], "-", 
        RowBox[{"bb", " ", "c", " ", "z"}], "+", 
        RowBox[{"b", " ", "cc", " ", "z"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["aa", "2"], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
             ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
             ")"}]}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"aa", " ", "bb"}], "+", 
           RowBox[{"cc", " ", 
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
             ")"}]}]}], ")"}]}], "-", 
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"bb", " ", "cc"}], "+", 
           RowBox[{"aa", " ", 
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["bb", "2"], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "+", "x", "+", "y", "-", "z"}], 
             ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
             ")"}]}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"aa", " ", "cc"}], "+", 
           RowBox[{"bb", " ", 
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
             ")"}]}]}], ")"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"bb", " ", "cc"}], "+", 
           RowBox[{"aa", " ", 
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["cc", "2"], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "+", "x", "-", "y", "+", "z"}], 
             ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"eigval", "-", "w", "-", "x", "+", "y", "+", "z"}], 
             ")"}]}]}], ")"}]}]}]}], "}"}], "/.", "wxyzToggRule"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.742472018936179*^9, 3.7424720210325117`*^9}, {
  3.742472099732152*^9, 3.7424721134873734`*^9}},
 CellLabel->
  "In[716]:=",ExpressionUUID->"91a7c7d2-059b-4dd2-ae66-483ed5882beb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["eigval", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["gg24", "2"], " ", "gg33"}], "+", 
    RowBox[{"2", " ", "gg23", " ", "gg24", " ", "gg34"}], "-", 
    RowBox[{"gg22", " ", 
     SuperscriptBox["gg34", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["gg23", "2"], " ", "gg44"}], "+", 
    RowBox[{"gg22", " ", "gg33", " ", "gg44"}], "+", 
    RowBox[{
     SuperscriptBox["eigval", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"gg22", "+", "gg33", "+", "gg44"}], ")"}]}], "+", 
    RowBox[{"eigval", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["gg23", "2"], "+", 
       SuperscriptBox["gg24", "2"], "-", 
       RowBox[{"gg22", " ", "gg33"}], "+", 
       SuperscriptBox["gg34", "2"], "-", 
       RowBox[{"gg22", " ", "gg44"}], "-", 
       RowBox[{"gg33", " ", "gg44"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["eigval", "2"]}], " ", "gg12"}], "+", 
    RowBox[{"gg14", " ", "gg24", " ", "gg33"}], "-", 
    RowBox[{"gg14", " ", "gg23", " ", "gg34"}], "-", 
    RowBox[{"gg13", " ", "gg24", " ", "gg34"}], "+", 
    RowBox[{"gg12", " ", 
     SuperscriptBox["gg34", "2"]}], "+", 
    RowBox[{"gg13", " ", "gg23", " ", "gg44"}], "-", 
    RowBox[{"gg12", " ", "gg33", " ", "gg44"}], "+", 
    RowBox[{"eigval", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "gg13"}], " ", "gg23"}], "-", 
       RowBox[{"gg14", " ", "gg24"}], "+", 
       RowBox[{"gg12", " ", 
        RowBox[{"(", 
         RowBox[{"gg33", "+", "gg44"}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["eigval", "2"]}], " ", "gg13"}], "-", 
    RowBox[{"gg14", " ", "gg23", " ", "gg24"}], "+", 
    RowBox[{"gg13", " ", 
     SuperscriptBox["gg24", "2"]}], "+", 
    RowBox[{"gg14", " ", "gg22", " ", "gg34"}], "-", 
    RowBox[{"gg12", " ", "gg24", " ", "gg34"}], "-", 
    RowBox[{"gg13", " ", "gg22", " ", "gg44"}], "+", 
    RowBox[{"gg12", " ", "gg23", " ", "gg44"}], "+", 
    RowBox[{"eigval", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "gg12"}], " ", "gg23"}], "-", 
       RowBox[{"gg14", " ", "gg34"}], "+", 
       RowBox[{"gg13", " ", 
        RowBox[{"(", 
         RowBox[{"gg22", "+", "gg44"}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["eigval", "2"]}], " ", "gg14"}], "-", 
    RowBox[{"gg13", " ", "gg23", " ", "gg24"}], "+", 
    RowBox[{"gg12", " ", "gg24", " ", "gg33"}], "+", 
    RowBox[{"gg14", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["gg23", "2"], "-", 
       RowBox[{"gg22", " ", "gg33"}]}], ")"}]}], "+", 
    RowBox[{"gg13", " ", "gg22", " ", "gg34"}], "-", 
    RowBox[{"gg12", " ", "gg23", " ", "gg34"}], "+", 
    RowBox[{"eigval", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "gg12"}], " ", "gg24"}], "+", 
       RowBox[{"gg14", " ", 
        RowBox[{"(", 
         RowBox[{"gg22", "+", "gg33"}], ")"}]}], "-", 
       RowBox[{"gg13", " ", "gg34"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7424721063838243`*^9, 3.742472114440261*^9}},
 CellLabel->
  "Out[716]=",ExpressionUUID->"11c8e46b-7f69-4134-b222-a7401a4c3aed"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sym", "[", 
       RowBox[{"\"\<gg\>\"", ",", "i", ",", "j"}], "]"}], "-", 
      RowBox[{"gg", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "i", ",", "4"}], "}"}]}], "]"}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.7424722350340767`*^9, 3.742472296400216*^9}, {
  3.74247250393085*^9, 
  3.742472505613865*^9}},ExpressionUUID->"4b9513b5-920b-47a4-bd5b-\
9b7f5f448cf6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"gg11", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg12", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg13", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg14", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg22", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg23", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg24", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"2", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg33", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg34", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"3", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"gg44", "-", 
    RowBox[{"gg", "\[LeftDoubleBracket]", 
     RowBox[{"4", ",", "4"}], "\[RightDoubleBracket]"}]}]}], "}"}]], "Output",\

 CellChangeTimes->{3.7424722992745123`*^9},
 CellLabel->
  "Out[717]=",ExpressionUUID->"286cc935-c5af-4ee0-bb79-8ebf4775b3e1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here is the element of the metric vierbein we need,
     later return to making a more elegant version of the eigval[gg]?\
\>", "Subsubsection",
 CellChangeTimes->{{3.7424725510153112`*^9, 
  3.742472582901046*^9}},ExpressionUUID->"651cf408-eab6-4f1b-8424-\
cf205efe2fce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvecMetric", "[", 
   RowBox[{"eigval_", ",", "gg_"}], "]"}], ":=", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Build", " ", "a", " ", "vierbein"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"gg11", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg12", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg13", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg14", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg22", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg23", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg24", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"2", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg33", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg34", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"3", ",", "4"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"gg44", "=", 
       RowBox[{"gg", "\[LeftDoubleBracket]", 
        RowBox[{"4", ",", "4"}], "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"vbbare", " ", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["eigval", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["gg24", "2"], " ", "gg33"}], "+", 
            RowBox[{"2", " ", "gg23", " ", "gg24", " ", "gg34"}], "-", 
            RowBox[{"gg22", " ", 
             SuperscriptBox["gg34", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["gg23", "2"], " ", "gg44"}], "+", 
            RowBox[{"gg22", " ", "gg33", " ", "gg44"}], "+", 
            RowBox[{
             SuperscriptBox["eigval", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"gg22", "+", "gg33", "+", "gg44"}], ")"}]}], "+", 
            RowBox[{"eigval", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["gg23", "2"], "+", 
               SuperscriptBox["gg24", "2"], "-", 
               RowBox[{"gg22", " ", "gg33"}], "+", 
               SuperscriptBox["gg34", "2"], "-", 
               RowBox[{"gg22", " ", "gg44"}], "-", 
               RowBox[{"gg33", " ", "gg44"}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["eigval", "2"]}], " ", "gg12"}], "+", 
            RowBox[{"gg14", " ", "gg24", " ", "gg33"}], "-", 
            RowBox[{"gg14", " ", "gg23", " ", "gg34"}], "-", 
            RowBox[{"gg13", " ", "gg24", " ", "gg34"}], "+", 
            RowBox[{"gg12", " ", 
             SuperscriptBox["gg34", "2"]}], "+", 
            RowBox[{"gg13", " ", "gg23", " ", "gg44"}], "-", 
            RowBox[{"gg12", " ", "gg33", " ", "gg44"}], "+", 
            RowBox[{"eigval", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "gg13"}], " ", "gg23"}], "-", 
               RowBox[{"gg14", " ", "gg24"}], "+", 
               RowBox[{"gg12", " ", 
                RowBox[{"(", 
                 RowBox[{"gg33", "+", "gg44"}], ")"}]}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["eigval", "2"]}], " ", "gg13"}], "-", 
            RowBox[{"gg14", " ", "gg23", " ", "gg24"}], "+", 
            RowBox[{"gg13", " ", 
             SuperscriptBox["gg24", "2"]}], "+", 
            RowBox[{"gg14", " ", "gg22", " ", "gg34"}], "-", 
            RowBox[{"gg12", " ", "gg24", " ", "gg34"}], "-", 
            RowBox[{"gg13", " ", "gg22", " ", "gg44"}], "+", 
            RowBox[{"gg12", " ", "gg23", " ", "gg44"}], "+", 
            RowBox[{"eigval", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "gg12"}], " ", "gg23"}], "-", 
               RowBox[{"gg14", " ", "gg34"}], "+", 
               RowBox[{"gg13", " ", 
                RowBox[{"(", 
                 RowBox[{"gg22", "+", "gg44"}], ")"}]}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["eigval", "2"]}], " ", "gg14"}], "-", 
            RowBox[{"gg13", " ", "gg23", " ", "gg24"}], "+", 
            RowBox[{"gg12", " ", "gg24", " ", "gg33"}], "+", 
            RowBox[{"gg14", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["gg23", "2"], "-", 
               RowBox[{"gg22", " ", "gg33"}]}], ")"}]}], "+", 
            RowBox[{"gg13", " ", "gg22", " ", "gg34"}], "-", 
            RowBox[{"gg12", " ", "gg23", " ", "gg34"}], "+", 
            RowBox[{"eigval", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "gg12"}], " ", "gg24"}], "+", 
               RowBox[{"gg14", " ", 
                RowBox[{"(", 
                 RowBox[{"gg22", "+", "gg33"}], ")"}]}], "-", 
               RowBox[{"gg13", " ", "gg34"}]}], ")"}]}]}]}], "}"}]}], ",", 
        "norm"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"norm", "=", " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"vbbare", ".", "vbbare"}], "]"}]}], ";", " ", 
       RowBox[{"vbbare", "/", "norm"}]}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.725575612366349*^9, 3.72557570949866*^9}, {
   3.7255842445435457`*^9, 3.725584257559821*^9}, {3.72558430173621*^9, 
   3.725584313739051*^9}, {3.7255849796150427`*^9, 3.7255850062316008`*^9}, {
   3.725585037682225*^9, 3.725585073930138*^9}, {3.725585120799941*^9, 
   3.725585123871475*^9}, {3.725585158541409*^9, 3.72558516776853*^9}, {
   3.741104614930942*^9, 3.741104623066741*^9}, {3.7411049544875793`*^9, 
   3.7411049628311777`*^9}, 3.741105089140779*^9, {3.742472156330155*^9, 
   3.742472231171352*^9}, {3.742472310691003*^9, 3.742472350780237*^9}, 
   3.742472383306925*^9, {3.7424724206365023`*^9, 3.742472446707629*^9}},
 CellLabel->
  "In[718]:=",ExpressionUUID->"a1740eaa-3d73-47b6-b990-c27dc6b119e9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check our random matrix above:", "Subsubsection",
 CellChangeTimes->{{3.742407482715917*^9, 
  3.7424074908917427`*^9}},ExpressionUUID->"01551329-7906-48c4-90f2-\
334c0c0b4047"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Tr", "[", "testggMat", "]"}], ",", 
    RowBox[{"Det", "[", "testggMat", "]"}], ",", 
    RowBox[{"testggMat", "-", 
     RowBox[{"Transpose", "[", "testggMat", "]"}]}], ",", 
    RowBox[{"Eigenvalues", "[", "testggMat", "]"}]}], "}"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7410535054432077`*^9, 3.741053535318554*^9}, 
   3.741053583860838*^9, {3.7424074416676292`*^9, 3.742407461624772*^9}},
 CellLabel->
  "In[669]:=",ExpressionUUID->"c25e6845-deca-442b-a630-90e688a0ce84"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"22.851663177000155`", ",", 
   RowBox[{"-", "713.9402368293287`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"16.119836234940152`", ",", "7.217423637348224`", ",", 
     RowBox[{"-", "2.731859813445628`"}], ",", "2.2462631181574118`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741053536314899*^9, 3.741053584546085*^9, 
  3.742407465690949*^9},
 CellLabel->
  "Out[669]=",ExpressionUUID->"1eb53303-1ab5-42ad-b0df-cb3225c8b041"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eigVecgg1", "=", 
   RowBox[{"Eigenvectors", "[", "testggMat", "]"}]}], ";", 
  RowBox[{"eigVecgg1", " ", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.74110709526422*^9, 3.741107100847741*^9}, {
  3.742407545899205*^9, 3.7424075794112883`*^9}},
 CellLabel->
  "In[670]:=",ExpressionUUID->"85d1d273-c5d2-46a4-bdbc-0b3913dab1e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.23375050218837864`", ",", 
   RowBox[{"-", "0.36902164415765565`"}], ",", 
   RowBox[{"-", "0.7268373863510279`"}], ",", 
   RowBox[{"-", "0.5299916439645702`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741107101331461*^9, 3.74240758106171*^9},
 CellLabel->
  "Out[670]=",ExpressionUUID->"eb94813b-d146-4401-a1a8-75b8e4c801b6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testqqRule", " ", "=", 
  RowBox[{"makeWXYZnumRule", "[", "testggMat", "]"}]}]], "Input",
 CellChangeTimes->{{3.741053755340493*^9, 3.741053767472752*^9}, 
   3.7424075953582697`*^9},
 CellLabel->
  "In[671]:=",ExpressionUUID->"0fcfb88d-f9c3-470f-9a4d-e6f847abe1a2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", "\[Rule]", "5.712915794250039`"}], ",", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"-", "2.673196656818712`"}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"-", "0.36333047286703213`"}]}], ",", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"-", "1.0340092049633274`"}]}], ",", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"-", "0.1368645733705236`"}]}], ",", 
   RowBox[{"aw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"b", "\[Rule]", 
    RowBox[{"-", "5.616309253481878`"}]}], ",", 
   RowBox[{"bw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"c", "\[Rule]", "1.4123557333593393`"}], ",", 
   RowBox[{"cw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"aa", "\[Rule]", "4.8462524230876625`"}], ",", 
   RowBox[{"aaw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"bb", "\[Rule]", "3.4197574670865496`"}], ",", 
   RowBox[{"bbw", "\[Rule]", "0.`"}], ",", 
   RowBox[{"cc", "\[Rule]", "3.3938302202961754`"}], ",", 
   RowBox[{"ccw", "\[Rule]", "0.`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741053770781211*^9, 3.742407616339054*^9},
 CellLabel->
  "Out[671]=",ExpressionUUID->"aba50ed0-1cf5-4a02-b748-0fdbafd1a067"]
}, Open  ]],

Cell[TextData[StyleBox["Need the rule for  a symmetric real matrix:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.742407761697381*^9, 3.7424077660737762`*^9}, {
  3.7424096130501347`*^9, 
  3.742409623665876*^9}},ExpressionUUID->"2976cdff-a8fb-4892-8e3f-\
5dd4b69f2d60"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"basicGGMetric", "=", 
  RowBox[{"Array", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sym", "[", 
      RowBox[{"\"\<gg\>\"", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"#1", ">", "#2"}], ",", "#2", ",", "#1"}], "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"#1", ">", "#2"}], ",", "#1", ",", "#2"}], "]"}]}], "]"}], 
     "&"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.742409767331752*^9, 3.742409794264636*^9}},
 CellLabel->
  "In[712]:=",ExpressionUUID->"6294a625-fb00-4b3f-929e-6923be75de0b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"gg11", ",", "gg12", ",", "gg13", ",", "gg14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gg12", ",", "gg22", ",", "gg23", ",", "gg24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gg13", ",", "gg23", ",", "gg33", ",", "gg34"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gg14", ",", "gg24", ",", "gg34", ",", "gg44"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7424097418607683`*^9, {3.74240978459205*^9, 3.7424097949520483`*^9}, 
   3.7424099595605173`*^9},
 CellLabel->
  "Out[712]=",ExpressionUUID->"b65ec3db-fb02-4289-8189-988e045f46de"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"basicGGMetric", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.742409876175098*^9, 3.7424098813911037`*^9}},
 CellLabel->
  "In[709]:=",ExpressionUUID->"7b7fb898-e0b1-425a-8b39-b40121235e33"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"gg11", "gg12", "gg13", "gg14"},
     {"gg12", "gg22", "gg23", "gg24"},
     {"gg13", "gg23", "gg33", "gg34"},
     {"gg14", "gg24", "gg34", "gg44"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7424098820847397`*^9},
 CellLabel->
  "Out[709]//MatrixForm=",ExpressionUUID->"7b600acf-16e5-468d-87b8-\
1b25a3e75781"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"wxyzToggRule", "=", 
   RowBox[{
    RowBox[{"makeWXYZnumRule", "[", 
     RowBox[{"Array", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"sym", "[", 
         RowBox[{"\"\<gg\>\"", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"#1", ">", "#2"}], ",", "#2", ",", "#1"}], "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"#1", ">", "#2"}], ",", "#1", ",", "#2"}], "]"}]}], "]"}],
         "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4"}], "}"}]}], "]"}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7424078290323467`*^9, 3.742407899478426*^9}, {
  3.742407945851605*^9, 3.742407957673038*^9}, {3.7424096326122017`*^9, 
  3.7424097248737087`*^9}, {3.742409831405532*^9, 3.7424098391052027`*^9}},
 CellLabel->
  "In[708]:=",ExpressionUUID->"4255e92d-59ab-472b-bdd0-b7de8bee7f9d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"gg11", "+", "gg22", "+", "gg33", "+", "gg44"}], ")"}]}]}], ",", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"gg11", "+", "gg22", "-", "gg33", "-", "gg44"}], ")"}]}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"gg11", "-", "gg22", "+", "gg33", "-", "gg44"}], ")"}]}]}], ",", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"gg11", "-", "gg22", "-", "gg33", "+", "gg44"}], ")"}]}]}], ",", 
   RowBox[{"a", "\[Rule]", "gg12"}], ",", 
   RowBox[{"aw", "\[Rule]", "0"}], ",", 
   RowBox[{"b", "\[Rule]", "gg13"}], ",", 
   RowBox[{"bw", "\[Rule]", "0"}], ",", 
   RowBox[{"c", "\[Rule]", "gg14"}], ",", 
   RowBox[{"cw", "\[Rule]", "0"}], ",", 
   RowBox[{"aa", "\[Rule]", "gg34"}], ",", 
   RowBox[{"aaw", "\[Rule]", "0"}], ",", 
   RowBox[{"bb", "\[Rule]", "gg24"}], ",", 
   RowBox[{"bbw", "\[Rule]", "0"}], ",", 
   RowBox[{"cc", "\[Rule]", "gg23"}], ",", 
   RowBox[{"ccw", "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7424078897797537`*^9, 3.7424079003549147`*^9}, 
   3.7424079582454853`*^9, {3.742409826152761*^9, 3.742409841035831*^9}},
 CellLabel->
  "Out[708]=",ExpressionUUID->"b2597aff-6b80-4fbc-bb2b-a27a9853a86c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "check", " ", "*)"}], "  ", 
  RowBox[{
   RowBox[{"hornA4mat", "/.", "wxyzToggRule"}], "//", "Simplify"}]}]], "Input",\

 CellChangeTimes->{{3.742407909537339*^9, 3.742407974327766*^9}, {
  3.742408010762928*^9, 3.742408016863778*^9}, {3.742409951741061*^9, 
  3.74240995548717*^9}},
 CellLabel->
  "In[711]:=",ExpressionUUID->"5bc0a014-547c-4fae-ad63-25ac84ad59be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"gg11", ",", "gg12", ",", "gg13", ",", "gg14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gg12", ",", "gg22", ",", "gg23", ",", "gg24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gg13", ",", "gg23", ",", "gg33", ",", "gg34"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gg14", ",", "gg24", ",", "gg34", ",", "gg44"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7424079641931353`*^9, 3.742407974711073*^9}, 
   3.742408018402277*^9, {3.742409943867383*^9, 3.742409955823557*^9}},
 CellLabel->
  "Out[711]=",ExpressionUUID->"6136a303-a372-4bd5-9a90-eb9e3193fb3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "makePn4NumRule"}]], "Input",
 CellChangeTimes->{{3.742407787258101*^9, 3.74240778797383*^9}},
 CellLabel->
  "In[672]:=",ExpressionUUID->"8f45e89d-d425-485e-b87b-4dc150520e15"],

Cell[CellGroupData[{

Cell["Global`makePn4NumRule", "Print", "PrintUsage",
 CellChangeTimes->{3.742407788754253*^9},
 CellTags->
  "Info6723742393388-6760036",ExpressionUUID->"d0f8cdf4-2ae8-49b8-b520-\
e82091ec7e06"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"makePn4NumRule", "[", "WXYZnumRule_", "]"}], ":=", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"p1", "\[Rule]", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "w"}]}], ",", 
            RowBox[{"p2", "\[Rule]", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["aa", "2"], "+", 
              SuperscriptBox["aaw", "2"], "+", 
              SuperscriptBox["aw", "2"], "-", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["bb", "2"], "+", 
              SuperscriptBox["bbw", "2"], "+", 
              SuperscriptBox["bw", "2"], "-", 
              SuperscriptBox["c", "2"], "-", 
              SuperscriptBox["cc", "2"], "+", 
              SuperscriptBox["ccw", "2"], "+", 
              SuperscriptBox["cw", "2"], "+", 
              RowBox[{"6", " ", 
               SuperscriptBox["w", "2"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["y", "2"], "+", 
                 SuperscriptBox["z", "2"]}], ")"}]}]}]}], ",", 
            RowBox[{"p3", "\[Rule]", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"aw", " ", "bbw", " ", "c"}], "-", 
                RowBox[{"aaw", " ", "bw", " ", "c"}], "-", 
                RowBox[{"aaw", " ", "bbw", " ", "cc"}], "+", 
                RowBox[{"aw", " ", "bw", " ", "cc"}], "-", 
                RowBox[{"aw", " ", "b", " ", "ccw"}], "-", 
                RowBox[{"aaw", " ", "bb", " ", "ccw"}], "+", 
                RowBox[{"aaw", " ", "b", " ", "cw"}], "+", 
                RowBox[{"aw", " ", "bb", " ", "cw"}], "-", 
                RowBox[{"a", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"bb", " ", "c"}], "+", 
                   RowBox[{"b", " ", "cc"}], "-", 
                   RowBox[{"bw", " ", "ccw"}], "+", 
                   RowBox[{"bbw", " ", "cw"}]}], ")"}]}], "-", 
                RowBox[{"aa", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"b", " ", "c"}], "+", 
                   RowBox[{"bb", " ", "cc"}], "+", 
                   RowBox[{"bbw", " ", "ccw"}], "-", 
                   RowBox[{"bw", " ", "cw"}]}], ")"}]}], "-", 
                RowBox[{
                 SuperscriptBox["aaw", "2"], " ", "w"}], "-", 
                RowBox[{
                 SuperscriptBox["aw", "2"], " ", "w"}], "+", 
                RowBox[{
                 SuperscriptBox["b", "2"], " ", "w"}], "+", 
                RowBox[{
                 SuperscriptBox["bb", "2"], " ", "w"}], "-", 
                RowBox[{
                 SuperscriptBox["bbw", "2"], " ", "w"}], "-", 
                RowBox[{
                 SuperscriptBox["bw", "2"], " ", "w"}], "+", 
                RowBox[{
                 SuperscriptBox["c", "2"], " ", "w"}], "+", 
                RowBox[{
                 SuperscriptBox["cc", "2"], " ", "w"}], "-", 
                RowBox[{
                 SuperscriptBox["ccw", "2"], " ", "w"}], "-", 
                RowBox[{
                 SuperscriptBox["cw", "2"], " ", "w"}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["w", "3"]}], "+", 
                RowBox[{
                 SuperscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"w", "-", "x"}], ")"}]}], "-", 
                RowBox[{
                 SuperscriptBox["aaw", "2"], " ", "x"}], "+", 
                RowBox[{
                 SuperscriptBox["aw", "2"], " ", "x"}], "+", 
                RowBox[{"2", " ", "w", " ", 
                 SuperscriptBox["x", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox["aa", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"w", "+", "x"}], ")"}]}], "-", 
                RowBox[{
                 SuperscriptBox["b", "2"], " ", "y"}], "+", 
                RowBox[{
                 SuperscriptBox["bb", "2"], " ", "y"}], "-", 
                RowBox[{
                 SuperscriptBox["bbw", "2"], " ", "y"}], "+", 
                RowBox[{
                 SuperscriptBox["bw", "2"], " ", "y"}], "+", 
                RowBox[{"2", " ", "w", " ", 
                 SuperscriptBox["y", "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["c", "2"]}], "+", 
                   SuperscriptBox["cc", "2"], "-", 
                   SuperscriptBox["ccw", "2"], "+", 
                   SuperscriptBox["cw", "2"], "-", 
                   RowBox[{"4", " ", "x", " ", "y"}]}], ")"}], " ", "z"}], 
                "+", 
                RowBox[{"2", " ", "w", " ", 
                 SuperscriptBox["z", "2"]}]}], ")"}]}]}], ",", 
            RowBox[{"p4", "\[Rule]", 
             RowBox[{"makeDetHornA4", "[", 
              RowBox[{
              "w", ",", "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c",
                ",", "aw", ",", "bw", ",", "cw", ",", "aa", ",", "bb", ",", 
               "cc", ",", "aaw", ",", "bbw", ",", "ccw"}], "]"}]}]}], "}"}], "/.",
           "\[VeryThinSpace]", "WXYZnumRule"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`makePn4NumRule],
  Editable->False]], "Print",
 CellChangeTimes->{3.742407788853429*^9},
 CellTags->
  "Info6723742393388-6760036",ExpressionUUID->"afb18cbe-1c63-4594-ad1c-\
8465f0d9deb6"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["These are fundamental:", "Subsubsection",
 CellChangeTimes->{{3.742408135246245*^9, 
  3.742408141238158*^9}},ExpressionUUID->"16f6c189-8105-4134-ae61-\
61836da29714"],

Cell[BoxData[
 RowBox[{
  RowBox[{"basicGGMetric", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"gg11", ",", "gg12", ",", "gg13", ",", "gg14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"gg21", ",", "gg22", ",", "gg23", ",", "gg24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"gg31", ",", "gg32", ",", "gg33", ",", "gg34"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"gg41", ",", "gg42", ",", "gg43", ",", "gg44"}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7424081550658493`*^9, 3.742408157870596*^9}},
 CellLabel->
  "In[683]:=",ExpressionUUID->"9bb53849-edc3-47e0-ada9-4392eff76e70"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"basicGGMetric", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.742408152935648*^9, 3.742408170141514*^9}},
 CellLabel->
  "In[684]:=",ExpressionUUID->"6867fb58-a75c-475f-b4e1-84e94b437672"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"gg11", "gg12", "gg13", "gg14"},
     {"gg21", "gg22", "gg23", "gg24"},
     {"gg31", "gg32", "gg33", "gg34"},
     {"gg41", "gg42", "gg43", "gg44"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7424081707058277`*^9},
 CellLabel->
  "Out[684]//MatrixForm=",ExpressionUUID->"8b2e3ca4-b052-467d-b818-\
220d863a5e4a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"basicGGMetricPnRules", " ", "=", " ", 
  RowBox[{
   RowBox[{"makePn4NumRule", "[", "wxyzToggRule", "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.742407709712389*^9, 3.7424077198101587`*^9}, {
  3.7424080367231407`*^9, 3.742408090322349*^9}},
 CellLabel->
  "In[681]:=",ExpressionUUID->"58ca9f24-4d99-4c7d-a807-15981fd2fbf4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "gg11"}], "-", "gg22", "-", "gg33", "-", "gg44"}]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "gg12"}], " ", "gg21"}], "-", 
     RowBox[{"gg13", " ", "gg31"}], "-", 
     RowBox[{"gg23", " ", "gg32"}], "+", 
     RowBox[{"gg22", " ", "gg33"}], "-", 
     RowBox[{"gg14", " ", "gg41"}], "-", 
     RowBox[{"gg24", " ", "gg42"}], "-", 
     RowBox[{"gg34", " ", "gg43"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gg22", "+", "gg33"}], ")"}], " ", "gg44"}], "+", 
     RowBox[{"gg11", " ", 
      RowBox[{"(", 
       RowBox[{"gg22", "+", "gg33", "+", "gg44"}], ")"}]}]}]}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{
     RowBox[{"gg11", " ", "gg23", " ", "gg32"}], "-", 
     RowBox[{"gg11", " ", "gg22", " ", "gg33"}], "+", 
     RowBox[{"gg14", " ", "gg22", " ", "gg41"}], "+", 
     RowBox[{"gg14", " ", "gg33", " ", "gg41"}], "-", 
     RowBox[{"gg14", " ", "gg21", " ", "gg42"}], "+", 
     RowBox[{"gg11", " ", "gg24", " ", "gg42"}], "+", 
     RowBox[{"gg24", " ", "gg33", " ", "gg42"}], "-", 
     RowBox[{"gg23", " ", "gg34", " ", "gg42"}], "-", 
     RowBox[{"gg14", " ", "gg31", " ", "gg43"}], "-", 
     RowBox[{"gg24", " ", "gg32", " ", "gg43"}], "+", 
     RowBox[{"gg11", " ", "gg34", " ", "gg43"}], "+", 
     RowBox[{"gg22", " ", "gg34", " ", "gg43"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"gg11", " ", "gg22"}], "-", 
        RowBox[{"gg23", " ", "gg32"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"gg11", "+", "gg22"}], ")"}], " ", "gg33"}]}], ")"}], " ", 
      "gg44"}], "+", 
     RowBox[{"gg13", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "gg21"}], " ", "gg32"}], "-", 
        RowBox[{"gg34", " ", "gg41"}], "+", 
        RowBox[{"gg31", " ", 
         RowBox[{"(", 
          RowBox[{"gg22", "+", "gg44"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"gg12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "gg23"}], " ", "gg31"}], "-", 
        RowBox[{"gg24", " ", "gg41"}], "+", 
        RowBox[{"gg21", " ", 
         RowBox[{"(", 
          RowBox[{"gg33", "+", "gg44"}], ")"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{"p4", "\[Rule]", 
    RowBox[{
     RowBox[{"gg12", " ", "gg24", " ", "gg33", " ", "gg41"}], "-", 
     RowBox[{"gg12", " ", "gg23", " ", "gg34", " ", "gg41"}], "-", 
     RowBox[{"gg11", " ", "gg24", " ", "gg33", " ", "gg42"}], "+", 
     RowBox[{"gg11", " ", "gg23", " ", "gg34", " ", "gg42"}], "-", 
     RowBox[{"gg12", " ", "gg24", " ", "gg31", " ", "gg43"}], "+", 
     RowBox[{"gg11", " ", "gg24", " ", "gg32", " ", "gg43"}], "+", 
     RowBox[{"gg12", " ", "gg21", " ", "gg34", " ", "gg43"}], "-", 
     RowBox[{"gg11", " ", "gg22", " ", "gg34", " ", "gg43"}], "+", 
     RowBox[{"gg14", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"gg23", " ", "gg32", " ", "gg41"}], "-", 
        RowBox[{"gg22", " ", "gg33", " ", "gg41"}], "-", 
        RowBox[{"gg23", " ", "gg31", " ", "gg42"}], "+", 
        RowBox[{"gg21", " ", "gg33", " ", "gg42"}], "+", 
        RowBox[{"gg22", " ", "gg31", " ", "gg43"}], "-", 
        RowBox[{"gg21", " ", "gg32", " ", "gg43"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"gg12", " ", "gg23", " ", "gg31"}], "-", 
        RowBox[{"gg11", " ", "gg23", " ", "gg32"}], "-", 
        RowBox[{"gg12", " ", "gg21", " ", "gg33"}], "+", 
        RowBox[{"gg11", " ", "gg22", " ", "gg33"}]}], ")"}], " ", "gg44"}], 
     "+", 
     RowBox[{"gg13", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "gg24"}], " ", "gg32", " ", "gg41"}], "+", 
        RowBox[{"gg22", " ", "gg34", " ", "gg41"}], "+", 
        RowBox[{"gg24", " ", "gg31", " ", "gg42"}], "-", 
        RowBox[{"gg21", " ", "gg34", " ", "gg42"}], "-", 
        RowBox[{"gg22", " ", "gg31", " ", "gg44"}], "+", 
        RowBox[{"gg21", " ", "gg32", " ", "gg44"}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.742408083695033*^9, 3.742408092432342*^9}},
 CellLabel->
  "Out[681]=",ExpressionUUID->"53bcb14a-a60d-4e2c-83e2-afb1526df64d"]
}, Open  ]],

Cell[TextData[StyleBox[" Check up on the abstraction:",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.742408189525469*^9, 
  3.742408202614171*^9}},ExpressionUUID->"7df1d327-f7a9-4da6-9847-\
c3414b3e8915"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makePnFromGG", "[", "ggmat4_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Tr", "[", "ggmat4", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Tr", "[", "ggmat4", "]"}], "2"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"Tr", "[", 
       RowBox[{"ggmat4", ".", "ggmat4"}], "]"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "6"], 
      SuperscriptBox[
       RowBox[{"Tr", "[", "ggmat4", "]"}], "3"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Tr", "[", 
       RowBox[{"ggmat4", ".", "ggmat4"}], "]"}], 
      RowBox[{"Tr", "[", "ggmat4", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"Tr", "[", 
       RowBox[{"ggmat4", ".", "ggmat4", ".", "ggmat4"}], "]"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Det", "[", "ggmat4", "]"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742408214630206*^9, 3.742408278765764*^9}, {
  3.742408319253784*^9, 3.7424084890293427`*^9}},
 CellLabel->
  "In[685]:=",ExpressionUUID->"95dd2224-09f1-4341-afc8-2457ca46c450"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makePnFromGG", "[", "basicGGMetric", "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.742408513474864*^9, 3.7424085207954473`*^9}},
 CellLabel->
  "In[687]:=",ExpressionUUID->"11f0903b-16a4-47fa-8d88-43704fd2e295"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "gg11"}], "-", "gg22", "-", "gg33", "-", "gg44"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "gg12"}], " ", "gg21"}], "-", 
    RowBox[{"gg13", " ", "gg31"}], "-", 
    RowBox[{"gg23", " ", "gg32"}], "+", 
    RowBox[{"gg22", " ", "gg33"}], "-", 
    RowBox[{"gg14", " ", "gg41"}], "-", 
    RowBox[{"gg24", " ", "gg42"}], "-", 
    RowBox[{"gg34", " ", "gg43"}], "+", 
    RowBox[{"gg22", " ", "gg44"}], "+", 
    RowBox[{"gg33", " ", "gg44"}], "+", 
    RowBox[{"gg11", " ", 
     RowBox[{"(", 
      RowBox[{"gg22", "+", "gg33", "+", "gg44"}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"gg11", " ", "gg23", " ", "gg32"}], "-", 
    RowBox[{"gg11", " ", "gg22", " ", "gg33"}], "+", 
    RowBox[{"gg14", " ", "gg22", " ", "gg41"}], "+", 
    RowBox[{"gg14", " ", "gg33", " ", "gg41"}], "-", 
    RowBox[{"gg14", " ", "gg21", " ", "gg42"}], "+", 
    RowBox[{"gg11", " ", "gg24", " ", "gg42"}], "+", 
    RowBox[{"gg24", " ", "gg33", " ", "gg42"}], "-", 
    RowBox[{"gg23", " ", "gg34", " ", "gg42"}], "-", 
    RowBox[{"gg14", " ", "gg31", " ", "gg43"}], "-", 
    RowBox[{"gg24", " ", "gg32", " ", "gg43"}], "+", 
    RowBox[{"gg11", " ", "gg34", " ", "gg43"}], "+", 
    RowBox[{"gg22", " ", "gg34", " ", "gg43"}], "-", 
    RowBox[{"gg11", " ", "gg22", " ", "gg44"}], "+", 
    RowBox[{"gg23", " ", "gg32", " ", "gg44"}], "-", 
    RowBox[{"gg11", " ", "gg33", " ", "gg44"}], "-", 
    RowBox[{"gg22", " ", "gg33", " ", "gg44"}], "+", 
    RowBox[{"gg13", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gg22", " ", "gg31"}], "-", 
       RowBox[{"gg21", " ", "gg32"}], "-", 
       RowBox[{"gg34", " ", "gg41"}], "+", 
       RowBox[{"gg31", " ", "gg44"}]}], ")"}]}], "+", 
    RowBox[{"gg12", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "gg23"}], " ", "gg31"}], "-", 
       RowBox[{"gg24", " ", "gg41"}], "+", 
       RowBox[{"gg21", " ", 
        RowBox[{"(", 
         RowBox[{"gg33", "+", "gg44"}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"gg12", " ", "gg24", " ", "gg33", " ", "gg41"}], "-", 
    RowBox[{"gg12", " ", "gg23", " ", "gg34", " ", "gg41"}], "-", 
    RowBox[{"gg11", " ", "gg24", " ", "gg33", " ", "gg42"}], "+", 
    RowBox[{"gg11", " ", "gg23", " ", "gg34", " ", "gg42"}], "-", 
    RowBox[{"gg12", " ", "gg24", " ", "gg31", " ", "gg43"}], "+", 
    RowBox[{"gg11", " ", "gg24", " ", "gg32", " ", "gg43"}], "+", 
    RowBox[{"gg12", " ", "gg21", " ", "gg34", " ", "gg43"}], "-", 
    RowBox[{"gg11", " ", "gg22", " ", "gg34", " ", "gg43"}], "+", 
    RowBox[{"gg14", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gg23", " ", "gg32", " ", "gg41"}], "-", 
       RowBox[{"gg22", " ", "gg33", " ", "gg41"}], "-", 
       RowBox[{"gg23", " ", "gg31", " ", "gg42"}], "+", 
       RowBox[{"gg21", " ", "gg33", " ", "gg42"}], "+", 
       RowBox[{"gg22", " ", "gg31", " ", "gg43"}], "-", 
       RowBox[{"gg21", " ", "gg32", " ", "gg43"}]}], ")"}]}], "+", 
    RowBox[{"gg12", " ", "gg23", " ", "gg31", " ", "gg44"}], "-", 
    RowBox[{"gg11", " ", "gg23", " ", "gg32", " ", "gg44"}], "-", 
    RowBox[{"gg12", " ", "gg21", " ", "gg33", " ", "gg44"}], "+", 
    RowBox[{"gg11", " ", "gg22", " ", "gg33", " ", "gg44"}], "+", 
    RowBox[{"gg13", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "gg24"}], " ", "gg32", " ", "gg41"}], "+", 
       RowBox[{"gg22", " ", "gg34", " ", "gg41"}], "+", 
       RowBox[{"gg24", " ", "gg31", " ", "gg42"}], "-", 
       RowBox[{"gg21", " ", "gg34", " ", "gg42"}], "-", 
       RowBox[{"gg22", " ", "gg31", " ", "gg44"}], "+", 
       RowBox[{"gg21", " ", "gg32", " ", "gg44"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.742408514936006*^9, 3.742408521277739*^9}},
 CellLabel->
  "Out[687]=",ExpressionUUID->"2632640e-8417-4010-a71b-d38b5d68ca0d"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"makePnFromGG", "[", "basicGGMetric", "]"}], "-", " ", 
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}]}], "/.", 
   "basicGGMetricPnRules"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7424085436508512`*^9, 3.7424085685470963`*^9}},
 CellLabel->
  "In[688]:=",ExpressionUUID->"4f4d06bd-204f-4c43-a377-5434622c493c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.742408569082519*^9},
 CellLabel->
  "Out[688]=",ExpressionUUID->"06881e8f-c4a9-4649-bd7e-04d470e5d62e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"makePnRulesFromGG", "[", "ggmat4_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p1", "\[Rule]", " ", 
     RowBox[{"-", 
      RowBox[{"Tr", "[", "ggmat4", "]"}]}]}], ",", 
    RowBox[{"p2", "\[Rule]", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Tr", "[", "ggmat4", "]"}], "2"]}], "-", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"Tr", "[", 
        RowBox[{"ggmat4", ".", "ggmat4"}], "]"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"p3", "\[Rule]", " ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"-", "1"}], "6"], 
       SuperscriptBox[
        RowBox[{"Tr", "[", "ggmat4", "]"}], "3"]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"Tr", "[", 
        RowBox[{"ggmat4", ".", "ggmat4"}], "]"}], 
       RowBox[{"Tr", "[", "ggmat4", "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "3"], 
       RowBox[{"Tr", "[", 
        RowBox[{"ggmat4", ".", "ggmat4", ".", "ggmat4"}], "]"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"p4", "\[Rule]", " ", 
     RowBox[{"Det", "[", "ggmat4", "]"}]}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742408214630206*^9, 3.742408278765764*^9}, {
  3.742408319253784*^9, 3.7424084890293427`*^9}, {3.742408676429673*^9, 
  3.742408701508059*^9}},
 CellLabel->
  "In[689]:=",ExpressionUUID->"259e6f8a-6481-4464-af3a-6a10018490c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], "/.", 
     RowBox[{"makePnRulesFromGG", "[", "basicGGMetric", "]"}]}], ")"}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], "/.", 
     "basicGGMetricPnRules"}], ")"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.742408739409131*^9, 3.742408833056896*^9}},
 CellLabel->
  "In[693]:=",ExpressionUUID->"c691869a-489d-4b10-8b3b-2baeb1969acd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.742408753646452*^9, 3.7424087747833233`*^9}, {
  3.742408827510151*^9, 3.742408834888785*^9}},
 CellLabel->
  "Out[693]=",ExpressionUUID->"0d8a5d03-50e2-4371-bb94-68a9b8e8c27a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Look at eigenvector", "Subsubsection",
 CellChangeTimes->{{3.742408877447729*^9, 
  3.74240888306353*^9}},ExpressionUUID->"5c90505d-522e-4ae9-9795-\
0543b85001dc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"wxyzToggRule", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
   RowBox[{"basicGGMetricPnRules", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.742408970999674*^9, 3.742408975090732*^9}, {
  3.7424093235919952`*^9, 3.7424093369006767`*^9}},
 CellLabel->
  "In[696]:=",ExpressionUUID->"abd48738-efde-4dce-a369-78d56605b12f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"gg11", "+", "gg22", "+", "gg33", "+", "gg44"}], ")"}]}]}], ",", 
   RowBox[{"p1", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "gg11"}], "-", "gg22", "-", "gg33", "-", "gg44"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.742408975579865*^9, 3.742409337345871*^9},
 CellLabel->
  "Out[696]=",ExpressionUUID->"4b824bba-a811-4df1-b00b-9019a9b53bba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"xyzEpsN", "[", 
     RowBox[{"1", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
    "basicGGMetricPnRules"}], "//", 
   RowBox[{
    RowBox[{"Short", "[", 
     RowBox[{"#", ",", "4"}], "]"}], "&"}]}]}]], "Input",
 CellChangeTimes->{{3.7424093506569347`*^9, 3.742409352460034*^9}, {
  3.742409431618967*^9, 3.742409449681343*^9}},
 CellLabel->
  "In[701]:=",ExpressionUUID->"8fc2f937-897a-4bc5-ae20-c8e3796542e2"],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"gg11", "+", "gg22", "+", "gg33", "+", "gg44"}], ")"}]}], "+", 
   FractionBox[
    SqrtBox[
     RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], 
    RowBox[{"2", " ", 
     SqrtBox["3"]}]], "+", 
   FractionBox[
    SqrtBox[
     RowBox[{
      RowBox[{
       FractionBox["3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "gg11"}], "-", "gg22", "-", 
          RowBox[{"\[LeftSkeleton]", "4", "\[RightSkeleton]"}], "-", "gg44"}],
          ")"}], "2"]}], "-", 
      RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "6"], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]}], 
        "]"}]}]}]], 
    RowBox[{"2", " ", 
     SqrtBox["3"]}]], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      SqrtBox["3"]}]], 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "gg11"}], "-", "gg22", "-", "gg33", "-", "gg44"}], 
           ")"}], "2"]}], "-", 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
          RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "6"], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[LeftSkeleton]", "13", "\[RightSkeleton]"}], "+", 
                  
                  RowBox[{"gg11", " ", 
                   RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]}], 
                 ")"}], "3"], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "9"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                    ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                    ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                    ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                    ")"}]}]}], ")"}]}], "+", 
                  RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
                 ")"}]}]}], ",", 
              SqrtBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]]}], 
             "]"}]}]}], "]"}]}]}], ")"}]}], ")"}]}]}],
  Short[#, 4]& ]], "Output",
 CellChangeTimes->{{3.742409346765749*^9, 3.742409373131909*^9}, {
  3.7424094375645523`*^9, 3.7424094503052692`*^9}},
 CellLabel->
  "Out[701]//Short=",ExpressionUUID->"3d6e3fdb-6b3c-4031-8554-340569fd59f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"w", ",", "x", ",", "y", ",", "z", ",", "a", ",", "aa"}], "}"}], "/.",
   "wxyzToggRule"}]], "Input",
 CellChangeTimes->{{3.742409479263645*^9, 3.7424095155390472`*^9}},
 CellLabel->
  "In[703]:=",ExpressionUUID->"52032332-b26f-4c8d-9c93-28d433fc1c15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"gg11", "+", "gg22", "+", "gg33", "+", "gg44"}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"gg11", "+", "gg22", "-", "gg33", "-", "gg44"}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"gg11", "-", "gg22", "+", "gg33", "-", "gg44"}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"gg11", "-", "gg22", "-", "gg33", "+", "gg44"}], ")"}]}], ",", 
   FractionBox[
    RowBox[{"gg12", "+", "gg21"}], "2"], ",", 
   FractionBox[
    RowBox[{"gg34", "+", "gg43"}], "2"]}], "}"}]], "Output",
 CellChangeTimes->{{3.7424094896375103`*^9, 3.7424095164440203`*^9}},
 CellLabel->
  "Out[703]=",ExpressionUUID->"ecff95c6-758a-4c50-be7b-d5ce7512ce94"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"eigval", " ", "=", " ", 
     RowBox[{
      RowBox[{"xyzEpsN", "[", 
       RowBox[{"1", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.",
       "basicGGMetricPnRules"}]}], "}"}], ",", "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{"eigenvecRMSDp1", "[", 
     RowBox[{
     "eigval", ",", "w", ",", "x", ",", "y", ",", "z", ",", "a", ",", "b", 
      ",", "c", ",", "aa", ",", "bb", ",", "cc"}], "]"}], "/.", 
    "wxyzToggRule"}]}]}]], "Input",
 CellChangeTimes->{{3.742408988250544*^9, 3.742409095591653*^9}, {
   3.7424091701552343`*^9, 3.742409212949915*^9}, 
   3.7424093010980062`*^9},ExpressionUUID->"b07fda96-5b7e-4484-9077-\
380d25c5cc61"]
}, Open  ]],

Cell[CellGroupData[{

Cell["-------------------------------", "Subsubsection",
 CellChangeTimes->{{3.742408963584649*^9, 
  3.742408965078781*^9}},ExpressionUUID->"d73fddf7-b9d5-4568-bf69-\
1b5551a8c03f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "NEW", " ", "TRACEFUL", " ", "eigenvector", " ", "is", " ", "RIGHT"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{"wVVeigvec", " ", "=", " ", 
   RowBox[{"eigenvecRMSDp1", "[", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"xyzEps0", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
       RowBox[{"makePnRulesFromGG", " ", "[", 
        RowBox[{
         RowBox[{"basicGGMetric", " ", "\\"}], ",", "\[IndentingNewLine]", 
         "x", ",", "y", ",", "z", ",", "a", ",", "b", ",", "c", ",", "aa", 
         ",", "bb", ",", "cc"}], "]"}]}], " ", "/.", 
      "testqqRule"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.741106926815502*^9, 3.741106939361031*^9}, {
  3.741106982430081*^9, 3.7411070743918*^9}, {3.7411071117972183`*^9, 
  3.74110712677597*^9}, {3.742409105763534*^9, 
  3.7424091347190027`*^9}},ExpressionUUID->"4d941590-3158-49fc-94a5-\
868b2a581a49"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9792171403627875`"}], ",", 
   RowBox[{"-", "0.003592334333214316`"}], ",", 
   RowBox[{"-", "0.0003948989172451336`"}], ",", "0.20278247263658802`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.741107063522792*^9, 3.741107075870273*^9}},
 CellLabel->
  "Out[621]=",ExpressionUUID->"04881e9f-c427-4926-b981-1477aa7ad549"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subVVRule", " ", "=", " ", 
  RowBox[{"makePn4NumRule", "[", "testqqRule", "]"}]}]], "Input",
 CellChangeTimes->{{3.741053865681738*^9, 3.741053888236103*^9}},
 CellLabel->
  "In[563]:=",ExpressionUUID->"df14731c-0a73-4562-b4b6-bc35a79ae1eb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", 
    RowBox[{"-", "100.`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", "102.15270555697018`"}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "33.26002861926827`"}]}], ",", 
   RowBox[{"p4", "\[Rule]", "3.4140164000254742`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.741053888841251*^9},
 CellLabel->
  "Out[563]=",ExpressionUUID->"7ff6228a-1d0e-41b4-8577-d6d7fea6f65f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"xyzEps0", "[", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
   "subVVRule"}]}]], "Input",
 CellChangeTimes->{{3.741053913530987*^9, 3.741053920639344*^9}},
 CellLabel->
  "In[564]:=",ExpressionUUID->"54864593-6b2e-4c33-8d8c-ac8b58e257e9"],

Cell[BoxData["98.9712467004448`"], "Output",
 CellChangeTimes->{3.741053921854197*^9},
 CellLabel->
  "Out[564]=",ExpressionUUID->"39a483c1-3cc3-4ac8-813b-c1fec3e2c444"]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"eigenvecRMSDp1", "[", 
    RowBox[{
    "98.9712467004448`", ",", "w", ",", "x", ",", "y", ",", "z", ",", "a", 
     ",", "b", ",", "c", ",", "aa", ",", "bb", ",", "cc"}], "]"}], " ", "/.", 
   "testqqRule"}]}]], "Input",
 CellChangeTimes->{{3.741055031057543*^9, 3.7410550605254993`*^9}, {
  3.74105523925893*^9, 3.741055269211606*^9}, {3.741107365540019*^9, 
  3.74110739341429*^9}},
 CellLabel->
  "In[624]:=",ExpressionUUID->"e6995b01-daed-467e-8fa1-5d15f46b2020"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Review from Histograms", "Subsubsection",
 CellChangeTimes->{{3.74240148677323*^9, 3.742401492165099*^9}, {
  3.742401835562695*^9, 
  3.7424018408985558`*^9}},ExpressionUUID->"bc7d658f-8a11-4c78-af26-\
0bbaf0ca77ff"],

Cell[BoxData[
 RowBox[{"oneFrmVSqmat", "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vVec", " ", "=", " ", "oneFrmVwVec"}], "}"}], ",", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"vVec", "[", 
        RowBox[{"[", "a", "]"}], "]"}], 
       RowBox[{"vVec", "[", 
        RowBox[{"[", "b", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "1", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "1", ",", "4"}], "}"}]}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.742236457036919*^9, 3.742236480473817*^9}, {
  3.7422365112104273`*^9, 3.742236580921495*^9}},
 CellLabel->
  "In[282]:=",ExpressionUUID->"30046e85-5060-4aa8-8f7b-d43fb53b8d61"],

Cell[BoxData[
 RowBox[{
  RowBox[{"build3DPntdataset", "[", 
   RowBox[{"npts", ",", 
    RowBox[{"quats", "[", 
     RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ","}]], "Input",ExpressionUUID->\
"30359b9b-b96f-4bc4-91a0-a842ff749860"],

Cell[BoxData[
 RowBox[{"sampleMetric", " ", "=", " "}]], "Input",
 CellChangeTimes->{{3.742400924663171*^9, 
  3.742400930121269*^9}},ExpressionUUID->"0f5541c1-1d33-4278-97ef-\
4e05bddd1f24"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Problem", " ", "with", " ", "Det", " ", "close", " ", "to", " ", "zero"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"oneFrmVSqPnRules", " ", "=", 
   RowBox[{"Chop", "[", " ", 
    RowBox[{"makePn4NumRule", "[", 
     RowBox[{"makeWXYZnumRule", "[", " ", "oneFrmVSqmat", "]"}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.742239250081716*^9, 3.742239291537552*^9}, {
  3.742239328065095*^9, 3.7422393331805763`*^9}, {3.742239367225281*^9, 
  3.74223939867301*^9}, {3.742239658490274*^9, 3.742239668703451*^9}, {
  3.74224065164881*^9, 3.742240652589923*^9}, {3.742240721509604*^9, 
  3.742240721989442*^9}},ExpressionUUID->"15d0ea75-a6e0-4ccb-9bfc-\
76a8998ddc9c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", 
    RowBox[{"-", "9893.358505026974`"}]}], ",", 
   RowBox[{"p2", "\[Rule]", "1.2051714293193072`*^-8"}], ",", 
   RowBox[{"p3", "\[Rule]", 
    RowBox[{"-", "0.0000152587890625`"}]}], ",", 
   RowBox[{"p4", "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.742239672978026*^9},
 CellLabel->
  "Out[309]=",ExpressionUUID->"bd6b7431-0098-445b-9b1e-e9037b0b7576"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"eigOptVSq", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"xyzEps0", "[", 
     RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "]"}], "/.", 
    "oneFrmVSqPnRules"}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.742239694657132*^9, 3.742239695333927*^9}, {
  3.742239730006613*^9, 3.7422397599418287`*^9}, {3.742240746890683*^9, 
  3.7422407539332314`*^9}, {3.7422408167123747`*^9, 3.742240817244843*^9}},
 CellLabel->
  "In[322]:=",ExpressionUUID->"f6a5c867-e094-44ec-9cec-34f691fdf253"],

Cell[BoxData[
 RowBox[{"eigvecvvrule", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"oneFrmVSqmat", "-", 
         RowBox[{"eigOptVSq", "*", 
          RowBox[{"IdentityMatrix", "[", "4", "]"}]}]}], ")"}], ".", 
       RowBox[{"{", 
        RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], " ", 
      "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.742239929348261*^9, 3.742239992947673*^9}, {
  3.7422400354094143`*^9, 3.742240056555317*^9}, {3.742240854524611*^9, 
  3.7422408568610287`*^9}},ExpressionUUID->"4641cb7b-710a-4355-8c53-\
e6e8a043951b"],

Cell[BoxData[
 RowBox[{"oneFrmVsqEigvec", " ", "=", " ", 
  RowBox[{"Normalize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "v1", ",", "v2", ",", "v3"}], "}"}], "/.", 
    "eigvecvvrule"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.742240005063607*^9, 3.742240028619945*^9}, {
   3.742240063110194*^9, 3.742240065019389*^9}, 3.742240868350498*^9},
 CellLabel->
  "In[323]:=",ExpressionUUID->"29ab5af1-ec04-4421-92d7-93a3f6d3df20"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Solution Utilities - find the graphs of the Cost and their\noptimal  \
quaternions  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["q", "0"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "09ec3d27-76c4-4b72-a62f-78642655cdf6"],
 ":  {q0, Delta0, FcnDelta[q]}"
}], "Section",
 CellChangeTimes->{{3.740594205074778*^9, 
  3.740594271826651*^9}},ExpressionUUID->"14c63ff0-cca3-4295-b97e-\
1478048ca260"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"solve2DPnt", "[", "data2Dpnt_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{"th0", ",", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a0", ",", "a1"}], "}"}], "_", "0"}], ",", " ", 
     RowBox[{"Delta_", "0"}], ",", " ", 
     RowBox[{"FcnDelta", "[", "a", "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.740621835863007*^9, 3.740621835867097*^9}, {
  3.740621885473665*^9, 
  3.740621892150625*^9}},ExpressionUUID->"8ef57942-a327-4ee3-a006-\
c2c2600024a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solve3DPnt", "[", "data3Dpnt_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{"q0", ",", " ", 
    RowBox[{"Delta_", "0"}], ",", " ", 
    RowBox[{"FcnDelta", "[", "a", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.740621842092499*^9, 3.7406218420938597`*^9}, {
  3.7406218962652903`*^9, 
  3.740621920593028*^9}},ExpressionUUID->"cefb0e75-97cd-4990-90c6-\
6d844ad777dd"],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.740621861795795*^9},ExpressionUUID->"86b959d7-05d4-4084-9136-\
51d342a2843b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solve2DFrm3", "[", "data2DFrm_", "]"}], " ", ":="}]], "Input",
 CellChangeTimes->{{3.740621863889614*^9, 3.740621867953165*^9}, {
  3.740621908361326*^9, 
  3.7406219247524757`*^9}},ExpressionUUID->"15f9a4cd-0b5f-4fd9-8372-\
c94bad4fd37b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solve3DFrm3", "[", "data3DFrm_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{"q0", ",", " ", 
    RowBox[{"DeltaRRR_", "0"}], ",", " ", 
    RowBox[{"FcnDelta", "[", "a", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.740621878840321*^9, 
  3.7406219295041723`*^9}},ExpressionUUID->"65076c31-4c36-4c87-987a-\
ebcd08e7f5ac"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{939, 1018},
WindowMargins->{{267, Automatic}, {29, Automatic}},
FrontEndVersion->"11.3 for Linux x86 (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info683742981000-7551584"->{
  Cell[406347, 11002, 189, 4, 46, "Print",ExpressionUUID->"c1e7ae49-ab68-47e5-8339-c6373c984492",
   CellTags->"Info683742981000-7551584"],
  Cell[406539, 11008, 5441, 118, 202, "Print",ExpressionUUID->"a5822828-3359-4efa-b872-9078f4e3dac0",
   CellTags->"Info683742981000-7551584"]},
 "Info5613729942257-2554935"->{
  Cell[2535812, 69365, 195, 4, 46, "Print",ExpressionUUID->"06c2aa12-8347-4274-beb6-764b90cbd11d",
   CellTags->"Info5613729942257-2554935"],
  Cell[2536010, 69371, 2402, 61, 114, "Print",ExpressionUUID->"ade43138-ac0c-433e-88da-ca368dfb8ad1",
   CellTags->"Info5613729942257-2554935"]},
 "Info6723742393388-6760036"->{
  Cell[3638635, 99947, 194, 4, 46, "Print",ExpressionUUID->"d0f8cdf4-2ae8-49b8-b520-e82091ec7e06",
   CellTags->"Info6723742393388-6760036"],
  Cell[3638832, 99953, 6192, 144, 158, "Print",ExpressionUUID->"afb18cbe-1c63-4594-ad1c-8465f0d9deb6",
   CellTags->"Info6723742393388-6760036"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info683742981000-7551584", 3678302, 101054},
 {"Info5613729942257-2554935", 3678619, 101059},
 {"Info6723742393388-6760036", 3678939, 101064}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 442, 10, 103, "Subchapter",ExpressionUUID->"748b753e-4146-4d83-9f41-de817b6938ac"],
Cell[CellGroupData[{
Cell[1047, 36, 267, 5, 31, "Input",ExpressionUUID->"0d3e2780-4c83-4dfe-bd7a-9a2ae99dbd24"],
Cell[1317, 43, 293, 5, 35, "Output",ExpressionUUID->"3eb14825-5a27-4364-9a07-d000a578597c"]
}, Open  ]],
Cell[1625, 51, 846, 20, 149, "Subsubsection",ExpressionUUID->"86f1d35a-8a35-4b0a-9499-f3fe147ad035"],
Cell[CellGroupData[{
Cell[2496, 75, 369, 7, 54, "Section",ExpressionUUID->"d3d6a088-9b74-4797-834f-c2ea66697417"],
Cell[2868, 84, 442, 10, 47, "Input",ExpressionUUID->"14650e04-f9a9-49ee-8226-13e251efd9fe",
 InitializationCell->True],
Cell[3313, 96, 436, 11, 47, "Input",ExpressionUUID->"83ae9efe-71d5-4467-80be-442d4c1e79d2",
 InitializationCell->True],
Cell[3752, 109, 753, 20, 47, "Input",ExpressionUUID->"685cdace-df77-407e-812f-c290ccd7f67c",
 InitializationCell->True],
Cell[4508, 131, 818, 23, 71, "Input",ExpressionUUID->"53d5ac48-a39b-44d5-9226-8872cb7a2299",
 InitializationCell->True],
Cell[5329, 156, 1008, 28, 117, "Input",ExpressionUUID->"abb174c0-13ff-40fe-8263-73135a6d4611",
 InitializationCell->True],
Cell[6340, 186, 1406, 29, 124, "Input",ExpressionUUID->"0a8d1987-5c5e-48e7-a597-85b066129f2f"],
Cell[CellGroupData[{
Cell[7771, 219, 227, 4, 45, "Subsubsection",ExpressionUUID->"ae332e6e-cdd7-4ccd-9ee5-d1a7e07aa149"],
Cell[8001, 225, 1620, 42, 140, "Input",ExpressionUUID->"c45cb2ee-ade6-4943-896c-6f20d73f1a8c",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[9646, 271, 445, 11, 31, "Input",ExpressionUUID->"db5aa688-2651-484c-8d37-15b81a4aea5d"],
Cell[10094, 284, 301, 9, 35, "Output",ExpressionUUID->"ba3c5dd7-27fe-4a37-9997-d2d0fb3fa8ae"]
}, Open  ]],
Cell[10410, 296, 1377, 32, 117, "Input",ExpressionUUID->"df6fc853-e4ea-4d84-a40a-27a5053d122c",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[11812, 332, 597, 15, 31, "Input",ExpressionUUID->"4faf3200-ceab-4b16-af71-c4e69f6a3c15"],
Cell[12412, 349, 299, 9, 35, "Output",ExpressionUUID->"4cbca77f-32a5-4a30-83ac-068f3faefd83"]
}, Open  ]],
Cell[12726, 361, 1516, 40, 117, "Input",ExpressionUUID->"58ce8dd4-1c51-4e82-adfa-c65d5b35cda8",
 InitializationCell->True],
Cell[14245, 403, 868, 24, 94, "Input",ExpressionUUID->"823e64a1-1ccf-4a20-951c-f28bd49ac925",
 InitializationCell->True],
Cell[15116, 429, 1237, 33, 117, "Input",ExpressionUUID->"3eb97bde-78c7-4df3-9c37-6ee9198eceec",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[16390, 467, 162, 3, 45, "Subsubsection",ExpressionUUID->"db71da26-9329-45f8-acd7-26db90dfe6ac"],
Cell[CellGroupData[{
Cell[16577, 474, 389, 10, 31, "Input",ExpressionUUID->"6ed01f54-f897-4279-bbd1-edac5de65cd9"],
Cell[16969, 486, 370, 10, 35, "Output",ExpressionUUID->"204f53f5-bc42-4767-ab99-96d45e256ef2"]
}, Open  ]],
Cell[17354, 499, 818, 21, 47, "Input",ExpressionUUID->"87ef30c6-2a04-4375-a307-5c16f065de84",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[18197, 524, 1125, 35, 31, "Input",ExpressionUUID->"b1385f34-7d59-4297-8850-b9193b5f3ccd"],
Cell[19325, 561, 352, 10, 35, "Output",ExpressionUUID->"f8b8eb7f-79a6-4a21-a7c0-d1fea2969620"]
}, Open  ]],
Cell[19692, 574, 482, 12, 47, "Input",ExpressionUUID->"3cd3795d-ffee-4a9f-9074-1ff2fcdeba6f",
 InitializationCell->True],
Cell[20177, 588, 3590, 96, 117, "Input",ExpressionUUID->"02b93f40-7208-40ba-bc64-465a5f8aa2f2",
 InitializationCell->True],
Cell[23770, 686, 518, 14, 47, "Input",ExpressionUUID->"d52ec479-6515-4a0d-82a5-e31eadf617b4",
 InitializationCell->True],
Cell[24291, 702, 723, 18, 71, "Input",ExpressionUUID->"e15aa61d-869b-47b9-82c7-c1222f8843f4",
 InitializationCell->True],
Cell[25017, 722, 1412, 44, 104, "Input",ExpressionUUID->"ee5959e4-427f-4753-b449-bfb8bb8f1e18",
 InitializationCell->True],
Cell[26432, 768, 2293, 62, 209, "Input",ExpressionUUID->"c600e65a-7d41-423b-b8f5-29e82b96c80f",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[28750, 834, 817, 20, 87, "Text",ExpressionUUID->"e3a52ec5-3c08-44b3-9cce-bd8f4f37bc2d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[29570, 856, 1477, 39, 85, "Input",ExpressionUUID->"313ab1c8-e19f-4744-8136-f35d85faa684",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[31050, 897, 3560, 83, 195, "Output",ExpressionUUID->"c82ad0dd-a769-46b2-b271-bb5eb9895bf6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[34613, 982, 1497, 42, 81, "Input",ExpressionUUID->"59726641-82d3-4482-97fe-76e1a7681b34",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[36113, 1026, 563, 14, 31, "Input",ExpressionUUID->"d64d477a-d745-4291-bec9-c9226f61c55b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[36679, 1042, 902, 27, 54, "Output",ExpressionUUID->"966ec782-74b7-47ae-b4c7-a669232d18e3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[37584, 1071, 409, 10, 31, "Input",ExpressionUUID->"712bf6f3-b95b-4471-9eaf-3f7092d89fc5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[37996, 1083, 595, 18, 35, "Output",ExpressionUUID->"c6e5a649-e307-4600-b4ad-d76da56b7042",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[38594, 1103, 323, 7, 31, "Input",ExpressionUUID->"cd24a97b-ec94-4ad7-aaa4-3b8018ae7082",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[38920, 1112, 706, 21, 35, "Output",ExpressionUUID->"5aee4ea4-e639-48e2-a149-abef2009d8b5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[39629, 1135, 373, 7, 37, "Text",ExpressionUUID->"c0f21a23-23eb-478b-b89b-36c8da924e1b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[40005, 1144, 1176, 32, 71, "Input",ExpressionUUID->"d5d4ecdf-3d0e-49b5-a836-381915f67d69",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[41184, 1178, 4969, 153, 195, "Output",ExpressionUUID->"b54bbded-4854-4946-84cb-b4f1ac6ea972",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[46168, 1334, 365, 7, 37, "Text",ExpressionUUID->"3af17cd1-3833-4524-85e3-8cc7394f41cb"],
Cell[46536, 1343, 1136, 32, 51, "Input",ExpressionUUID->"a8d2c8a1-a1b6-4f54-9bc8-b5374e3be367",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[47697, 1379, 539, 14, 31, "Input",ExpressionUUID->"3010849a-3b37-4fd3-b91d-d07677847819"],
Cell[48239, 1395, 195, 5, 35, "Output",ExpressionUUID->"b235437c-2273-49bd-bce3-e952b210960d"]
}, Open  ]],
Cell[48449, 1403, 1590, 47, 94, "Input",ExpressionUUID->"4729d88a-ae2c-44a9-93dd-831e1d438474",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[50064, 1454, 294, 8, 31, "Input",ExpressionUUID->"05fb42c6-6db5-4061-a493-4daf109d40f3"],
Cell[50361, 1464, 893, 28, 86, "Output",ExpressionUUID->"90aa1f45-17fe-4615-81d8-164cca898da4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51291, 1497, 1361, 39, 78, "Input",ExpressionUUID->"53b3c949-d43b-4684-b078-18e19f5205e2"],
Cell[52655, 1538, 468, 12, 35, "Output",ExpressionUUID->"d649776a-eb38-4099-866d-9f84689ba05f"]
}, Open  ]],
Cell[53138, 1553, 507, 14, 37, "Text",ExpressionUUID->"94086087-c539-4056-9bde-423c381abf9d"],
Cell[53648, 1569, 5490, 147, 278, "Input",ExpressionUUID->"b386e61c-41ed-4b66-97ae-23235a6e2efc",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[59163, 1720, 969, 28, 55, "Input",ExpressionUUID->"3d06ba70-a6bf-4263-b908-a5e255b970a9"],
Cell[60135, 1750, 195, 5, 35, "Output",ExpressionUUID->"92c0ae0b-4791-48f6-8561-445b205c9e9c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60367, 1760, 512, 9, 66, "Text",ExpressionUUID->"9eaeb7c8-c247-429f-85de-fad15bd67612",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[60882, 1771, 1765, 52, 85, "Input",ExpressionUUID->"d8039ebd-1804-460f-b335-9f97966598f2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[62650, 1825, 5486, 171, 412, "Output",ExpressionUUID->"7d38776d-cdf7-4b4a-8102-eb206276ebe8",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[68139, 1998, 893, 25, 35, "Input",ExpressionUUID->"ec686e09-4e03-4863-bd9f-af3af7fe6b4f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[69035, 2025, 316, 6, 35, "Output",ExpressionUUID->"7d26e16d-c532-414c-a99c-df9ed51b1ae1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[69354, 2033, 790, 20, 55, "Input",ExpressionUUID->"ecd5792a-6168-4032-a039-f421283cd23e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[70147, 2055, 81338, 2130, 2059, "Output",ExpressionUUID->"2670487b-3385-4219-8c42-5fedd8269f3f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[151488, 4187, 885, 25, 58, "Input",ExpressionUUID->"d03a8885-e85f-4f6b-832e-39b4d0d0db0e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[152376, 4214, 297, 5, 35, "Output",ExpressionUUID->"72431feb-5f40-4851-a045-c3e04e3839a1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[152676, 4221, 1101, 32, 58, "Input",ExpressionUUID->"30392f69-dbfd-493a-8e5e-148203044a13",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[153780, 4255, 407, 10, 35, "Output",ExpressionUUID->"1dc9496e-3261-4c8f-a6ab-0c7d0672e4ba",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[154190, 4267, 885, 24, 58, "Input",ExpressionUUID->"04ff1977-2449-4edf-9a9e-0cdacff2ffdd",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[155078, 4293, 297, 5, 35, "Output",ExpressionUUID->"88ed134e-2da5-454f-aa80-41baa8d2d91a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[155378, 4300, 1441, 31, 101, "Input",ExpressionUUID->"54fe3d21-183d-43ce-aeac-bc186495a0c9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[156822, 4333, 913, 13, 289, "Output",ExpressionUUID->"e9c61812-4dbc-47ad-9fd4-5450c8eef737",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[157738, 4348, 208, 4, 31, "Input",ExpressionUUID->"c7536897-61ad-4c43-a90e-727ea342a540",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[157949, 4354, 288, 6, 39, "Text",ExpressionUUID->"c2618caa-ede1-4660-8233-ba134ac90890",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[158240, 4362, 1476, 36, 78, "Input",ExpressionUUID->"c9e59cb5-490a-44a6-ab5d-ccb074754947",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[159719, 4400, 678, 18, 31, "Input",ExpressionUUID->"9b8db173-f303-4672-99c9-df41e03a9a8b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[160400, 4420, 3278, 100, 151, "Output",ExpressionUUID->"d7e9bb88-0021-4757-af1b-eb964628d323",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[163681, 4522, 6225, 153, 262, "Input",ExpressionUUID->"b75942f0-ab45-4de6-832a-976c1700b16f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[169909, 4677, 1099, 30, 55, "Input",ExpressionUUID->"bdc4bd6a-80d3-4f77-8dbd-94a61b6e530f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[171011, 4709, 294, 6, 35, "Output",ExpressionUUID->"e0c1dbb6-fa54-4672-b594-7f429e10e108",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[171320, 4718, 278, 6, 37, "Text",ExpressionUUID->"b7b2c110-6e58-421e-8469-db16d2735ee4"],
Cell[171601, 4726, 2887, 70, 232, "Input",ExpressionUUID->"aeef4b89-aac9-4416-ba20-4c37d3f66fd2",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[174513, 4800, 354, 10, 31, "Input",ExpressionUUID->"0b333c87-1c40-41bf-874a-dac61eefd811"],
Cell[174870, 4812, 805, 25, 35, "Output",ExpressionUUID->"6a29b381-644e-433a-a3fe-89b456d93830"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175712, 4842, 302, 8, 31, "Input",ExpressionUUID->"dd5a830d-cee2-4cdf-9e0b-443c2867a93c"],
Cell[176017, 4852, 1540, 46, 93, "Output",ExpressionUUID->"9425af53-d180-4335-8196-a7865f1cbf99"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177594, 4903, 904, 27, 55, "Input",ExpressionUUID->"f368d518-32c2-422f-8bdb-0fd58cc4f8cb"],
Cell[178501, 4932, 182, 4, 35, "Output",ExpressionUUID->"b640dbee-4276-4238-b853-2c017f6b0884"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178720, 4941, 1425, 42, 81, "Input",ExpressionUUID->"2e6608f9-a2eb-4b20-9542-f85f23d5fed1"],
Cell[180148, 4985, 2022, 62, 93, "Output",ExpressionUUID->"805ade3b-e004-44e4-9244-3788d5e8b675"]
}, Open  ]],
Cell[182185, 5050, 3823, 106, 186, "Input",ExpressionUUID->"edc70156-a6c4-4084-a4f2-68e36b5725b8",
 InitializationCell->True],
Cell[186011, 5158, 439, 8, 87, "Text",ExpressionUUID->"d070abeb-7b5a-43c2-b3e8-191ea649fe90"],
Cell[186453, 5168, 13473, 339, 862, "Input",ExpressionUUID->"1379b963-3089-4bd1-abfd-543249af94e1",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[199951, 5511, 836, 25, 55, "Input",ExpressionUUID->"cbd5ea1a-4234-40b8-90d9-6987f59aad80"],
Cell[200790, 5538, 370, 11, 35, "Output",ExpressionUUID->"5a3f7a1f-0e43-4c00-b0e8-d8e8cbda0da9"]
}, Open  ]],
Cell[201175, 5552, 219, 4, 31, "Input",ExpressionUUID->"2dee8d68-a221-486c-bb72-96c52f18c72c"],
Cell[CellGroupData[{
Cell[201419, 5560, 183, 3, 31, "Input",ExpressionUUID->"1aa5afb5-03b0-43c7-a90d-12ff8b98887b"],
Cell[201605, 5565, 183, 4, 52, "Output",ExpressionUUID->"fb7c0628-c49b-4d27-9529-80450d9630fd"]
}, Open  ]],
Cell[201803, 5572, 4371, 100, 255, "Input",ExpressionUUID->"1b231e7a-d134-4b2a-8271-d14836ca222f",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[206199, 5676, 336, 9, 31, "Input",ExpressionUUID->"7f20c1b9-727a-4b60-9fc7-b1ba641317b5"],
Cell[206538, 5687, 553, 15, 35, "Output",ExpressionUUID->"6fbc493f-dfd0-4cbe-8fa9-1c04ca9cfbd7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[207128, 5707, 411, 9, 55, "Input",ExpressionUUID->"44afc2b1-5740-41ad-8c7e-d0457a1e5ab9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[207542, 5718, 670, 15, 35, "Output",ExpressionUUID->"82cadfc8-755a-48a1-b226-cb4f869bb6d3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[208215, 5735, 420, 10, 31, "Input",ExpressionUUID->"748629fc-0168-494d-ac50-bfbb4d8a8960",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[208638, 5747, 2618, 65, 86, "Output",ExpressionUUID->"20160821-10fb-4873-9806-979315d4c84b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[211259, 5814, 1176, 34, 78, "Input",ExpressionUUID->"bcacd23a-fe2b-454e-a10c-b4a7822197cf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[212438, 5850, 1575, 42, 82, "Output",ExpressionUUID->"b13632ed-6870-40e3-8c3e-370722aa2c35",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[214016, 5894, 482, 11, 31, "Input",ExpressionUUID->"4fab7ee6-1348-4d8d-bab6-96a4cdf653b9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[214501, 5907, 807, 19, 35, "Output",ExpressionUUID->"88f7cf61-979a-4da2-9b08-dce0cc5c9a58",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[215311, 5928, 636, 17, 31, "Input",ExpressionUUID->"791d5b50-b6dd-489e-a02c-d299bb6cd691",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[215950, 5947, 424, 10, 35, "Output",ExpressionUUID->"a3987152-0800-42da-b7bf-c9951184814d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[216377, 5959, 1742, 45, 124, "Input",ExpressionUUID->"746e750e-cc03-458f-af87-06757ad3b22a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[218122, 6006, 432, 11, 31, "Input",ExpressionUUID->"9f448b6a-347f-4813-960a-bb130ff229ea",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[218557, 6019, 1063, 26, 59, "Output",ExpressionUUID->"4c39c365-4bb3-4a14-8097-40a572ec88dd",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[219623, 6047, 417, 10, 31, "Input",ExpressionUUID->"8e784fd2-ed48-43f0-92ae-aa8d826fcb6c",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[220043, 6059, 676, 16, 35, "Output",ExpressionUUID->"795b6b6d-3a74-4823-ad36-af4ccdbc9a0c",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[220722, 6077, 485, 12, 31, "Input",ExpressionUUID->"db364916-a81a-46e9-b3e3-5df12d2bbc9f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[221210, 6091, 1094, 26, 59, "Output",ExpressionUUID->"7383b543-0c33-4f93-a7c5-61dd3c8cd71d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[222307, 6119, 877, 23, 55, "Input",ExpressionUUID->"14dc3aab-5a23-4601-bf95-d0019de0dece",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[223187, 6144, 1064, 26, 59, "Output",ExpressionUUID->"611f2af6-277a-4556-9049-97ee46c934d6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[224254, 6172, 348, 8, 31, "Input",ExpressionUUID->"e5228c88-e70c-4a62-8456-585cac464f33",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[224605, 6182, 743, 20, 35, "Output",ExpressionUUID->"5e1c3e9b-1007-48b8-b811-00e988c4ceba",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[225351, 6204, 323, 7, 31, "Input",ExpressionUUID->"ae55ac47-d22e-46d1-ae57-36aa29732b3b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[225677, 6213, 630, 15, 35, "Output",ExpressionUUID->"7d746430-8508-42a4-8b86-3a3a565fabf9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[226310, 6230, 505, 12, 31, "Input",ExpressionUUID->"bb757c42-1621-4175-8c11-3545ef5031f0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[226818, 6244, 258, 5, 35, "Output",ExpressionUUID->"db1f1b51-f397-4ea2-a7e7-92aee8f5f1af",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[227079, 6251, 2614, 65, 78, "Input",ExpressionUUID->"e60b2c30-7147-433c-b4e4-45cd1f1e939d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[229696, 6318, 2361, 48, 126, "Output",ExpressionUUID->"af748b6c-fec9-41b0-89bb-0bb2866f2d57",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[232072, 6369, 423, 8, 22, "Message",ExpressionUUID->"59644dce-2b59-45a3-8587-9be5306d6aaa"],
Cell[232498, 6379, 442, 9, 22, "Message",ExpressionUUID->"07e1d662-05b7-4625-9e71-4e77445efb68"],
Cell[232943, 6390, 442, 9, 22, "Message",ExpressionUUID->"04f93c91-3dea-418b-8e44-3328679b712e"],
Cell[233388, 6401, 410, 8, 22, "Message",ExpressionUUID->"c15a3b5b-c11b-43db-ae99-573c3260bcb5"],
Cell[233801, 6411, 595, 10, 108, "Text",ExpressionUUID->"cd687a2e-5201-4c32-93f6-33c091757497"],
Cell[234399, 6423, 1929, 52, 209, "Input",ExpressionUUID->"dc20f87c-24d4-485c-b77d-a83a82735735",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[236353, 6479, 1038, 31, 108, "Input",ExpressionUUID->"af55f316-e8ba-451f-8d1d-c9959e023d9d"],
Cell[237394, 6512, 382, 11, 35, "Output",ExpressionUUID->"791e646a-0602-4703-a8ed-f4aaeaffea0a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237813, 6528, 611, 16, 55, "Input",ExpressionUUID->"a64b76e0-53a3-4b8e-9a84-1c6dc7188219"],
Cell[238427, 6546, 346, 10, 35, "Output",ExpressionUUID->"359c70cd-363d-480f-9afe-7ff4be4ab349"]
}, Open  ]],
Cell[238788, 6559, 131, 3, 31, "Input",ExpressionUUID->"32a75acb-acf5-4f16-877b-bd80906bab18"],
Cell[238922, 6564, 1529, 41, 117, "Input",ExpressionUUID->"1948996e-8c99-4955-b232-db505c837334",
 InitializationCell->True],
Cell[240454, 6607, 2593, 65, 186, "Input",ExpressionUUID->"f83f57bd-4ea2-4740-92c0-6a3f1d68a370",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[243072, 6676, 283, 6, 37, "Text",ExpressionUUID->"d6fcc2fc-1fb8-4ee9-ac64-ef125cb1c702",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[243358, 6684, 589, 15, 31, "Input",ExpressionUUID->"5b6453b7-1ddd-4982-9050-6758d28a2598",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[243950, 6701, 333, 8, 35, "Output",ExpressionUUID->"b43ddad9-f9e9-49ef-ab8c-7b6daf054d1b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[244286, 6711, 493, 14, 31, "Input",ExpressionUUID->"e443908f-9e32-4610-9ec0-cdec7fe37083",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[244782, 6727, 751, 20, 35, "Output",ExpressionUUID->"10cb87b1-5783-498d-8c3b-66f4c66d5bf0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[245536, 6749, 2728, 72, 193, "Input",ExpressionUUID->"6a8ecf06-315a-4aa3-bad0-53a6d49964b5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[248267, 6823, 67590, 1460, 206, "Output",ExpressionUUID->"c4f8d7d2-2ab8-40ea-bae0-1f57442d6907",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[315894, 8288, 414, 11, 35, "Text",ExpressionUUID->"5ac11885-fe92-436d-9440-03e8245ac652",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[316311, 8301, 973, 28, 55, "Input",ExpressionUUID->"1b49c889-3181-486b-ae88-2e48bf8d6b30",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[317287, 8331, 1890, 54, 93, "Output",ExpressionUUID->"2c3645d3-6b0c-48c1-a297-d472dde93c20",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[319180, 8387, 3360, 93, 108, "Input",ExpressionUUID->"660b1eda-1291-4918-97a7-fd311852a14f",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[322543, 8482, 2880, 80, 77, "Output",ExpressionUUID->"bc1465c4-ae1c-4f1e-8d28-275182d825ff",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[325426, 8564, 710, 18, 31, "Input",ExpressionUUID->"29974b0d-3dc3-46fc-85fa-ad78c6f03160",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}],
Cell[326139, 8584, 2835, 85, 120, "Output",ExpressionUUID->"e58b40c7-f3da-4e6b-88a5-a97c9370e97b",
 CellGroupingRules->{"GroupTogetherGrouping", 10001.}]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[329035, 8676, 423, 6, 68, "Section",ExpressionUUID->"ea156c93-390a-40b0-b9e4-13e491dd53e8"],
Cell[329461, 8684, 1214, 31, 85, "Input",ExpressionUUID->"a6863ca0-67a1-454b-b8d1-08567101ccbe"],
Cell[330678, 8717, 429, 8, 37, "Text",ExpressionUUID->"0c6c834c-1733-4164-831d-fd99406549cc",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[CellGroupData[{
Cell[331132, 8729, 530, 14, 31, "Input",ExpressionUUID->"43bc3b1f-d892-4736-9c4f-cc1c91deb70d"],
Cell[331665, 8745, 231, 4, 35, "Output",ExpressionUUID->"9f9cad83-7e18-4b4f-855f-5ed9a4347ea4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331933, 8754, 256, 6, 31, "Input",ExpressionUUID->"f5e2e995-391f-4c1a-9498-3380df0cf807"],
Cell[332192, 8762, 679, 17, 59, "Output",ExpressionUUID->"b6a5f092-9151-412f-ac94-0df8062a7d35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[332908, 8784, 433, 10, 31, "Input",ExpressionUUID->"4b8665f4-376d-44b1-a890-42d0c1ab6f29"],
Cell[333344, 8796, 2640, 76, 187, "Output",ExpressionUUID->"1a0f180c-f092-43c0-a06f-0d254e9eaf6e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[336045, 8879, 261, 5, 65, "Subchapter",ExpressionUUID->"e523ad89-3903-43e3-84bf-6534ef2522fc"],
Cell[336309, 8886, 265, 6, 31, "Input",ExpressionUUID->"e808e76c-f034-4ce1-b530-326ab82a58ab"],
Cell[336577, 8894, 454, 11, 31, "Input",ExpressionUUID->"59eb3e4b-73ca-4735-8611-4e816140d8b3"],
Cell[337034, 8907, 395, 10, 31, "Input",ExpressionUUID->"1000df5c-8457-47a6-bfa5-0e780767f7ea"],
Cell[337432, 8919, 345, 9, 31, "Input",ExpressionUUID->"8cc3e9d3-aa9a-4988-9e13-7fe238bac849"],
Cell[337780, 8930, 1066, 28, 78, "Input",ExpressionUUID->"1c4c4d7d-8f79-408c-bc05-ee2b1dfe34ac"],
Cell[338849, 8960, 1194, 30, 78, "Input",ExpressionUUID->"aa5d76b6-9b8a-43d9-92e1-b853ec6fc8f4"],
Cell[CellGroupData[{
Cell[340068, 8994, 196, 4, 31, "Input",ExpressionUUID->"0aff2cfd-8866-47ba-b1ac-dc5972c71f50"],
Cell[340267, 9000, 2314, 60, 128, "Output",ExpressionUUID->"0f97a779-8d18-4d6b-b069-781c79f67c76"]
}, Open  ]],
Cell[CellGroupData[{
Cell[342618, 9065, 329, 9, 31, "Input",ExpressionUUID->"aa874b8b-f178-40b7-ae48-9abd09b4597c"],
Cell[342950, 9076, 449, 13, 35, "Output",ExpressionUUID->"2bcbf03d-1da1-4413-9d81-54b85ac04235"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343436, 9094, 567, 15, 117, "Text",ExpressionUUID->"c0005cd0-c90e-4b09-8d45-45044a7d3b1d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[344006, 9111, 3589, 104, 185, "Input",ExpressionUUID->"9b946ebc-ea11-4f0c-bb3c-b3357e20bf27",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[347598, 9217, 5925, 193, 382, "Input",ExpressionUUID->"d4e84bf1-d993-4fe3-be2c-31bf5644a831",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[353526, 9412, 422, 8, 82, "Text",ExpressionUUID->"0ccd9650-2787-437e-a240-0d94e09331bd",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[353951, 9422, 2116, 62, 156, "Input",ExpressionUUID->"94bb3881-9c31-421c-85a8-8d176094f942",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[356070, 9486, 1050, 36, 68, "Output",ExpressionUUID->"20b95de8-4fe7-4259-a35d-f19a29b06ce4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[357123, 9524, 2266, 64, 156, "Input",ExpressionUUID->"5cfc5699-8557-48da-9c94-aa718473153b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[359392, 9590, 1195, 39, 68, "Output",ExpressionUUID->"3ca72701-7bc3-421a-8551-5f90982d94e5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[360590, 9631, 2064, 61, 156, "Input",ExpressionUUID->"df2b95c4-64e5-43bd-a87f-a278bd8977dc",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[362657, 9694, 748, 25, 68, "Output",ExpressionUUID->"3943c3c2-49eb-46ca-9ff7-dfd4d086a0f7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[363442, 9724, 1095, 31, 143, "Input",ExpressionUUID->"bad0fdd9-f69b-4c3a-ac4e-e5470b2e222c"],
Cell[364540, 9757, 675, 22, 52, "Output",ExpressionUUID->"afc03b1b-aec9-44be-86e4-e6d20b87d2a9"]
}, Open  ]],
Cell[365230, 9782, 861, 27, 78, "Input",ExpressionUUID->"bb3c6292-0046-4196-9507-56297fd07ae4",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[366116, 9813, 1271, 37, 102, "Input",ExpressionUUID->"12d56fec-c68f-42a1-b5ba-cebe2fb3d629",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True],
Cell[367390, 9852, 965, 30, 47, "Input",ExpressionUUID->"3fa53f0f-53ca-4e4c-a89a-291de517a150",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[368358, 9884, 1090, 33, 48, "Input",ExpressionUUID->"7e1bc77d-151f-4375-b4e0-e7beea27e1a4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[369451, 9919, 2040, 61, 87, "Input",ExpressionUUID->"ef3e1d89-8477-4dac-b0f3-36932074b698",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[371494, 9982, 207, 4, 35, "Output",ExpressionUUID->"007a4982-442b-4e6e-98cf-aeef3b1b10a2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[371738, 9991, 862, 23, 74, "Input",ExpressionUUID->"117bc67e-bb2d-45f6-882f-f30e93e98d25"],
Cell[372603, 10016, 348, 9, 39, "Output",ExpressionUUID->"e4328809-cc98-451f-b414-5eefe0ec72c6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[372988, 10030, 658, 18, 31, "Input",ExpressionUUID->"a4bcc574-54bf-48a1-bdd3-615c414a1ac9"],
Cell[373649, 10050, 623, 21, 53, "Output",ExpressionUUID->"3dcbf1f6-81bc-4966-9328-12677d7ff669"]
}, Open  ]],
Cell[CellGroupData[{
Cell[374309, 10076, 543, 17, 31, "Input",ExpressionUUID->"92f9325e-6eaa-4d2f-a88a-073796ab53b9"],
Cell[374855, 10095, 156, 3, 35, "Output",ExpressionUUID->"a220556b-586f-4f15-98c4-551989ae61e4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[375048, 10103, 805, 24, 55, "Input",ExpressionUUID->"fe52a415-7aa5-44dc-a945-5eccdb0c3d2d"],
Cell[375856, 10129, 1014, 34, 94, "Output",ExpressionUUID->"310c86ad-9813-43c2-aca5-a08db582c4be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[376907, 10168, 340, 10, 31, "Input",ExpressionUUID->"065101e7-4570-48ad-994d-6b89b06a6fbc"],
Cell[377250, 10180, 363, 11, 52, "Output",ExpressionUUID->"f58d336b-d131-4091-8947-6878f28aa370"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377650, 10196, 568, 16, 31, "Input",ExpressionUUID->"20197db0-5360-41ee-a1e1-9b519f7b1df6"],
Cell[378221, 10214, 542, 18, 57, "Output",ExpressionUUID->"aa0331aa-1202-4414-95c8-29d6c220c2af"]
}, Open  ]],
Cell[CellGroupData[{
Cell[378800, 10237, 640, 21, 71, "Input",ExpressionUUID->"5ca6a947-4f91-4c56-91c4-9d9a0247cecf"],
Cell[379443, 10260, 259, 9, 52, "Output",ExpressionUUID->"9c6eb6c1-db96-49af-a66d-9bdcca0da2c2"]
}, Open  ]],
Cell[379717, 10272, 442, 11, 47, "Input",ExpressionUUID->"3652efd4-4b05-4efa-95e2-ddc676fc2588",
 InitializationCell->True],
Cell[380162, 10285, 213, 4, 31, "Input",ExpressionUUID->"0f68d42c-19ca-4b34-a16d-2f6a031740a6"],
Cell[380378, 10291, 3551, 92, 475, "Input",ExpressionUUID->"bfafe1db-94f6-4a65-902a-f06dc6d43598",
 InitializationCell->True],
Cell[383932, 10385, 4572, 117, 587, "Input",ExpressionUUID->"1bf50598-7ea3-4609-af1f-eb014ea51110",
 InitializationCell->True],
Cell[388507, 10504, 377, 7, 37, "Text",ExpressionUUID->"cbe54daf-051f-47e5-a764-732073ed6914"],
Cell[388887, 10513, 4644, 118, 587, "Input",ExpressionUUID->"fe37daee-5463-407e-9a06-baa0c45f9d36",
 InitializationCell->True],
Cell[393534, 10633, 3782, 97, 496, "Input",ExpressionUUID->"b97da43f-f9a3-4ee4-a5c9-46057fb3202e",
 InitializationCell->True],
Cell[397319, 10732, 246, 5, 37, "Text",ExpressionUUID->"e4168531-de11-4e3c-ae49-839b8ca9fa27"],
Cell[397568, 10739, 2086, 57, 193, "Input",ExpressionUUID->"7350e831-66d0-449e-987f-d874647ba0d7",
 InitializationCell->True],
Cell[399657, 10798, 264, 6, 37, "Text",ExpressionUUID->"3c91d99f-2f99-4650-8f5a-89929bc5fe7a"],
Cell[CellGroupData[{
Cell[399946, 10808, 180, 2, 31, "Input",ExpressionUUID->"02bdf75f-fcbf-4445-a8e3-d1ee09940806"],
Cell[400129, 10812, 401, 10, 35, "Output",ExpressionUUID->"98d70663-edf5-4283-b311-aae2e584c7b4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[400567, 10827, 389, 9, 31, "Input",ExpressionUUID->"4bcaecce-cd51-4188-8d1a-5652b3a66663"],
Cell[400959, 10838, 1610, 46, 105, "Output",ExpressionUUID->"0e2cd394-fbd6-4ffa-9e0f-ce1c1075548e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[402606, 10889, 191, 3, 31, "Input",ExpressionUUID->"513000f1-764b-432f-b225-3a4ae60a0ce9"],
Cell[402800, 10894, 1133, 33, 59, "Output",ExpressionUUID->"17200187-e53b-4dd0-8333-60427836d797"]
}, Open  ]],
Cell[CellGroupData[{
Cell[403970, 10932, 255, 5, 31, "Input",ExpressionUUID->"c205b439-da2f-4e44-9fa4-2afc98c0c7d6"],
Cell[404228, 10939, 512, 12, 35, "Output",ExpressionUUID->"5f30ad6e-ff43-432a-aebf-21a170c712d0"]
}, Open  ]],
Cell[404755, 10954, 277, 6, 37, "Text",ExpressionUUID->"21a0ba0c-d60a-4341-8535-7dda02e45759"],
Cell[405035, 10962, 319, 7, 37, "Text",ExpressionUUID->"014f9ba4-1838-477b-954a-d5b69d0f8ce1"],
Cell[CellGroupData[{
Cell[405379, 10973, 180, 2, 31, "Input",ExpressionUUID->"40748e7b-b4f3-44a4-9233-194c6b3f9919"],
Cell[405562, 10977, 525, 13, 35, "Output",ExpressionUUID->"27b0fa65-ae9d-4a6d-a83b-4d673dae12ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406124, 10995, 198, 3, 31, "Input",ExpressionUUID->"0c8a03dd-9ad2-4bf9-a3ba-97cbaf0f60df"],
Cell[CellGroupData[{
Cell[406347, 11002, 189, 4, 46, "Print",ExpressionUUID->"c1e7ae49-ab68-47e5-8339-c6373c984492",
 CellTags->"Info683742981000-7551584"],
Cell[406539, 11008, 5441, 118, 202, "Print",ExpressionUUID->"a5822828-3359-4efa-b872-9078f4e3dac0",
 CellTags->"Info683742981000-7551584"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[412029, 11132, 651, 17, 55, "Input",ExpressionUUID->"f6ee43f8-df5d-4b82-bf03-daa77c0a4dc4"],
Cell[412683, 11151, 1499, 37, 105, "Output",ExpressionUUID->"f6b24bf9-addf-4da6-8ea4-a293c617cdc2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[414219, 11193, 150, 2, 31, "Input",ExpressionUUID->"51dbfc67-c1ba-41d1-94ca-8267723789a5"],
Cell[414372, 11197, 1495, 36, 105, "Output",ExpressionUUID->"a808b9cc-7681-4d9c-85f3-993d796b17c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[415904, 11238, 516, 12, 55, "Input",ExpressionUUID->"aeae8c53-2cf4-4a2a-88f7-b94fb90b4fab"],
Cell[416423, 11252, 3642, 102, 194, "Output",ExpressionUUID->"4f9521fa-d3ab-412b-bc9c-d161cb275f0a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[420102, 11359, 255, 5, 31, "Input",ExpressionUUID->"6487a81a-6b26-431a-b9e4-b0e3d4efef94"],
Cell[420360, 11366, 490, 12, 35, "Output",ExpressionUUID->"c3001de2-d754-4e19-b4f0-3af29c75ce50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[420887, 11383, 482, 15, 35, "Input",ExpressionUUID->"63dcfda5-add2-476d-b16f-6f10b0d8c0e1"],
Cell[421372, 11400, 1636, 54, 59, "Output",ExpressionUUID->"4faab36c-7e94-4e06-8f00-a7694636abbe"]
}, Open  ]],
Cell[423023, 11457, 279, 6, 37, "Text",ExpressionUUID->"5536ad9f-48a3-439f-9edc-31013be67ea1"],
Cell[CellGroupData[{
Cell[423327, 11467, 570, 13, 31, "Input",ExpressionUUID->"eaec67b9-e2db-4c8e-a4a4-a9939cdc200b"],
Cell[423900, 11482, 5061, 137, 230, "Output",ExpressionUUID->"13d5bf72-d8f3-4ee7-9f61-eb82bd8df40b"]
}, Closed]],
Cell[CellGroupData[{
Cell[428998, 11624, 567, 13, 27, "Input",ExpressionUUID->"23c60a05-549e-43e2-bbdb-0a61bb84d1a2"],
Cell[429568, 11639, 18268, 466, 981, "Output",ExpressionUUID->"5037799b-955d-4053-b324-601b1a15f789"]
}, Closed]],
Cell[CellGroupData[{
Cell[447873, 12110, 250, 6, 27, "Input",ExpressionUUID->"0f6fb15f-19f2-4373-a4a5-7a33034c3fbd"],
Cell[448126, 12118, 214, 4, 35, "Output",ExpressionUUID->"8b396f20-aef1-4574-8b79-dab37f727aaa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448377, 12127, 314, 7, 31, "Input",ExpressionUUID->"e95600d9-c1c0-44bd-b353-66bec5088a4a"],
Cell[448694, 12136, 240, 4, 35, "Output",ExpressionUUID->"4ea5f875-7247-4fd7-a5e3-04a1df593531"]
}, Open  ]],
Cell[448949, 12143, 129, 3, 31, "Input",ExpressionUUID->"b8094579-cdc7-4fa1-8862-a7610507be96"],
Cell[449081, 12148, 195, 4, 31, "Input",ExpressionUUID->"ae39a321-2ce4-43ec-88c7-22ebf1e0ab9d"],
Cell[CellGroupData[{
Cell[449301, 12156, 323, 8, 31, "Input",ExpressionUUID->"beb93e13-23c7-4a48-a36a-2b74c5593586"],
Cell[449627, 12166, 290, 7, 35, "Output",ExpressionUUID->"b84aedb3-e987-4604-a484-be263683374e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449954, 12178, 331, 7, 31, "Input",ExpressionUUID->"4bdc57da-cb8d-466a-88f3-8cf13cbb84d3"],
Cell[450288, 12187, 296, 6, 35, "Output",ExpressionUUID->"fe06540e-91ba-4917-895c-6dba7c8c5574"]
}, Open  ]],
Cell[CellGroupData[{
Cell[450621, 12198, 866, 25, 62, "Input",ExpressionUUID->"77a5fa93-71c9-4859-a7cf-5f63c7a40faa"],
Cell[451490, 12225, 1001, 32, 59, "Output",ExpressionUUID->"9100869b-3985-4ad9-a76a-e0e6cbec247a"]
}, Open  ]],
Cell[452506, 12260, 154, 3, 31, "Input",ExpressionUUID->"32041c54-28d5-4c74-8de3-1d2a434bcb7f"],
Cell[CellGroupData[{
Cell[452685, 12267, 367, 10, 31, "Input",ExpressionUUID->"7cef1013-ae98-49b4-8d0d-7019ca61d986"],
Cell[453055, 12279, 202, 6, 35, "Output",ExpressionUUID->"acb2d488-650c-4765-b45e-e6d143dd50b5"]
}, Open  ]],
Cell[453272, 12288, 574, 16, 31, "Input",ExpressionUUID->"ba874959-5793-4edd-bb51-8d4f63970788"],
Cell[CellGroupData[{
Cell[453871, 12308, 244, 6, 31, "Input",ExpressionUUID->"835e2ad5-48cf-45a0-b172-19c3acfb06d6"],
Cell[454118, 12316, 1002, 25, 59, "Output",ExpressionUUID->"64f07190-1007-402f-81b7-39b5af34aee0"]
}, Open  ]],
Cell[455135, 12344, 546, 14, 31, "Input",ExpressionUUID->"da0925b4-57aa-45b0-96b4-7dec533fd2ee"],
Cell[CellGroupData[{
Cell[455706, 12362, 224, 5, 31, "Input",ExpressionUUID->"51699fbd-be56-49b9-b68d-d411241e2cee"],
Cell[455933, 12369, 1025, 25, 59, "Output",ExpressionUUID->"702549d1-7032-4630-892b-4c9c4451bae0"]
}, Open  ]],
Cell[456973, 12397, 335, 11, 39, "Text",ExpressionUUID->"cee6ae20-760e-4e3b-8795-eb0c4b5abb5a"],
Cell[CellGroupData[{
Cell[457333, 12412, 305, 8, 31, "Input",ExpressionUUID->"c3349716-ffda-4d2c-8c72-6a97cd50bc10"],
Cell[457641, 12422, 300, 9, 35, "Output",ExpressionUUID->"4dfdb64f-84b9-4f60-9cf0-dcf27c21fdef"]
}, Open  ]],
Cell[457956, 12434, 204, 4, 37, "Text",ExpressionUUID->"43734a4a-3879-477f-8f1f-e40f2492d28b"],
Cell[458163, 12440, 480, 13, 31, "Input",ExpressionUUID->"e1887f12-dc1e-495e-a25e-b95933bb9aac"],
Cell[CellGroupData[{
Cell[458668, 12457, 270, 8, 31, "Input",ExpressionUUID->"d9c7f057-47c9-4974-94d0-f520327e2b76"],
Cell[458941, 12467, 276, 9, 35, "Output",ExpressionUUID->"1f605ce0-af5a-4fec-84f7-c63ae57d3ffa"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[459266, 12482, 329, 7, 141, "Subchapter",ExpressionUUID->"86feb067-2bf4-4d77-b515-378a39a1609b"],
Cell[CellGroupData[{
Cell[459620, 12493, 166, 3, 31, "Input",ExpressionUUID->"b38bad19-4f52-498f-a62a-a58d45d87a30"],
Cell[459789, 12498, 2069, 71, 185, "Output",ExpressionUUID->"541b92db-2091-4946-9703-6052f3b83f9e"]
}, Open  ]],
Cell[461873, 12572, 758, 24, 78, "Input",ExpressionUUID->"a753b40a-5a36-4bb4-90b2-b9a3f3c6f573",
 InitializationCell->True],
Cell[462634, 12598, 1928, 59, 173, "Input",ExpressionUUID->"92b6f116-3ec4-48ce-a89a-fa29e292c524",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[464587, 12661, 747, 24, 62, "Input",ExpressionUUID->"5cfba0b2-8075-40e4-8eef-107277e0cd41"],
Cell[465337, 12687, 278, 7, 54, "Output",ExpressionUUID->"d5ae8931-0ba5-4bf8-ab1f-140b3db3dbd4"]
}, Open  ]],
Cell[465630, 12697, 181, 5, 31, "Input",ExpressionUUID->"571deb14-e7f6-455e-a6b8-8f34c62b36be"],
Cell[CellGroupData[{
Cell[465836, 12706, 434, 11, 55, "Input",ExpressionUUID->"acb7e5d8-c8c9-46ec-b311-19e1634199c7"],
Cell[466273, 12719, 12274, 358, 675, "Output",ExpressionUUID->"ea11446f-bd98-4d53-86ed-7383d19d17e5"]
}, Closed]],
Cell[478562, 13080, 5025, 127, 524, "Input",ExpressionUUID->"82c826e3-9847-4885-a44d-282d8b205196",
 InitializationCell->True],
Cell[483590, 13209, 4716, 132, 560, "Input",ExpressionUUID->"7d7195f9-ea9c-41aa-acf4-10e866568465",
 InitializationCell->True],
Cell[488309, 13343, 236, 5, 37, "Text",ExpressionUUID->"ea430988-606e-49de-9047-25b1f4cca0a7"],
Cell[CellGroupData[{
Cell[488570, 13352, 949, 29, 55, "Input",ExpressionUUID->"db8b037c-df67-48a5-bbb4-f87df7c1c0f6"],
Cell[489522, 13383, 236, 6, 35, "Output",ExpressionUUID->"2f1b732d-32d2-4ce9-9d58-72f5b7db4d02"]
}, Open  ]],
Cell[489773, 13392, 607, 19, 55, "Input",ExpressionUUID->"9f9a6468-56c2-424b-9b97-4e04f6aad47b"],
Cell[490383, 13413, 1601, 44, 101, "Input",ExpressionUUID->"5f745f49-0d92-4170-bd40-544e71efa961"],
Cell[491987, 13459, 691, 18, 55, "Input",ExpressionUUID->"bd1f20c1-8af6-4c7f-b422-59c2abafd9a0"],
Cell[CellGroupData[{
Cell[492703, 13481, 211, 4, 31, "Input",ExpressionUUID->"919f7a6b-526c-46e7-bd09-90d4b04d37c3"],
Cell[492917, 13487, 3983, 93, 151, "Output",ExpressionUUID->"b4d0d35f-d80e-48b9-8b10-7caa69d669b1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[496937, 13585, 474, 12, 55, "Input",ExpressionUUID->"24739dc8-b6ed-425f-8b63-3346f4bc54ac"],
Cell[497414, 13599, 1790, 46, 82, "Output",ExpressionUUID->"81c28879-d4c7-485a-9dde-e623f4364fe8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[499241, 13650, 1079, 32, 55, "Input",ExpressionUUID->"0d8742d5-9812-4d66-856a-4cf95ffd5919"],
Cell[500323, 13684, 351, 10, 35, "Output",ExpressionUUID->"ce54e555-0026-4b87-a7ff-0290fdff527b"]
}, Open  ]],
Cell[500689, 13697, 237, 5, 37, "Text",ExpressionUUID->"2e1f86e8-e009-491d-ae5e-5e477bfdab7a"],
Cell[500929, 13704, 695, 21, 31, "Input",ExpressionUUID->"db77bf6e-8d7d-42c5-bdce-aa2f35086741"],
Cell[CellGroupData[{
Cell[501649, 13729, 349, 9, 31, "Input",ExpressionUUID->"a2eda75f-063a-4d3e-8dd9-dae327645767"],
Cell[502001, 13740, 878, 24, 59, "Output",ExpressionUUID->"c3485109-74fc-4134-beb7-df9e7c9ad5f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[502916, 13769, 294, 7, 31, "Input",ExpressionUUID->"210130fe-59b5-4f56-9b11-bad49abada55"],
Cell[503213, 13778, 3985, 93, 151, "Output",ExpressionUUID->"8ae62fa5-2227-4eca-a129-de60b98921d4"]
}, Open  ]],
Cell[507213, 13874, 1024, 30, 55, "Input",ExpressionUUID->"4690e876-dfa8-4815-b6e6-1f51b045b871"],
Cell[CellGroupData[{
Cell[508262, 13908, 440, 10, 31, "Input",ExpressionUUID->"b01a1c10-8523-4457-8bf1-21351f60f21a"],
Cell[508705, 13920, 878, 24, 59, "Output",ExpressionUUID->"e96a7e5b-7d02-4228-bb9a-9e2cd714c163"]
}, Open  ]],
Cell[CellGroupData[{
Cell[509620, 13949, 676, 20, 55, "Input",ExpressionUUID->"980de284-b1ca-40c9-b507-579e4d830352"],
Cell[510299, 13971, 1445, 37, 82, "Output",ExpressionUUID->"d59ff1ce-27e8-460c-a55f-83135a561c39"]
}, Open  ]],
Cell[CellGroupData[{
Cell[511781, 14013, 1253, 37, 55, "Input",ExpressionUUID->"df51ab2e-7098-4cd4-baa3-50d8a82cdb30"],
Cell[513037, 14052, 1540, 38, 82, "Output",ExpressionUUID->"9ad25639-4bab-4fe3-b7b5-ef1c5092f5fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[514614, 14095, 852, 25, 55, "Input",ExpressionUUID->"4049bde2-a4e7-4623-bcd5-6c9aef8a8e41"],
Cell[515469, 14122, 1419, 37, 82, "Output",ExpressionUUID->"a8b52994-4319-4fb4-b68d-18d47699d1c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516925, 14164, 346, 8, 97, "Subsubsection",ExpressionUUID->"69705374-ec6a-43a1-a48c-52de1b63aad3"],
Cell[CellGroupData[{
Cell[517296, 14176, 999, 29, 55, "Input",ExpressionUUID->"1ca2f849-32d7-42e1-b8ba-fcfb20aa4f5b"],
Cell[518298, 14207, 2930, 76, 142, "Output",ExpressionUUID->"11acd642-bc1b-4ebd-98c8-a65ea40dc40d"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[521289, 14290, 249, 4, 65, "Subchapter",ExpressionUUID->"80371059-b02f-4410-a2d2-5b004fbef82b"],
Cell[521541, 14296, 6999, 194, 457, "Input",ExpressionUUID->"c1abb585-1122-4ffc-b284-5f86155fcd83",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[528565, 14494, 411, 7, 71, "Subsubsection",ExpressionUUID->"807788fa-39ef-413a-86d6-1d6b9f9600f0"],
Cell[CellGroupData[{
Cell[529001, 14505, 241, 5, 31, "Input",ExpressionUUID->"06727341-1095-465b-85e8-1a15157d2b47"],
Cell[529245, 14512, 12253, 315, 559, "Output",ExpressionUUID->"50e61bac-cd22-4336-93c2-b09200a2a2fa"]
}, Closed]],
Cell[541513, 14830, 1957, 57, 247, "Input",ExpressionUUID->"de0583c2-8b93-4f8d-890d-99964d3e869f"],
Cell[543473, 14889, 2887, 77, 347, "Input",ExpressionUUID->"b22de601-2df6-4513-9d04-dd026dae8a82"],
Cell[546363, 14968, 1663, 49, 163, "Input",ExpressionUUID->"6f5ab490-cf3d-40d5-9321-d4a4b568673a"],
Cell[548029, 15019, 1308, 33, 84, "Input",ExpressionUUID->"152ccef4-2cc3-452c-bcf9-c010f6a7c9dc"],
Cell[549340, 15054, 1022, 28, 75, "Input",ExpressionUUID->"25a8fd56-44e7-4ec4-8cf9-5c460b302731"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[550411, 15088, 183, 3, 65, "Subchapter",ExpressionUUID->"67314e02-9e3b-4a80-88b4-110a6d60a5b6"],
Cell[CellGroupData[{
Cell[550619, 15095, 385, 6, 55, "Subsection",ExpressionUUID->"6bce817c-12d6-4bd3-b896-2982bbd001ad"],
Cell[551007, 15103, 1298, 38, 117, "Input",ExpressionUUID->"67ca6994-2b9d-4f97-9415-e1642dd232fb",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[552330, 15145, 194, 3, 45, "Subsubsection",ExpressionUUID->"95118b21-6173-4094-9e80-5fe18e3d1b73"],
Cell[552527, 15150, 898, 25, 71, "Input",ExpressionUUID->"1f9a2d66-72a3-4dd6-80b6-4c2ac2584f4c",
 InitializationCell->True],
Cell[553428, 15177, 886, 24, 71, "Input",ExpressionUUID->"d92aaa99-ed5e-4952-ba3b-72b1199f9105",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[554339, 15205, 193, 4, 31, "Input",ExpressionUUID->"313df013-2625-448d-960f-5596de7f1cde"],
Cell[554535, 15211, 710, 19, 35, "Output",ExpressionUUID->"2be6d02c-038d-4a2b-b91d-04dce16d998c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555282, 15235, 689, 18, 31, "Input",ExpressionUUID->"01e0da64-7b11-4882-aea0-25c73cedf7d5"],
Cell[555974, 15255, 399, 10, 35, "Output",ExpressionUUID->"428a925b-9d09-4c8b-91e1-d1a846f3fa8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[556410, 15270, 648, 17, 31, "Input",ExpressionUUID->"7a4c8d8c-a033-4fba-bb6b-cf12556d070e"],
Cell[557061, 15289, 524, 13, 35, "Output",ExpressionUUID->"4e6f8402-a300-4769-b05a-0634668a3985"]
}, Open  ]],
Cell[CellGroupData[{
Cell[557622, 15307, 1077, 30, 55, "Input",ExpressionUUID->"3997e4c7-7d43-4f4b-804e-b45e63d0dac9"],
Cell[558702, 15339, 214, 4, 35, "Output",ExpressionUUID->"17a350b4-7f33-4add-8057-aaa783eb2d8c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[558953, 15348, 953, 22, 78, "Input",ExpressionUUID->"647f8a96-6772-46fa-8e8a-959628badeac"],
Cell[559909, 15372, 1548, 38, 105, "Output",ExpressionUUID->"8ffdeefc-8566-4aa2-892c-948467fce6b3"]
}, Open  ]],
Cell[561472, 15413, 194, 3, 35, "Text",ExpressionUUID->"7a2e08ab-2397-47b9-a5e2-27bc8700b875"],
Cell[561669, 15418, 567, 15, 47, "Input",ExpressionUUID->"f7f9e68b-8336-4c6e-a824-645d04dad8bc",
 InitializationCell->True],
Cell[562239, 15435, 1267, 36, 117, "Input",ExpressionUUID->"b1dfe5c2-bf33-4554-8476-d4c7ad6b46ac",
 InitializationCell->True],
Cell[563509, 15473, 645, 16, 71, "Input",ExpressionUUID->"1236bef2-3aac-4742-9d6b-f05e71a945d6",
 InitializationCell->True],
Cell[564157, 15491, 1667, 40, 140, "Input",ExpressionUUID->"36303099-486c-4316-b59e-9d30638bf11b",
 InitializationCell->True],
Cell[565827, 15533, 810, 25, 71, "Input",ExpressionUUID->"da722435-9605-43f0-ab03-8cc4702702ab",
 InitializationCell->True],
Cell[566640, 15560, 3581, 109, 151, "Input",ExpressionUUID->"3485fb63-976d-407b-b2ac-9fe87540aeb8",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[570246, 15673, 735, 22, 55, "Input",ExpressionUUID->"1ca7a4ac-5221-49f8-bdf6-858ababd455d"],
Cell[570984, 15697, 1408, 43, 66, "Output",ExpressionUUID->"f1ee88e5-37c7-47a9-b1b1-07a20e6d228e"]
}, Open  ]],
Cell[572407, 15743, 701, 19, 55, "Input",ExpressionUUID->"feb65915-6a73-4dba-9c29-d25cac6b2906"],
Cell[573111, 15764, 3157, 89, 140, "Input",ExpressionUUID->"51e37d1a-6c46-48fb-954c-75ebfbef568f",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[576293, 15857, 516, 12, 31, "Input",ExpressionUUID->"b7b3f3c1-0f28-4f53-8ea2-0d7ecaa61167"],
Cell[576812, 15871, 224, 5, 35, "Output",ExpressionUUID->"93380237-28c0-4853-984c-2ce8422917b1"]
}, Open  ]],
Cell[577051, 15879, 4912, 134, 196, "Input",ExpressionUUID->"e73eb0b4-031f-49d4-aec3-268449cd63ab",
 InitializationCell->True],
Cell[581966, 16015, 186, 4, 31, "Input",ExpressionUUID->"e087b651-5c13-4eae-a0e2-93b17fbc24bf"],
Cell[CellGroupData[{
Cell[582177, 16023, 820, 23, 71, "Input",ExpressionUUID->"3c14f83a-7265-499f-b435-4dde199c6850",
 InitializationCell->True],
Cell[583000, 16048, 743, 21, 59, "Output",ExpressionUUID->"e229cf45-4b17-480c-a95e-1782a5f711f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[583780, 16074, 877, 24, 94, "Input",ExpressionUUID->"e30ab8be-593d-4d7c-bffb-a927e4c80315",
 InitializationCell->True],
Cell[584660, 16100, 8493, 256, 393, "Output",ExpressionUUID->"7056c233-de63-4f8a-b8e7-01a8f0f94b87"]
}, Open  ]],
Cell[593168, 16359, 422, 11, 31, "Input",ExpressionUUID->"515bf23a-844e-4adc-9069-79caad5d48d4"],
Cell[593593, 16372, 505, 14, 31, "Input",ExpressionUUID->"7eca3e70-c0d5-4b94-9754-0e79ec62432b"],
Cell[594101, 16388, 1085, 29, 94, "Input",ExpressionUUID->"8c9ac3af-634a-4558-8286-47aba84782ab",
 InitializationCell->True],
Cell[595189, 16419, 1261, 33, 94, "Input",ExpressionUUID->"2594ee35-007b-4417-becb-388b3c923eba",
 InitializationCell->True],
Cell[596453, 16454, 412, 10, 31, "Input",ExpressionUUID->"fe60e243-0b77-47f3-8182-f5533cb3ec78"],
Cell[CellGroupData[{
Cell[596890, 16468, 163, 3, 31, "Input",ExpressionUUID->"35d8acf5-9ae4-47d4-b9d7-047255f85f88"],
Cell[597056, 16473, 681, 22, 42, "Output",ExpressionUUID->"a4a31dcc-83f7-4df0-8e18-9f833d5f7287"]
}, Open  ]],
Cell[597752, 16498, 956, 28, 61, "Input",ExpressionUUID->"37fcc4d0-310f-4407-ac7a-b266e8c18f21",
 InitializationCell->True],
Cell[598711, 16528, 1071, 33, 119, "Input",ExpressionUUID->"61e46162-00dd-4600-ab67-e09a212abf9b"],
Cell[599785, 16563, 1477, 47, 144, "Input",ExpressionUUID->"83e1c73a-eb0e-45ed-a6d6-0f0cc972c154",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[601287, 16614, 496, 14, 31, "Input",ExpressionUUID->"58a464e5-b839-4172-8243-14947c88da34"],
Cell[601786, 16630, 810, 22, 59, "Output",ExpressionUUID->"e1f2e347-1685-40f0-8597-b0b5d04a9e3c"]
}, Open  ]],
Cell[602611, 16655, 950, 26, 71, "Input",ExpressionUUID->"f604762a-2154-47df-82fd-1d860733af2a",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[603586, 16685, 1083, 31, 86, "Input",ExpressionUUID->"30915239-75e1-45d4-9fea-b50de9ac5af9"],
Cell[604672, 16718, 542, 17, 42, "Output",ExpressionUUID->"1aa3cc3c-3a86-47df-ae2c-9ac96d96a8a5"]
}, Open  ]],
Cell[605229, 16738, 727, 21, 51, "Input",ExpressionUUID->"f7916ba6-5aa9-4d97-8029-1a684a93d364",
 InitializationCell->True],
Cell[605959, 16761, 722, 22, 77, "Input",ExpressionUUID->"52361237-8431-4d96-b52c-5bad57c5d8ac",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[606718, 16788, 375, 7, 42, "Subsubsection",ExpressionUUID->"eca59d51-953e-4610-bc06-77b959a2d58e"],
Cell[CellGroupData[{
Cell[607118, 16799, 677, 21, 35, "Input",ExpressionUUID->"57c119f5-2184-426f-91ec-aed51baac19d"],
Cell[607798, 16822, 887, 27, 39, "Output",ExpressionUUID->"17304259-fde2-40d8-bfc1-23e412b84fab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[608722, 16854, 838, 25, 55, "Input",ExpressionUUID->"89ed5645-3ac7-42c6-8301-6e672e5edb9a"],
Cell[609563, 16881, 4435, 122, 252, "Output",ExpressionUUID->"397e27c4-f566-4ee9-b477-a0ac09899821"]
}, Open  ]],
Cell[CellGroupData[{
Cell[614035, 17008, 165, 3, 31, "Input",ExpressionUUID->"e0a00ccd-fb3e-41e0-9b1e-89f54e01eb42"],
Cell[614203, 17013, 357, 10, 35, "Output",ExpressionUUID->"6aebd41b-90fc-4fe1-a77e-81d5b4de5932"]
}, Open  ]],
Cell[CellGroupData[{
Cell[614597, 17028, 546, 14, 31, "Input",ExpressionUUID->"e21a2b87-a0ee-41bf-8563-fce62d0e9542"],
Cell[615146, 17044, 1787, 53, 130, "Output",ExpressionUUID->"3f0fe256-62cc-411d-878b-227866862565"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[616994, 17104, 534, 8, 83, "Subsection",ExpressionUUID->"618496fe-949b-4587-9e0f-e7161a652bef"],
Cell[617531, 17114, 188, 4, 37, "Text",ExpressionUUID->"4acf8f6a-bd58-4edc-a305-38a0e65df23d"],
Cell[CellGroupData[{
Cell[617744, 17122, 1298, 37, 78, "Input",ExpressionUUID->"e91253f4-7aaf-4ee8-9eb7-155f9ce86755"],
Cell[619045, 17161, 258, 7, 35, "Output",ExpressionUUID->"71d05b55-0cb0-42ec-861c-497dac5a3315"]
}, Open  ]],
Cell[CellGroupData[{
Cell[619340, 17173, 3297, 97, 150, "Input",ExpressionUUID->"1899d0e4-7aa7-4879-883f-db080e080ffd"],
Cell[622640, 17272, 8298, 251, 336, "Output",ExpressionUUID->"fbf1e7bf-ef8e-4a4a-a4ed-d9907172224c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[630975, 17528, 969, 28, 55, "Input",ExpressionUUID->"462d73d8-35e0-4b4b-a8de-cb834b2583b8"],
Cell[631947, 17558, 195, 5, 35, "Output",ExpressionUUID->"3e1f38e8-c67f-4cf5-89e3-18b765d764f9"]
}, Open  ]],
Cell[632157, 17566, 358, 11, 37, "Text",ExpressionUUID->"9310eac2-1293-4ad9-9a0c-87b77be79323"],
Cell[CellGroupData[{
Cell[632540, 17581, 289, 7, 31, "Input",ExpressionUUID->"6ff7e967-3906-45b1-b76f-9ee4bfc9fd22"],
Cell[632832, 17590, 3201, 99, 151, "Output",ExpressionUUID->"8f2ccf5c-4e91-42d8-a31f-929bb2d4bd80"]
}, Open  ]],
Cell[CellGroupData[{
Cell[636070, 17694, 946, 28, 78, "Input",ExpressionUUID->"bacac8d0-38db-4339-a9dc-0ea9c41b84d2"],
Cell[637019, 17724, 3223, 99, 151, "Output",ExpressionUUID->"6695b583-5660-4784-88b9-a81913957089"]
}, Open  ]],
Cell[CellGroupData[{
Cell[640279, 17828, 546, 14, 78, "Input",ExpressionUUID->"dc810fe9-e5fe-40ad-9977-f58c6c3a6ce8"],
Cell[640828, 17844, 1504, 38, 105, "Output",ExpressionUUID->"38eb0bd8-eaa1-4e37-8834-0629d6b03c7b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[642369, 17887, 1371, 35, 101, "Input",ExpressionUUID->"e24160d2-6004-4483-91f8-65bc490629ea"],
Cell[643743, 17924, 1550, 39, 105, "Output",ExpressionUUID->"2a1512a2-724f-4b26-a1ba-0358601f5ef9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[645330, 17968, 180, 2, 31, "Input",ExpressionUUID->"ae045007-0c2a-4dde-8581-97aef3004af7"],
Cell[645513, 17972, 1497, 37, 105, "Output",ExpressionUUID->"5f4147db-c1d6-425e-85e8-d78891aad6d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[647047, 18014, 216, 3, 31, "Input",ExpressionUUID->"1b5fb84e-84b2-4638-9568-5dfc4b238bae"],
Cell[647266, 18019, 1493, 36, 105, "Output",ExpressionUUID->"9433fc66-aa68-4884-9fa5-f342ae99ef7c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[648796, 18060, 199, 4, 31, "Input",ExpressionUUID->"b1198c9f-be64-49df-8f05-7173f615644b"],
Cell[648998, 18066, 517, 13, 35, "Output",ExpressionUUID->"80ca97e4-d22b-4a2b-8812-4e52a2248a6c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[649552, 18084, 1222, 34, 71, "Input",ExpressionUUID->"b5698570-6286-4bc0-b694-5a1055bf9ede",
 InitializationCell->True],
Cell[650777, 18120, 1119, 32, 59, "Output",ExpressionUUID->"d1b9d1c0-a4af-4a64-a58e-8f2b59ba8546"]
}, Open  ]],
Cell[651911, 18155, 2370, 69, 140, "Input",ExpressionUUID->"759d0fb9-9fd0-469b-9980-65eab75583a4",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[654306, 18228, 354, 8, 31, "Input",ExpressionUUID->"e60ab638-7b39-47f4-a1ee-0cdccda6d822"],
Cell[654663, 18238, 516, 13, 35, "Output",ExpressionUUID->"3f110cf0-9864-4b49-a12e-0775544b9fee"]
}, Open  ]],
Cell[655194, 18254, 2863, 72, 163, "Input",ExpressionUUID->"15bc2aa9-20bc-48dc-bfdb-e1dc151c8c35",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[658082, 18330, 296, 7, 31, "Input",ExpressionUUID->"0389ef8b-ea72-4095-b9dc-fc83ec58da77"],
Cell[658381, 18339, 1358, 39, 101, "Output",ExpressionUUID->"b1efd0dd-6f52-4f6f-9f2f-a6dd24876a39"]
}, Open  ]],
Cell[CellGroupData[{
Cell[659776, 18383, 241, 5, 31, "Input",ExpressionUUID->"dd54f50e-e9e7-4a4e-bd72-6a9eb8330b95"],
Cell[660020, 18390, 798, 23, 101, "Output",ExpressionUUID->"be2244d1-a066-4a16-b6b0-8857875c633e"]
}, Open  ]],
Cell[660833, 18416, 12103, 335, 566, "Input",ExpressionUUID->"df46155b-30ca-493e-83e2-0a96511e48d3",
 InitializationCell->True],
Cell[672939, 18753, 1370, 37, 94, "Input",ExpressionUUID->"79650e84-bc82-439f-90f7-df98f9ba0e9a",
 InitializationCell->True],
Cell[674312, 18792, 273, 7, 31, "Input",ExpressionUUID->"6f442079-cc87-4eb3-8b1f-9dc43a927429"],
Cell[674588, 18801, 13942, 369, 1063, "Input",ExpressionUUID->"4181d2bc-0b45-466a-acfc-e795789b7146",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[688555, 19174, 212, 4, 45, "Subsubsection",ExpressionUUID->"9ccd6b29-dcb5-42dd-936d-0d981ddd549e"],
Cell[688770, 19180, 1172, 28, 55, "Input",ExpressionUUID->"edaef0f3-8907-434a-8248-96133c179dd5"],
Cell[689945, 19210, 2274, 55, 117, "Input",ExpressionUUID->"0aa810af-2ebc-4dca-883f-fc3590d2ca2a",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[692244, 19269, 819, 18, 78, "Input",ExpressionUUID->"ad2b0aa1-a5c3-4a4d-86e6-a4a968debe0f"],
Cell[693066, 19289, 1478, 38, 105, "Output",ExpressionUUID->"022f3dae-c0c8-4aaa-b310-4d3d0d389ae6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[694581, 19332, 311, 7, 31, "Input",ExpressionUUID->"edd84f1c-8f71-4c90-9654-551d4bf7fc15"],
Cell[694895, 19341, 1480, 38, 105, "Output",ExpressionUUID->"c243069e-bcd3-41ed-a908-51d5ce25222d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[696412, 19384, 235, 6, 31, "Input",ExpressionUUID->"f2763c62-833c-4eb5-9c3b-9c7d3a46ce04"],
Cell[696650, 19392, 468, 12, 35, "Output",ExpressionUUID->"9672ec8d-4077-4840-9649-06e6659e9f29"]
}, Open  ]],
Cell[697133, 19407, 1637, 40, 101, "Input",ExpressionUUID->"849e37af-2f5f-4c35-8341-57f85ce4937e"],
Cell[CellGroupData[{
Cell[698795, 19451, 90, 0, 31, "Input",ExpressionUUID->"4da2ee8a-753f-4f7b-8d33-d088824c55cd"],
Cell[698888, 19453, 993, 30, 59, "Output",ExpressionUUID->"1d01a2c7-b4ec-4a84-bf21-aad49d4314aa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[699918, 19488, 334, 8, 31, "Input",ExpressionUUID->"1e90a5b9-04f4-4568-9f19-55971eb8fd70"],
Cell[700255, 19498, 1497, 37, 105, "Output",ExpressionUUID->"75f5774d-0734-48fb-bb84-89dea81931bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[701789, 19540, 569, 15, 55, "Input",ExpressionUUID->"955979ab-1beb-434f-9978-48c09df80fe5"],
Cell[702361, 19557, 1419, 42, 86, "Output",ExpressionUUID->"f9915e73-0aca-49d1-9e4e-1dfa207cefae"]
}, Open  ]],
Cell[703795, 19602, 1478, 43, 82, "Input",ExpressionUUID->"e40922a1-f408-425f-b2f5-7fdcdc935835"],
Cell[705276, 19647, 1406, 29, 124, "Input",ExpressionUUID->"27e01e39-f8fd-413c-bbd0-5afd3f4d7934"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[706731, 19682, 374, 7, 83, "Subsection",ExpressionUUID->"88adb178-7a73-428f-9286-ca9685485261",
 InitializationCell->True],
Cell[707108, 19691, 732, 22, 47, "Input",ExpressionUUID->"b582bad8-0497-4761-9ee7-5e19d819b721",
 InitializationCell->True],
Cell[707843, 19715, 694, 17, 47, "Input",ExpressionUUID->"7da6d278-41c5-4d0c-99ea-62913c932084",
 InitializationCell->True],
Cell[708540, 19734, 1159, 30, 94, "Input",ExpressionUUID->"8aa9c222-633b-4fd4-a948-428c5d700713",
 InitializationCell->True],
Cell[709702, 19766, 535, 15, 47, "Input",ExpressionUUID->"126d0b7e-e015-4a29-b3c4-6cf34ae72c2c",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[710262, 19785, 482, 13, 31, "Input",ExpressionUUID->"39141cf5-9079-4f9f-b7b1-80a485d9bd70"],
Cell[710747, 19800, 4858, 144, 147, "Output",ExpressionUUID->"c4406b77-dbc4-4efe-bd55-2267410d5f24"]
}, Closed]],
Cell[715620, 19947, 5145, 148, 204, "Input",ExpressionUUID->"9cdeb71c-2f16-4091-98d4-994142cdad7c",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[720790, 20099, 641, 17, 47, "Input",ExpressionUUID->"61fa5ba0-dc17-4cff-9044-ee36881a5968",
 InitializationCell->True],
Cell[721434, 20118, 938, 21, 35, "Output",ExpressionUUID->"fdcf34b4-d4c8-41f5-bd85-2d4749b7cad8",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[722409, 20144, 1180, 32, 71, "Input",ExpressionUUID->"82e9c269-b94e-4f44-95e5-d7aafbed69f8",
 InitializationCell->True],
Cell[723592, 20178, 1222, 35, 70, "Output",ExpressionUUID->"c647b83e-51e1-44f8-96c5-de7d2232e45e",
 InitializationCell->True]
}, Open  ]],
Cell[724829, 20216, 350, 8, 37, "Text",ExpressionUUID->"465c7270-7ce7-48bf-8d75-196e8ed8e835",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[725204, 20228, 656, 16, 55, "Input",ExpressionUUID->"17edab1a-3d71-4020-9a2b-51fa6b856701"],
Cell[725863, 20246, 879, 24, 35, "Output",ExpressionUUID->"e5b03144-3738-4f62-9454-c715d852f0b0",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[726779, 20275, 318, 8, 31, "Input",ExpressionUUID->"376a3228-14e3-45db-b9c7-776b6cd2428e"],
Cell[727100, 20285, 2802, 91, 105, "Output",ExpressionUUID->"9addf5ed-e99a-494a-9b45-c0f939863c09",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[729939, 20381, 234, 5, 31, "Input",ExpressionUUID->"43e6d814-b185-4389-a6f1-cbcf44812536"],
Cell[730176, 20388, 960, 29, 39, "Output",ExpressionUUID->"17faaa74-b48d-4922-833e-9b6322f0a66b",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[731173, 20422, 381, 10, 55, "Input",ExpressionUUID->"be6d759c-3d9d-4fb1-8933-072b40ab7d0e"],
Cell[731557, 20434, 984, 29, 39, "Output",ExpressionUUID->"e1b701cf-847f-46c5-8b8e-1b42adb3b340",
 InitializationCell->True]
}, Open  ]],
Cell[732556, 20466, 1058, 31, 78, "Input",ExpressionUUID->"1273c529-81cb-48ee-8981-98ced3a4f218",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[733639, 20501, 315, 6, 31, "Input",ExpressionUUID->"748bfe50-4c45-4037-8ae9-6c8ad30a1427"],
Cell[733957, 20509, 858, 25, 42, "Output",ExpressionUUID->"fb0113ef-4f57-4384-a168-1922a0e25227",
 InitializationCell->True]
}, Open  ]],
Cell[734830, 20537, 340, 7, 37, "Text",ExpressionUUID->"a4721fa4-2f74-4712-9148-45ea135fa7bb"],
Cell[735173, 20546, 907, 26, 96, "Input",ExpressionUUID->"7e0ec31f-d0c8-400f-8343-85b3064d54f4",
 InitializationCell->True],
Cell[736083, 20574, 669, 19, 47, "Input",ExpressionUUID->"f9086c5d-25ef-4a9d-806b-901d0c85d7bf",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[736777, 20597, 774, 21, 55, "Input",ExpressionUUID->"1f2b76cc-bf2d-49df-9512-98dd79f1133c"],
Cell[737554, 20620, 792, 24, 42, "Output",ExpressionUUID->"fb04b4cd-2248-404f-a262-1180a71c9f87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[738383, 20649, 858, 26, 96, "Input",ExpressionUUID->"3822d4c6-5760-4381-b15e-620902cf3c1b",
 InitializationCell->True],
Cell[739244, 20677, 938, 26, 42, "Output",ExpressionUUID->"00bacca3-f944-4931-ba60-7dc940bbfed0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[740231, 20709, 368, 6, 55, "Subsection",ExpressionUUID->"3ece1528-0a8f-4c73-aa3d-5954067d6db4"],
Cell[CellGroupData[{
Cell[740624, 20719, 170, 3, 45, "Subsubsection",ExpressionUUID->"5c4c37db-517a-42d9-9d9a-d021f63f0af3"],
Cell[740797, 20724, 1162, 31, 94, "Input",ExpressionUUID->"f02fba56-fd35-434d-b63a-6f378a0cf9e3",
 InitializationCell->True],
Cell[741962, 20757, 1184, 30, 94, "Input",ExpressionUUID->"03c293f8-3e49-4612-9eca-317599480906",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[743171, 20791, 557, 13, 47, "Input",ExpressionUUID->"1d97d220-bfc4-4b6f-a8f6-9269121aee02",
 InitializationCell->True],
Cell[743731, 20806, 2476, 63, 82, "Output",ExpressionUUID->"0b6b6b36-a942-4263-a4f4-9630bafa23a5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[746256, 20875, 178, 3, 45, "Subsubsection",ExpressionUUID->"2be63612-62d7-4d6d-b83c-9466d3e5dbd5"],
Cell[CellGroupData[{
Cell[746459, 20882, 774, 21, 71, "Input",ExpressionUUID->"c5a5e403-1efa-4fb8-982f-a2540edc06fa",
 InitializationCell->True],
Cell[747236, 20905, 2861, 84, 134, "Output",ExpressionUUID->"ca66adbd-5c96-4d02-b71a-8162f246e1a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[750134, 20994, 774, 21, 71, "Input",ExpressionUUID->"c6564fd0-b83d-4d58-990b-7ee7d1c3709d",
 InitializationCell->True],
Cell[750911, 21017, 2828, 84, 134, "Output",ExpressionUUID->"358736e7-86c5-4185-a84c-82c29f922a9f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[753776, 21106, 774, 21, 71, "Input",ExpressionUUID->"d559d9db-c761-4bd6-a810-9f7477e85cac",
 InitializationCell->True],
Cell[754553, 21129, 2861, 84, 134, "Output",ExpressionUUID->"fcd1d77c-ba42-4fe0-a252-4d3b68f6ebbd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[757451, 21218, 396, 10, 31, "Input",ExpressionUUID->"da7eb22d-9717-4646-9c35-a0b38de7a8e2"],
Cell[757850, 21230, 2695, 87, 92, "Output",ExpressionUUID->"f81425c6-1569-473e-93d4-3cc27bfbb0db"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[760606, 21324, 417, 7, 55, "Subsection",ExpressionUUID->"033abeaa-9ff8-4062-a43a-ecb37e3d1e7f"],
Cell[761026, 21333, 1997, 54, 190, "Input",ExpressionUUID->"612276d9-0190-4fee-861f-82bf5b17f963",
 InitializationCell->True],
Cell[763026, 21389, 1560, 47, 78, "Input",ExpressionUUID->"ce054aeb-1623-4049-9751-3542413407c8",
 InitializationCell->True],
Cell[764589, 21438, 1395, 42, 98, "Input",ExpressionUUID->"48415baa-8bc8-413c-bd99-808551c99a94"],
Cell[765987, 21482, 2433, 66, 190, "Input",ExpressionUUID->"f73b4535-050e-463a-abd7-192084010358"],
Cell[CellGroupData[{
Cell[768445, 21552, 356, 9, 31, "Input",ExpressionUUID->"ce48f801-5afa-477c-9b10-8c904674ada3"],
Cell[768804, 21563, 2760, 98, 113, "Output",ExpressionUUID->"4d7dd7ff-dba8-465f-b383-d73370b6533c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[771601, 21666, 916, 33, 88, "Input",ExpressionUUID->"2bb6254d-58dd-40ca-9a23-b432987db5ba"],
Cell[772520, 21701, 2758, 98, 113, "Output",ExpressionUUID->"ed6abd2c-98f5-4c6f-862f-854144a18db5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[775315, 21804, 535, 12, 71, "Subsubsection",ExpressionUUID->"141104a3-bfc6-4ad0-9ab7-bf014443cb05"],
Cell[775853, 21818, 2331, 79, 126, "Output",ExpressionUUID->"9b87f944-d618-4862-8a2c-36efc2ebaeaa"],
Cell[CellGroupData[{
Cell[778209, 21901, 3858, 108, 255, "Input",ExpressionUUID->"499d196a-3a2c-4a96-8403-2e3c1f21c9ef",
 InitializationCell->True],
Cell[782070, 22011, 2010, 41, 128, "Output",ExpressionUUID->"6851f36c-7acc-47fa-b444-0c3830eb2ac3"]
}, Open  ]],
Cell[784095, 22055, 297, 6, 35, "Text",ExpressionUUID->"a506b88e-c482-4339-a2bc-43eedb371d02"],
Cell[CellGroupData[{
Cell[784417, 22065, 247, 6, 47, "Input",ExpressionUUID->"33e78a90-8487-4c6a-9f10-4c35b2bf29e7",
 InitializationCell->True],
Cell[784667, 22073, 415, 10, 35, "Output",ExpressionUUID->"ef1ab93e-7036-4b93-9e5c-bb749b81df72"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[785155, 22091, 187, 3, 65, "Subchapter",ExpressionUUID->"d7a7c3ad-1a72-4ca4-9796-67d44c49bcc7"],
Cell[CellGroupData[{
Cell[785367, 22098, 416, 9, 107, "Section",ExpressionUUID->"86ab74dd-59de-4932-ad76-11a70f563be4"],
Cell[785786, 22109, 681, 19, 94, "Input",ExpressionUUID->"308fbeb4-bd7c-44d0-89de-604d1e03470c",
 InitializationCell->True],
Cell[786470, 22130, 3676, 92, 404, "Input",ExpressionUUID->"bba538e6-4911-4493-923b-347d1e5322e6",
 InitializationCell->True],
Cell[790149, 22224, 476, 9, 37, "Text",ExpressionUUID->"1ff41014-7646-4ae6-a380-deb88fab83e1"],
Cell[790628, 22235, 3652, 92, 439, "Input",ExpressionUUID->"d12ad918-b48d-4d49-b2fe-dfc1e7d2bf31",
 InitializationCell->True],
Cell[794283, 22329, 581, 16, 31, "Input",ExpressionUUID->"efad12e7-2d97-40d1-a8eb-ff1aa82e2484"],
Cell[CellGroupData[{
Cell[794889, 22349, 263, 7, 31, "Input",ExpressionUUID->"865565b0-cfeb-472e-8803-d893f22d2df4"],
Cell[795155, 22358, 385, 11, 35, "Output",ExpressionUUID->"fdb7ed68-9720-491e-90db-4191e713d529"]
}, Open  ]],
Cell[795555, 22372, 922, 25, 55, "Input",ExpressionUUID->"1b0525df-dbe0-4f01-8aa8-11a88e0df142"],
Cell[796480, 22399, 320, 8, 97, "Subsubsection",ExpressionUUID->"035104c9-abf2-455d-8559-de93ffbd0093"],
Cell[CellGroupData[{
Cell[796825, 22411, 319, 7, 63, "Subsubsection",ExpressionUUID->"c58def6e-e417-4082-983b-0a37654b378b"],
Cell[CellGroupData[{
Cell[797169, 22422, 492, 10, 123, "Subsubsection",ExpressionUUID->"07c4f485-a9d2-484c-9b60-e75f976d63a0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[797664, 22434, 657, 16, 31, "Input",ExpressionUUID->"bf70c048-b9e9-4cb0-b6dd-82e3743e5dc1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[798324, 22452, 51175, 1263, 1962, "Output",ExpressionUUID->"52f67b2f-e349-45bb-b974-e7485801f0ca",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[849502, 23717, 494, 11, 31, "Input",ExpressionUUID->"d5310281-82b8-4144-8b66-ae7f74eeaf20",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[849999, 23730, 300, 7, 35, "Output",ExpressionUUID->"9fd3955a-6c1a-4299-ab5a-326ddfd4cef8",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[850302, 23739, 52447, 1275, 3290, "Input",ExpressionUUID->"cdd23bed-da3e-4592-90b6-bb10f2805342",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True],
Cell[902752, 25016, 357, 7, 70, "Output",ExpressionUUID->"0a3eaf0c-32ed-469a-b1b4-0336961166a1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[903112, 25025, 311, 6, 31, "Input",ExpressionUUID->"712f47e2-e02c-498e-8a07-fc786e3824db",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[903426, 25033, 8321, 229, 483, "Output",ExpressionUUID->"f883c9ff-4f9c-4142-88a9-7b9aaa64743d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[911750, 25264, 456, 11, 31, "Input",ExpressionUUID->"1ab649bb-8308-4736-9f83-5d9203a3205f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[912209, 25277, 209, 4, 35, "Output",ExpressionUUID->"346baf77-c55e-4537-8579-51faa67b6e6d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[912421, 25283, 12846, 322, 821, "Input",ExpressionUUID->"7b385e8d-9664-4ee4-9adc-141c70456321",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, {6}]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[925325, 25612, 367, 7, 107, "Section",ExpressionUUID->"96d38920-c3da-4b45-b338-8c172a5a31e0"],
Cell[CellGroupData[{
Cell[925717, 25623, 570, 9, 55, "Subsection",ExpressionUUID->"8a555d77-ed5b-4ec7-b45d-f08b135eb9e8"],
Cell[CellGroupData[{
Cell[926312, 25636, 158, 3, 31, "Input",ExpressionUUID->"9dc3b45a-c31d-4b78-8a8e-377867a68f66"],
Cell[926473, 25641, 212, 6, 35, "Output",ExpressionUUID->"aec73414-b6ec-4bfa-b32b-e8f59b1c0a6c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[926722, 25652, 160, 3, 31, "Input",ExpressionUUID->"897fda65-af50-40e2-8136-47244e99ea9f"],
Cell[926885, 25657, 796, 21, 59, "Output",ExpressionUUID->"5e276b53-27b8-4081-a6ce-68ff10d48d7f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[927718, 25683, 160, 3, 31, "Input",ExpressionUUID->"0d33f367-fc7e-4233-86c7-79d78e38f959"],
Cell[927881, 25688, 885, 28, 39, "Output",ExpressionUUID->"2efb1e49-b768-44b6-b59e-86ac44a360d9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[928803, 25721, 163, 3, 31, "Input",ExpressionUUID->"1ae38b82-181f-42aa-b8d5-16854dcc402a"],
Cell[928969, 25726, 678, 21, 42, "Output",ExpressionUUID->"d43ef1da-579c-43ab-87b2-d572014fe5fd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[929684, 25752, 233, 6, 31, "Input",ExpressionUUID->"77957f45-5ca2-46b9-844b-879274c78a59"],
Cell[929920, 25760, 1399, 43, 66, "Output",ExpressionUUID->"1ee04e31-cd24-4a12-b710-abce6b982e42"]
}, Open  ]],
Cell[931334, 25806, 214, 5, 39, "Text",ExpressionUUID->"b7f6ae70-cebc-46bf-8b28-f68337991c25"],
Cell[CellGroupData[{
Cell[931573, 25815, 162, 3, 31, "Input",ExpressionUUID->"fdbcc1b4-84de-4495-81d8-81cb5085fc04"],
Cell[931738, 25820, 517, 15, 35, "Output",ExpressionUUID->"b6477a22-6d00-485a-b404-a8999117e482"]
}, Open  ]],
Cell[CellGroupData[{
Cell[932292, 25840, 159, 3, 31, "Input",ExpressionUUID->"c806a309-def9-40fa-8f81-bf011eaf5d8f"],
Cell[932454, 25845, 723, 27, 70, "Output",ExpressionUUID->"0cee07eb-716a-4a99-9c30-885f10f98a2d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[933214, 25877, 335, 9, 47, "Input",ExpressionUUID->"a44ef51d-7641-4e6b-adc2-e376272a8c1d",
 InitializationCell->True],
Cell[933552, 25888, 860, 27, 42, "Output",ExpressionUUID->"4c57dcde-24dd-4ca2-bbdf-9fe0f678e7fb"]
}, Open  ]],
Cell[934427, 25918, 531, 16, 87, "Text",ExpressionUUID->"5ba0104a-3400-4ef0-a522-039da93dd071"],
Cell[934961, 25936, 1827, 49, 186, "Input",ExpressionUUID->"727659cc-ceb5-4e9d-917e-06832c3654af",
 InitializationCell->True],
Cell[936791, 25987, 885, 22, 47, "Input",ExpressionUUID->"19e54979-864c-480e-a3d2-82ad906320f6",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[937701, 26013, 243, 6, 31, "Input",ExpressionUUID->"049330ba-a237-4c92-9e23-601bd55886b9"],
Cell[937947, 26021, 908, 26, 59, "Output",ExpressionUUID->"fdcfc7a7-610b-40d3-b8d4-8cc3e1c398dc"]
}, Open  ]],
Cell[938870, 26050, 986, 24, 71, "Input",ExpressionUUID->"1bab9c02-358f-4403-b425-47c08a183c35",
 InitializationCell->True],
Cell[939859, 26076, 1035, 25, 71, "Input",ExpressionUUID->"917dd72b-142c-4b88-96e4-97e7f4409807",
 InitializationCell->True],
Cell[940897, 26103, 1032, 25, 71, "Input",ExpressionUUID->"bc0c8c1c-6c60-4701-92ed-ceed2c1f8ed7",
 InitializationCell->True],
Cell[941932, 26130, 262, 6, 37, "Text",ExpressionUUID->"64a7fb00-6003-4374-a3e5-3452ec2d6440"]
}, Open  ]],
Cell[CellGroupData[{
Cell[942231, 26141, 237, 4, 55, "Subsection",ExpressionUUID->"5914b33c-a89d-42d0-ad65-312c4844a24e"],
Cell[CellGroupData[{
Cell[942493, 26149, 160, 3, 31, "Input",ExpressionUUID->"b703ee47-ec6e-4159-a6d1-f3f536b88628"],
Cell[942656, 26154, 4308, 124, 161, "Output",ExpressionUUID->"bd6f76eb-e1b0-4b57-8cc1-eb49d6d57390"]
}, Open  ]],
Cell[CellGroupData[{
Cell[947001, 26283, 90, 0, 31, "Input",ExpressionUUID->"3e5bb8f4-f0cc-49e9-bde8-529bc7f2a5b0"],
Cell[947094, 26285, 767, 24, 42, "Output",ExpressionUUID->"dff96e23-d74d-49e0-96e7-501ea4eb1221"]
}, Open  ]],
Cell[CellGroupData[{
Cell[947898, 26314, 512, 12, 55, "Input",ExpressionUUID->"e33525b7-be81-4fa6-9898-0a8634118d77"],
Cell[948413, 26328, 533, 16, 39, "Output",ExpressionUUID->"96b07a95-3280-4079-a885-83dfa4b91c55"]
}, Open  ]],
Cell[CellGroupData[{
Cell[948983, 26349, 346, 8, 47, "Input",ExpressionUUID->"e8cccc7b-8fa2-4142-bcb2-25a564bfae82",
 InitializationCell->True],
Cell[949332, 26359, 1304, 36, 39, "Output",ExpressionUUID->"0d01425d-ac7a-4a01-a63a-9f7b1c5b63d5",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[950673, 26400, 346, 8, 47, "Input",ExpressionUUID->"ad5996cd-ec1a-4a59-bdeb-fe1ca0e64c67",
 InitializationCell->True],
Cell[951022, 26410, 1297, 36, 39, "Output",ExpressionUUID->"ff9bcc3c-a410-4bdd-8a19-c385578b9f32",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[952356, 26451, 346, 8, 47, "Input",ExpressionUUID->"72ceb395-04de-4a79-9742-abbabf10a0ec",
 InitializationCell->True],
Cell[952705, 26461, 1299, 36, 39, "Output",ExpressionUUID->"bc358d57-fd7c-42bf-9acc-103c4c9b4860",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[954053, 26503, 571, 9, 55, "Subsection",ExpressionUUID->"73849663-b678-4fed-b6c0-290cd0cb7fef"],
Cell[CellGroupData[{
Cell[954649, 26516, 156, 3, 31, "Input",ExpressionUUID->"9c888607-062a-43dc-b9f0-f7d87ccf6d19"],
Cell[954808, 26521, 791, 24, 39, "Output",ExpressionUUID->"1c388e7a-a2ab-4406-ac30-5e4387d0c6c4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[955636, 26550, 181, 4, 31, "Input",ExpressionUUID->"0d4bec01-3056-4e53-aec4-362cca3dedbd"],
Cell[955820, 26556, 904, 28, 39, "Output",ExpressionUUID->"b69c66a3-5bba-43fd-999b-e6b8264d2fa2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[956761, 26589, 187, 3, 45, "Subsubsection",ExpressionUUID->"efad827f-7d0c-42cf-96a2-d6f7e31eb03c"],
Cell[956951, 26594, 1165, 34, 35, "Input",ExpressionUUID->"5bece78e-bf95-4b67-a43c-59fb34c2efbc"],
Cell[CellGroupData[{
Cell[958141, 26632, 396, 8, 37, "Text",ExpressionUUID->"0c090c69-ad9f-4f9b-8da1-78d98ed7c3ae",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[958540, 26642, 583, 15, 31, "Input",ExpressionUUID->"b2e64cae-5449-4c76-b9b4-4c17aa065c10",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[959126, 26659, 536, 11, 41, "Message",ExpressionUUID->"73efb13b-e767-4142-8127-9b8b61eda145",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[959665, 26672, 214, 4, 35, "Output",ExpressionUUID->"3c909a88-0b1a-43b6-8c39-472f2d7d14b1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[959916, 26681, 2102, 58, 97, "Input",ExpressionUUID->"e5df0962-e5e3-42b0-afcb-c233037fcd45"],
Cell[962021, 26741, 1132, 35, 39, "Output",ExpressionUUID->"8e7f67af-4750-4dd7-b2f6-b953f37b139e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[963190, 26781, 446, 13, 31, "Input",ExpressionUUID->"84d01e6b-3ac6-430c-846c-54b8b58ffa6b"],
Cell[963639, 26796, 137, 3, 35, "Output",ExpressionUUID->"6bec49ee-6841-42df-97a0-5bd5ea42dde5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[963813, 26804, 179, 4, 31, "Input",ExpressionUUID->"c4d3de55-a35a-410a-8999-938fdbedb23b"],
Cell[963995, 26810, 158, 3, 35, "Output",ExpressionUUID->"dbddbcf6-8227-48f6-aa8b-63788cac3a6f"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[964214, 26820, 1610, 40, 151, "Subsection",ExpressionUUID->"dd850bf1-4353-47e6-a545-8aa768a93124"],
Cell[CellGroupData[{
Cell[965849, 26864, 303, 8, 31, "Input",ExpressionUUID->"5c15008c-47b0-4b29-9af3-5674aba9caaf"],
Cell[966155, 26874, 752, 22, 42, "Output",ExpressionUUID->"47d93f9d-d048-4aea-9857-3e3ce19bf459"]
}, Open  ]],
Cell[CellGroupData[{
Cell[966944, 26901, 1684, 48, 124, "Input",ExpressionUUID->"1ee72016-c005-400e-9051-0b8d40cdf808",
 InitializationCell->True],
Cell[968631, 26951, 1104, 29, 42, "Output",ExpressionUUID->"23271b87-9a59-4f56-b866-b07923964543"]
}, Open  ]],
Cell[CellGroupData[{
Cell[969772, 26985, 802, 19, 55, "Input",ExpressionUUID->"e58b21b0-a69c-4a89-9b7c-f3ac1289be4d"],
Cell[970577, 27006, 161, 3, 35, "Output",ExpressionUUID->"b3864e7f-b781-4e8a-aa4f-23ffd1e9104b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[970775, 27014, 204, 4, 31, "Input",ExpressionUUID->"e98d3c28-d15a-4668-8a0b-28e99773aa99"],
Cell[970982, 27020, 175, 5, 35, "Output",ExpressionUUID->"b1100980-7e9f-4e67-a7d2-08f184a5cb94"]
}, Open  ]],
Cell[CellGroupData[{
Cell[971194, 27030, 195, 3, 45, "Subsubsection",ExpressionUUID->"7d9497f7-9a27-4833-9eb1-e0563accf5d8"],
Cell[CellGroupData[{
Cell[971414, 27037, 480, 14, 31, "Input",ExpressionUUID->"613056c4-3040-44d4-acd0-0c39bcc4f3b7"],
Cell[971897, 27053, 470, 16, 52, "Output",ExpressionUUID->"d3bdda0f-8fff-43d9-8309-01bd799547e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[972404, 27074, 652, 19, 55, "Input",ExpressionUUID->"c7f62065-5bb1-4299-97d0-4abbb6e40a35"],
Cell[973059, 27095, 226, 6, 35, "Output",ExpressionUUID->"214767c9-3c9b-4a38-87ad-b50b8c6a3d41"]
}, Open  ]],
Cell[CellGroupData[{
Cell[973322, 27106, 477, 14, 31, "Input",ExpressionUUID->"53ed8ab8-4a5b-4a94-8b8b-9d88822a545c"],
Cell[973802, 27122, 322, 9, 56, "Output",ExpressionUUID->"2c43ebb8-6b86-4e0f-a3ac-5a56304d4828"]
}, Open  ]],
Cell[CellGroupData[{
Cell[974161, 27136, 647, 17, 55, "Input",ExpressionUUID->"ab9b2a7b-de76-4969-b8db-e036f5d2ea95"],
Cell[974811, 27155, 200, 5, 56, "Output",ExpressionUUID->"0c55e234-40aa-40bd-97e7-3d6446a4dcf3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[975060, 27166, 396, 9, 97, "Subsubsection",ExpressionUUID->"1f0219ed-ca91-45e3-b78a-fa92f01c9a3c"],
Cell[CellGroupData[{
Cell[975481, 27179, 164, 3, 31, "Input",ExpressionUUID->"2688636b-d65b-4f6d-80cf-2898756af5d4"],
Cell[975648, 27184, 550, 22, 42, "Output",ExpressionUUID->"63a5a5a5-0366-4b57-ae4b-b4b7819b1676"]
}, Open  ]],
Cell[CellGroupData[{
Cell[976235, 27211, 313, 7, 31, "Input",ExpressionUUID->"af88f397-d775-43e2-bd9f-043143230d16"],
Cell[976551, 27220, 659, 17, 59, "Output",ExpressionUUID->"d3f94273-4144-4a38-95d6-faee21160032"]
}, Open  ]],
Cell[CellGroupData[{
Cell[977247, 27242, 408, 12, 35, "Input",ExpressionUUID->"019d4e75-1d8e-46fe-8e62-a2866ce95c26"],
Cell[977658, 27256, 1321, 31, 82, "Output",ExpressionUUID->"a985ae01-746a-4c34-9bb4-9595dfa01c2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[979016, 27292, 513, 15, 35, "Input",ExpressionUUID->"e70d44a5-317b-40d3-9327-317d08769a32"],
Cell[979532, 27309, 6660, 153, 358, "Output",ExpressionUUID->"cee175df-4aa7-4566-a253-f1bfcc0876bb"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[986241, 27468, 308, 7, 71, "Subsubsection",ExpressionUUID->"7163b380-a495-4d22-890e-dbdcc8b0db38"],
Cell[CellGroupData[{
Cell[986574, 27479, 655, 19, 55, "Input",ExpressionUUID->"acb057af-5495-49e6-ba7a-08c29804be99"],
Cell[987232, 27500, 2440, 66, 151, "Output",ExpressionUUID->"92a1fc51-8fae-450b-bdfb-513551df0235"]
}, Open  ]],
Cell[CellGroupData[{
Cell[989709, 27571, 491, 15, 35, "Input",ExpressionUUID->"ff670a31-12a2-458b-8973-a00d2bcd12f7"],
Cell[990203, 27588, 1380, 33, 82, "Output",ExpressionUUID->"aa0b64d0-0fcd-4b9d-89cc-adcdf7a2c3da"]
}, Open  ]],
Cell[CellGroupData[{
Cell[991620, 27626, 317, 9, 31, "Input",ExpressionUUID->"248389d3-e6de-4206-9ac0-cf1365cb3ec4"],
Cell[991940, 27637, 808, 27, 39, "Output",ExpressionUUID->"76f2b9db-67c3-4a19-85ba-767289ec43da"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[992809, 27671, 299, 5, 55, "Subsection",ExpressionUUID->"d2d29c37-8d2b-4f2f-bf58-75e086cd0fba"],
Cell[CellGroupData[{
Cell[993133, 27680, 758, 19, 101, "Input",ExpressionUUID->"42bb45a5-cd3d-43a7-aa90-0112b32d5291"],
Cell[993894, 27701, 212, 4, 35, "Output",ExpressionUUID->"5ae2c121-5c94-419c-9f5b-88a55d557d8a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[994143, 27710, 191, 3, 45, "Subsubsection",ExpressionUUID->"784594f6-c3ee-4af0-abed-02cbfe789338"],
Cell[CellGroupData[{
Cell[994359, 27717, 416, 9, 82, "Text",ExpressionUUID->"9b982e08-57c1-4fa9-a175-28bf181a47dd",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True],
Cell[994778, 27728, 29472, 707, 1993, "Input",ExpressionUUID->"b59aed32-ea1c-4927-90f5-0ee79a21dcb6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1024299, 28441, 80, 0, 45, "Subsubsection",ExpressionUUID->"3b12fdc1-0f29-4d8b-b4a1-1e5219fcd92d"],
Cell[CellGroupData[{
Cell[1024404, 28445, 214, 5, 31, "Input",ExpressionUUID->"0f9b4e20-1c29-43cd-890a-b6e010d52007"],
Cell[1024621, 28452, 2560, 74, 132, "Output",ExpressionUUID->"6136a5eb-58d9-4c7e-a82f-4113be5da763"]
}, Open  ]],
Cell[1027196, 28529, 2759, 77, 529, "Input",ExpressionUUID->"89fabb60-3145-4d99-9d77-6c7417d38ce6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1029992, 28611, 251, 5, 45, "Subsubsection",ExpressionUUID->"76f099e7-1c83-44de-853b-e29e3b026429"],
Cell[CellGroupData[{
Cell[1030268, 28620, 478, 12, 31, "Input",ExpressionUUID->"c2caf62d-62eb-455d-9b31-4aab30aa4f19",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1030749, 28634, 29144, 709, 1581, "Input",ExpressionUUID->"68b3a474-6e32-4651-a343-5bf1992e85df",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True]
}, Closed]],
Cell[1059908, 29346, 397, 10, 27, "Input",ExpressionUUID->"93a10120-ec54-4564-ba72-9fec6c434f48"],
Cell[CellGroupData[{
Cell[1060330, 29360, 212, 5, 31, "Input",ExpressionUUID->"6e9f92a7-38e1-4150-8a48-9331171b1ad9"],
Cell[1060545, 29367, 13725, 347, 593, "Output",ExpressionUUID->"5004a6d6-b546-44fd-bfbb-b493aa989705"]
}, Closed]],
Cell[1074285, 29717, 466, 10, 43, "Input",ExpressionUUID->"cac4a47f-9b8b-4f1a-b36d-1db6b5206ad1",
 InitializationCell->True],
Cell[1074754, 29729, 487, 10, 47, "Input",ExpressionUUID->"8df2d2e3-1d0b-4dd0-b547-5643c01a4291",
 InitializationCell->True],
Cell[1075244, 29741, 488, 10, 47, "Input",ExpressionUUID->"866af361-114a-4ece-b1ca-e8eb66a8dbab",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1075757, 29755, 164, 3, 31, "Input",ExpressionUUID->"239302ae-9676-411b-8ce5-e33bbed83ad0"],
Cell[1075924, 29760, 677, 21, 42, "Output",ExpressionUUID->"64f0ec53-8e67-40d2-af00-1fcb6c460f36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1076638, 29786, 1320, 34, 104, "Input",ExpressionUUID->"3b2e6a2b-1323-4ed6-82f7-72f937f4c04b"],
Cell[1077961, 29822, 353, 10, 56, "Output",ExpressionUUID->"7a7d2c23-8108-4771-9920-ff2285302c45"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1078351, 29837, 530, 16, 55, "Input",ExpressionUUID->"e018a5ac-4fe5-4949-9a08-4245300fc910"],
Cell[1078884, 29855, 968, 22, 59, "Output",ExpressionUUID->"cc39b555-ce0c-4e30-abbf-2f407af8cc34"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1079889, 29882, 946, 29, 58, "Input",ExpressionUUID->"4f0f5b80-4e31-44a0-89bd-68fef8ecbf37"],
Cell[1080838, 29913, 1615, 42, 105, "Output",ExpressionUUID->"14c99e67-b558-414a-8661-3d9efa3acbe9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1082502, 29961, 278, 8, 71, "Subsubsection",ExpressionUUID->"1b543b32-aa42-49de-b96d-5fc4ef82976c"],
Cell[CellGroupData[{
Cell[1082805, 29973, 208, 5, 31, "Input",ExpressionUUID->"64b370c8-e2da-4336-9362-1edbb6f1c02d"],
Cell[1083016, 29980, 13717, 347, 747, "Output",ExpressionUUID->"47cf586c-c977-4302-a68b-d28f3ab2cdd1"]
}, Open  ]],
Cell[1096748, 30330, 2587, 72, 238, "Input",ExpressionUUID->"24f4d9c8-e216-4e35-ab8b-f62e38e8fe50"],
Cell[CellGroupData[{
Cell[1099360, 30406, 3791, 107, 177, "Input",ExpressionUUID->"df896d09-d2db-4d4a-be5c-df05f34fc4b3"],
Cell[1103154, 30515, 3130, 98, 122, "Output",ExpressionUUID->"b9f3996d-4d49-4ccf-b978-b4ef07e4f29c"]
}, Open  ]],
Cell[1106299, 30616, 471, 11, 31, "Input",ExpressionUUID->"9c709c53-9afa-4a09-aff3-b12d4e8d354d"],
Cell[1106773, 30629, 4959, 141, 308, "Input",ExpressionUUID->"9a7fce60-9b5a-4d52-9522-cefffa89e3d2"],
Cell[1111735, 30772, 419, 9, 31, "Input",ExpressionUUID->"82130228-851e-4e3f-9d75-092db577f58b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1112191, 30786, 247, 8, 45, "Subsubsection",ExpressionUUID->"2f7ceb33-272f-440b-b95c-9dc31ba8413a"],
Cell[CellGroupData[{
Cell[1112463, 30798, 438, 12, 31, "Input",ExpressionUUID->"21700de6-c098-460b-b8a3-171cfecb6d7f"],
Cell[1112904, 30812, 2520, 90, 134, "Output",ExpressionUUID->"3680cfeb-dc5c-4603-a7a0-3a5196e2364a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1115461, 30907, 168, 3, 31, "Input",ExpressionUUID->"fb429649-379e-4a6f-ba73-1c2d8e52eee6"],
Cell[1115632, 30912, 1301, 45, 93, "Output",ExpressionUUID->"19d4500c-4c38-478d-9c0a-5978967c2b11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1116970, 30962, 217, 5, 31, "Input",ExpressionUUID->"4b9c121a-3d0d-44b3-a7f3-e7c9899fc6af"],
Cell[1117190, 30969, 453, 19, 42, "Output",ExpressionUUID->"04f739b8-0559-4794-a678-eee5fcdfabb6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1117680, 30993, 518, 16, 35, "Input",ExpressionUUID->"2acaf471-7744-41c3-a7f8-12f78b3f6b5a"],
Cell[1118201, 31011, 595, 14, 35, "Output",ExpressionUUID->"fa3b81b9-728c-474c-9ce0-b005b6cc9dba"]
}, Open  ]],
Cell[1118811, 31028, 267, 7, 31, "Input",ExpressionUUID->"7b7edf81-8439-4c4d-a6c8-2795bb31e84f"],
Cell[1119081, 31037, 273, 6, 37, "Text",ExpressionUUID->"85cbdd26-c899-4f34-a2f4-a2c4613f47e6"],
Cell[CellGroupData[{
Cell[1119379, 31047, 705, 22, 61, "Input",ExpressionUUID->"5b143e7c-3e1f-4e22-8710-cc9bb0c339dd",
 InitializationCell->True],
Cell[1120087, 31071, 894, 22, 52, "Output",ExpressionUUID->"496718b7-7619-45fa-a51c-e8301a465c81"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1121018, 31098, 578, 17, 55, "Input",ExpressionUUID->"60df9774-1599-450f-8026-d75df9dbb0c1"],
Cell[1121599, 31117, 490, 15, 39, "Output",ExpressionUUID->"cf6bc4f1-3899-4c22-95ad-f565000ef291"]
}, Open  ]],
Cell[1122104, 31135, 458, 8, 62, "Text",ExpressionUUID->"9df28f4e-05b1-4221-a760-9666a416be93"],
Cell[CellGroupData[{
Cell[1122587, 31147, 1264, 34, 84, "Input",ExpressionUUID->"32642c59-42bf-46c3-a69c-1da7f1b3caa6"],
Cell[1123854, 31183, 141, 3, 35, "Output",ExpressionUUID->"09b4d44b-01f3-4e93-83ab-609dd1d0562f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1124032, 31191, 1888, 55, 138, "Input",ExpressionUUID->"023c7e39-5e8b-4018-b70f-82064c2429d1"],
Cell[1125923, 31248, 1839, 52, 105, "Output",ExpressionUUID->"1e410786-48d6-4cba-98e1-4ceb41ae8d6c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1127799, 31305, 519, 16, 62, "Text",ExpressionUUID->"ed96d342-a82d-4481-8a07-f8dc8c5368be",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1128321, 31323, 30917, 808, 1551, "Input",ExpressionUUID->"343b6896-465a-45ce-b219-89423080d75b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True]
}, Closed]],
Cell[1159253, 32134, 604, 19, 41, "Input",ExpressionUUID->"c1147e3c-8cec-4071-9d50-ce75d917ee22"],
Cell[1159860, 32155, 602, 12, 47, "Input",ExpressionUUID->"0ddb7dba-d647-4d9a-b1c5-53865c2ae716",
 InitializationCell->True],
Cell[1160465, 32169, 596, 12, 47, "Input",ExpressionUUID->"59a85797-a9bd-461d-9ee6-11d1d4fa5434",
 InitializationCell->True],
Cell[1161064, 32183, 598, 12, 47, "Input",ExpressionUUID->"e42dfe64-e594-4e85-bfb7-4c861ac1009a",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1161711, 32201, 265, 5, 55, "Subsection",ExpressionUUID->"b94e480c-96d6-49ce-8567-265e3d90d821"],
Cell[1161979, 32208, 487, 11, 31, "Input",ExpressionUUID->"a203e57c-4542-4db8-9b30-a38643245614"],
Cell[CellGroupData[{
Cell[1162491, 32223, 166, 3, 31, "Input",ExpressionUUID->"79111f10-660f-47a1-856d-d794d44cb7e2"],
Cell[1162660, 32228, 835, 31, 52, "Output",ExpressionUUID->"c6392880-f850-43ea-9fd3-158c6498016d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1163532, 32264, 325, 9, 31, "Input",ExpressionUUID->"8f3f5671-a8ec-4711-a395-b33f8e103990"],
Cell[1163860, 32275, 5141, 145, 382, "Output",ExpressionUUID->"ec05cfec-8ce6-48ab-8b96-870f455973aa"]
}, Closed]],
Cell[CellGroupData[{
Cell[1169038, 32425, 315, 8, 27, "Input",ExpressionUUID->"f977a199-b2f3-4653-8504-5d1652b086b1"],
Cell[1169356, 32435, 6429, 187, 264, "Output",ExpressionUUID->"e872081f-f8fc-428c-9514-94e3d6c84ce2"]
}, Closed]],
Cell[CellGroupData[{
Cell[1175822, 32627, 407, 9, 63, "Subsubsection",ExpressionUUID->"956ce4f5-b0e7-4a51-a2b4-522f69c355f6"],
Cell[CellGroupData[{
Cell[1176254, 32640, 990, 30, 55, "Input",ExpressionUUID->"f66d22a1-eba9-4113-a0e5-e5a5bb03fd2e"],
Cell[1177247, 32672, 486, 13, 35, "Output",ExpressionUUID->"4e0d8ee8-58ea-4b93-933e-3b9d6e88cb8b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1177782, 32691, 170, 3, 45, "Subsubsection",ExpressionUUID->"cd2abf52-45ca-419c-a391-91972834049f"],
Cell[CellGroupData[{
Cell[1177977, 32698, 782, 22, 68, "Input",ExpressionUUID->"1aead640-1db1-477e-a132-ef3eab07fdff"],
Cell[1178762, 32722, 3097, 94, 125, "Output",ExpressionUUID->"56431e38-de66-42f2-8a58-ac228cd95b9d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1181908, 32822, 168, 3, 45, "Subsubsection",ExpressionUUID->"3d979113-2693-48fa-93d2-3475c1b27589"],
Cell[CellGroupData[{
Cell[1182101, 32829, 811, 23, 68, "Input",ExpressionUUID->"9cc67419-87db-4dfa-b99e-c0074da94e01"],
Cell[1182915, 32854, 14350, 399, 546, "Output",ExpressionUUID->"5ccee4ad-023e-4a8d-9ac1-789a23c93f74"]
}, Open  ]],
Cell[1197280, 33256, 5300, 152, 351, "Input",ExpressionUUID->"2e1d65b9-9c28-4a0c-8a38-5a4429ba8eba"],
Cell[CellGroupData[{
Cell[1202605, 33412, 2556, 69, 141, "Input",ExpressionUUID->"1d1855d5-0805-4178-9866-a4cbcfe71cd9"],
Cell[1205164, 33483, 12655, 320, 429, "Output",ExpressionUUID->"9ab0923b-b8ea-41a8-ad0e-afbf8c8408d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1217856, 33808, 3406, 97, 213, "Input",ExpressionUUID->"3edb1027-787a-41dd-8abb-7c4a0508d3a4"],
Cell[1221265, 33907, 3074, 85, 131, "Output",ExpressionUUID->"07e3df2e-ef7d-46f9-ac53-196838429652"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1224376, 33997, 992, 31, 72, "Input",ExpressionUUID->"3d2c2156-4882-4cdf-ad43-839c50c57aa7"],
Cell[1225371, 34030, 754, 26, 47, "Output",ExpressionUUID->"3a9da2f8-276b-44ce-9658-0ef3b4cddfd2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1226162, 34061, 1429, 42, 120, "Input",ExpressionUUID->"db3667b0-3e9c-42a9-ad6f-f5ff58256ae9"],
Cell[1227594, 34105, 1327, 41, 72, "Output",ExpressionUUID->"8ce98167-b734-41f1-972d-cfcd0a23ee8f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1228958, 34151, 972, 30, 79, "Input",ExpressionUUID->"de654cd4-eebe-4929-a36c-f65ff37e7778"],
Cell[1229933, 34183, 553, 18, 39, "Output",ExpressionUUID->"81386f91-d140-4d4a-be36-249fe7c08f8e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1230523, 34206, 638, 19, 35, "Input",ExpressionUUID->"8682e5a5-e151-4721-84f3-8868a8b5c7c6"],
Cell[1231164, 34227, 565, 18, 39, "Output",ExpressionUUID->"47d9290b-81dc-4019-a208-3b21d76ab099"]
}, Open  ]],
Cell[1231744, 34248, 1905, 56, 128, "Input",ExpressionUUID->"8f4e7c18-e944-45d6-b661-c26887fd13ac"],
Cell[1233652, 34306, 324, 6, 62, "Text",ExpressionUUID->"7d4ebcfd-5e8b-4790-9a16-8adcd8f7571d"],
Cell[CellGroupData[{
Cell[1234001, 34316, 446, 12, 31, "Input",ExpressionUUID->"f79180d3-1fe2-4e54-9cfb-b547798b4c58"],
Cell[1234450, 34330, 4842, 134, 199, "Output",ExpressionUUID->"488bdd90-167e-4654-ab38-c0888051d166"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1239329, 34469, 371, 10, 31, "Input",ExpressionUUID->"8240d31d-81b3-4740-bb13-c2b9499dcba7"],
Cell[1239703, 34481, 24727, 766, 1025, "Output",ExpressionUUID->"ce66026c-75cb-49bd-b7d8-af69d018900f"]
}, Closed]],
Cell[1264445, 35250, 243, 6, 27, "Input",ExpressionUUID->"e41fa25b-528c-43bc-a793-c6734b1ec706"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1264749, 35263, 334, 5, 68, "Section",ExpressionUUID->"2b662d35-dca6-4397-846b-26944d959c90"],
Cell[CellGroupData[{
Cell[1265108, 35272, 295, 7, 31, "Input",ExpressionUUID->"9bfa4c40-2f94-40fb-8598-c87a5ad18396"],
Cell[1265406, 35281, 770, 24, 42, "Output",ExpressionUUID->"11b6479d-4420-4f23-ba3d-93a5aaad29c6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1266213, 35310, 401, 11, 37, "Text",ExpressionUUID->"ca15be02-6c36-4cd6-be83-0c21f88aba69",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1266617, 35323, 239, 4, 31, "Input",ExpressionUUID->"a3166c3d-3c42-48ab-9805-31627af81fea",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1266859, 35329, 596, 16, 35, "Output",ExpressionUUID->"9acc49f5-20b1-479c-8e96-95c9dc117c84",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1267458, 35347, 238, 4, 31, "Input",ExpressionUUID->"f2cfe403-0b2c-492e-8f38-f1f99a119818",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1267699, 35353, 776, 28, 70, "Output",ExpressionUUID->"f47eef85-3397-455d-b099-4628470e69cf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1268478, 35383, 243, 4, 31, "Input",ExpressionUUID->"2a94b3fe-1c03-464c-b490-35378b01f5ff",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1268724, 35389, 892, 24, 59, "Output",ExpressionUUID->"a524cffe-afef-4364-a1af-0fe64463b857",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1269619, 35415, 239, 4, 31, "Input",ExpressionUUID->"859435cd-b9b6-46c9-9a67-85aa429b4644",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1269861, 35421, 846, 25, 42, "Output",ExpressionUUID->"ab556633-cd31-4f4d-bf87-46be67df8b2b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1270744, 35451, 366, 9, 71, "Subsubsection",ExpressionUUID->"103acbd7-a683-4719-b35f-aa984a77144e"],
Cell[1271113, 35462, 357, 10, 31, "Input",ExpressionUUID->"a73e7163-467a-44d7-a5d2-ee12368b0ab0"],
Cell[CellGroupData[{
Cell[1271495, 35476, 365, 9, 31, "Input",ExpressionUUID->"15a18862-8bd7-4dd3-8899-095914c66af3"],
Cell[1271863, 35487, 762, 22, 59, "Output",ExpressionUUID->"56b57a82-a9a3-4a5a-bc92-46c139207a2d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1272662, 35514, 336, 9, 31, "Input",ExpressionUUID->"d9c6532b-45c7-47be-9c96-6f4cb1296fe1"],
Cell[1273001, 35525, 1129, 35, 65, "Output",ExpressionUUID->"9708764f-95a7-40a6-8d26-87cd9f74d486"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1274167, 35565, 792, 22, 55, "Input",ExpressionUUID->"75847604-ce41-415a-a2a9-4dc119850728"],
Cell[1274962, 35589, 1014, 29, 59, "Output",ExpressionUUID->"6a8951eb-2e70-44c3-909a-4ef36dd94c0b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1276013, 35623, 712, 19, 55, "Input",ExpressionUUID->"5832725c-6012-4c01-8231-06a43114a692"],
Cell[1276728, 35644, 2103, 51, 105, "Output",ExpressionUUID->"9fb6e0c2-24d6-4e0f-85ac-5e994d577852"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1278868, 35700, 807, 20, 78, "Input",ExpressionUUID->"39ecf648-09a4-4c9f-9408-2d42380f4c25"],
Cell[1279678, 35722, 1031, 25, 59, "Output",ExpressionUUID->"54264e24-fb7a-4496-a8b8-d249d5a3ad5d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1280746, 35752, 214, 5, 31, "Input",ExpressionUUID->"5a06f251-01b4-4dd2-b9f5-bcfa1e3de799"],
Cell[1280963, 35759, 682, 14, 59, "Output",ExpressionUUID->"76e058dd-72d5-4f81-84e4-f8a16a5ce9a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1281682, 35778, 702, 18, 55, "Input",ExpressionUUID->"b3a3c7ff-0b74-4bbb-8724-1b62840cff81"],
Cell[1282387, 35798, 2564, 70, 105, "Output",ExpressionUUID->"c14d972b-a035-489c-aa28-057b37b5039e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1284988, 35873, 1305, 33, 101, "Input",ExpressionUUID->"e649c6f5-9920-450e-83af-7d390d46496d"],
Cell[1286296, 35908, 8239, 228, 541, "Output",ExpressionUUID->"37170fbf-c94f-4b4c-bdf0-9eb58e797428"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1294584, 36142, 281, 5, 55, "Subsection",ExpressionUUID->"116842f2-a940-413d-ae56-20c627068455"],
Cell[1294868, 36149, 9779, 260, 1411, "Input",ExpressionUUID->"4fcfdc0d-853f-4f75-8fb9-ff28c495390d",
 InitializationCell->True],
Cell[1304650, 36411, 204, 5, 37, "Text",ExpressionUUID->"750b2897-9777-418b-bac8-6d8d28b98383"],
Cell[1304857, 36418, 600, 16, 35, "Input",ExpressionUUID->"3ad64b2b-11ed-4bc7-8fd2-38c2b3a3571c"],
Cell[CellGroupData[{
Cell[1305482, 36438, 689, 22, 62, "Input",ExpressionUUID->"134a5dad-c6af-496b-aead-fde272d81889"],
Cell[1306174, 36462, 618, 21, 52, "Output",ExpressionUUID->"1f8471e1-ee22-405d-8443-235ec6c18541"]
}, Open  ]],
Cell[1306807, 36486, 495, 14, 35, "Input",ExpressionUUID->"58513c2e-d800-4acc-9031-1298451834e1"],
Cell[1307305, 36502, 567, 19, 62, "Input",ExpressionUUID->"d81b5cbd-b17d-4556-a6b5-18fe698ff83c"],
Cell[1307875, 36523, 3676, 92, 338, "Input",ExpressionUUID->"11f4f4ab-a51e-4864-93e8-121dd0114402",
 InitializationCell->True],
Cell[1311554, 36617, 476, 9, 37, "Text",ExpressionUUID->"529ba78f-60a6-4ecc-a728-a3f2637023bb"],
Cell[1312033, 36628, 3652, 92, 371, "Input",ExpressionUUID->"b9c65a37-46c7-4256-9ba5-755daeafb963",
 InitializationCell->True],
Cell[1315688, 36722, 294, 6, 37, "Text",ExpressionUUID->"e9e72fa1-cd64-4d31-8856-ffa3fbb07751"],
Cell[CellGroupData[{
Cell[1316007, 36732, 192, 5, 31, "Input",ExpressionUUID->"a999a4b1-2ec6-4d66-9af9-ae0558e459a1"],
Cell[1316202, 36739, 553, 23, 42, "Output",ExpressionUUID->"bcf2f9d4-0d0d-4724-ba21-5053463ed6d4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1316792, 36767, 502, 16, 31, "Input",ExpressionUUID->"9c11b120-52b4-4077-a54d-8496616b6e8c"],
Cell[1317297, 36785, 996, 23, 59, "Output",ExpressionUUID->"c171cbbe-6ea6-4100-bfc2-41868a2dd3c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1318330, 36813, 263, 7, 31, "Input",ExpressionUUID->"908faae1-ae63-477f-9bbd-c36b14ef807b"],
Cell[1318596, 36822, 385, 11, 35, "Output",ExpressionUUID->"75d2e25b-5384-4c3d-8ee3-8d49a66af3af"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1319018, 36838, 908, 27, 78, "Input",ExpressionUUID->"ff6357d0-f1df-423a-83cb-3095dabbcf4d"],
Cell[1319929, 36867, 1022, 23, 59, "Output",ExpressionUUID->"23c87fb0-acf5-464f-9121-7ff2c1cb0f30"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1320988, 36895, 1548, 40, 150, "Input",ExpressionUUID->"8a4260ca-a088-4b35-9021-fe3107cf9d1b"],
Cell[1322539, 36937, 1492, 45, 105, "Output",ExpressionUUID->"d98127c9-7600-44a9-a094-f65e13a20109"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1324068, 36987, 828, 23, 55, "Input",ExpressionUUID->"121f447e-6127-4289-8fc7-766e92cea6a8"],
Cell[1324899, 37012, 1456, 45, 105, "Output",ExpressionUUID->"b6c3664c-ebc6-48ed-b190-6281b9b05c1b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1326392, 37062, 863, 21, 78, "Input",ExpressionUUID->"25cdcf5d-6b3f-45c7-8b1c-1ef194929ee1"],
Cell[1327258, 37085, 982, 25, 59, "Output",ExpressionUUID->"ab296eaf-7b2a-4bd5-b4e7-1f6aad8273b2"]
}, Open  ]],
Cell[1328255, 37113, 269, 5, 45, "Subsubsection",ExpressionUUID->"2623e09e-2199-4f29-a5c6-c1bbeddffeb9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1328573, 37124, 544, 10, 263, "Section",ExpressionUUID->"ce8bc90a-56de-4ede-9614-42fe375e1e42"],
Cell[CellGroupData[{
Cell[1329142, 37138, 162, 3, 31, "Input",ExpressionUUID->"a9e5ea41-6811-4a1b-8f14-97affa81c7b3"],
Cell[1329307, 37143, 799, 22, 59, "Output",ExpressionUUID->"bc7e68e0-2303-42df-be2b-24ee783e5426"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1330143, 37170, 952, 27, 78, "Input",ExpressionUUID->"873efcf1-8c79-4f7d-bdb7-836d0ab3ae7a"],
Cell[1331098, 37199, 1007, 31, 66, "Output",ExpressionUUID->"9c08a036-d274-4692-8b87-92eb76cf06bc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1332142, 37235, 169, 4, 31, "Input",ExpressionUUID->"c79948ee-043d-4d83-b6a8-1f4300577823"],
Cell[1332314, 37241, 894, 29, 66, "Output",ExpressionUUID->"e67644e0-d7ad-4e50-a695-fea658c1de62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1333245, 37275, 605, 15, 31, "Input",ExpressionUUID->"648816ec-1d1c-4d6c-8c17-1c562aafbdd9"],
Cell[1333853, 37292, 142, 3, 35, "Output",ExpressionUUID->"302721bd-92b5-4d49-96ca-902ec250fc88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1334032, 37300, 195, 4, 31, "Input",ExpressionUUID->"eafba17b-14dc-4183-a9eb-a6d8cbfcde05"],
Cell[1334230, 37306, 176, 5, 35, "Output",ExpressionUUID->"ebde61d2-365f-4a4d-b3ac-01b5f7c763e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1334443, 37316, 257, 6, 31, "Input",ExpressionUUID->"953f8e1b-7ca3-4e86-8571-f55acc6a6ba7"],
Cell[1334703, 37324, 2318, 54, 289, "Output",ExpressionUUID->"ffd1e0fc-739b-4407-b8ca-72255155de60"]
}, Open  ]],
Cell[1337036, 37381, 239, 5, 37, "Text",ExpressionUUID->"c08cd79c-8a23-45fc-a05a-2cdb188006e0"],
Cell[1337278, 37388, 293, 7, 31, "Input",ExpressionUUID->"fb574f50-80e9-4a59-93d8-8831eaf2ae1a"],
Cell[1337574, 37397, 435, 12, 31, "Input",ExpressionUUID->"544c3816-e595-4a47-8eee-079a6161bf9b"],
Cell[CellGroupData[{
Cell[1338034, 37413, 192, 4, 31, "Input",ExpressionUUID->"c9cda687-2180-4998-98c7-3e755b4c024e"],
Cell[1338229, 37419, 140, 3, 35, "Output",ExpressionUUID->"250854fd-faac-44fd-a7d1-d74c93302aa1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1338418, 37428, 277, 6, 107, "Section",ExpressionUUID->"e24839de-a86b-4af5-a1e7-08accb866d49"],
Cell[1338698, 37436, 674, 18, 71, "Input",ExpressionUUID->"9d1f0985-7a18-4253-baad-ad5e1fd02cdd",
 InitializationCell->True],
Cell[1339375, 37456, 523, 14, 31, "Input",ExpressionUUID->"c842ba0a-ac10-45fb-b98d-cbd5a1378ecf"],
Cell[CellGroupData[{
Cell[1339923, 37474, 381, 10, 31, "Input",ExpressionUUID->"70e6a672-ce97-4727-93df-9eb9f7b60e6d"],
Cell[1340307, 37486, 754, 25, 39, "Output",ExpressionUUID->"e903fd41-5e97-47de-a0e1-0af507234db9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1341098, 37516, 231, 5, 45, "Subsubsection",ExpressionUUID->"f4497281-db92-45b7-9f97-8aea9fef7ed2"],
Cell[CellGroupData[{
Cell[1341354, 37525, 603, 17, 31, "Input",ExpressionUUID->"35614563-8e85-47fc-92ad-d17288d5dc9b"],
Cell[1341960, 37544, 1311, 39, 66, "Output",ExpressionUUID->"26cbaf65-daaf-4871-917b-e6d82864a560"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1343308, 37588, 513, 14, 31, "Input",ExpressionUUID->"891877f0-95be-4794-a5e0-80c4d77d33af"],
Cell[1343824, 37604, 647, 21, 39, "Output",ExpressionUUID->"f5cb505f-1580-453b-bd56-dbc84cae80b6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1344508, 37630, 381, 10, 31, "Input",ExpressionUUID->"d0b68d97-72c3-4801-9798-0566f842975f"],
Cell[1344892, 37642, 754, 25, 39, "Output",ExpressionUUID->"8d65456d-e11b-4b80-8f39-53134e43bb00"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1345695, 37673, 306, 7, 71, "Subsubsection",ExpressionUUID->"56abce51-0622-4c67-8724-1557152abd44"],
Cell[CellGroupData[{
Cell[1346026, 37684, 386, 12, 35, "Input",ExpressionUUID->"d08456c5-7c52-449a-ae53-49e55f6f5da5"],
Cell[1346415, 37698, 300, 8, 35, "Output",ExpressionUUID->"8773145a-9063-4b21-9795-436fc656bb25"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1346752, 37711, 411, 12, 35, "Input",ExpressionUUID->"e3372279-7c3e-4711-92f5-e3a2337e612c"],
Cell[1347166, 37725, 327, 9, 35, "Output",ExpressionUUID->"99b7f510-a198-48f6-8a98-27bf6b1e36f7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1347530, 37739, 573, 16, 35, "Input",ExpressionUUID->"a07aede9-5809-4081-80a7-723deb6c2f83"],
Cell[1348106, 37757, 35048, 903, 1929, "Output",ExpressionUUID->"c5f52691-502a-4b76-b4e2-71aa6634db4d"]
}, Closed]],
Cell[1383169, 38663, 571, 15, 31, "Input",ExpressionUUID->"26883152-c541-4b78-b992-59645f528c3b"],
Cell[CellGroupData[{
Cell[1383765, 38682, 397, 11, 31, "Input",ExpressionUUID->"b403f1e4-32c2-40a5-8ee3-4210075e3d0a"],
Cell[1384165, 38695, 952, 21, 59, "Output",ExpressionUUID->"fe93dbe4-fc12-45f0-978d-dc3c69608088"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1385154, 38721, 616, 17, 55, "Input",ExpressionUUID->"582df10e-c21e-4bf0-8040-8694c2de634b"],
Cell[1385773, 38740, 950, 25, 59, "Output",ExpressionUUID->"fb2caa82-16c4-4be3-af4c-3cc66a85926d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1386760, 38770, 303, 8, 31, "Input",ExpressionUUID->"2ab353f5-0cca-404b-a339-d891c45aef34"],
Cell[1387066, 38780, 921, 21, 59, "Output",ExpressionUUID->"c6c015d4-366e-4430-b0c5-e791aa47fe65"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1388036, 38807, 231, 4, 55, "Subsection",ExpressionUUID->"51088bd8-a758-47d2-8185-4e8eb85cff53"],
Cell[CellGroupData[{
Cell[1388292, 38815, 92, 0, 31, "Input",ExpressionUUID->"63f30ff6-e3ef-4e25-9b11-5632f559d533"],
Cell[1388387, 38817, 37667, 1003, 2006, "Output",ExpressionUUID->"6f644f43-ec5f-47fe-a7c2-c2715f87e945"]
}, Closed]],
Cell[CellGroupData[{
Cell[1426091, 39825, 261, 6, 27, "Input",ExpressionUUID->"100bebe7-74b7-4cda-a7bc-c7bc5ce2187c"],
Cell[1426355, 39833, 33821, 897, 1929, "Output",ExpressionUUID->"70d42414-460a-4856-a9c5-54bf22cb6975"]
}, Closed]],
Cell[CellGroupData[{
Cell[1460213, 40735, 369, 10, 27, "Input",ExpressionUUID->"40d099a9-e806-44b2-a06f-64fb435ac2b8"],
Cell[1460585, 40747, 921, 21, 59, "Output",ExpressionUUID->"9b1571b9-1b87-4749-85ff-3e81b0ddd52e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1461543, 40773, 354, 10, 31, "Input",ExpressionUUID->"7f424ef7-9517-4842-838d-e61241b1f361"],
Cell[1461900, 40785, 926, 21, 59, "Output",ExpressionUUID->"217e7da8-2565-48dc-88c3-de9b3f402c5f"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1462899, 40814, 556, 12, 293, "Subchapter",ExpressionUUID->"0e5d5f38-e69f-4b42-aca8-31d273396768"],
Cell[CellGroupData[{
Cell[1463480, 40830, 187, 3, 68, "Section",ExpressionUUID->"bb0c565f-72c4-48fe-b24b-549b82909420"],
Cell[CellGroupData[{
Cell[1463692, 40837, 492, 10, 123, "Subsubsection",ExpressionUUID->"928014f0-8b14-409c-9640-f60a15176f73",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1464187, 40849, 657, 16, 31, "Input",ExpressionUUID->"0b807712-d511-43c2-8c38-e4e7b6777d4b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1464847, 40867, 51175, 1263, 1962, "Output",ExpressionUUID->"59435f09-5886-447c-be0a-bd5573bc41fe",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1516025, 42132, 494, 11, 31, "Input",ExpressionUUID->"7165341b-6151-4b79-8781-5eec4ee8940b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1516522, 42145, 300, 7, 35, "Output",ExpressionUUID->"cf7790ea-128e-4db4-bda9-9c5544c5e6ee",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1516825, 42154, 52447, 1275, 4779, "Input",ExpressionUUID->"9c634a09-9018-486f-b479-254d15138ad6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True],
Cell[1569275, 43431, 355, 7, 70, "Output",ExpressionUUID->"bd89b38d-89e9-41ce-976b-570965e0f57b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1569633, 43440, 311, 6, 31, "Input",ExpressionUUID->"d7fac020-17fd-4586-a4dc-f27f646ccbcf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1569947, 43448, 8321, 229, 483, "Output",ExpressionUUID->"c1b00209-e44b-482f-ab22-1b51201d791e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1578271, 43679, 456, 11, 31, "Input",ExpressionUUID->"dbbd2e03-ea60-4a0e-af17-c6193a2dad92",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1578730, 43692, 209, 4, 35, "Output",ExpressionUUID->"e7d36695-8e3f-40f9-9273-7d99372fa1f8",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1578942, 43698, 12846, 322, 821, "Input",ExpressionUUID->"042ca01b-65e4-43fe-91d2-f1337d35b769",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, {6}]],
Cell[CellGroupData[{
Cell[1591822, 44025, 1454, 46, 92, "Input",ExpressionUUID->"4a346d1d-9ee5-4083-be49-04ecd457e139"],
Cell[1593279, 44073, 332, 7, 35, "Output",ExpressionUUID->"a2eaef17-1f5e-45ac-90a8-2ee96e378f21"]
}, Open  ]],
Cell[1593626, 44083, 305, 7, 37, "Text",ExpressionUUID->"53b8c3e2-5748-4e28-84ab-65f6d3daefc5"],
Cell[CellGroupData[{
Cell[1593956, 44094, 875, 23, 55, "Input",ExpressionUUID->"c1d8c447-cc96-4959-bca2-a9da416a9158"],
Cell[1594834, 44119, 336, 8, 35, "Output",ExpressionUUID->"9477bbb4-c81c-4081-a478-7d3c0d832d49"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1595219, 44133, 220, 5, 68, "Section",ExpressionUUID->"45d6d7f0-1139-41bb-9701-1001c726f0b0"],
Cell[CellGroupData[{
Cell[1595464, 44142, 220, 4, 55, "Subsection",ExpressionUUID->"a1434f94-1714-4fb4-9472-316da32423d1"],
Cell[1595687, 44148, 1781, 52, 117, "Input",ExpressionUUID->"8e9fab91-9d36-4ace-a1b8-c663b53933a5",
 InitializationCell->True],
Cell[1597471, 44202, 2425, 60, 124, "Input",ExpressionUUID->"6c7b0d4c-e65e-46cb-a153-1028c0f80e31"],
Cell[CellGroupData[{
Cell[1599921, 44266, 866, 26, 31, "Input",ExpressionUUID->"82ba6b7a-d672-484b-aa35-35ba76a9bf29"],
Cell[1600790, 44294, 526, 11, 408, "Output",ExpressionUUID->"f31b7adc-27da-4468-974d-ef878cad5079"]
}, Open  ]],
Cell[1601331, 44308, 2784, 72, 186, "Input",ExpressionUUID->"225e7529-bda3-493f-a13a-900523259659",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1604140, 44384, 1274, 35, 78, "Input",ExpressionUUID->"fe9e6967-7451-4a2b-b081-b8c793ad060d"],
Cell[1605417, 44421, 795, 19, 340, "Output",ExpressionUUID->"667883d9-6673-47b1-8fef-25e2c721ffc9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1606249, 44445, 282, 6, 71, "Subsubsection",ExpressionUUID->"f127affe-bd70-4170-9409-724f7ec39747"],
Cell[1606534, 44453, 1719, 44, 140, "Input",ExpressionUUID->"38f3ba01-6fa8-4290-8e06-718c7ac59104",
 InitializationCell->True],
Cell[1608256, 44499, 3990, 103, 278, "Input",ExpressionUUID->"d2f034f3-7e42-4aac-881a-d942e9d62d85",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1612295, 44608, 307, 6, 55, "Subsection",ExpressionUUID->"64a81cbe-a3fc-45e9-a09b-088f7e939180"],
Cell[1612605, 44616, 451, 13, 47, "Input",ExpressionUUID->"21f7e861-24d7-48a9-850a-8b865fe2ecd9",
 InitializationCell->True],
Cell[1613059, 44631, 1310, 35, 117, "Input",ExpressionUUID->"f8c24c6d-ee62-478f-96be-836d8a3366d4",
 InitializationCell->True],
Cell[1614372, 44668, 472, 14, 31, "Input",ExpressionUUID->"7e40dfe0-faa5-4321-bc0e-92f03f710474"],
Cell[1614847, 44684, 381, 10, 31, "Input",ExpressionUUID->"9994aa8b-3d01-4fc9-aff9-e8c2a55092d2"],
Cell[CellGroupData[{
Cell[1615253, 44698, 263, 6, 31, "Input",ExpressionUUID->"c342a626-9fa1-4d43-935f-9120a601046d"],
Cell[1615519, 44706, 595, 16, 35, "Output",ExpressionUUID->"1902fbd4-8ca8-4cde-98bf-8ceca08066b4"]
}, Open  ]],
Cell[1616129, 44725, 612, 18, 89, "Text",ExpressionUUID->"557ba19b-5628-4e2c-8f8d-bfc6cd4b4afd"],
Cell[1616744, 44745, 1550, 38, 101, "Input",ExpressionUUID->"e3c5e168-bd9b-4dbe-a329-467a1a7203d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1618331, 44788, 315, 6, 55, "Subsection",ExpressionUUID->"b37350dd-eb45-4da0-9e36-272c4784e8d3"],
Cell[1618649, 44796, 1528, 42, 117, "Input",ExpressionUUID->"01bf7736-05d3-4d8d-a4b6-e53282146db6",
 InitializationCell->True],
Cell[1620180, 44840, 371, 10, 31, "Input",ExpressionUUID->"04c087fe-3a64-4489-aca5-6ba7ff264860"],
Cell[CellGroupData[{
Cell[1620576, 44854, 1052, 30, 55, "Input",ExpressionUUID->"c01d5973-068b-49d7-bc9e-1a9b1e0ca7a9"],
Cell[1621631, 44886, 13379, 229, 210, "Output",ExpressionUUID->"9dcf100e-0575-4ea5-8425-f817a33706da"]
}, Closed]],
Cell[1635025, 45118, 1578, 42, 113, "Input",ExpressionUUID->"1b4eb2fd-172f-454f-8148-8eebb4a211d6",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1636628, 45164, 1177, 32, 55, "Input",ExpressionUUID->"44475253-dbe5-44f0-8a93-272162e239f9"],
Cell[1637808, 45198, 13347, 228, 240, "Output",ExpressionUUID->"a1a125ef-160d-4fea-b100-7059781e4b53"]
}, Closed]],
Cell[1651170, 45429, 1459, 39, 113, "Input",ExpressionUUID->"0955d75f-974f-4043-8229-765cb07389f3",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1652654, 45472, 456, 11, 31, "Input",ExpressionUUID->"02b7029a-dbab-476c-ba33-b574471a6e21"],
Cell[1653113, 45485, 7185, 127, 369, "Output",ExpressionUUID->"3d03023e-1057-45fa-b2e2-f01ebb117f3e"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1660347, 45618, 520, 15, 83, "Subsection",ExpressionUUID->"0b59c1c4-0563-4ea6-ab68-212e3414da71"],
Cell[CellGroupData[{
Cell[1660892, 45637, 490, 11, 97, "Subsubsection",ExpressionUUID->"c9fd29f4-f536-4bdb-9956-94e1c4126fdd"],
Cell[1661385, 45650, 858, 25, 55, "Input",ExpressionUUID->"92ae226f-e829-42e7-a5dc-255bf2cc7ac1"],
Cell[1662246, 45677, 3082, 84, 193, "Input",ExpressionUUID->"82c4ae53-b9b8-47a1-9530-fd0184ba247c"],
Cell[CellGroupData[{
Cell[1665353, 45765, 419, 12, 31, "Input",ExpressionUUID->"8aba0a8c-d29a-4fb1-b7c2-ba8e94be113f"],
Cell[1665775, 45779, 287, 8, 35, "Output",ExpressionUUID->"b1d839ad-7c0f-4bfc-aaf2-9b05d5023878"]
}, Open  ]],
Cell[1666077, 45790, 4445, 113, 262, "Input",ExpressionUUID->"ec1424eb-e0a9-4e2f-96b8-a9419c517d18"],
Cell[1670525, 45905, 188, 4, 31, "Input",ExpressionUUID->"63f0ce34-4bf9-4bb2-a65c-3a17a5dcc988"],
Cell[CellGroupData[{
Cell[1670738, 45913, 367, 9, 31, "Input",ExpressionUUID->"4b0b3dc3-5341-44f9-bca0-cb050f1e120b"],
Cell[1671108, 45924, 616, 17, 35, "Output",ExpressionUUID->"c44a6ead-5bea-4b9c-b81c-d7b6bceef2c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1671761, 45946, 643, 16, 55, "Input",ExpressionUUID->"3741a0a3-6525-40ee-8979-94ab0ff093b9"],
Cell[1672407, 45964, 411, 11, 35, "Output",ExpressionUUID->"60847a7d-5a94-42ae-8577-2595dcb2262d"]
}, Open  ]],
Cell[1672833, 45978, 2304, 58, 124, "Input",ExpressionUUID->"a06eaf49-52d3-401d-9630-585f08b029e5"]
}, Open  ]],
Cell[1675152, 46039, 229, 5, 45, "Subsubsection",ExpressionUUID->"a7a9d3bb-0a9c-44ae-a41c-b60172a75f36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1675418, 46049, 602, 10, 111, "Subsection",ExpressionUUID->"78f9eaeb-0c4d-4578-a8e4-04e97687ce37"],
Cell[CellGroupData[{
Cell[1676045, 46063, 247, 4, 45, "Subsubsection",ExpressionUUID->"6212d223-1e45-4c40-9ca6-d469c15d6e30"],
Cell[1676295, 46069, 3658, 89, 255, "Input",ExpressionUUID->"b7cd2f07-6b3d-4c4f-aa3d-4825f3117f9b",
 InitializationCell->True],
Cell[1679956, 46160, 4642, 117, 278, "Input",ExpressionUUID->"7f02ee15-ad8a-4275-9e38-e56c29f27f3b",
 InitializationCell->True],
Cell[1684601, 46279, 5600, 139, 324, "Input",ExpressionUUID->"278b9420-2336-43d3-a1e4-f6adc01f3403",
 InitializationCell->True],
Cell[1690204, 46420, 242, 6, 31, "Input",ExpressionUUID->"c2288df7-09b0-4b64-a1c8-e44a09e6ffa2"],
Cell[CellGroupData[{
Cell[1690471, 46430, 192, 3, 31, "Input",ExpressionUUID->"fc56b136-f1e7-4676-9021-8ff5e4249f9f"],
Cell[1690666, 46435, 2100, 58, 128, "Output",ExpressionUUID->"f6ff81d3-de6a-4b7a-8c3f-1e4085088395"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1692803, 46498, 223, 4, 31, "Input",ExpressionUUID->"d9d6fff1-8285-4804-8a63-e9acfa47c8c6"],
Cell[1693029, 46504, 2877, 70, 174, "Output",ExpressionUUID->"7b4e8489-9e6d-4644-b487-6adca9a5909f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1695955, 46580, 222, 5, 45, "Subsubsection",ExpressionUUID->"b20e3063-22dd-485d-b7d3-1698e99c3821"],
Cell[1696180, 46587, 235, 5, 37, "Text",ExpressionUUID->"d3c273c4-6211-4d97-b078-9bfb6d4d6ae7"],
Cell[1696418, 46594, 1925, 52, 163, "Input",ExpressionUUID->"cd0269e6-3f10-4836-963c-6154352a646f",
 InitializationCell->True],
Cell[1698346, 46648, 1616, 49, 117, "Input",ExpressionUUID->"4fbc9b90-b183-4a06-85c8-97e313423616",
 InitializationCell->True],
Cell[1699965, 46699, 1444, 41, 117, "Input",ExpressionUUID->"2321b27b-8c47-46e5-a8cd-db2d6295ef02",
 InitializationCell->True],
Cell[1701412, 46742, 311, 8, 35, "Text",ExpressionUUID->"f7f03bd2-c84f-4f28-a556-687ee6a7a417"],
Cell[1701726, 46752, 1068, 28, 71, "Input",ExpressionUUID->"3ce06a9b-fb35-4832-8968-06d876d75191",
 InitializationCell->True],
Cell[1702797, 46782, 827, 22, 71, "Input",ExpressionUUID->"42c7601c-233a-49ac-a78c-44d7478d9a85",
 InitializationCell->True],
Cell[1703627, 46806, 208, 5, 37, "Text",ExpressionUUID->"d24bc4ba-d798-45ac-bbe3-75c9689f8b9b"],
Cell[1703838, 46813, 2083, 55, 163, "Input",ExpressionUUID->"d0291087-5f9f-4744-a296-3edab177661f",
 InitializationCell->True],
Cell[1705924, 46870, 281, 6, 37, "Text",ExpressionUUID->"233cbc9a-ef05-4d7b-9196-0867e1e4c088"],
Cell[1706208, 46878, 2788, 67, 186, "Input",ExpressionUUID->"337e2fe3-dbf8-4e29-91d3-1602f362f54f",
 InitializationCell->True],
Cell[1708999, 46947, 285, 6, 37, "Text",ExpressionUUID->"42053f00-0580-4035-940e-245bd8248238"],
Cell[1709287, 46955, 1611, 44, 140, "Input",ExpressionUUID->"8901fa69-a9f4-49a7-bafd-69b90487165e",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[1710935, 47004, 301, 6, 42, "Subsubsection",ExpressionUUID->"f226df65-a2ff-4d93-b97e-e76ae11f0af5"],
Cell[1711239, 47012, 3229, 86, 209, "Input",ExpressionUUID->"ec42596e-1d4b-4c85-947b-7848a490c949",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1714493, 47102, 1077, 30, 55, "Input",ExpressionUUID->"7b8e80c8-2a9d-44c6-a0e2-5f2db208cdf3"],
Cell[1715573, 47134, 214, 4, 35, "Output",ExpressionUUID->"8df6f92b-b78b-4e06-847c-98c02694bcb3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1715824, 47143, 180, 2, 31, "Input",ExpressionUUID->"656a5abc-2824-4fed-a0f4-9b3ad7faca3d"],
Cell[1716007, 47147, 527, 13, 35, "Output",ExpressionUUID->"09c6487d-2de3-4ef7-83d8-b07228d75499"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1716571, 47165, 182, 2, 31, "Input",ExpressionUUID->"ebdbcd98-274b-49fa-817c-c0c39401a0f4"],
Cell[1716756, 47169, 1497, 37, 105, "Output",ExpressionUUID->"37b5bfe3-792a-4a63-95ff-bd0dfba6f800"]
}, Open  ]],
Cell[1718268, 47209, 260, 6, 37, "Text",ExpressionUUID->"8c9cc8c7-e3e0-4e48-85a5-63f7d2b4c3a0"],
Cell[CellGroupData[{
Cell[1718553, 47219, 323, 7, 31, "Input",ExpressionUUID->"a1fd190c-0786-4419-bfa2-75148f5f04b3"],
Cell[1718879, 47228, 125741, 2539, 7136, "Output",ExpressionUUID->"ea7f79be-bb6b-4dbe-815e-fae0e8453851"]
}, Closed]],
Cell[CellGroupData[{
Cell[1844657, 49772, 331, 8, 27, "Input",ExpressionUUID->"d051315b-7a77-4257-a9d1-749285d6ecfe"],
Cell[1844991, 49782, 6311, 149, 371, "Output",ExpressionUUID->"a69f17f8-7a48-47d5-a4b5-25f2ead752d0"]
}, Closed]],
Cell[1851317, 49934, 477, 13, 33, "Text",ExpressionUUID->"7674dc3c-c67f-4486-9046-3731f258db88"],
Cell[CellGroupData[{
Cell[1851819, 49951, 897, 21, 55, "Input",ExpressionUUID->"47f0e5d5-9aad-4e81-abed-a2b45d65510a"],
Cell[1852719, 49974, 1518, 37, 105, "Output",ExpressionUUID->"2fbbb8a8-2dc1-4947-97cd-0165c758d0e6"]
}, Open  ]],
Cell[1854252, 50014, 4677, 120, 255, "Input",ExpressionUUID->"81991b07-e844-4041-bebb-a0084bf20285",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1858954, 50138, 181, 3, 31, "Input",ExpressionUUID->"500c3252-b0d4-4bfa-aad3-7237700f963f"],
Cell[1859138, 50143, 492, 12, 35, "Output",ExpressionUUID->"3df205d7-a87e-4332-b454-d1f12db1d2f5"]
}, Open  ]],
Cell[1859645, 50158, 489, 9, 137, "Text",ExpressionUUID->"8c78b9bf-1fec-4628-9522-ee3e71c0bc4a"],
Cell[1860137, 50169, 382, 10, 31, "Input",ExpressionUUID->"95adb7b7-cf51-4150-b3cb-49580abd8b00"],
Cell[CellGroupData[{
Cell[1860544, 50183, 630, 17, 31, "Input",ExpressionUUID->"c6146199-a807-415a-aced-31b64f928d55"],
Cell[1861177, 50202, 891, 28, 59, "Output",ExpressionUUID->"f6a6ab34-545d-4094-9c94-46ee0718ae92"]
}, Open  ]],
Cell[1862083, 50233, 3951, 103, 255, "Input",ExpressionUUID->"21a1289c-e7e3-48c7-ac5f-05019f3f5846",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1866059, 50340, 450, 11, 55, "Input",ExpressionUUID->"672206f6-6762-4772-939a-fbb093ab62be"],
Cell[1866512, 50353, 317, 8, 35, "Output",ExpressionUUID->"14ec31c4-5c8a-4a61-8662-c74d14e053be"]
}, Open  ]],
Cell[1866844, 50364, 645, 17, 55, "Input",ExpressionUUID->"3e994c3f-5863-4f9f-8c7a-fedb9628f5ea"],
Cell[CellGroupData[{
Cell[1867514, 50385, 968, 24, 55, "Input",ExpressionUUID->"86be3751-8045-49ef-a795-58a9ac3d77e0"],
Cell[1868485, 50411, 889, 28, 59, "Output",ExpressionUUID->"d91f16cb-7ab9-4c0d-8e95-809b6ffea840"]
}, Open  ]],
Cell[1869389, 50442, 2893, 77, 209, "Input",ExpressionUUID->"8a4f62bf-026b-46d0-b1a6-94650a07d21c",
 InitializationCell->True],
Cell[1872285, 50521, 3678, 87, 308, "Input",ExpressionUUID->"8606ac3b-bdb9-428d-a6f3-95bd33dbe53e"],
Cell[CellGroupData[{
Cell[1875988, 50612, 294, 7, 31, "Input",ExpressionUUID->"94198237-8a3e-4125-8345-70d976952f4b"],
Cell[1876285, 50621, 341, 8, 35, "Output",ExpressionUUID->"74c7e466-a531-4b96-a3c7-c21958336836"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1876663, 50634, 456, 12, 31, "Input",ExpressionUUID->"a8b7c446-59d4-43e0-b428-0b678c933515"],
Cell[1877122, 50648, 153, 3, 35, "Output",ExpressionUUID->"c8a37ecb-be0f-4a10-bbbe-dde2c086590d"]
}, Open  ]],
Cell[1877290, 50654, 308, 6, 66, "Text",ExpressionUUID->"e74315e9-3351-40eb-8eae-0159c5121f1a"],
Cell[CellGroupData[{
Cell[1877623, 50664, 834, 21, 55, "Input",ExpressionUUID->"1b567ba0-b69f-4b7f-9182-10cb484bb8b0"],
Cell[1878460, 50687, 1935, 58, 66, "Output",ExpressionUUID->"7c38b373-6b1b-469c-b647-f4cd3d901d1a"]
}, Open  ]],
Cell[1880410, 50748, 4392, 111, 236, "Input",ExpressionUUID->"507117fc-c9dc-4626-807b-24fa9e919d30",
 InitializationCell->True],
Cell[1884805, 50861, 566, 17, 90, "Text",ExpressionUUID->"5aceff53-fd28-46e2-a985-12c0383e4f1a"],
Cell[CellGroupData[{
Cell[1885396, 50882, 456, 12, 31, "Input",ExpressionUUID->"1071c746-c54f-4ef0-a4d0-d8e7c3d487ca"],
Cell[1885855, 50896, 153, 3, 35, "Output",ExpressionUUID->"88ff9db9-8d87-4575-88a4-ba4b85fe6f80"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1886045, 50904, 1457, 39, 133, "Input",ExpressionUUID->"848c5655-3cd4-46ef-9c0f-36d89b472776"],
Cell[1887505, 50945, 202, 4, 35, "Output",ExpressionUUID->"c710cd32-d93b-4215-926a-9add663d3e32"]
}, Open  ]],
Cell[1887722, 50952, 241, 5, 37, "Text",ExpressionUUID->"31439d02-e183-4d61-b6f2-70b1ed21b2f6"],
Cell[CellGroupData[{
Cell[1887988, 50961, 709, 20, 31, "Input",ExpressionUUID->"357bd0c8-2303-4356-8af6-d4c9bf91fbd2"],
Cell[1888700, 50983, 337, 9, 35, "Output",ExpressionUUID->"482ce49d-11ec-40ed-8015-0a311a3a2a70"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1889074, 50997, 872, 24, 81, "Input",ExpressionUUID->"b83831c4-8f59-4e16-82b8-2732aed67283"],
Cell[1889949, 51023, 6864, 212, 316, "Output",ExpressionUUID->"3e12a57c-a343-4d17-913b-4d2d1006304b"]
}, Closed]],
Cell[CellGroupData[{
Cell[1896850, 51240, 398, 11, 27, "Input",ExpressionUUID->"9ce812aa-1227-470a-9ba9-fc6f7a9ce70d"],
Cell[1897251, 51253, 1099, 33, 39, "Output",ExpressionUUID->"a3df1748-0db6-4233-b9fe-568890625853"]
}, Open  ]],
Cell[1898365, 51289, 7793, 226, 374, "Input",ExpressionUUID->"909055a9-3adb-44a7-9889-639d89efdd06",
 InitializationCell->True],
Cell[1906161, 51517, 1777, 40, 163, "Input",ExpressionUUID->"0a6d182d-3335-474f-9e65-fc09bf1646f2",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1907963, 51561, 228, 6, 31, "Input",ExpressionUUID->"fdc7018b-5a8a-4b14-8743-97212a20d025"],
Cell[1908194, 51569, 317, 8, 35, "Output",ExpressionUUID->"80220554-d9c5-4ff1-bd3b-f7f2d5b8f8be"]
}, Open  ]],
Cell[1908526, 51580, 126, 2, 31, "Input",ExpressionUUID->"352b2145-af9d-4988-9984-4751340f7800"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1908689, 51587, 249, 4, 45, "Subsubsection",ExpressionUUID->"963d0e94-8155-411e-bd6b-ea597de20b8d"],
Cell[1908941, 51593, 301, 6, 35, "Text",ExpressionUUID->"53ad1d05-d3b8-4ae0-bd65-272909327ce2"],
Cell[CellGroupData[{
Cell[1909267, 51603, 337, 8, 31, "Input",ExpressionUUID->"afaa8b24-d226-41e0-afef-7722e47ee1af"],
Cell[1909607, 51613, 317, 8, 35, "Output",ExpressionUUID->"3ce7f506-20fe-4613-963e-b5926b13e045"]
}, Open  ]],
Cell[1909939, 51624, 409, 10, 31, "Input",ExpressionUUID->"11c0472a-759c-4dec-a0d5-a16e399c5470"],
Cell[CellGroupData[{
Cell[1910373, 51638, 248, 5, 31, "Input",ExpressionUUID->"a3339dbe-16d6-4d9b-ac81-d83e34cd1813"],
Cell[1910624, 51645, 341, 8, 35, "Output",ExpressionUUID->"74d6abd5-1621-4467-ac08-501972004213"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1911002, 51658, 213, 4, 31, "Input",ExpressionUUID->"ce0220ae-6317-4cad-b053-add5bf9797ae"],
Cell[1911218, 51664, 325, 8, 35, "Output",ExpressionUUID->"74acf894-8294-4ab3-95f4-7122ed2a638d"]
}, Open  ]],
Cell[1911558, 51675, 449, 9, 31, "Input",ExpressionUUID->"242a620f-f803-4f5f-836e-ebfdfa8e155e"],
Cell[CellGroupData[{
Cell[1912032, 51688, 284, 6, 31, "Input",ExpressionUUID->"99dabda8-c7dd-4d1e-af44-29611ac1931c"],
Cell[1912319, 51696, 244, 6, 35, "Output",ExpressionUUID->"615342ee-9ca1-40a4-af3e-432f84683654"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1912600, 51707, 228, 5, 31, "Input",ExpressionUUID->"494b455e-6b6d-43bc-bde6-be9c84ca5921"],
Cell[1912831, 51714, 319, 8, 35, "Output",ExpressionUUID->"42058337-fc2f-4083-b5b6-6d80a086050f"]
}, Open  ]],
Cell[1913165, 51725, 791, 22, 71, "Input",ExpressionUUID->"19313102-62e4-44c8-917f-2c74d25f1f8e",
 InitializationCell->True],
Cell[1913959, 51749, 521, 13, 31, "Input",ExpressionUUID->"19f42711-7e30-4b90-8872-719a392b0a89"],
Cell[CellGroupData[{
Cell[1914505, 51766, 275, 6, 31, "Input",ExpressionUUID->"51144aec-f00e-468d-acd4-e8c98023313e"],
Cell[1914783, 51774, 316, 8, 35, "Output",ExpressionUUID->"2f5f3c71-6faf-42b4-8ade-6d8020cf2fde"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1915136, 51787, 210, 4, 31, "Input",ExpressionUUID->"9cfde19b-5bee-4cb9-b365-6f3f7145aac1"],
Cell[1915349, 51793, 322, 8, 35, "Output",ExpressionUUID->"3736d703-b065-4da5-b128-d701f07eac1c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1915708, 51806, 370, 9, 31, "Input",ExpressionUUID->"740fe786-df26-4aae-bb49-be4164ee1895"],
Cell[1916081, 51817, 323, 8, 35, "Output",ExpressionUUID->"14015dd8-bffd-40bd-874a-55adc14eb8bb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1916441, 51830, 826, 20, 55, "Input",ExpressionUUID->"8adfb90e-9f8a-4e1e-afd1-6e96926dc2d8"],
Cell[1917270, 51852, 323, 8, 35, "Output",ExpressionUUID->"74eb019a-4f9a-41cd-8af1-3a0b90c8d95d"]
}, Open  ]],
Cell[1917608, 51863, 313, 9, 60, "Text",ExpressionUUID->"00e3b058-aff9-4034-beec-bba1caf8474d"],
Cell[CellGroupData[{
Cell[1917946, 51876, 753, 19, 55, "Input",ExpressionUUID->"d7dc7cb4-31e9-4ffc-ac11-a6e06555cf12"],
Cell[1918702, 51897, 1028, 25, 59, "Output",ExpressionUUID->"cf182fa2-b999-4b7c-9d0f-efe6d56f6169"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1919767, 51927, 226, 4, 31, "Input",ExpressionUUID->"a2bb902b-60b1-45fd-81b3-3eea0ab1c65f"],
Cell[1919996, 51933, 298, 7, 35, "Output",ExpressionUUID->"8ba09cab-4f16-4bb0-bbb4-c299375b81c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1920331, 51945, 157, 3, 31, "Input",ExpressionUUID->"8819026c-80b4-447b-848d-063aa25dd6bc"],
Cell[1920491, 51950, 1000, 25, 59, "Output",ExpressionUUID->"7cc8de70-a158-41e7-9281-4161f47e25a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1921528, 51980, 656, 14, 55, "Input",ExpressionUUID->"759d20db-557a-4275-a9ad-92a62d248da1"],
Cell[1922187, 51996, 1072, 26, 59, "Output",ExpressionUUID->"4071f15c-8dae-42a9-ae2e-d8be68189c04"]
}, Open  ]],
Cell[1923274, 52025, 404, 9, 60, "Text",ExpressionUUID->"60cf9f94-3b31-4e5a-a0d6-662c3f8a2afc"],
Cell[CellGroupData[{
Cell[1923703, 52038, 334, 8, 31, "Input",ExpressionUUID->"def766d6-e300-4653-9b36-48f4c21354e9"],
Cell[1924040, 52048, 1028, 26, 59, "Output",ExpressionUUID->"b795a1b1-0984-4fa8-9a16-dfc1eb4a0986"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1925105, 52079, 220, 4, 31, "Input",ExpressionUUID->"d8a236a5-7481-4918-b023-2af591332851"],
Cell[1925328, 52085, 366, 8, 35, "Output",ExpressionUUID->"6cff6773-05b5-40a2-bb4a-36e0bf0acc87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1925731, 52098, 546, 12, 55, "Input",ExpressionUUID->"e4d2787a-6873-4dd3-8d04-65b6beddf953"],
Cell[1926280, 52112, 1050, 26, 59, "Output",ExpressionUUID->"4c9d0002-e996-4411-8dfb-fe5bbd51607b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1927379, 52144, 228, 5, 45, "Subsubsection",ExpressionUUID->"4dd362ea-0fda-401c-bc6c-7031f37a0c96"],
Cell[1927610, 52151, 154, 3, 31, "Input",ExpressionUUID->"c7aa03f8-76b1-4295-be67-686da7ff1816"],
Cell[CellGroupData[{
Cell[1927789, 52158, 516, 13, 55, "Input",ExpressionUUID->"5189b946-fa66-4526-9753-d78bae6a0479"],
Cell[1928308, 52173, 815, 21, 59, "Output",ExpressionUUID->"0a8b8550-5ea9-418f-9b5e-370a9fc9f8ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1929160, 52199, 263, 5, 31, "Input",ExpressionUUID->"1530873f-5e69-4afb-bd01-f3d7f9e1f39b"],
Cell[1929426, 52206, 1093, 25, 59, "Output",ExpressionUUID->"4eae0198-e318-4ae7-ae07-d45cf859c300"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1930556, 52236, 273, 6, 31, "Input",ExpressionUUID->"35051284-039d-4f2f-b411-ea7ad436b333"],
Cell[1930832, 52244, 358, 9, 35, "Output",ExpressionUUID->"61475354-00f5-4a2e-9cf5-b6e97e4b7195"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1931227, 52258, 859, 20, 78, "Input",ExpressionUUID->"3e0af743-c73f-4041-a8e1-8433204f1a37"],
Cell[1932089, 52280, 380, 9, 35, "Output",ExpressionUUID->"08433c74-ae75-474a-bfaf-3ccf1e08d78a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1932506, 52294, 259, 5, 31, "Input",ExpressionUUID->"efe34b3a-93cd-418d-bef4-bea3aebc3183"],
Cell[1932768, 52301, 784, 18, 59, "Output",ExpressionUUID->"19d72660-6b39-4c01-8b76-bcd7336a5380"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1933589, 52324, 287, 6, 31, "Input",ExpressionUUID->"e992a06c-e768-4ab3-b631-cf41f52333e8"],
Cell[1933879, 52332, 458, 12, 39, "Output",ExpressionUUID->"869392f7-e10c-4460-90a6-c29302a57c7d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1934374, 52349, 266, 5, 31, "Input",ExpressionUUID->"b086d7b4-599c-4d9e-b688-e063e281d446"],
Cell[1934643, 52356, 439, 11, 35, "Output",ExpressionUUID->"74b58dfe-de04-464f-b7ea-d025fe8b1014"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1935119, 52372, 313, 8, 31, "Input",ExpressionUUID->"1193df1d-004f-4813-8aa2-75eb6411f81b"],
Cell[1935435, 52382, 169, 3, 35, "Output",ExpressionUUID->"13502213-c5cb-4b07-bbd7-549a7722d386"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1935641, 52390, 267, 7, 31, "Input",ExpressionUUID->"302c3f1f-194e-4b81-a6ad-bc6bf12b19d3"],
Cell[1935911, 52399, 171, 3, 35, "Output",ExpressionUUID->"3703fc22-4082-4551-b2b1-c481049dca15"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1936119, 52407, 564, 13, 31, "Input",ExpressionUUID->"be16d0b3-5477-4abe-845a-53216980720d"],
Cell[1936686, 52422, 370, 9, 35, "Output",ExpressionUUID->"85f42547-8eae-4852-9d52-41e4c7c4b854"]
}, Open  ]],
Cell[1937071, 52434, 435, 8, 87, "Text",ExpressionUUID->"3ee53b94-3bd5-448e-bcbc-46214ba100c5"],
Cell[1937509, 52444, 520, 12, 31, "Input",ExpressionUUID->"32607901-204d-4690-ab46-1c2e7d419495"],
Cell[CellGroupData[{
Cell[1938054, 52460, 402, 10, 31, "Input",ExpressionUUID->"d00e9d7c-a8cc-449f-953b-e195f0ee9291"],
Cell[1938459, 52472, 322, 8, 35, "Output",ExpressionUUID->"6905571f-809a-4293-9915-30e4bfe6ffa7"]
}, Open  ]],
Cell[1938796, 52483, 242, 5, 37, "Text",ExpressionUUID->"089bce06-c2d5-475d-bd02-5f110d2a4104"],
Cell[CellGroupData[{
Cell[1939063, 52492, 1381, 39, 89, "Input",ExpressionUUID->"de17dc08-9fd2-416d-836d-30b0581c4000"],
Cell[1940447, 52533, 170, 3, 35, "Output",ExpressionUUID->"086a6873-4cec-406a-80d6-149bb77f5efc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1940654, 52541, 4610, 116, 548, "Input",ExpressionUUID->"b7fa96ec-2102-47ba-a4f9-f9874429a716"],
Cell[1945267, 52659, 3424, 71, 468, "Output",ExpressionUUID->"ea412e96-9dba-4962-88c8-91b70997a911"],
Cell[1948694, 52732, 417, 8, 22, "Message",ExpressionUUID->"11c7e6e7-c29d-4844-8d95-41d32accdafe"],
Cell[1949114, 52742, 455, 9, 22, "Message",ExpressionUUID->"0cfa20bf-1c90-4586-9f9f-fe88449cae34"],
Cell[1949572, 52753, 453, 9, 22, "Message",ExpressionUUID->"dd4b48e2-683d-4f1a-88e3-f3577267f448"],
Cell[1950028, 52764, 410, 8, 22, "Message",ExpressionUUID->"beab6507-b10d-42cb-8897-976bbeca91e7"],
Cell[1950441, 52774, 416, 8, 22, "Message",ExpressionUUID->"4eb4fd06-339d-4bbd-b3ce-6343351342ab"],
Cell[1950860, 52784, 452, 9, 22, "Message",ExpressionUUID->"1aff7bd6-a499-4543-aea1-b48f2e4d7f68"],
Cell[1951315, 52795, 452, 9, 22, "Message",ExpressionUUID->"bc88cfb0-f77a-436f-841d-3291f79b9dfa"],
Cell[1951770, 52806, 409, 8, 22, "Message",ExpressionUUID->"a69058d3-568c-4fa3-9fbd-6c6a771428b0"],
Cell[1952182, 52816, 415, 8, 22, "Message",ExpressionUUID->"609721e3-f753-4ac5-b50a-4b3cea125cf8"],
Cell[1952600, 52826, 450, 9, 22, "Message",ExpressionUUID->"736542bc-abe6-4c6e-90bf-a3d2b6a15d2f"],
Cell[1953053, 52837, 450, 9, 22, "Message",ExpressionUUID->"0584e417-03ee-40e4-a496-cc31637fda5e"],
Cell[1953506, 52848, 407, 8, 22, "Message",ExpressionUUID->"c4aad8e8-7889-422f-bbb2-03cbfab70b40"],
Cell[1953916, 52858, 415, 8, 22, "Message",ExpressionUUID->"e58324f4-920f-4f9e-aea8-0ba8c1da8b3b"],
Cell[1954334, 52868, 451, 9, 22, "Message",ExpressionUUID->"80963834-a7a4-43f9-a91d-65d3c9910b06"],
Cell[1954788, 52879, 453, 9, 22, "Message",ExpressionUUID->"a71c9a57-c9b7-4c23-8c0d-65cf375d2e3f"],
Cell[1955244, 52890, 408, 8, 22, "Message",ExpressionUUID->"bcd231b5-06dc-41ec-89bf-760f1ee35c65"],
Cell[1955655, 52900, 417, 8, 22, "Message",ExpressionUUID->"e489a821-fdbf-48b3-bfef-ba539ccbd429"],
Cell[1956075, 52910, 453, 9, 22, "Message",ExpressionUUID->"f3bf51c9-b4e7-4274-aff0-f78e5d5417d3"],
Cell[1956531, 52921, 455, 9, 22, "Message",ExpressionUUID->"ecc7106b-864e-4af8-bd6c-481b8e644496"],
Cell[1956989, 52932, 410, 8, 22, "Message",ExpressionUUID->"42afeed0-135c-480e-b0c1-010333e54176"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1957436, 52945, 1943, 51, 143, "Input",ExpressionUUID->"593fdd4b-1b46-4583-8265-07ba2edb9f23"],
Cell[1959382, 52998, 516, 12, 35, "Output",ExpressionUUID->"a954fcbf-8461-4b9e-8efd-e9588272b485"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1959935, 53015, 324, 8, 31, "Input",ExpressionUUID->"ed26c67f-b4a6-4512-92f9-bd7b41f5a2b6"],
Cell[1960262, 53025, 321, 8, 35, "Output",ExpressionUUID->"23d0f95d-3710-471a-b4c5-08223da3edea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1960620, 53038, 3621, 95, 283, "Input",ExpressionUUID->"1da10d78-e228-4c3f-85ce-3151434361ec"],
Cell[1964244, 53135, 782, 19, 59, "Output",ExpressionUUID->"cf37a831-2818-4007-9ae1-f7608f017fd1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1965063, 53159, 305, 5, 45, "Subsubsection",ExpressionUUID->"36e96544-5f77-4799-9a51-4280dc6e0e5f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1965371, 53166, 1118, 30, 71, "Input",ExpressionUUID->"f6d99348-5c96-4a32-b286-e4178e595aac",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True],
Cell[1966492, 53198, 1461, 38, 78, "Input",ExpressionUUID->"93ecf169-bcfb-4df9-8d74-02111007e41b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True]
}, Open  ]],
Cell[1967968, 53239, 129, 3, 31, "Input",ExpressionUUID->"26455cb9-5463-4eb4-a17b-ca967d0e7053"],
Cell[1968100, 53244, 1225, 35, 101, "Input",ExpressionUUID->"df1531cf-68cd-4d80-a321-a68e601dbcf9",
 InitializationCell->True],
Cell[1969328, 53281, 1473, 39, 117, "Input",ExpressionUUID->"54bc6bab-bc00-4705-8b3d-c1b62853cb9f",
 InitializationCell->True],
Cell[1970804, 53322, 1466, 37, 94, "Input",ExpressionUUID->"b6ba970c-5415-42d7-802a-382c34cb32e1",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1972295, 53363, 542, 12, 31, "Input",ExpressionUUID->"634c540f-c0a7-4adc-85d7-fc14f4026ad5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1972840, 53377, 273, 5, 35, "Output",ExpressionUUID->"a607a15b-fc3a-4fd9-a4af-80e23a21eb65",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1973116, 53384, 1009, 26, 85, "Input",ExpressionUUID->"2b6dccc5-0bcd-4054-9927-41d5325c4fe9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1974128, 53412, 612, 14, 35, "Output",ExpressionUUID->"a85ce8c4-d0e0-47f4-8ef4-2caa9c000099",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1974743, 53428, 495, 12, 31, "Input",ExpressionUUID->"d8eab257-e912-4819-bce5-b9baebcd082f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1975241, 53442, 410, 8, 35, "Output",ExpressionUUID->"dfafc066-1c28-4b89-b280-32e2c7f2e1f0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1975654, 53452, 1061, 27, 85, "Input",ExpressionUUID->"d45ed26b-968d-480c-99a9-9b9aabe1c983",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1976718, 53481, 589, 13, 35, "Output",ExpressionUUID->"e4e04728-ba07-4287-9b1f-5381b178fa88",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1977310, 53496, 549, 12, 31, "Input",ExpressionUUID->"8f15f8e8-8589-40fb-909a-80dadac4e953",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1977862, 53510, 398, 9, 35, "Output",ExpressionUUID->"a6cbad46-3413-4892-861e-aec4fdb1d26b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1978263, 53521, 1112, 26, 78, "Input",ExpressionUUID->"cd9cac67-1829-4e70-863d-e61510aae97e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1979378, 53549, 343, 8, 35, "Output",ExpressionUUID->"5eb57308-1d14-4e2f-84e4-a814d12703df",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1979724, 53559, 329, 6, 39, "Text",ExpressionUUID->"e5298d57-ed96-4de6-9518-2eb90551090a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1980056, 53567, 2731, 72, 124, "Input",ExpressionUUID->"387e1031-e76d-4b4d-8620-163faf598030",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1982790, 53641, 11798, 216, 246, "Output",ExpressionUUID->"1f0635da-f772-465e-a24d-0aef84b35be0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1994591, 53859, 801, 19, 55, "Input",ExpressionUUID->"6ee86164-df0f-41da-a46f-cc30cc1ea55f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1995395, 53880, 335, 8, 35, "Output",ExpressionUUID->"6c186f01-a527-4910-8a53-227a5ca69036",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1995733, 53890, 2775, 72, 124, "Input",ExpressionUUID->"3477b900-045b-4594-886b-f39e7e7b2770",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[1998511, 53964, 11131, 206, 248, "Output",ExpressionUUID->"c182d96a-6a0e-4b55-88e4-e18b66e2e05a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2009645, 54172, 2827, 73, 124, "Input",ExpressionUUID->"e49eea1b-15eb-475c-a6e4-ac61634e8271",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2012475, 54247, 10905, 201, 248, "Output",ExpressionUUID->"432357ba-9d9f-4bd6-a62b-556b36930bc2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2023383, 54450, 306, 6, 45, "Subsubsection",ExpressionUUID->"accc498e-71ed-4c86-b46e-c58846cf9934",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2023692, 54458, 646, 18, 31, "Input",ExpressionUUID->"b27f67ff-6730-4d45-8fe7-7570663bb53b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2024341, 54478, 307, 7, 35, "Output",ExpressionUUID->"057278a7-478b-48c6-93b9-434d5b2d1f67",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2024651, 54487, 1055, 28, 78, "Input",ExpressionUUID->"a9334ba8-752e-4469-af07-1fbcb0209494",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2025709, 54517, 2247, 66, 172, "Output",ExpressionUUID->"470c5687-4c16-45f7-b765-ea147c5c823a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2027959, 54585, 1117, 31, 58, "Input",ExpressionUUID->"0bd72bef-b924-4b5a-ae59-60e90386e48f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2029079, 54618, 1199, 38, 55, "Output",ExpressionUUID->"9c136397-ebe0-405f-b56f-eb5e6348d8e5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2030281, 54658, 249, 4, 45, "Subsubsection",ExpressionUUID->"3fb5127f-bf44-47ce-a94b-04c6b82d841d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2030533, 54664, 3261, 87, 318, "Input",ExpressionUUID->"86c17a47-664e-461c-9329-2bd48e84f895",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True],
Cell[2033797, 54753, 580, 15, 31, "Input",ExpressionUUID->"55864a24-f7d2-4ef7-b176-f8b46ac112d5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2034380, 54770, 9371, 217, 565, "Output",ExpressionUUID->"f98c8aee-6a1c-4cda-b718-5f4e58331c38",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2043754, 54989, 362, 8, 31, "Input",ExpressionUUID->"3dd3a9e4-5963-4f89-8a06-ac9917228fd6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2044119, 54999, 10602, 176, 345, 1899, 33, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"d5a618ae-cecf-4cbb-a78e-daf4917956e2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2054724, 55177, 441, 8, 31, "Input",ExpressionUUID->"3e40daa9-4235-48cd-a230-4e5ff48cd945",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2055168, 55187, 1041, 25, 59, "Output",ExpressionUUID->"9a51d2d6-4edc-4566-a178-52306ac3e5ac",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2056212, 55214, 305, 6, 31, "Input",ExpressionUUID->"167021a7-c3c3-4337-9b7b-1f4cd53600dc",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2056520, 55222, 449, 10, 35, "Output",ExpressionUUID->"217c2f7e-b43f-44e6-b494-dbe0c739a378",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2056972, 55234, 306, 6, 31, "Input",ExpressionUUID->"b3857005-e286-4cd3-a218-387f5dd183b1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2057281, 55242, 1104, 26, 59, "Output",ExpressionUUID->"d98a107d-6c95-4e63-bdc7-7df6cff9118c",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2058388, 55270, 343, 8, 31, "Input",ExpressionUUID->"0db90163-6aef-4a8c-9d4b-5a6e36809fe1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2058734, 55280, 394, 8, 35, "Output",ExpressionUUID->"5c1fb435-575f-454b-b499-b5f3fc8a96d3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2059131, 55290, 652, 14, 31, "Input",ExpressionUUID->"d0c86b0c-cf85-4829-ba9b-222076e4e820",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2059786, 55306, 2308, 41, 329, "Output",ExpressionUUID->"6cca2a41-df60-4f6b-bed2-516dce91453a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2062097, 55349, 640, 16, 31, "Input",ExpressionUUID->"a8ab30c8-8646-4bc1-8f47-df43004a44e7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2062740, 55367, 249, 4, 35, "Output",ExpressionUUID->"856450b2-027a-4e7c-8174-154ec16b14b3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2062992, 55373, 260, 5, 31, "Input",ExpressionUUID->"fdb0c79b-5f6d-4046-b864-4870b3f3442c",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2063255, 55380, 394, 8, 35, "Output",ExpressionUUID->"82c852f1-47f9-4eaa-953e-1ec81e900a4d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2063652, 55390, 316, 7, 31, "Input",ExpressionUUID->"068b90ea-e0f6-4043-8ddd-c1a8fdc2c0c7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2063971, 55399, 407, 8, 35, "Output",ExpressionUUID->"c98f09e3-b9d8-43e8-b040-0e9a9ec4c466",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2064381, 55409, 1373, 33, 108, "Input",ExpressionUUID->"b9ff3da9-a3ba-4f70-a50c-4664ca21e146",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2065757, 55444, 695, 14, 59, "Message",ExpressionUUID->"7929fe3b-5f09-48f9-92f3-8faf1eac02c2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2066455, 55460, 657, 16, 35, "Output",ExpressionUUID->"b31da96a-3f8c-448c-8dc0-d0bb3986618a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2067115, 55478, 445, 11, 31, "Input",ExpressionUUID->"0ccae733-5729-4946-8454-d5ea87914d00",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2067563, 55491, 459, 10, 35, "Output",ExpressionUUID->"1389bc41-91e4-4496-941a-8a0582e11248",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2068025, 55503, 986, 26, 55, "Input",ExpressionUUID->"d6539c4d-5f53-400f-847f-1e76aaf15ac8",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2069014, 55531, 301, 5, 35, "Output",ExpressionUUID->"7b20b040-353f-4db3-bb9b-39ad69916f7a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2069318, 55538, 279, 5, 37, "Text",ExpressionUUID->"1b50adad-2f1d-46ac-8120-d2413bf9e127",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2069600, 55545, 1454, 35, 85, "Input",ExpressionUUID->"f5f0a952-c8f6-41c2-8e0f-3a8a3d0bdf32",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2071057, 55582, 625, 15, 35, "Output",ExpressionUUID->"c1f0072f-17b8-412e-aba8-2116eb38a59e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2071685, 55599, 468, 11, 31, "Input",ExpressionUUID->"70eabe11-ee9a-4115-830b-7f5762c51d57",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2072156, 55612, 427, 9, 35, "Output",ExpressionUUID->"f2d6c94c-34b1-4137-9e74-e18174657ba9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2072586, 55623, 1011, 26, 55, "Input",ExpressionUUID->"9bb0ef62-903b-4510-aaac-7da358a751c3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2073600, 55651, 274, 5, 35, "Output",ExpressionUUID->"bf868468-c473-464a-9b98-36b7bce4449c",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2073877, 55658, 542, 14, 31, "Input",ExpressionUUID->"70934af3-2f83-473f-b11f-6a98e0cc0a17",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2074422, 55674, 249, 4, 35, "Output",ExpressionUUID->"87887f14-ef6e-4106-9dfb-54f73f819e53",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2074674, 55680, 416, 8, 71, "Subsubsection",ExpressionUUID->"10ab4eae-4529-4436-b760-554553358ef2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2075093, 55690, 357, 8, 31, "Input",ExpressionUUID->"990ba5f9-0720-4aca-bada-bb467337d5ee",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2075453, 55700, 248, 4, 35, "Output",ExpressionUUID->"43ff589f-34f0-4690-8e83-99bb612101f0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2075704, 55706, 456, 10, 31, "Input",ExpressionUUID->"e5d1ba4a-442e-4fcb-8a4e-63d8aaec4b84",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2076163, 55718, 301, 5, 35, "Output",ExpressionUUID->"45eb4c31-0c1b-4747-b510-2f0277840125",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2076467, 55725, 206, 4, 31, "Input",ExpressionUUID->"17399dac-047f-4793-a4d2-158316e61fbe",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2076676, 55731, 206, 4, 31, "Input",ExpressionUUID->"ff4b30bf-a48c-4a09-9cc0-992a9df62cd2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2076885, 55737, 503, 13, 31, "Input",ExpressionUUID->"7d67ce46-f748-4c22-af89-09cb518b1362",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2077391, 55752, 1387, 36, 74, "Output",ExpressionUUID->"bcb08ad1-4bf4-43e9-b65e-96b08a2fc987",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2078781, 55790, 1670, 43, 78, "Input",ExpressionUUID->"9a7328b6-d332-4895-99a5-03dff0d1c29f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True],
Cell[2080454, 55835, 607, 15, 78, "Input",ExpressionUUID->"85b13877-8052-4695-b268-a7676c263c9f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2081064, 55852, 514, 13, 55, "Input",ExpressionUUID->"0ab03119-8da4-44b2-ace1-298921ce5d3d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2081581, 55867, 325, 7, 35, "Output",ExpressionUUID->"f4548690-3d03-42ab-9d0c-0965f5fb7ca4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2081909, 55876, 576, 12, 55, "Input",ExpressionUUID->"8f488b73-e911-432e-98ce-29a2909c098f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2082488, 55890, 250, 4, 35, "Output",ExpressionUUID->"b33cef65-6f12-4e7d-9894-3fdbaeff6f84",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2082741, 55896, 593, 14, 55, "Input",ExpressionUUID->"635c8f76-965a-4a4c-a099-96a3996809e2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2083337, 55912, 248, 4, 35, "Output",ExpressionUUID->"459764e0-4716-4057-ad98-69c95366811c",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2083588, 55918, 2956, 76, 216, "Input",ExpressionUUID->"004f4e01-2402-4966-a62d-87569983ca1c",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2086547, 55996, 16249, 293, 377, "Output",ExpressionUUID->"3865fe13-21c3-40b0-a823-dfcb0289979f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2102799, 56291, 1288, 33, 170, "Input",ExpressionUUID->"7fcd1526-9ab3-421b-a3c7-6f6bd7426ab4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2104090, 56326, 344, 8, 35, "Output",ExpressionUUID->"75e4e3ce-55d7-4f89-99d5-fb74ff675a00",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2104437, 56336, 203, 3, 31, "Input",ExpressionUUID->"225ea84a-fba5-4b8a-a5be-df76249335a1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2104643, 56341, 193, 4, 31, "Input",ExpressionUUID->"6b66a389-9390-49ef-bf14-9e94e56195fe",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2104839, 56347, 462, 10, 31, "Input",ExpressionUUID->"8882ff76-4b8d-44e2-9c19-0bd68acb2f8b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2105304, 56359, 1132, 28, 59, "Output",ExpressionUUID->"9858d2f1-64e2-4ccc-8a33-d107bf90888b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2106439, 56389, 298, 6, 31, "Input",ExpressionUUID->"7b1be2df-dc23-4fe4-9f27-89f520d71d3d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2106740, 56397, 420, 9, 35, "Output",ExpressionUUID->"a5024dfe-023b-472e-b55b-814c5ca7470a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2107209, 56412, 169, 3, 45, "Subsubsection",ExpressionUUID->"76bc5cf7-e0b3-49be-baca-d224d88ec7af"],
Cell[2107381, 56417, 281, 6, 31, "Input",ExpressionUUID->"a4d789f4-5707-4ac8-bbab-79555dd2ac26"],
Cell[2107665, 56425, 356, 9, 31, "Input",ExpressionUUID->"543841a3-3d21-448e-a55f-9abe75a3cd3e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2108058, 56439, 199, 3, 45, "Subsubsection",ExpressionUUID->"a9ba0a59-3191-444b-b571-8c7e08d33039"],
Cell[CellGroupData[{
Cell[2108282, 56446, 160, 3, 31, "Input",ExpressionUUID->"5d841571-01ae-4e16-8434-ac512a62bb2f"],
Cell[2108445, 56451, 669, 20, 35, "Output",ExpressionUUID->"e5f04057-e88a-4a13-b746-657185b78e02"]
}, Open  ]],
Cell[2109129, 56474, 2390, 71, 218, "Input",ExpressionUUID->"6a9b6a13-71a3-47c1-bcdb-3688acb3cc83",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2111544, 56549, 202, 4, 31, "Input",ExpressionUUID->"48714568-6525-4bde-b566-14f6873a2e1f"],
Cell[2111749, 56555, 521, 14, 35, "Output",ExpressionUUID->"91c248fd-8005-4348-a60e-dc2cbdc73f4b"]
}, Open  ]],
Cell[2112285, 56572, 267, 6, 35, "Text",ExpressionUUID->"847cb2a5-47f1-4a29-9036-178ce7ae1b50"],
Cell[CellGroupData[{
Cell[2112577, 56582, 487, 11, 55, "Input",ExpressionUUID->"c97c0365-fe77-4a9e-b1b8-f41a9dc36928"],
Cell[2113067, 56595, 1321, 38, 86, "Output",ExpressionUUID->"d5589b8c-cf25-40c0-a326-d74a0bce169b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2114425, 56638, 150, 3, 31, "Input",ExpressionUUID->"8e480af6-484f-4266-b92a-ededf66f9f05"],
Cell[2114578, 56643, 1334, 39, 101, "Output",ExpressionUUID->"48517134-cfa1-406d-b3fd-e265c9f2e551"]
}, Open  ]],
Cell[2115927, 56685, 8779, 266, 786, "Input",ExpressionUUID->"a69c8452-2fee-4344-bad1-f5d602243e92",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2124731, 56955, 386, 10, 31, "Input",ExpressionUUID->"a360f094-f880-4cfa-a54e-ecddf0fdf79b"],
Cell[2125120, 56967, 1036, 28, 59, "Output",ExpressionUUID->"8fe07238-7e72-4689-be9d-033c7bf45a28"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2126193, 57000, 193, 5, 31, "Input",ExpressionUUID->"cfd564e6-5cd1-4fd2-bd8a-611cfed9be0d"],
Cell[2126389, 57007, 842, 21, 59, "Output",ExpressionUUID->"5fecd9d9-0057-4a00-b9bc-6623ab08f00b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2127268, 57033, 159, 3, 31, "Input",ExpressionUUID->"acace04f-f11f-499b-a903-d16d17ba06b9"],
Cell[2127430, 57038, 4305, 123, 161, "Output",ExpressionUUID->"89f377ec-6550-480d-a8a2-aca923777dbe"]
}, Closed]],
Cell[2131750, 57164, 4947, 133, 169, "Input",ExpressionUUID->"d74b5efd-770a-4d59-bf52-40cccc9371e4",
 InitializationCell->True],
Cell[2136700, 57299, 510, 12, 55, "Input",ExpressionUUID->"8f0ef87a-3e6b-4935-9fdc-65de8223dcd3"],
Cell[CellGroupData[{
Cell[2137235, 57315, 513, 14, 31, "Input",ExpressionUUID->"970f7621-c77c-447a-a426-6bcbb34fb259"],
Cell[2137751, 57331, 1252, 33, 82, "Output",ExpressionUUID->"3b90c94f-eb14-4821-bb5f-93f1294aaa8a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2139040, 57369, 578, 20, 62, "Text",ExpressionUUID->"8c7679a7-b637-4569-b8f2-a300e3c75b3e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2139621, 57391, 389, 7, 31, "Input",ExpressionUUID->"822a9c4a-3a9b-4d77-9548-508a155ed8ef",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2140013, 57400, 623, 15, 35, "Output",ExpressionUUID->"2fbeeb40-ea2d-4ce6-8495-e159630da827",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2140639, 57417, 1364, 34, 101, "Input",ExpressionUUID->"ed85d8e2-8723-4499-a433-24397c6849e8",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2142006, 57453, 798, 22, 59, "Output",ExpressionUUID->"a7511c4a-8b4d-4d8a-ab77-6cf57addd2db",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2142807, 57477, 1292, 33, 78, "Input",ExpressionUUID->"961ea8cb-eddb-4631-a821-fc6750ee2666",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2144102, 57512, 5147, 138, 233, "Output",ExpressionUUID->"be8f512b-1fe3-4597-a470-09eadeac0c54",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[2149264, 57653, 131, 3, 31, "Input",ExpressionUUID->"97857eed-fc13-412b-b10f-f0146404ffbf"],
Cell[2149398, 57658, 217, 5, 37, "Text",ExpressionUUID->"466e97d7-6c09-43f4-9fdd-a8a26d771403"],
Cell[CellGroupData[{
Cell[2149640, 57667, 161, 3, 31, "Input",ExpressionUUID->"36d779af-56c6-4c7e-a363-90c176edfed5"],
Cell[2149804, 57672, 993, 30, 59, "Output",ExpressionUUID->"9d873097-13e9-42c2-8b37-09faee97278b"]
}, Open  ]],
Cell[2150812, 57705, 217, 4, 31, "Input",ExpressionUUID->"f7dbcd92-973a-4a31-a166-f472848befa2"],
Cell[2151032, 57711, 1574, 40, 94, "Input",ExpressionUUID->"da471091-7977-463c-bd32-2007d71b35e5",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2152631, 57755, 559, 12, 55, "Input",ExpressionUUID->"1ff4bfed-03bd-4a94-8295-025fd1197868"],
Cell[2153193, 57769, 155, 3, 35, "Output",ExpressionUUID->"eb7b7ae2-d056-4731-b642-64d4ff795923"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2153385, 57777, 1282, 36, 81, "Input",ExpressionUUID->"dea62121-94c1-444b-96e4-c37e1ebe9bc2"],
Cell[2154670, 57815, 4043, 114, 138, "Output",ExpressionUUID->"7027db94-5d4a-4ccf-bc9f-d3adfdec61ed"]
}, Open  ]],
Cell[2158728, 57932, 5029, 129, 222, "Input",ExpressionUUID->"9fa2a61d-7357-43bf-8336-490200fb90c8",
 InitializationCell->True],
Cell[2163760, 58063, 535, 12, 55, "Input",ExpressionUUID->"faf53a21-9d57-431b-ae83-1a345b055da3"],
Cell[CellGroupData[{
Cell[2164320, 58079, 559, 14, 31, "Input",ExpressionUUID->"bebab335-ee0c-4050-b155-fc6eaa92706e"],
Cell[2164882, 58095, 1083, 30, 59, "Output",ExpressionUUID->"7ac3ce8e-b6e3-4783-b59f-9adcdef2f541"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2166002, 58130, 644, 17, 78, "Input",ExpressionUUID->"2218073f-32bc-40f5-8490-e9be178a8360"],
Cell[2166649, 58149, 848, 22, 59, "Output",ExpressionUUID->"dd429c25-c011-4389-9e7a-4237724d24f6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2167546, 58177, 227, 5, 52, "Subsubsection",ExpressionUUID->"1dd6488f-139e-44aa-a2a6-a1e7cc15235c"],
Cell[CellGroupData[{
Cell[2167798, 58186, 118, 2, 31, "Input",ExpressionUUID->"b0fff4ab-47a7-44e1-9669-3c4c3ee82099"],
Cell[2167919, 58190, 1501, 38, 105, "Output",ExpressionUUID->"27d88df5-33c6-4045-9e0b-3dbc4718cf47"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2169457, 58233, 216, 4, 31, "Input",ExpressionUUID->"ea9694b1-75bc-4b8c-a510-f1ba4da8a96a"],
Cell[2169676, 58239, 1347, 35, 74, "Output",ExpressionUUID->"3f90521e-058c-4fe7-8734-435249516e64"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2171060, 58279, 360, 8, 55, "Input",ExpressionUUID->"b3a866b2-7e6d-41ec-8462-2042f6b546d1"],
Cell[2171423, 58289, 1446, 40, 74, "Output",ExpressionUUID->"72266491-b4cd-4e8b-b2cc-3d01e81fc22f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2172906, 58334, 680, 20, 78, "Input",ExpressionUUID->"5bc13e1e-630d-4f6c-8b5f-c0c6399e6049"],
Cell[2173589, 58356, 244, 5, 35, "Output",ExpressionUUID->"b5800002-1644-4ef5-a31e-510f2c4307b2"]
}, Open  ]],
Cell[2173848, 58364, 298, 8, 31, "Input",ExpressionUUID->"1be82c95-4bb9-4971-83fe-a7c13574d783"],
Cell[CellGroupData[{
Cell[2174171, 58376, 233, 5, 31, "Input",ExpressionUUID->"2c1191ea-b978-4b12-a6ec-92ef501967d6"],
Cell[2174407, 58383, 836, 23, 39, "Output",ExpressionUUID->"82cef49c-4ca8-44bb-bde4-cfc1edcbba8d"]
}, Open  ]],
Cell[2175258, 58409, 586, 18, 31, "Input",ExpressionUUID->"f18696c0-e9fb-4d08-aaa6-83443271a14a"],
Cell[CellGroupData[{
Cell[2175869, 58431, 959, 27, 112, "Input",ExpressionUUID->"cab463a4-2614-4b33-9c7a-b972f8c276c5"],
Cell[2176831, 58460, 474, 13, 39, "Output",ExpressionUUID->"a2b33715-bdb3-4a02-85a6-22c630c80436"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2177354, 58479, 159, 3, 45, "Subsubsection",ExpressionUUID->"75c1db07-edd2-4980-be80-3cef5723beaf"],
Cell[CellGroupData[{
Cell[2177538, 58486, 942, 23, 35, "Input",ExpressionUUID->"c2579004-87fb-4431-a9ec-3b9b82574df8"],
Cell[2178483, 58511, 1377, 37, 62, "Output",ExpressionUUID->"6ace9591-7ab5-4789-b798-7cf38ef8d43e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2179897, 58553, 630, 19, 31, "Input",ExpressionUUID->"0e1f01c3-77ff-4202-ba05-3c70e40c5398"],
Cell[2180530, 58574, 352, 10, 52, "Output",ExpressionUUID->"21695b5c-90ce-42d3-a130-5775d248fdc3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2180919, 58589, 589, 18, 48, "Input",ExpressionUUID->"5ebf1278-faca-4199-8169-95897ee7920a"],
Cell[2181511, 58609, 862, 23, 39, "Output",ExpressionUUID->"ef7eab37-bc59-48d8-8917-ed382a9b41cb"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2182422, 58638, 161, 3, 45, "Subsubsection",ExpressionUUID->"49edc810-1df7-4b22-9f51-68a40bf35e9a"],
Cell[CellGroupData[{
Cell[2182608, 58645, 760, 21, 55, "Input",ExpressionUUID->"37999a61-ef7d-4ced-9f79-210b67b27ab2"],
Cell[2183371, 58668, 2220, 61, 108, "Output",ExpressionUUID->"dc60a00d-4668-4dcb-8959-5e6cf64fca85"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2185628, 58734, 1011, 28, 31, "Input",ExpressionUUID->"983fdc82-5a58-4044-8afc-85b5bc1ee873"],
Cell[2186642, 58764, 514, 15, 52, "Output",ExpressionUUID->"c0eced75-ae4d-4ff1-8e64-576522367911"]
}, Open  ]],
Cell[2187171, 58782, 129, 3, 31, "Input",ExpressionUUID->"04df9630-dbe5-4948-b738-d9fab06c2bf4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2187337, 58790, 179, 3, 45, "Subsubsection",ExpressionUUID->"dfd236e7-b2a6-4cf1-8a04-37dc0a148ddc"],
Cell[CellGroupData[{
Cell[2187541, 58797, 1808, 54, 208, "Input",ExpressionUUID->"056c49ef-681d-4f72-bc1a-28791c1ae97a"],
Cell[2189352, 58853, 229, 5, 35, "Output",ExpressionUUID->"e5c312c6-79ca-426c-b6b7-8f3dbac6a541"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2189630, 58864, 245, 4, 45, "Subsubsection",ExpressionUUID->"321395e8-e5c0-44bb-aa85-df100d9685fe"],
Cell[2189878, 58870, 3151, 88, 155, "Input",ExpressionUUID->"9b6ec4fb-aed3-4306-bd8d-ff0c28a201a8",
 InitializationCell->True],
Cell[2193032, 58960, 295, 6, 37, "Text",ExpressionUUID->"51eac93e-8f42-4dd7-b7ce-10a2425deaca"],
Cell[CellGroupData[{
Cell[2193352, 58970, 448, 12, 31, "Input",ExpressionUUID->"d102d7a8-0cfe-4ea8-8034-602f1cc3fe15"],
Cell[2193803, 58984, 456, 12, 35, "Output",ExpressionUUID->"d02dfd5b-5d8b-49b5-bd36-e1b851983830"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2194296, 59001, 232, 5, 31, "Input",ExpressionUUID->"86e7143e-165e-47cd-89ae-5b35953b5ab7"],
Cell[2194531, 59008, 653, 21, 39, "Output",ExpressionUUID->"5f07f53e-f0c6-43c8-9e8f-37212e63f417"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2195221, 59034, 926, 23, 101, "Input",ExpressionUUID->"6887ca06-537f-4845-80f6-ebf1ea5dbc12"],
Cell[2196150, 59059, 1210, 19, 82, "Output",ExpressionUUID->"02f3c188-27bd-4a15-8a67-ff6910c38432"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2197397, 59083, 951, 24, 124, "Input",ExpressionUUID->"a6c787a8-0bfd-4180-8a97-e30a45ccc565"],
Cell[2198351, 59109, 2817, 105, 82, "Output",ExpressionUUID->"7cda377f-621a-44cb-9b76-7d48d21ccf00"]
}, Open  ]],
Cell[2201183, 59217, 300, 6, 37, "Text",ExpressionUUID->"ea6a1c5b-36ba-4c2a-b6e7-a1aeb9514d60"],
Cell[CellGroupData[{
Cell[2201508, 59227, 450, 12, 31, "Input",ExpressionUUID->"90799a22-a964-4b62-a400-84e6db93e156"],
Cell[2201961, 59241, 428, 11, 35, "Output",ExpressionUUID->"34e8df9e-5664-4591-bbbb-649a85edc20a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2202426, 59257, 899, 22, 124, "Input",ExpressionUUID->"d132a9a8-92b3-47c3-a79f-ec42488edd5b"],
Cell[2203328, 59281, 2608, 78, 105, "Output",ExpressionUUID->"4346fab0-64c9-4e1d-931e-1b10f8a49b74"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2205973, 59364, 184, 4, 31, "Input",ExpressionUUID->"f1d1cb09-1d77-46c4-aadb-b7619475c0d4"],
Cell[2206160, 59370, 296, 10, 35, "Output",ExpressionUUID->"7af5222c-578a-4a0a-b284-7d88cdfe42c0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2206493, 59385, 893, 22, 124, "Input",ExpressionUUID->"02320950-f2fc-489d-8048-ff07570423db"],
Cell[2207389, 59409, 1793, 61, 59, "Output",ExpressionUUID->"9041694c-6b79-4c7a-8a94-2e6ea106b19c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2209231, 59476, 298, 6, 45, "Subsubsection",ExpressionUUID->"a125393e-5818-4ced-b444-fb65ef9346e0"],
Cell[CellGroupData[{
Cell[2209554, 59486, 376, 9, 31, "Input",ExpressionUUID->"230bf0e7-9976-47ce-867a-3c2feb6628a5"],
Cell[2209933, 59497, 156, 3, 35, "Output",ExpressionUUID->"fcbf3c51-7e1c-4e84-9fe4-e054c2cec592"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2210126, 59505, 1551, 41, 124, "Input",ExpressionUUID->"a1cd676d-c82e-4766-b806-ccde70f3de3b"],
Cell[2211680, 59548, 1173, 31, 59, "Output",ExpressionUUID->"51e2236d-5819-42ea-bb8b-dd4654f93fe3"]
}, Open  ]],
Cell[2212868, 59582, 301, 6, 62, "Text",ExpressionUUID->"6af59048-7641-4dbe-9db8-795933c41aad"],
Cell[CellGroupData[{
Cell[2213194, 59592, 1508, 41, 124, "Input",ExpressionUUID->"1c88d72e-a8f9-4b4d-904c-f1f944ad47f3"],
Cell[2214705, 59635, 451, 10, 22, "Message",ExpressionUUID->"af437db0-eeb2-4c6c-b332-19a09d632ecf"],
Cell[2215159, 59647, 451, 10, 22, "Message",ExpressionUUID->"9cafc88e-16d3-427e-9e27-49332cfce561"],
Cell[2215613, 59659, 451, 10, 22, "Message",ExpressionUUID->"e3cec28d-1063-4f5d-b7a7-58bab10be95c"],
Cell[2216067, 59671, 401, 9, 22, "Message",ExpressionUUID->"4d38fd9b-fcd0-4d0d-a6f0-d3862b34b3b5"],
Cell[2216471, 59682, 1414, 33, 82, "Output",ExpressionUUID->"121161bb-9243-4cc5-87eb-b46f28c7d373"]
}, Open  ]],
Cell[2217900, 59718, 165, 3, 31, "Input",ExpressionUUID->"056ceca7-3020-4cf5-b12e-6218b408c682"],
Cell[2218068, 59723, 129, 3, 31, "Input",ExpressionUUID->"d0de3bfa-5ac6-4714-95a8-d9bd569c77b1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2218234, 59731, 300, 7, 45, "Subsubsection",ExpressionUUID->"a197fc58-ec01-4c90-b17a-c271f7a91730"],
Cell[2218537, 59740, 257, 6, 37, "Text",ExpressionUUID->"f2e6e107-7f5f-47d6-8442-51adff2307cc"],
Cell[2218797, 59748, 652, 15, 47, "Input",ExpressionUUID->"e3fd09f0-a77f-430a-8d16-336693e72fa0",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2219498, 59769, 288, 5, 55, "Subsection",ExpressionUUID->"9292fb44-f54d-488e-89ab-7703dde55878"],
Cell[CellGroupData[{
Cell[2219811, 59778, 1158, 31, 78, "Input",ExpressionUUID->"7c34e1c1-1e39-48d6-aafb-b2cc39f35383"],
Cell[2220972, 59811, 5366, 156, 220, "Output",ExpressionUUID->"ff936dd0-ffb3-471a-aaad-d0192135fd69"]
}, Open  ]],
Cell[2226353, 59970, 1347, 35, 104, "Input",ExpressionUUID->"d71c990e-fcf1-4fbf-a785-0ea0cb18e194"],
Cell[2227703, 60007, 4214, 100, 292, "Input",ExpressionUUID->"281c209a-f5ec-4827-a31f-c9f887b04808",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2231942, 60111, 182, 3, 45, "Subsubsection",ExpressionUUID->"bee69428-b163-4ea7-b198-071591c8eac9"],
Cell[2232127, 60116, 1571, 39, 209, "Input",ExpressionUUID->"363a5cd6-f032-477f-838a-3d48bb9ab7dc",
 InitializationCell->True],
Cell[2233701, 60157, 1418, 35, 186, "Input",ExpressionUUID->"8254cc8f-1538-43f6-bdba-ee72e1a656c3",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2235144, 60196, 393, 10, 31, "Input",ExpressionUUID->"fefafc70-f989-41b4-ae81-096d46831720"],
Cell[2235540, 60208, 389, 10, 35, "Output",ExpressionUUID->"9792afcc-3c1f-42af-acd1-4e61c76e18f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2235966, 60223, 470, 11, 31, "Input",ExpressionUUID->"25b7e61f-c395-4cdb-af91-fc40fc65293e"],
Cell[2236439, 60236, 389, 10, 35, "Output",ExpressionUUID->"53d863df-2257-440f-b27b-5a7e160fc3b0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2236877, 60252, 232, 4, 45, "Subsubsection",ExpressionUUID->"0c38f3f8-f0ae-406c-bbb8-63f36f235d4f"],
Cell[2237112, 60258, 341, 9, 31, "Input",ExpressionUUID->"b218700e-3b68-4dd2-9d78-229b6f8c6157"],
Cell[CellGroupData[{
Cell[2237478, 60271, 264, 5, 31, "Input",ExpressionUUID->"e73debe0-df24-41d0-b647-314b35a8967e"],
Cell[2237745, 60278, 444, 13, 35, "Output",ExpressionUUID->"8985eb51-5297-4ec3-a68f-421c5213abb4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2238226, 60296, 459, 11, 31, "Input",ExpressionUUID->"66cb68c9-6481-4c98-bd24-91b0dddb5e3f"],
Cell[2238688, 60309, 975, 25, 59, "Output",ExpressionUUID->"f7b7c3c7-aeb7-4db4-9a20-9800e7f023de"]
}, Open  ]],
Cell[2239678, 60337, 498, 9, 112, "Text",ExpressionUUID->"3bb79ead-8bfd-4ea7-9431-40ef843a450b"],
Cell[2240179, 60348, 1977, 50, 209, "Input",ExpressionUUID->"6aa86839-afed-48ad-aafe-befa9edea0d9",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2242181, 60402, 366, 7, 31, "Input",ExpressionUUID->"7fac0e6c-b56a-47a6-995e-015050593c6f"],
Cell[2242550, 60411, 1323, 32, 82, "Output",ExpressionUUID->"75704603-a133-40e3-81d9-431411206b73"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2243910, 60448, 365, 9, 31, "Input",ExpressionUUID->"70fdcc5f-e6a6-4ea4-96c8-8572bb0a1362"],
Cell[2244278, 60459, 1259, 31, 82, "Output",ExpressionUUID->"0134546a-d34d-4c99-a44e-a0fc9dbc7ff9"]
}, Open  ]],
Cell[2245552, 60493, 1823, 45, 186, "Input",ExpressionUUID->"719d53ab-2159-4c4d-8f8f-a4826cead0d2",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2247400, 60542, 247, 5, 31, "Input",ExpressionUUID->"e8d71445-3ecc-4f0d-87e0-324bbe79348f"],
Cell[2247650, 60549, 1261, 31, 82, "Output",ExpressionUUID->"84aedfe2-4814-48d2-9d57-4cd1ad97a660"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2248972, 60587, 343, 5, 55, "Subsection",ExpressionUUID->"6d62e101-2a7a-45bc-b020-d9b8e23778ab"],
Cell[CellGroupData[{
Cell[2249340, 60596, 184, 3, 31, "Input",ExpressionUUID->"999a8688-8518-4d0b-a507-cc2e713ffbc5"],
Cell[2249527, 60601, 1016, 30, 59, "Output",ExpressionUUID->"ee5bd601-7ce5-4622-9972-9b3ec2b101a5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2250580, 60636, 533, 13, 31, "Input",ExpressionUUID->"0643396e-465a-4903-81e8-ef5a3514a2ae"],
Cell[2251116, 60651, 697, 20, 35, "Output",ExpressionUUID->"c76d07c6-867c-4f7e-9a3b-7682ef0eb907"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2251850, 60676, 1208, 31, 78, "Input",ExpressionUUID->"01894aab-aba1-47a7-96dd-de984d540d21"],
Cell[2253061, 60709, 5984, 178, 255, "Output",ExpressionUUID->"346cf623-1f00-45a9-b4f5-e0029dd06ffa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2259082, 60892, 1885, 48, 135, "Input",ExpressionUUID->"f6dd9ff7-7e7f-4f0b-b44d-06063b8d8a03"],
Cell[2260970, 60942, 3870, 118, 191, "Output",ExpressionUUID->"106e6712-85fa-46ab-805d-a1ec8a5fca06"]
}, Open  ]],
Cell[2264855, 61063, 5511, 140, 302, "Input",ExpressionUUID->"daf62a1c-556f-47f1-be2e-e58e84cc0129",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2270415, 61209, 980, 32, 136, "Section",ExpressionUUID->"f3034191-ac83-45ca-bd0d-8c177663ca87"],
Cell[CellGroupData[{
Cell[2271420, 61245, 162, 3, 31, "Input",ExpressionUUID->"879e4241-85dd-4b0d-98d5-681a3efad84d"],
Cell[2271585, 61250, 391, 11, 35, "Output",ExpressionUUID->"d74fc34a-a0ff-4e75-a7c4-f1172df1651f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2272013, 61266, 467, 12, 47, "Input",ExpressionUUID->"6357e4ec-cf08-4f26-ab1c-d4893293bae9",
 InitializationCell->True],
Cell[2272483, 61280, 418, 10, 35, "Output",ExpressionUUID->"8e9bec1f-d09c-4fce-8053-34a828c8806b"]
}, Open  ]],
Cell[2272916, 61293, 630, 16, 55, "Input",ExpressionUUID->"d7319550-6baf-4ad3-8c34-4afb22e50694"],
Cell[2273549, 61311, 710, 19, 55, "Input",ExpressionUUID->"a89565f0-6bb2-4a30-9389-9f1bdeff023c"],
Cell[2274262, 61332, 1136, 38, 69, "Input",ExpressionUUID->"3b68db44-25fb-404a-8143-853441c36577"],
Cell[2275401, 61372, 1040, 28, 78, "Input",ExpressionUUID->"cf432475-d057-405d-8041-c94831204f3b"],
Cell[CellGroupData[{
Cell[2276466, 61404, 234, 5, 55, "Subsection",ExpressionUUID->"7b182b51-19ae-4117-9f55-465049fc7667"],
Cell[CellGroupData[{
Cell[2276725, 61413, 401, 9, 58, "Text",ExpressionUUID->"b56c26ad-e3ae-44bd-939c-71bd22576276",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2277129, 61424, 596, 15, 31, "Input",ExpressionUUID->"860cc18b-43da-4d8f-92c5-98eda12aca34",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2277728, 61441, 13220, 325, 1233, "Input",ExpressionUUID->"da40dacf-05e6-4168-9bc2-b202625d331d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2290997, 61772, 238, 4, 55, "Subsection",ExpressionUUID->"2caae632-3ee0-439d-b108-d918a02fbfca"],
Cell[2291238, 61778, 1031, 30, 35, "Input",ExpressionUUID->"35b1a766-79a0-46f4-9222-e758c3064e22"],
Cell[2292272, 61810, 880, 25, 45, "Input",ExpressionUUID->"8646f4de-12a6-41e9-be4c-722bed29d39e"],
Cell[2293155, 61837, 831, 25, 80, "Input",ExpressionUUID->"db37f37c-85f3-49c0-b893-78edaee33bb7"],
Cell[CellGroupData[{
Cell[2294011, 61866, 204, 4, 45, "Subsubsection",ExpressionUUID->"a36fd601-b0a4-41e6-b27a-e415ecd5486b"],
Cell[2294218, 61872, 1167, 32, 62, "Input",ExpressionUUID->"0487b397-640f-47f8-9dc1-e78274fb4ec8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2295422, 61909, 202, 4, 45, "Subsubsection",ExpressionUUID->"f16b87e5-5c79-4b0d-9a8f-b027a465f7f8"],
Cell[2295627, 61915, 1164, 28, 35, "Input",ExpressionUUID->"ebba0f84-d7e3-4596-9af8-5900022dc61b"],
Cell[2296794, 61945, 1214, 31, 58, "Input",ExpressionUUID->"f902dcd8-309d-49f8-8e4f-84a7a2f3eb86"],
Cell[2298011, 61978, 429, 8, 37, "Text",ExpressionUUID->"4f07eab1-7203-49bf-84db-c45dd830eef7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[CellGroupData[{
Cell[2298465, 61990, 530, 14, 31, "Input",ExpressionUUID->"30640830-db03-459e-9a38-f745f64ee550"],
Cell[2298998, 62006, 231, 4, 35, "Output",ExpressionUUID->"046271aa-d562-4e81-b6ed-ae7dec2845d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2299266, 62015, 256, 6, 31, "Input",ExpressionUUID->"30d1f437-8ec6-42a7-8bd1-4eb772f0401e"],
Cell[2299525, 62023, 679, 17, 59, "Output",ExpressionUUID->"1f0f637e-2f38-453c-887d-b2853e09d204"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2300241, 62045, 433, 10, 31, "Input",ExpressionUUID->"99641aae-ed4e-404a-b3bf-d3f67856d190"],
Cell[2300677, 62057, 2554, 74, 170, "Output",ExpressionUUID->"296ef6f1-e59d-4759-bae5-c8cd6cbefe75"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2303292, 62138, 468, 11, 111, "Subsection",ExpressionUUID->"6e65e322-5cfd-4e5f-95b3-6c732a17d6cb"],
Cell[2303763, 62151, 1553, 46, 163, "Input",ExpressionUUID->"f5755d51-2a11-40bd-b4da-9c5b3bc26408"],
Cell[CellGroupData[{
Cell[2305341, 62201, 1051, 34, 58, "Input",ExpressionUUID->"d32f7ccd-a6ee-4d9a-a839-0b051a6ed994"],
Cell[2306395, 62237, 1701, 52, 89, "Output",ExpressionUUID->"e36b3197-2ddb-475c-85bb-b8caefda37b9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2308133, 62294, 685, 19, 31, "Input",ExpressionUUID->"20a1c202-0902-4637-b2de-590344de0a61"],
Cell[2308821, 62315, 739, 22, 39, "Output",ExpressionUUID->"f6d5b112-9512-430b-8b07-264209c89187"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2309597, 62342, 541, 16, 35, "Input",ExpressionUUID->"a6d0af5f-bf0d-464e-8ec0-25fa72df9620"],
Cell[2310141, 62360, 450, 13, 39, "Output",ExpressionUUID->"96511ada-8f91-4a8b-bda4-5a9d64ba16cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2310628, 62378, 710, 21, 35, "Input",ExpressionUUID->"2c2b6bf1-3667-4a08-ad83-f642a84926e9"],
Cell[2311341, 62401, 541, 16, 39, "Output",ExpressionUUID->"b51170a6-7c37-4fc1-bfaf-b62b34a36202"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2311919, 62422, 443, 14, 35, "Input",ExpressionUUID->"157d62f8-77a2-4e87-a2c9-a5a773c6f125"],
Cell[2312365, 62438, 325, 9, 39, "Output",ExpressionUUID->"41bd86f0-3969-4f0f-9184-634e8906b608"]
}, Open  ]],
Cell[2312705, 62450, 168, 4, 31, "Input",ExpressionUUID->"537d3fb1-6761-46b7-be7f-09556751979b"],
Cell[2312876, 62456, 129, 3, 31, "Input",ExpressionUUID->"e2b79411-27a6-4f97-bbd7-315f746494eb"],
Cell[CellGroupData[{
Cell[2313030, 62463, 485, 13, 31, "Input",ExpressionUUID->"36f74659-9506-4d65-ab86-c4d4e0d6113c"],
Cell[2313518, 62478, 508, 17, 39, "Output",ExpressionUUID->"511ca021-6489-475d-a47b-6c01b27db02d"]
}, Open  ]],
Cell[2314041, 62498, 1043, 31, 35, "Input",ExpressionUUID->"ce85d041-a08a-4d3a-8f9a-27f2a6180775"],
Cell[2315087, 62531, 1663, 49, 163, "Input",ExpressionUUID->"e2912d93-dc96-4e74-89ef-1f474a1c7b51"],
Cell[2316753, 62582, 804, 24, 71, "Input",ExpressionUUID->"6a027c63-843e-45f0-a6c3-76910e63cea3"],
Cell[2317560, 62608, 238, 5, 31, "Input",ExpressionUUID->"880c515e-40db-492d-8f9e-cdb31e391e32"],
Cell[2317801, 62615, 3514, 100, 197, "Input",ExpressionUUID->"a2df0327-dcb7-4302-ab3d-fcfc8802b452"],
Cell[2321318, 62717, 1509, 47, 94, "Input",ExpressionUUID->"8f31ffa5-30d2-4bf0-a97f-d67bbbe442b2"],
Cell[CellGroupData[{
Cell[2322852, 62768, 189, 3, 45, "Subsubsection",ExpressionUUID->"66ab8d0e-6bf2-4086-8104-ff553c5d0729"],
Cell[CellGroupData[{
Cell[2323066, 62775, 1117, 34, 58, "Input",ExpressionUUID->"52e72da5-abb2-432d-a755-267db6e04054"],
Cell[2324186, 62811, 758, 22, 39, "Output",ExpressionUUID->"b7bc4075-607b-4ceb-894e-378369ee8e62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2324981, 62838, 778, 23, 35, "Input",ExpressionUUID->"d0d10b31-4055-4a46-92bc-06774b049399"],
Cell[2325762, 62863, 600, 18, 35, "Output",ExpressionUUID->"e07f96f5-6704-46a8-9357-a4e01757805f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2326399, 62886, 421, 10, 55, "Input",ExpressionUUID->"cf73d454-f89e-414d-9029-af2b24208769"],
Cell[2326823, 62898, 165, 4, 35, "Output",ExpressionUUID->"435ca909-41b8-4cad-be54-a7e3e469f9e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2327025, 62907, 595, 19, 35, "Input",ExpressionUUID->"5edfb859-8170-4283-859b-14140058b5e8"],
Cell[2327623, 62928, 297, 9, 35, "Output",ExpressionUUID->"31bd5b48-9055-49bd-a810-7a8bdba15e65"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2327957, 62942, 630, 17, 31, "Input",ExpressionUUID->"d2d3c32d-5850-428b-bf4c-e51285809e71"],
Cell[2328590, 62961, 193, 5, 52, "Output",ExpressionUUID->"5ef0c086-a60c-4a59-97f6-6a96445bd86a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2328820, 62971, 232, 5, 31, "Input",ExpressionUUID->"16e17424-cb75-49e3-9ea6-fad5d5fe1203"],
Cell[2329055, 62978, 860, 26, 47, "Output",ExpressionUUID->"ec4c3213-3dde-4d3b-acf0-f8b9826d9b35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2329952, 63009, 2307, 65, 235, "Input",ExpressionUUID->"2983eeed-423f-40f0-9848-7baa0d1d5838"],
Cell[2332262, 63076, 307, 9, 39, "Output",ExpressionUUID->"8e18d509-5243-4b06-a661-09b46d5e71a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2332606, 63090, 542, 15, 31, "Input",ExpressionUUID->"74aba718-03c4-4865-981c-9c22fb749d13"],
Cell[2333151, 63107, 2841, 84, 166, "Output",ExpressionUUID->"1c1ec28c-ee3a-428c-b89b-c519ff05523d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2336029, 63196, 936, 26, 78, "Input",ExpressionUUID->"2632f4a4-79d1-41a1-923f-32630766306b"],
Cell[2336968, 63224, 441, 10, 35, "Output",ExpressionUUID->"f49e3654-e400-48ff-8b28-359cc0716dc2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2337458, 63240, 257, 6, 45, "Subsubsection",ExpressionUUID->"4338c631-6f04-4418-ae63-3f9abcd21813"],
Cell[CellGroupData[{
Cell[2337740, 63250, 630, 16, 55, "Input",ExpressionUUID->"6f0a7345-bf41-423a-9fc5-6d8c4c0112e5"],
Cell[2338373, 63268, 268, 7, 35, "Output",ExpressionUUID->"1a563cea-36b3-4e08-b790-fe4bb65bd03b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2338678, 63280, 313, 8, 31, "Input",ExpressionUUID->"b9ca66ce-1ee4-4526-863a-337d9ed2ff77"],
Cell[2338994, 63290, 266, 5, 35, "Output",ExpressionUUID->"a75dd173-7040-4b33-a4d2-90a8bea253be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2339297, 63300, 289, 8, 31, "Input",ExpressionUUID->"ef3e4d5f-12b6-401d-bfd2-208b3fbb3116"],
Cell[2339589, 63310, 150, 3, 35, "Output",ExpressionUUID->"b3be68e3-d212-4973-8afd-132263615e49"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2339776, 63318, 1494, 43, 130, "Input",ExpressionUUID->"ce1334d3-249d-4410-b778-50c2b165a5ef"],
Cell[2341273, 63363, 483, 11, 35, "Output",ExpressionUUID->"efccf885-b752-4ae6-b08a-74a714e1cec5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2341793, 63379, 179, 3, 31, "Input",ExpressionUUID->"5e494133-43fa-4000-b0c2-5e18b62aba02"],
Cell[2341975, 63384, 2231, 67, 131, "Output",ExpressionUUID->"3ebd688a-aafe-4c63-aa4f-9bd51e5566d4"]
}, Open  ]],
Cell[2344221, 63454, 5545, 142, 630, "Input",ExpressionUUID->"7dd93c16-6379-492b-8a33-87053856b75f"],
Cell[CellGroupData[{
Cell[2349791, 63600, 2113, 59, 169, "Input",ExpressionUUID->"de861241-8a19-4d1a-9ea1-fc2784769310"],
Cell[2351907, 63661, 281, 9, 39, "Output",ExpressionUUID->"963731ec-95a0-4396-bc7f-276dce8e7322"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2352225, 63675, 3634, 94, 426, "Input",ExpressionUUID->"dea814ae-2d71-4e01-8d0a-fcc0e41c770c"],
Cell[2355862, 63771, 2184, 64, 100, "Output",ExpressionUUID->"d909ef64-0068-49e7-9e67-128662a4baaa"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2358095, 63841, 542, 12, 149, "Subsubsection",ExpressionUUID->"c00db58a-ca82-473d-b48d-b4678cd626a9"],
Cell[CellGroupData[{
Cell[2358662, 63857, 633, 20, 33, "Input",ExpressionUUID->"70d449e3-dda4-4625-9b8c-d9757612ed86"],
Cell[2359298, 63879, 872, 30, 52, "Output",ExpressionUUID->"51796e3d-e54a-47f5-9056-c89c1a1d0c76"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2360207, 63914, 457, 11, 31, "Input",ExpressionUUID->"56428cf4-f70e-45fa-8cae-1c151212cd7b"],
Cell[2360667, 63927, 286, 7, 35, "Output",ExpressionUUID->"d51473f1-1e78-495e-9c7c-3a447cfa0cd4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2360990, 63939, 560, 17, 62, "Input",ExpressionUUID->"afd9a56a-5910-4ade-887e-b46d4d020c8c"],
Cell[2361553, 63958, 526, 16, 52, "Output",ExpressionUUID->"4f019186-056d-4e58-b4e3-46a99ed9681c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2362116, 63979, 241, 6, 31, "Input",ExpressionUUID->"9bf4ac57-cb98-4143-add6-47f9d7f9f231"],
Cell[2362360, 63987, 354, 10, 35, "Output",ExpressionUUID->"d6292501-23a3-45ce-ab7a-8702cf97ec1c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2362751, 64002, 573, 18, 35, "Input",ExpressionUUID->"7ba22fc1-e24b-4489-83eb-2362cff63539"],
Cell[2363327, 64022, 156, 3, 35, "Output",ExpressionUUID->"2a8460f7-0d6d-4f65-96ef-1f7af79e30a4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2363520, 64030, 540, 16, 35, "Input",ExpressionUUID->"fd649d17-7eed-4699-8f33-fe62ec2b33f8"],
Cell[2364063, 64048, 2842, 95, 198, "Output",ExpressionUUID->"cad43703-84bd-4728-bf35-3d3ea6cf7140"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2366942, 64148, 456, 14, 35, "Input",ExpressionUUID->"68d904f7-6960-43e9-ad09-90ffa2507a31"],
Cell[2367401, 64164, 2575, 85, 141, "Output",ExpressionUUID->"cb89ec29-b804-476d-b1fa-6a66afdba637"]
}, Open  ]],
Cell[2369991, 64252, 902, 27, 68, "Input",ExpressionUUID->"4745cb24-2107-4ad0-9e60-936499954dd2"],
Cell[CellGroupData[{
Cell[2370918, 64283, 651, 22, 62, "Input",ExpressionUUID->"f971c556-9fcd-411f-b33c-fedf8c070873"],
Cell[2371572, 64307, 646, 21, 52, "Output",ExpressionUUID->"b26c8d9c-6b14-42c3-98e4-e9236a98c558"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2372255, 64333, 2873, 84, 193, "Input",ExpressionUUID->"fdbe4e81-1d9e-4718-80b7-4bb4867a31ef"],
Cell[2375131, 64419, 2452, 72, 142, "Output",ExpressionUUID->"580ea0c5-5a81-4fea-be17-e85b8ae3e9a4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2377620, 64496, 2230, 61, 196, "Input",ExpressionUUID->"7c6e794f-c016-4b5c-aee3-749f36239e49"],
Cell[2379853, 64559, 314, 10, 47, "Output",ExpressionUUID->"732498dd-4559-41df-ae90-d95ccd5e657c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2380204, 64574, 993, 30, 103, "Input",ExpressionUUID->"3d8f8d7a-1159-43a8-b3a5-c65a241bcf8a"],
Cell[2381200, 64606, 410, 10, 35, "Output",ExpressionUUID->"491a56d5-4a9d-482d-8365-843655db30bd"]
}, Open  ]],
Cell[2381625, 64619, 863, 28, 37, "Input",ExpressionUUID->"f2718423-c462-4860-bfb9-63c736804a3e"],
Cell[CellGroupData[{
Cell[2382513, 64651, 806, 26, 74, "Input",ExpressionUUID->"4c83e247-a1bb-41c5-b0ae-f75568edf7e6"],
Cell[2383322, 64679, 742, 24, 63, "Output",ExpressionUUID->"b7544906-1002-41c0-93de-bbd1a92e8b67"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2384113, 64709, 281, 6, 45, "Subsubsection",ExpressionUUID->"1e1c0099-f6e4-4562-af0d-b5d3316302a5"],
Cell[2384397, 64717, 1713, 50, 179, "Input",ExpressionUUID->"f9f9d650-8633-4bf0-ba0d-0882bc674309",
 InitializationCell->True],
Cell[2386113, 64769, 1361, 35, 100, "Input",ExpressionUUID->"a08ee633-549b-4294-9e70-45ab457a2893",
 InitializationCell->True],
Cell[2387477, 64806, 1075, 30, 91, "Input",ExpressionUUID->"b5136d90-2e9d-48c4-b69e-66214f0d5fd5",
 InitializationCell->True],
Cell[2388555, 64838, 2010, 59, 236, "Input",ExpressionUUID->"a1aaa429-14c9-40d5-8663-d5a0f47151d0",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2390590, 64901, 463, 12, 31, "Input",ExpressionUUID->"404619b1-528f-4913-873e-6e32f32f0bd8"],
Cell[2391056, 64915, 154, 3, 35, "Output",ExpressionUUID->"7f2a9b4f-e092-4728-b411-bbd07657d6b7"]
}, Open  ]],
Cell[2391225, 64921, 2914, 78, 293, "Input",ExpressionUUID->"05638ad8-4a95-468a-8b19-2b473d7787e4",
 InitializationCell->True],
Cell[2394142, 65001, 2661, 72, 293, "Input",ExpressionUUID->"19427b4b-12e0-4f1b-9ec8-a7b8d6435bcc",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2396828, 65077, 414, 10, 31, "Input",ExpressionUUID->"ce18bd1e-5172-4902-915c-bb54afac04ea"],
Cell[2397245, 65089, 4288, 145, 433, "Output",ExpressionUUID->"08ac2336-064c-45db-91ed-e98b413f4e78"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2401582, 65240, 243, 4, 45, "Subsubsection",ExpressionUUID->"e873e24e-2550-4990-9a08-7a93b6f23a4e"],
Cell[CellGroupData[{
Cell[2401850, 65248, 402, 8, 37, "Text",ExpressionUUID->"da7f0ea6-164c-4443-b6c2-d33e93498c87",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2402255, 65258, 454, 10, 31, "Input",ExpressionUUID->"925b9d56-f933-45ad-b881-1f61995c664f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2402712, 65270, 938, 29, 47, "Output",ExpressionUUID->"7abfc3a8-6063-4804-8d8a-567a78b5038d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2403653, 65301, 988, 29, 35, "Input",ExpressionUUID->"0d45098d-6531-4e8d-9574-f3baf86de23b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2404644, 65332, 788, 22, 39, "Output",ExpressionUUID->"a9a30b35-c03c-41eb-9bd7-8a0986a62e1b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2405435, 65356, 922, 25, 31, "Input",ExpressionUUID->"17e43fc7-0ca9-42c0-a06e-f8da68c09874",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2406360, 65383, 808, 23, 39, "Output",ExpressionUUID->"55f8bb42-ab79-4db6-9591-82fd4ac8f9be",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2407171, 65408, 1958, 58, 110, "Input",ExpressionUUID->"5661ec59-eb94-4539-a64a-eb1dfc4e0dbb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2409132, 65468, 207, 4, 35, "Output",ExpressionUUID->"06d3bd82-a724-4b65-a4c2-4f96ef518d4f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[2409354, 65475, 1084, 31, 81, "Input",ExpressionUUID->"686c6c68-d509-4d0d-b78d-f8e521be3fdb",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2410463, 65510, 366, 10, 31, "Input",ExpressionUUID->"3c75eaff-ab66-4c77-9962-f1bca3fff10f"],
Cell[2410832, 65522, 130, 3, 35, "Output",ExpressionUUID->"72694d66-0217-428d-bad4-63f850bcb523"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2410999, 65530, 240, 5, 31, "Input",ExpressionUUID->"27b76226-c8b3-4070-beb3-5be7e94bf730"],
Cell[2411242, 65537, 3094, 89, 172, "Output",ExpressionUUID->"76d94af6-efbe-4da9-9c37-bf5b12b5fb56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2414373, 65631, 242, 5, 31, "Input",ExpressionUUID->"b7520839-396e-41a9-88d7-50da049fde6e"],
Cell[2414618, 65638, 2880, 87, 172, "Output",ExpressionUUID->"ca1168f5-937a-4420-8a1a-c038c09aa5c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2417535, 65730, 503, 12, 55, "Input",ExpressionUUID->"cbed455d-791d-42a3-84d7-8aa72af27977"],
Cell[2418041, 65744, 169, 5, 52, "Output",ExpressionUUID->"d8c32c74-0a26-44a9-a94b-3df0d5a7e9b4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2418247, 65754, 704, 20, 57, "Input",ExpressionUUID->"9a381dfe-bddc-413a-8617-66f65190483c"],
Cell[2418954, 65776, 201, 5, 52, "Output",ExpressionUUID->"e7a6dca0-b7b9-4b34-88d4-d11b7c3aa90d"]
}, Open  ]],
Cell[2419170, 65784, 324, 6, 35, "Text",ExpressionUUID->"c2d511ff-7580-405d-96a3-5ec248eedc89"],
Cell[CellGroupData[{
Cell[2419519, 65794, 154, 3, 31, "Input",ExpressionUUID->"ae100c0c-2623-458b-8484-c0c7e1c861c5"],
Cell[2419676, 65799, 860, 26, 47, "Output",ExpressionUUID->"3e413777-feb9-4902-9811-f5c8c22b1aa7"]
}, Open  ]],
Cell[2420551, 65828, 1253, 37, 125, "Input",ExpressionUUID->"65cb3dce-6cbd-47be-9a9a-946f4d2b3f1b"],
Cell[CellGroupData[{
Cell[2421829, 65869, 317, 7, 31, "Input",ExpressionUUID->"763e2936-9444-4cfc-a8b5-9cc46b9d6702"],
Cell[2422149, 65878, 1204, 36, 81, "Output",ExpressionUUID->"ca85eb59-eeea-46b2-ae3f-60c2961933c4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2423390, 65919, 274, 7, 31, "Input",ExpressionUUID->"63b1faf8-f520-4e54-95b7-45c77ba95f91"],
Cell[2423667, 65928, 1218, 37, 81, "Output",ExpressionUUID->"0498168a-3671-412c-b4d5-3fb3bb093bda"]
}, Open  ]],
Cell[2424900, 65968, 1329, 38, 125, "Input",ExpressionUUID->"4dfc68f6-ce49-4bb4-a7ae-c8b478a9de14"],
Cell[CellGroupData[{
Cell[2426254, 66010, 463, 13, 31, "Input",ExpressionUUID->"6498cf6b-055b-43ae-9ba2-899984b56b0c"],
Cell[2426720, 66025, 444, 13, 39, "Output",ExpressionUUID->"17ddc0f2-09ff-483d-844e-ad1b1d58b094"]
}, Open  ]],
Cell[2427179, 66041, 489, 15, 35, "Text",ExpressionUUID->"f9a35a63-50ac-4376-9a95-1b5fb998713d"],
Cell[2427671, 66058, 1406, 42, 111, "Input",ExpressionUUID->"3a58c67a-07b2-4799-b709-96bdf6e1fbe1"],
Cell[2429080, 66102, 425, 11, 31, "Input",ExpressionUUID->"e8200106-1376-44cf-a1c3-c1b279824764"],
Cell[2429508, 66115, 264, 7, 31, "Input",ExpressionUUID->"4247d3f2-a2e7-4d42-98fc-db5f50b6e497"],
Cell[CellGroupData[{
Cell[2429797, 66126, 3626, 91, 491, "Input",ExpressionUUID->"b9b04cc6-02e7-4a88-b790-18a431ceb31b"],
Cell[2433426, 66219, 1817, 53, 126, "Output",ExpressionUUID->"186e1d81-5111-4f9c-bb42-77ad7bf35841"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2435280, 66277, 3762, 92, 491, "Input",ExpressionUUID->"ba6a8fbf-d27f-4642-adbd-bb799c644c30"],
Cell[2439045, 66371, 989, 34, 60, "Output",ExpressionUUID->"266444db-f73d-44d6-9923-7a5d6c7c13fd"]
}, Open  ]],
Cell[2440049, 66408, 904, 29, 74, "Input",ExpressionUUID->"de5ebfc2-9a69-4483-80be-dbb36dd24c41"],
Cell[2440956, 66439, 228, 5, 37, "Text",ExpressionUUID->"76ec34c1-c127-4a22-af2d-d6c30d843bd8"],
Cell[CellGroupData[{
Cell[2441209, 66448, 157, 3, 31, "Input",ExpressionUUID->"2ac86d5e-f7df-4e6f-87a1-a8df758c1e47"],
Cell[2441369, 66453, 959, 30, 54, "Output",ExpressionUUID->"0e40ec8b-90d3-4719-947f-d211110f7808"]
}, Open  ]],
Cell[2442343, 66486, 262, 6, 31, "Input",ExpressionUUID->"521d6301-065a-46fc-9cc0-93a8a1427cc0"],
Cell[CellGroupData[{
Cell[2442630, 66496, 3031, 78, 467, "Input",ExpressionUUID->"da3cb858-dc21-4e0f-93bc-f1a96e8cd0b0"],
Cell[2445664, 66576, 769, 25, 60, "Output",ExpressionUUID->"ba58bca3-cd66-4f8d-aa8c-b1b44f84ec68"]
}, Open  ]],
Cell[2446448, 66604, 228, 5, 37, "Text",ExpressionUUID->"93fe7075-be2e-410a-b52b-0cc024e0a9b0"],
Cell[2446679, 66611, 262, 6, 31, "Input",ExpressionUUID->"a860efb5-5fd4-4089-a7de-85128b1d9640"],
Cell[CellGroupData[{
Cell[2446966, 66621, 2981, 77, 468, "Input",ExpressionUUID->"756923b7-fe22-4c72-8c94-cdedc261e55a"],
Cell[2449950, 66700, 763, 25, 60, "Output",ExpressionUUID->"f9440cf1-cfb3-4b31-8ca8-aa500f62f5c8"]
}, Open  ]],
Cell[2450728, 66728, 228, 5, 37, "Text",ExpressionUUID->"c7db0fac-788f-4c4b-86e8-38188391f9d7"],
Cell[2450959, 66735, 734, 26, 74, "Input",ExpressionUUID->"c3dc3b28-900a-4f11-a95f-60b9b453f814"],
Cell[2451696, 66763, 131, 3, 31, "Input",ExpressionUUID->"627b33c0-43a0-4fd4-b401-45cbb46882e5"],
Cell[CellGroupData[{
Cell[2451852, 66770, 1401, 43, 62, "Input",ExpressionUUID->"7b90a541-81f9-47b2-b527-ab84de8c2cae"],
Cell[2453256, 66815, 910, 27, 47, "Output",ExpressionUUID->"9981ad70-38f9-4b26-a803-1e31ec70ea5a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2454203, 66847, 222, 5, 31, "Input",ExpressionUUID->"e17539ba-4ace-44e2-a1f0-eb3e4c285740"],
Cell[2454428, 66854, 858, 26, 47, "Output",ExpressionUUID->"12ab3633-98eb-44db-b60c-abba0a66931d"]
}, Open  ]],
Cell[2455301, 66883, 2085, 60, 198, "Input",ExpressionUUID->"46d1b39f-2127-4b19-9a8d-58d4ac780084",
 InitializationCell->True],
Cell[2457389, 66945, 2038, 58, 198, "Input",ExpressionUUID->"ec2477dd-5e61-4513-8b53-366fc252850a",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2459464, 67008, 186, 3, 45, "Subsubsection",ExpressionUUID->"d10ef776-1c0b-4fd9-bfe0-1583ffaf8cfd"],
Cell[2459653, 67013, 507, 21, 45, "Input",ExpressionUUID->"69b2f2ab-90e2-47f9-921c-8615db8a3af5"],
Cell[CellGroupData[{
Cell[2460185, 67038, 211, 5, 31, "Input",ExpressionUUID->"6a5c7e19-2b9e-4c1b-b954-662c2f88f053"],
Cell[2460399, 67045, 1232, 42, 69, "Output",ExpressionUUID->"4e263b24-ce8c-45f3-b7d6-e51430756b36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2461668, 67092, 161, 3, 31, "Input",ExpressionUUID->"66c945a4-b4f2-45cf-bd40-492aa2e170f4"],
Cell[2461832, 67097, 370, 10, 35, "Output",ExpressionUUID->"9d92310b-dfb7-43f0-bffe-f82fd271bb00"]
}, Open  ]],
Cell[2462217, 67110, 643, 16, 55, "Input",ExpressionUUID->"c76fb55a-67f5-4791-a4fe-3a40c4aca070"],
Cell[CellGroupData[{
Cell[2462885, 67130, 162, 3, 31, "Input",ExpressionUUID->"7c9d2f3b-d4ab-41b8-b77b-9e5d2de7761e"],
Cell[2463050, 67135, 4308, 124, 138, "Output",ExpressionUUID->"ec0fb25b-6abc-47c2-b6fc-51f854c5148d"]
}, Closed]],
Cell[CellGroupData[{
Cell[2467395, 67264, 527, 12, 27, "Input",ExpressionUUID->"1b3f0563-d781-42ef-bddf-ecd78a56cbf3"],
Cell[2467925, 67278, 989, 24, 59, "Output",ExpressionUUID->"5be6b874-33fc-4fc1-9fcf-f18fe6db73c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2468951, 67307, 311, 8, 31, "Input",ExpressionUUID->"6298be96-65ca-4dda-9335-6bcc1eece29c"],
Cell[2469265, 67317, 353, 8, 35, "Output",ExpressionUUID->"c0da8f1a-6a08-4695-945d-55cef6fdd705"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2469655, 67330, 258, 5, 31, "Input",ExpressionUUID->"aa49f412-2f4d-4ebc-b44a-2595e72466a3"],
Cell[2469916, 67337, 741, 16, 59, "Output",ExpressionUUID->"cee06f80-a2c8-486f-ba97-51431af50f71"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2470694, 67358, 244, 5, 31, "Input",ExpressionUUID->"e9a191d6-d916-4b30-bce5-0e1e045b8078"],
Cell[2470941, 67365, 411, 11, 35, "Output",ExpressionUUID->"827f5011-23ca-46e6-85d4-3866175c31f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2471389, 67381, 443, 12, 31, "Input",ExpressionUUID->"9489b222-3d7b-4801-9718-8452aeea1323"],
Cell[2471835, 67395, 328, 7, 35, "Output",ExpressionUUID->"77e085fb-83e5-485c-836c-7ffe4c61ace8"]
}, Open  ]],
Cell[2472178, 67405, 131, 3, 31, "Input",ExpressionUUID->"78b32fa5-8a60-47d7-ae35-391be16cbab5"],
Cell[CellGroupData[{
Cell[2472334, 67412, 278, 8, 31, "Input",ExpressionUUID->"3fe6be68-9549-487d-bdd0-f5dce3d9a50a"],
Cell[2472615, 67422, 211, 6, 35, "Output",ExpressionUUID->"07c93748-ae2f-4c7b-8332-be637f622444"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2472863, 67433, 934, 27, 99, "Input",ExpressionUUID->"279e9979-2682-43f7-98fe-a51731c94a6a"],
Cell[2473800, 67462, 358, 8, 35, "Output",ExpressionUUID->"93582518-b808-47a9-8a8b-b72426ffc930"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2474207, 67476, 180, 3, 45, "Subsubsection",ExpressionUUID->"ca99359c-246e-45f8-9f4a-dabbf6dac20a"],
Cell[CellGroupData[{
Cell[2474412, 67483, 680, 22, 80, "Input",ExpressionUUID->"df46acb5-4fcb-46e7-86ac-468f96ab1803"],
Cell[2475095, 67507, 3740, 111, 163, "Output",ExpressionUUID->"f162fa06-26a6-4e93-a486-418036701d2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2478872, 67623, 269, 7, 31, "Input",ExpressionUUID->"558654db-8ac7-42c6-a0ba-dbb95d14924f"],
Cell[2479144, 67632, 2163, 67, 86, "Output",ExpressionUUID->"c3fd9236-b7f2-4c41-8e50-f58012b034f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2481344, 67704, 753, 24, 80, "Input",ExpressionUUID->"76e24d9d-5ed2-41e7-8ed6-c039ff369458"],
Cell[2482100, 67730, 2355, 74, 163, "Output",ExpressionUUID->"d70e7748-3ec9-4f26-8c52-719214f91326"]
}, Open  ]],
Cell[2484470, 67807, 274, 6, 37, "Text",ExpressionUUID->"21833b4c-7ffe-402c-8704-296b7dd6de20"],
Cell[CellGroupData[{
Cell[2484769, 67817, 174, 3, 31, "Input",ExpressionUUID->"af2c5c54-3603-4208-8b9c-95e27b20bb34"],
Cell[2484946, 67822, 2790, 85, 172, "Output",ExpressionUUID->"1fb61822-338a-4d6d-b113-253ba759bfb9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2487785, 67913, 281, 6, 45, "Subsubsection",ExpressionUUID->"efa785ce-a92a-43a8-af92-22f7b9716bf1"],
Cell[CellGroupData[{
Cell[2488091, 67923, 313, 8, 31, "Input",ExpressionUUID->"bab49aa3-e8a4-4576-b83f-f5ca9abaf879"],
Cell[2488407, 67933, 8575, 236, 448, "Output",ExpressionUUID->"a8a069d7-f9ee-4db5-a3e0-fb0318d61f88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2497019, 68174, 865, 23, 92, "Input",ExpressionUUID->"c4606a39-1da7-47d6-a633-2cbb8c3d1e27"],
Cell[2497887, 68199, 8871, 249, 513, "Output",ExpressionUUID->"caf8b914-64f6-40f5-8a67-5ead18ef488e"]
}, Open  ]],
Cell[2506773, 68451, 129, 3, 31, "Input",ExpressionUUID->"55ebbbd6-5129-4a25-aa2d-75c15e1b46af"],
Cell[2506905, 68456, 242, 5, 37, "Text",ExpressionUUID->"9ae8ff14-2b17-4ecc-a2ac-529307822345"],
Cell[CellGroupData[{
Cell[2507172, 68465, 1227, 40, 92, "Input",ExpressionUUID->"a46ab581-5588-4327-8150-b0a40d7c3c39"],
Cell[2508402, 68507, 302, 7, 35, "Output",ExpressionUUID->"2959a759-0ef0-4b09-8e37-0da56426f886"]
}, Open  ]],
Cell[2508719, 68517, 129, 3, 31, "Input",ExpressionUUID->"747f9591-d44c-4877-84e0-b111a94820c3"],
Cell[CellGroupData[{
Cell[2508873, 68524, 391, 10, 31, "Input",ExpressionUUID->"d8a7cfef-898b-443d-919d-35e4a2af9403"],
Cell[2509267, 68536, 6086, 167, 476, "Output",ExpressionUUID->"e639a290-b785-4e26-98e6-c89fda0e0f40"]
}, Closed]],
Cell[2515368, 68706, 129, 3, 27, "Input",ExpressionUUID->"9416af3d-39f3-4fe0-85dc-7bb533894987"],
Cell[2515500, 68711, 261, 6, 37, "Text",ExpressionUUID->"b254904d-5177-468b-a344-5403f9b8e929"],
Cell[CellGroupData[{
Cell[2515786, 68721, 1307, 41, 92, "Input",ExpressionUUID->"3844387a-02ce-4fa8-80fa-57ed28e3c5f4"],
Cell[2517096, 68764, 325, 8, 35, "Output",ExpressionUUID->"c4eb6bf2-74a8-41d7-a94a-703640ed6281"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2517458, 68777, 1309, 41, 92, "Input",ExpressionUUID->"236aefe0-e5eb-447d-b1d5-cf60d2103463"],
Cell[2518770, 68820, 326, 8, 35, "Output",ExpressionUUID->"fc9a30a3-52d5-4773-88d7-244e722c5dce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2519133, 68833, 1156, 31, 78, "Input",ExpressionUUID->"9cbb889a-ad6d-4f5a-9e51-9eef2bc680a9"],
Cell[2520292, 68866, 322, 8, 35, "Output",ExpressionUUID->"fc822c57-2d3c-4a00-8191-a69e2474e330"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2520651, 68879, 1130, 30, 78, "Input",ExpressionUUID->"bca6b66a-7764-46be-bf8c-f187236a6770"],
Cell[2521784, 68911, 321, 8, 35, "Output",ExpressionUUID->"cebe77b4-bd0d-4127-9d34-140427853b01"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2522190, 68928, 330, 8, 103, "Subchapter",ExpressionUUID->"dea249ad-3d82-4765-9e5a-66f2374b0cba"],
Cell[CellGroupData[{
Cell[2522545, 68940, 556, 8, 224, "Section",ExpressionUUID->"e07e3747-2f1f-4287-a3c6-ad415c41ddcb"],
Cell[2523104, 68950, 331, 6, 71, "Subsubsection",ExpressionUUID->"98318130-04e5-46e6-a155-55cb2461ecb4"],
Cell[CellGroupData[{
Cell[2523460, 68960, 317, 5, 63, "Subsubsection",ExpressionUUID->"7e5514b3-76e3-4306-a3ee-3dcfd87bde94"],
Cell[CellGroupData[{
Cell[2523802, 68969, 298, 7, 31, "Input",ExpressionUUID->"4b2fe16e-110f-4303-973b-80338c3d8f69"],
Cell[2524103, 68978, 453, 15, 52, "Output",ExpressionUUID->"31856571-753e-43a9-ac0b-b2d3bdb13409"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2524593, 68998, 572, 15, 55, "Input",ExpressionUUID->"f10e9980-b48c-4580-a998-8c8507c9ed49"],
Cell[2525168, 69015, 468, 16, 52, "Output",ExpressionUUID->"4a356485-5dfc-40e2-b9a7-db87a993b234"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2525685, 69037, 174, 3, 45, "Subsubsection",ExpressionUUID->"f8d413d3-b8bb-48e8-a322-7f4f4682db6d"],
Cell[CellGroupData[{
Cell[2525884, 69044, 450, 12, 31, "Input",ExpressionUUID->"bb562291-7ee4-41ce-a32f-2dee7e77bbe6"],
Cell[2526337, 69058, 506, 14, 35, "Output",ExpressionUUID->"8bed5c1a-952f-453e-8279-6bc885f90918"]
}, Open  ]],
Cell[2526858, 69075, 506, 15, 47, "Input",ExpressionUUID->"39988314-0d0e-4fdc-9fd5-3e3ecad71ca0",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2527389, 69094, 330, 9, 47, "Input",ExpressionUUID->"cf02d56d-4ae3-4d77-a8d5-55611461a906",
 InitializationCell->True],
Cell[2527722, 69105, 1518, 46, 93, "Output",ExpressionUUID->"74dea895-ecb9-4851-9a15-9af54e23795a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2529277, 69156, 775, 20, 47, "Input",ExpressionUUID->"db7c990d-c841-4eb6-89b5-8fbd371bce04",
 InitializationCell->True],
Cell[2530055, 69178, 1654, 49, 88, "Output",ExpressionUUID->"7968bf23-821a-4d8e-9b61-0e615169b0a2"]
}, Open  ]],
Cell[2531724, 69230, 1220, 36, 55, "Input",ExpressionUUID->"a21478ea-5ff8-4ec2-8e21-daf4b23040f6"],
Cell[2532947, 69268, 1397, 40, 101, "Input",ExpressionUUID->"75d6debf-5e50-4459-a87d-0282bc3bff80"],
Cell[CellGroupData[{
Cell[2534369, 69312, 196, 4, 31, "Input",ExpressionUUID->"a907d08a-cf7b-4d9f-8b28-2a919c91701d"],
Cell[2534568, 69318, 996, 34, 59, "Output",ExpressionUUID->"25f218b1-0c8e-4edb-97c1-1f07b27ccf33"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2535601, 69357, 186, 4, 31, "Input",ExpressionUUID->"6133bf13-7d18-41f3-b26f-ee61b2e4178e"],
Cell[CellGroupData[{
Cell[2535812, 69365, 195, 4, 46, "Print",ExpressionUUID->"06c2aa12-8347-4274-beb6-764b90cbd11d",
 CellTags->"Info5613729942257-2554935"],
Cell[2536010, 69371, 2402, 61, 114, "Print",ExpressionUUID->"ade43138-ac0c-433e-88da-ca368dfb8ad1",
 CellTags->"Info5613729942257-2554935"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2538461, 69438, 540, 13, 31, "Input",ExpressionUUID->"15ced56d-9e55-4505-87e1-740ee0d8b71e"],
Cell[2539004, 69453, 1139, 35, 59, "Output",ExpressionUUID->"2983a6a5-2aa5-4db6-b114-a9059df716bd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2540180, 69493, 383, 8, 31, "Input",ExpressionUUID->"4dd08596-be9d-46af-a9ea-7f9ce8c3f7d9"],
Cell[2540566, 69503, 1543, 48, 59, "Output",ExpressionUUID->"6da58bf1-32cd-4eea-ae24-69a590180ecd"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2542158, 69557, 254, 6, 45, "Subsubsection",ExpressionUUID->"e9f5784b-5967-4021-b910-8fd9ec0484cd"],
Cell[CellGroupData[{
Cell[2542437, 69567, 269, 7, 31, "Input",ExpressionUUID->"71802f1e-a2a4-4c1b-a855-ef9b43ab2ace"],
Cell[2542709, 69576, 1890, 58, 66, "Output",ExpressionUUID->"ac73fe84-803c-4a51-9640-980bea751de4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2544636, 69639, 228, 5, 31, "Input",ExpressionUUID->"650b8e5a-ff61-46e3-9397-9863a94a4ec9"],
Cell[2544867, 69646, 1890, 58, 66, "Output",ExpressionUUID->"dc0a0e99-e18e-4a22-8024-608c9139b06c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2546794, 69709, 270, 7, 31, "Input",ExpressionUUID->"a04c6470-d847-40f0-b064-3c73c190444e"],
Cell[2547067, 69718, 1780, 52, 66, "Output",ExpressionUUID->"0d94d3fe-fe3e-4618-9fb0-d2f0610838cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2548884, 69775, 933, 26, 58, "Input",ExpressionUUID->"cf4cbdaf-5259-4a18-a280-05f80c764b6c"],
Cell[2549820, 69803, 666, 21, 35, "Output",ExpressionUUID->"9b9d8413-5b5d-4c4e-9cf0-2c87b9735da6"]
}, Open  ]],
Cell[2550501, 69827, 5657, 119, 163, "Input",ExpressionUUID->"00875229-2a54-4048-a638-292b68f11e3c",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2556195, 69951, 259, 6, 45, "Subsubsection",ExpressionUUID->"ebe00750-65c5-4487-bea6-37e320157ab8"],
Cell[2556457, 69959, 5886, 125, 242, "Input",ExpressionUUID->"6c6f8167-316c-4cf6-aaae-a5f812ba88e1",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2562368, 70088, 669, 20, 35, "Input",ExpressionUUID->"04793b22-7eda-4989-b476-467c11ac011e"],
Cell[2563040, 70110, 278, 8, 35, "Output",ExpressionUUID->"44b8c98d-5f8e-4b3e-9c23-aaa751c90e52"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2563355, 70123, 838, 26, 35, "Input",ExpressionUUID->"86a67f13-1ce5-4e36-83aa-a73dc2a50bae"],
Cell[2564196, 70151, 963, 31, 55, "Output",ExpressionUUID->"82b33f14-5cb7-4f30-adb8-801210488c2b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2565196, 70187, 475, 14, 31, "Input",ExpressionUUID->"2ba249c6-2979-4b5c-a963-cd2532c4e9f8"],
Cell[2565674, 70203, 744, 23, 52, "Output",ExpressionUUID->"cfe189ec-c83b-4af4-b924-bf261060b2e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2566455, 70231, 586, 14, 31, "Input",ExpressionUUID->"f8252dbb-5584-4b2d-b568-878d968cb70a"],
Cell[2567044, 70247, 1160, 35, 59, "Output",ExpressionUUID->"8f95f0db-f29c-4b9c-9a68-7b78764e1885"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2568241, 70287, 242, 5, 31, "Input",ExpressionUUID->"24b75deb-d704-4774-b08a-b55ec6c3d3a3"],
Cell[2568486, 70294, 494, 13, 35, "Output",ExpressionUUID->"165414b5-e42a-4c23-87f4-a96f23a236ee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2569017, 70312, 237, 6, 31, "Input",ExpressionUUID->"f8fd27c7-db62-420e-ad92-59aec13e772f"],
Cell[2569257, 70320, 2173, 69, 125, "Output",ExpressionUUID->"4f9c971f-ee8d-4832-aac7-3dbce30fdd4e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2571479, 70395, 320, 7, 45, "Subsubsection",ExpressionUUID->"38df78d5-7c3c-4413-9a5f-0d9b590dd2b9"],
Cell[CellGroupData[{
Cell[2571824, 70406, 2032, 50, 101, "Input",ExpressionUUID->"72627476-44a2-4521-a2a8-f6f9388c9931"],
Cell[2573859, 70458, 1518, 46, 93, "Output",ExpressionUUID->"4e5c8420-03a1-40e3-9993-b59602a4274b"]
}, Open  ]],
Cell[2575392, 70507, 6048, 129, 242, "Input",ExpressionUUID->"766b49a5-8f6b-48a5-8b2d-e77722ab9ac2",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2581465, 70640, 240, 7, 31, "Input",ExpressionUUID->"2e7c05b2-82c7-49ac-a67d-86300d685e17"],
Cell[2581708, 70649, 398, 13, 52, "Output",ExpressionUUID->"364fbe2d-57ca-4153-b1fc-a55430693e10"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2582143, 70667, 670, 19, 35, "Input",ExpressionUUID->"fded999b-54bd-4a1a-b6ad-bdb1db1396a3"],
Cell[2582816, 70688, 271, 6, 35, "Output",ExpressionUUID->"58d6f35a-d431-4aad-8799-eb7343c99400"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2583124, 70699, 286, 7, 31, "Input",ExpressionUUID->"7f0b8b7e-d53a-4ecd-8d51-38524f413bc7"],
Cell[2583413, 70708, 2359, 75, 125, "Output",ExpressionUUID->"2f88b1da-8420-4a96-8b75-3bb6a53696ee"]
}, Open  ]],
Cell[2585787, 70786, 227, 5, 37, "Text",ExpressionUUID->"7170e754-7a1b-4bec-bcc3-2d15bc3371c5"],
Cell[CellGroupData[{
Cell[2586039, 70795, 449, 12, 31, "Input",ExpressionUUID->"939e954c-f0ca-4dfa-93e9-f64c814861a0"],
Cell[2586491, 70809, 1097, 36, 52, "Output",ExpressionUUID->"e590bceb-ceff-47b2-b9b9-76b051740de2"]
}, Open  ]],
Cell[2587603, 70848, 386, 11, 35, "Input",ExpressionUUID->"52f441fd-3f1b-46b7-824b-19bb6d19b4b0"],
Cell[CellGroupData[{
Cell[2588014, 70863, 533, 16, 62, "Input",ExpressionUUID->"4a53c152-0e49-482d-9954-52f3abd9ecaa"],
Cell[2588550, 70881, 453, 15, 52, "Output",ExpressionUUID->"22a41f87-de3f-48b5-98e5-6b6981c1625c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2589040, 70901, 267, 7, 31, "Input",ExpressionUUID->"dfe8af71-82a7-4182-8943-771d50725e67"],
Cell[2589310, 70910, 387, 9, 22, "Message",ExpressionUUID->"c31fc08b-72dc-441d-97e9-901613535c7f"],
Cell[2589700, 70921, 387, 9, 22, "Message",ExpressionUUID->"8cb890ea-339c-4239-8002-509390486014"],
Cell[2590090, 70932, 389, 9, 22, "Message",ExpressionUUID->"bbf7db40-4e50-475e-adf0-3f1ac980379e"],
Cell[2590482, 70943, 402, 9, 22, "Message",ExpressionUUID->"7cf9a150-21d5-405b-a780-6b1fe16b7cab"],
Cell[2590887, 70954, 247, 6, 35, "Output",ExpressionUUID->"5d979d2a-01c4-4c4b-b7d4-a091926042df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2591171, 70965, 328, 9, 31, "Input",ExpressionUUID->"3edae438-e9b5-43e9-9093-18ab267c78f7"],
Cell[2591502, 70976, 337, 8, 35, "Output",ExpressionUUID->"68eb6fca-5d39-4c87-b572-5cef3520420b"]
}, Open  ]],
Cell[2591854, 70987, 233, 5, 37, "Text",ExpressionUUID->"6f51ee58-c55d-4ccf-bafe-c290ac33a121"],
Cell[CellGroupData[{
Cell[2592112, 70996, 708, 21, 35, "Input",ExpressionUUID->"8b40e888-5d7e-474f-ba8c-e6a53854a816"],
Cell[2592823, 71019, 566, 16, 35, "Output",ExpressionUUID->"0fae188a-ce7c-4090-b1be-ba79cbe9c3c3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2593426, 71040, 269, 7, 31, "Input",ExpressionUUID->"b551254a-9a5a-4974-9dc0-22d98ce25eab"],
Cell[2593698, 71049, 1115, 36, 52, "Output",ExpressionUUID->"3277be49-5349-4d34-a9d8-7f15e8b65e47"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2594850, 71090, 853, 26, 35, "Input",ExpressionUUID->"cffb80a7-da9d-4b13-9568-9f2c5ccc611d"],
Cell[2595706, 71118, 347, 11, 52, "Output",ExpressionUUID->"354c99bd-9008-4154-a846-57d3aeb8c6f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2596090, 71134, 427, 11, 31, "Input",ExpressionUUID->"7d53b038-e08c-4985-a023-157490dcb88a"],
Cell[2596520, 71147, 568, 17, 35, "Output",ExpressionUUID->"72e7244b-0456-4eca-b4f2-1d62000a0641"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2597125, 71169, 270, 7, 31, "Input",ExpressionUUID->"1e8c0f20-56da-4687-bc25-7486f4363858"],
Cell[2597398, 71178, 1164, 37, 52, "Output",ExpressionUUID->"3999f0c7-f639-4a0a-85d1-422dfaf36626"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2598599, 71220, 693, 21, 35, "Input",ExpressionUUID->"af1fed60-8e4c-43f1-b8d0-b50c29f0731b"],
Cell[2599295, 71243, 345, 11, 52, "Output",ExpressionUUID->"8d86c7b4-a58c-4346-82d5-7541fd8c142e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2599689, 71260, 245, 5, 60, "Subsection",ExpressionUUID->"0f773ee7-5633-4764-a0b4-45c531d7c038"],
Cell[CellGroupData[{
Cell[2599959, 71269, 161, 3, 31, "Input",ExpressionUUID->"f95994bb-ad27-488c-9229-b1b2e8cbc643"],
Cell[2600123, 71274, 1087, 33, 59, "Output",ExpressionUUID->"aad57d81-dc0d-4eac-82cf-0f24540baff1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2601247, 71312, 158, 3, 31, "Input",ExpressionUUID->"3dc7634e-9de6-4946-8a86-4af2a017707f"],
Cell[2601408, 71317, 380, 11, 35, "Output",ExpressionUUID->"e2104a76-6a0a-46b4-9680-627151dfc1fe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2601825, 71333, 87, 0, 31, "Input",ExpressionUUID->"5ccac34d-7d82-4aeb-aab7-c85166c1d91e"],
Cell[2601915, 71335, 1518, 46, 93, "Output",ExpressionUUID->"b4105868-ac99-4340-bf02-1c2067bc42dd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2603470, 71386, 249, 5, 31, "Input",ExpressionUUID->"84abafc8-2409-4211-a1bb-e6341fd1d097"],
Cell[2603722, 71393, 2562, 82, 172, "Output",ExpressionUUID->"8ee20102-ae18-4628-8e7a-702c52e2a137"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2606321, 71480, 930, 29, 58, "Input",ExpressionUUID->"86f01d23-f816-4f3e-a030-43202b4a5904"],
Cell[2607254, 71511, 280, 8, 35, "Output",ExpressionUUID->"f38ca781-3198-4dcc-ab30-bddc95e5e27b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2607571, 71524, 248, 5, 31, "Input",ExpressionUUID->"ed8e9b54-8419-4a9e-b288-960b710f77aa"],
Cell[2607822, 71531, 1828, 62, 172, "Output",ExpressionUUID->"473af762-f3c6-4238-914d-5d75d9913b36"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2609699, 71599, 282, 5, 55, "Subsection",ExpressionUUID->"6e8f8ba9-3f36-4b5a-a802-4364fb60946e"],
Cell[2609984, 71606, 745, 21, 31, "Input",ExpressionUUID->"20dc2ef4-c83c-47ce-95e6-7fce8abf2874"],
Cell[2610732, 71629, 266, 6, 37, "Text",ExpressionUUID->"97135793-8073-4b2e-a596-391ac9774fbd"],
Cell[2611001, 71637, 1174, 33, 124, "Input",ExpressionUUID->"ce3789f7-6e2c-4abd-882e-e0fb91af6236"],
Cell[2612178, 71672, 152, 3, 31, "Input",ExpressionUUID->"588fdb5c-20a9-4b7a-a181-ed1742f0ff54"],
Cell[2612333, 71677, 269, 6, 31, "Input",ExpressionUUID->"96dddb66-9342-4adc-a829-a08c08c59af8"],
Cell[CellGroupData[{
Cell[2612627, 71687, 254, 6, 31, "Input",ExpressionUUID->"16bbb3db-d923-4fff-88a4-1dda4445ee8c"],
Cell[2612884, 71695, 3645, 68, 242, "Output",ExpressionUUID->"d78789c3-8028-446d-803e-4c210b99da0d"]
}, Closed]],
Cell[2616544, 71766, 355, 7, 27, "Input",ExpressionUUID->"c3d94627-7394-479e-a2c7-4da67e5823b6"],
Cell[CellGroupData[{
Cell[2616924, 71777, 264, 7, 31, "Input",ExpressionUUID->"e89362b7-0a4e-4fa5-b9dd-0aaa71b8638f"],
Cell[2617191, 71786, 243, 7, 35, "Output",ExpressionUUID->"eb678012-3d78-4bcf-80be-d29d33f17151"]
}, Open  ]],
Cell[2617449, 71796, 308, 6, 31, "Input",ExpressionUUID->"ec2d21fa-c08d-46de-b7b6-875724ed9dba"],
Cell[CellGroupData[{
Cell[2617782, 71806, 276, 7, 31, "Input",ExpressionUUID->"262bdb2d-63ea-496c-bfb1-0267717bf7de"],
Cell[2618061, 71815, 4915, 118, 170, "Output",ExpressionUUID->"08ab67c5-2496-4957-9b3a-c70ec8c9e970"]
}, Closed]],
Cell[2622991, 71936, 289, 7, 27, "Input",ExpressionUUID->"f4455f83-005d-4476-9f35-4d08658e573d"],
Cell[CellGroupData[{
Cell[2623305, 71947, 545, 15, 31, "Input",ExpressionUUID->"1e8a6f31-ffac-4230-8bf5-93fce4e6820d"],
Cell[2623853, 71964, 701, 21, 35, "Output",ExpressionUUID->"0e6e3203-c4ee-4d41-8370-c615b0980937"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2624591, 71990, 291, 5, 45, "Subsubsection",ExpressionUUID->"bb2ee3ea-4385-4af4-969b-ea0935e794de"],
Cell[CellGroupData[{
Cell[2624907, 71999, 378, 10, 31, "Input",ExpressionUUID->"728f4214-f101-423a-adf3-70388deebe98"],
Cell[2625288, 72011, 997, 25, 59, "Output",ExpressionUUID->"f36382ec-4ef1-40dd-9856-47036d5128f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2626322, 72041, 513, 13, 31, "Input",ExpressionUUID->"dfd6d525-f664-4df8-afb8-eb61bb50680f"],
Cell[2626838, 72056, 977, 25, 59, "Output",ExpressionUUID->"b9ed29e5-da8e-4d1e-aa1e-1cd152ba1959"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2627852, 72086, 241, 6, 31, "Input",ExpressionUUID->"c70fd04e-08e5-4c76-9bdc-9c5befdd6378"],
Cell[2628096, 72094, 992, 25, 59, "Output",ExpressionUUID->"20fba401-2c8f-4df7-9a72-1e6ce22733b3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2629125, 72124, 212, 5, 31, "Input",ExpressionUUID->"8c8d40c1-1fb7-4236-bc89-40b7cf641893"],
Cell[2629340, 72131, 664, 19, 59, "Output",ExpressionUUID->"cbda5880-f6e7-4812-b320-9920df584b4a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2630041, 72155, 288, 8, 31, "Input",ExpressionUUID->"b874b9b3-4f88-4926-b287-9247266ff9e6"],
Cell[2630332, 72165, 519, 14, 35, "Output",ExpressionUUID->"43095691-a7f9-4756-94a2-b665697dec01"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2630888, 72184, 1639, 42, 101, "Input",ExpressionUUID->"5879ab8b-ffd6-48b6-9576-053b50cb31c0"],
Cell[2632530, 72228, 2089, 50, 128, "Output",ExpressionUUID->"97646823-07f7-4fd0-b072-734335ac17ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2634656, 72283, 173, 4, 31, "Input",ExpressionUUID->"8022f630-c9c9-424d-89c8-b0f16479deab"],
Cell[2634832, 72289, 2190, 52, 128, "Output",ExpressionUUID->"8eb0e034-0477-470a-b4f8-9bbf38ccc1d7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2637059, 72346, 349, 10, 31, "Input",ExpressionUUID->"aacbaa7d-23c3-4ccd-84fb-9d76469a265f"],
Cell[2637411, 72358, 409, 9, 35, "Output",ExpressionUUID->"cfd54a0a-9d34-452d-a249-9d2c7916e86c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2637869, 72373, 566, 15, 123, "Subsubsection",ExpressionUUID->"8b679976-3c63-43af-ad24-28426480b79d"],
Cell[CellGroupData[{
Cell[2638460, 72392, 632, 17, 55, "Input",ExpressionUUID->"aebb3569-e017-430a-9ad1-4b41e35c3872"],
Cell[2639095, 72411, 628, 16, 35, "Output",ExpressionUUID->"e227f4a6-6a77-4844-a0ec-6ecca6d9cdc5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2639760, 72432, 681, 17, 31, "Input",ExpressionUUID->"31951883-09d0-472e-b773-db2f64779211"],
Cell[2640444, 72451, 366, 10, 35, "Output",ExpressionUUID->"0f01bd0f-a376-455c-9339-54f2f4a44fdc"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2640859, 72467, 273, 7, 71, "Subsubsection",ExpressionUUID->"8898f12e-d68a-4e38-85b4-844a06d24a07"],
Cell[CellGroupData[{
Cell[2641157, 72478, 200, 4, 31, "Input",ExpressionUUID->"76dd7336-beaf-4a49-9618-036b2f540450"],
Cell[2641360, 72484, 2560, 82, 172, "Output",ExpressionUUID->"5dbf3e10-b8ce-4ef9-b8a8-fa4e97a7148e"]
}, Closed]],
Cell[CellGroupData[{
Cell[2643957, 72571, 494, 15, 27, "Input",ExpressionUUID->"c7fc41b6-e358-49a5-ba83-fe90ccc644f0"],
Cell[2644454, 72588, 2373, 74, 93, "Output",ExpressionUUID->"ff494ee5-4a52-4f7b-91f6-659a702c9bd3"]
}, Closed]],
Cell[CellGroupData[{
Cell[2646864, 72667, 185, 4, 27, "Input",ExpressionUUID->"263c9fbe-5f0f-4541-aa18-49456530ec3b"],
Cell[2647052, 72673, 4458, 142, 172, "Output",ExpressionUUID->"bf2b90a2-fa27-4e2a-ba00-c3b9baf406c7"]
}, Open  ]],
Cell[2651525, 72818, 275, 6, 37, "Text",ExpressionUUID->"5447b17c-1377-47fc-bfbe-b2588b12c2ae"],
Cell[CellGroupData[{
Cell[2651825, 72828, 5647, 171, 233, "Input",ExpressionUUID->"82996c19-553d-46c9-bcae-fe997c51e79c"],
Cell[2657475, 73001, 3828, 120, 172, "Output",ExpressionUUID->"73b29324-ec76-46c6-a40c-852a90d39694"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2661340, 73126, 280, 6, 31, "Input",ExpressionUUID->"a2645a1c-d924-44a8-8f74-b251d86f5c4d"],
Cell[2661623, 73134, 1850, 62, 172, "Output",ExpressionUUID->"76b5d9a2-3d9b-4d53-b7f9-38a759b847e4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2663510, 73201, 443, 12, 31, "Input",ExpressionUUID->"5992a122-3c58-42ab-8553-baa93d4735cc"],
Cell[2663956, 73215, 511, 13, 52, "Output",ExpressionUUID->"fd1be11e-eb1f-4334-ab1d-0f6aad8f9c7e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2664504, 73233, 443, 12, 31, "Input",ExpressionUUID->"127fccc9-e871-4657-8657-61808f6874db"],
Cell[2664950, 73247, 1555, 43, 105, "Output",ExpressionUUID->"156db2b1-8dc6-4cb5-8f0e-382bac48b45d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2666542, 73295, 251, 6, 31, "Input",ExpressionUUID->"613f8e85-2de0-4c7f-bff0-838521c4043e"],
Cell[2666796, 73303, 163, 3, 35, "Output",ExpressionUUID->"96f5c0fb-c3c6-430b-9dbf-b13d17acd2ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2666996, 73311, 817, 23, 31, "Input",ExpressionUUID->"bf86a4be-c25b-409b-998c-fc285c65c338"],
Cell[2667816, 73336, 15887, 418, 727, "Output",ExpressionUUID->"cda9554f-718c-4ea3-a10b-0d35758a1b8c"]
}, Closed]],
Cell[CellGroupData[{
Cell[2683740, 73759, 900, 26, 27, "Input",ExpressionUUID->"a111f1aa-4790-4ba9-a454-69035e80cc12"],
Cell[2684643, 73787, 819, 20, 59, "Output",ExpressionUUID->"4e1361f9-cb88-4479-86b1-268d39c14616"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2685499, 73812, 420, 10, 31, "Input",ExpressionUUID->"2ec76564-c2fc-4530-8259-cc0c3dd363c2"],
Cell[2685922, 73824, 331, 7, 35, "Output",ExpressionUUID->"4a359c9f-af06-4bfb-84e8-56320bf1c28f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2686302, 73837, 202, 3, 45, "Subsubsection",ExpressionUUID->"090340f9-d18e-4386-9ab7-2713aefa5e0d"],
Cell[2686507, 73842, 170, 4, 31, "Input",ExpressionUUID->"d21aad07-eee0-48bf-930a-9fc6f3a9c5b8"],
Cell[CellGroupData[{
Cell[2686702, 73850, 1090, 27, 31, "Input",ExpressionUUID->"d08c4d4d-4092-4002-914a-acd7df8a3b01"],
Cell[2687795, 73879, 6108, 184, 332, "Output",ExpressionUUID->"ee4a8dd8-1cd2-4796-98c3-a1169ecac87b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2693940, 74068, 1071, 27, 31, "Input",ExpressionUUID->"bfd9a233-0169-404c-b7fb-b09044222937"],
Cell[2695014, 74097, 6195, 187, 332, "Output",ExpressionUUID->"0a521b5e-f856-4f3f-a47d-e8cd27f00ad9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2701246, 74289, 1015, 26, 31, "Input",ExpressionUUID->"01a3f283-60b9-4458-89af-ce687edd6110"],
Cell[2702264, 74317, 6235, 187, 332, "Output",ExpressionUUID->"1952d420-befd-4fc5-b9c6-db98005c1311"]
}, Open  ]],
Cell[2708514, 74507, 3208, 99, 280, "Input",ExpressionUUID->"72fd4b52-065f-44bb-bce3-996047ed4c1d"],
Cell[2711725, 74608, 3063, 97, 257, "Input",ExpressionUUID->"1db74f9e-ee1e-4850-9386-d3cff4973468"],
Cell[2714791, 74707, 3017, 91, 257, "Input",ExpressionUUID->"b343c8ea-3a80-4501-9026-e52df81bb591"],
Cell[2717811, 74800, 2962, 91, 257, "Input",ExpressionUUID->"dd8d70a8-1522-457e-a747-21d6d724d620"],
Cell[2720776, 74893, 2870, 89, 257, "Input",ExpressionUUID->"d7c2ce70-d255-41f8-9384-20e9d2257381"],
Cell[2723649, 74984, 482, 9, 112, "Text",ExpressionUUID->"27469f78-e04b-407e-8456-fcf1f185173c"],
Cell[2724134, 74995, 23815, 606, 1632, "Input",ExpressionUUID->"16de1c50-3d8b-4234-866e-67b2ad1db656",
 InitializationCell->True],
Cell[2747952, 75603, 131, 3, 31, "Input",ExpressionUUID->"6cc0520d-e988-4daf-a415-a3249b347d66"],
Cell[2748086, 75608, 475, 13, 31, "Input",ExpressionUUID->"180a23dd-d82c-4f42-a1ee-a1e1426b3432"],
Cell[CellGroupData[{
Cell[2748586, 75625, 900, 26, 31, "Input",ExpressionUUID->"c4622e26-408b-4099-a776-b3822c1401e3"],
Cell[2749489, 75653, 819, 20, 59, "Output",ExpressionUUID->"20c47784-ce0c-42f6-9ca7-4fdbd325a514"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2750345, 75678, 218, 5, 31, "Input",ExpressionUUID->"28f4bb3d-c131-4120-ab64-730f7f42bc9e"],
Cell[2750566, 75685, 328, 8, 35, "Output",ExpressionUUID->"08c2a916-77fc-47b8-92d0-c08e3245f6c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2750931, 75698, 255, 6, 31, "Input",ExpressionUUID->"8b23ba7e-e6cd-4a8a-9266-59ada3dac772"],
Cell[2751189, 75706, 666, 19, 59, "Output",ExpressionUUID->"64ff0906-630d-461d-a7c0-806383da49de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2751892, 75730, 211, 5, 31, "Input",ExpressionUUID->"8f655ce1-8887-47a1-b77b-41a10f291497"],
Cell[2752106, 75737, 664, 19, 59, "Output",ExpressionUUID->"d510948a-fd47-42da-a15a-c986be37adf1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2752807, 75761, 252, 6, 31, "Input",ExpressionUUID->"ef9a8765-b315-44c9-85ff-8816a3c0aabf"],
Cell[2753062, 75769, 325, 8, 35, "Output",ExpressionUUID->"11b9ac54-6b8f-45e4-a454-71f44d62d5a4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2753424, 75782, 214, 5, 31, "Input",ExpressionUUID->"99f5afd3-93c5-43f1-865c-dd80776e0ddb"],
Cell[2753641, 75789, 1019, 27, 59, "Output",ExpressionUUID->"0eae39f1-b024-4c10-a3ca-4378ca268ac4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2754697, 75821, 309, 8, 31, "Input",ExpressionUUID->"cea869db-0c30-4aec-944c-1b7154dfe749"],
Cell[2755009, 75831, 311, 8, 35, "Output",ExpressionUUID->"35bed5fb-8c6b-4041-8b49-3b9821c563de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2755357, 75844, 256, 6, 31, "Input",ExpressionUUID->"ab4e7038-60f1-468d-8e17-96707d302743"],
Cell[2755616, 75852, 320, 8, 35, "Output",ExpressionUUID->"da7e8463-9adc-4db3-9df8-82c17831aed3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2755973, 75865, 516, 14, 55, "Input",ExpressionUUID->"2c167861-3141-43d0-ae03-66ce3b37500e"],
Cell[2756492, 75881, 148, 3, 35, "Output",ExpressionUUID->"6906cc3a-5ae6-48d7-ad9e-7b8fef1bafea"]
}, Open  ]],
Cell[2756655, 75887, 253, 5, 37, "Text",ExpressionUUID->"c9fae57b-ac56-43dc-8ddb-62c3e7b81ba7"],
Cell[CellGroupData[{
Cell[2756933, 75896, 187, 4, 31, "Input",ExpressionUUID->"0ac097cb-116e-4f7e-aecc-ceb337562214"],
Cell[2757123, 75902, 296, 8, 35, "Output",ExpressionUUID->"fad37f6a-15d1-4196-bfef-4231bf78d0ff"]
}, Open  ]],
Cell[2757434, 75913, 332, 7, 82, "Text",ExpressionUUID->"fcccf5e8-61e5-4755-bdb3-6066c66962ba"],
Cell[CellGroupData[{
Cell[2757791, 75924, 187, 4, 31, "Input",ExpressionUUID->"fc4c3097-74d4-4dd8-8709-c950ca572f21"],
Cell[2757981, 75930, 289, 6, 35, "Output",ExpressionUUID->"d357fd82-567e-417d-aace-ddfc138a3b38"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2758307, 75941, 416, 11, 31, "Input",ExpressionUUID->"45433c52-7a1a-4c71-9f89-17ac6d07be14"],
Cell[2758726, 75954, 1309, 37, 82, "Output",ExpressionUUID->"819c2668-472e-4b20-ad3a-3bcd0a2116a0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2760084, 75997, 388, 9, 97, "Subsubsection",ExpressionUUID->"867f88fc-739f-4950-9634-6fdad66baf8a"],
Cell[CellGroupData[{
Cell[2760497, 76010, 514, 14, 31, "Input",ExpressionUUID->"354d0bc6-7e15-4442-a834-8b447ae2c94b"],
Cell[2761014, 76026, 309, 7, 35, "Output",ExpressionUUID->"e2b963b4-5dd7-437c-ae62-d2eef9205f87"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[2761362, 76038, 356, 6, 83, "Subsection",ExpressionUUID->"2d322cad-43ce-4c91-911a-a342e1d51cf5"],
Cell[2761721, 76046, 424, 7, 95, "Subsection",ExpressionUUID->"9fc61eea-1a2d-4b47-be51-f77c9f332ee4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2762194, 76059, 378, 8, 103, "Subchapter",ExpressionUUID->"e9f101fe-f952-4de2-9348-8bd43d7143a9"],
Cell[CellGroupData[{
Cell[2762597, 76071, 284, 7, 31, "Input",ExpressionUUID->"b1ab3183-a210-4824-a8a8-c55c26894a35"],
Cell[2762884, 76080, 2447, 69, 86, "Output",ExpressionUUID->"d2937f02-b456-4fa3-b3cc-02fea6b8f44e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2765368, 76154, 379, 6, 83, "Subsection",ExpressionUUID->"54625e08-5e18-4db0-a5d5-b52864239f3b"],
Cell[CellGroupData[{
Cell[2765772, 76164, 428, 12, 31, "Input",ExpressionUUID->"72a14f17-02a7-497f-9f08-d918e220c35c"],
Cell[2766203, 76178, 393, 12, 35, "Output",ExpressionUUID->"79c90fda-4507-487c-b99e-4c638101ff4e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2766633, 76195, 408, 12, 31, "Input",ExpressionUUID->"3143e5ab-c83e-46d9-9468-d4dc5a0e11b7"],
Cell[2767044, 76209, 410, 12, 35, "Output",ExpressionUUID->"aaca863b-7427-4a0f-b633-1e9768ece16d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2767491, 76226, 415, 12, 31, "Input",ExpressionUUID->"e24a16a2-019d-424c-bf99-f2a9a0f7d744"],
Cell[2767909, 76240, 413, 13, 35, "Output",ExpressionUUID->"c9101bb8-83f9-4743-8f7f-131f79d892bb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2768359, 76258, 3282, 102, 283, "Input",ExpressionUUID->"49fd5125-300e-40e6-9f74-ac6a1ed466e8"],
Cell[2771644, 76362, 1174, 38, 80, "Output",ExpressionUUID->"44c7eb48-6d6b-4502-9c67-bd2d93b3737d"]
}, Open  ]],
Cell[2772833, 76403, 1391, 40, 58, "Input",ExpressionUUID->"047a741c-e85e-4932-91ba-bb01ddbb304d"],
Cell[2774227, 76445, 2703, 74, 134, "Input",ExpressionUUID->"75e1b6c5-3a6f-4447-8d4e-f860bb0611f7"],
Cell[CellGroupData[{
Cell[2776955, 76523, 396, 11, 31, "Input",ExpressionUUID->"93cefd13-46eb-467b-b8e1-8b679616c074"],
Cell[2777354, 76536, 963, 29, 39, "Output",ExpressionUUID->"365224d0-c0fa-4cff-abbc-6e8900925cb7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2778354, 76570, 246, 7, 31, "Input",ExpressionUUID->"5328f72c-9087-4b2f-91b8-4ee900f786d9"],
Cell[2778603, 76579, 890, 30, 39, "Output",ExpressionUUID->"53481ff8-b671-44cd-9844-4c102fd8df11"]
}, Open  ]],
Cell[2779508, 76612, 769, 18, 31, "Input",ExpressionUUID->"a9b81567-ee6d-439f-92e5-1afbdccf455b"],
Cell[CellGroupData[{
Cell[2780302, 76634, 1453, 45, 81, "Input",ExpressionUUID->"ae0cf2a4-8ac4-414f-beb3-b7fd544342d6"],
Cell[2781758, 76681, 202, 4, 35, "Output",ExpressionUUID->"78ab691d-8716-443d-927f-0ebbbe2404da"]
}, Open  ]],
Cell[2781975, 76688, 630, 16, 31, "Input",ExpressionUUID->"77b1ddde-8545-4d5c-9a3b-862bc78ff7d7"],
Cell[CellGroupData[{
Cell[2782630, 76708, 1315, 41, 81, "Input",ExpressionUUID->"7fbb1a98-4605-4857-8407-341fd5ef0d28"],
Cell[2783948, 76751, 130, 3, 35, "Output",ExpressionUUID->"866fd94f-9b6c-4a8b-9cbb-e5fb9642c4b2"]
}, Open  ]],
Cell[2784093, 76757, 632, 16, 31, "Input",ExpressionUUID->"4ab39b15-2528-4324-b6f0-bdd23ee62089"],
Cell[CellGroupData[{
Cell[2784750, 76777, 1144, 33, 81, "Input",ExpressionUUID->"a6e8ed35-fdb3-41ec-9ad1-f4f9ae94cdf8"],
Cell[2785897, 76812, 782, 24, 39, "Output",ExpressionUUID->"0ce946b8-0002-4363-abab-945ca6622138"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2786716, 76841, 958, 25, 62, "Input",ExpressionUUID->"a4aa7674-eb9a-4e25-b821-a7fdfeac2adb"],
Cell[2787677, 76868, 130, 3, 35, "Output",ExpressionUUID->"64653358-5246-4433-8a4a-639bd1532408"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2787844, 76876, 387, 9, 71, "Subsubsection",ExpressionUUID->"564f0c08-6fe6-4750-8eea-bde2429770e6"],
Cell[2788234, 76887, 556, 14, 31, "Input",ExpressionUUID->"94402875-1b7f-46ba-bb16-766aa1f5a66d"],
Cell[2788793, 76903, 561, 14, 31, "Input",ExpressionUUID->"1a6217fb-322a-4f78-89ac-47d3ec67276e"],
Cell[CellGroupData[{
Cell[2789379, 76921, 217, 5, 31, "Input",ExpressionUUID->"7ba3309a-c851-4b8f-b9a0-676145ee206b"],
Cell[2789599, 76928, 1454, 42, 82, "Output",ExpressionUUID->"1022d30a-f326-47a6-b421-a83127ed3ef5"]
}, Open  ]],
Cell[2791068, 76973, 1395, 45, 97, "Input",ExpressionUUID->"30413919-ddc3-45fe-869f-b8eb29cd7829",
 InitializationCell->True],
Cell[2792466, 77020, 1147, 34, 74, "Input",ExpressionUUID->"d1db127b-580d-48ef-ba68-1d21e76bacd1",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2793638, 77058, 1174, 32, 55, "Input",ExpressionUUID->"2472035c-8a56-4eb0-9981-d3418b2958f8"],
Cell[2794815, 77092, 2253, 67, 93, "Output",ExpressionUUID->"17f9543f-c0a6-4550-a7dc-c52552ce8b3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2797105, 77164, 430, 13, 31, "Input",ExpressionUUID->"33f14055-47d6-4c0e-b767-891d5069fe7f"],
Cell[2797538, 77179, 185, 5, 35, "Output",ExpressionUUID->"c6899f01-8391-4bac-ad0f-f9babe82933e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2797784, 77191, 319, 6, 55, "Subsection",ExpressionUUID->"2a597259-8922-4d10-9997-c726d540a2d1"],
Cell[CellGroupData[{
Cell[2798128, 77201, 164, 3, 31, "Input",ExpressionUUID->"80f748d4-9c1a-42ef-905d-ba63c8b78ef5"],
Cell[2798295, 77206, 669, 20, 35, "Output",ExpressionUUID->"59ad59da-9cba-4e97-8081-6cabb5628015"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2799001, 77231, 165, 3, 31, "Input",ExpressionUUID->"498bc3d4-485b-42f6-abf1-f8bfd362fa47"],
Cell[2799169, 77236, 719, 21, 59, "Output",ExpressionUUID->"fdb47613-9391-4d1b-9b38-171c79d808d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2799925, 77262, 165, 3, 31, "Input",ExpressionUUID->"c46b4d97-e86d-4690-aacf-95fbbe29c098"],
Cell[2800093, 77267, 721, 21, 59, "Output",ExpressionUUID->"07f4ad45-6128-4da0-8c66-9f1723a93be0"]
}, Open  ]],
Cell[2800829, 77291, 12951, 367, 1044, "Input",ExpressionUUID->"622b51cc-9f82-4671-8b6e-70861ddddb79"],
Cell[CellGroupData[{
Cell[2813805, 77662, 283, 7, 31, "Input",ExpressionUUID->"625a1e91-f67f-4167-8181-505a1183f64d"],
Cell[2814091, 77671, 4088, 120, 172, "Output",ExpressionUUID->"24a7a406-ec94-4dfa-83ad-2f0e42ca958f"]
}, Closed]],
Cell[CellGroupData[{
Cell[2818216, 77796, 815, 23, 51, "Input",ExpressionUUID->"20818587-7d5c-4b72-9671-a81a127c0071"],
Cell[2819034, 77821, 5317, 141, 255, "Output",ExpressionUUID->"23d28412-7032-4fc0-b668-1fa5fd059390"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2824388, 77967, 206, 3, 45, "Subsubsection",ExpressionUUID->"4bf5fce4-1258-4005-bb88-b7d43e00d065"],
Cell[CellGroupData[{
Cell[2824619, 77974, 284, 7, 31, "Input",ExpressionUUID->"085b53e7-059a-4b20-928d-54afb950ac4e"],
Cell[2824906, 77983, 2447, 69, 86, "Output",ExpressionUUID->"b8fb0225-b80f-4707-a82e-5cf7c105191d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2827390, 78057, 301, 7, 31, "Input",ExpressionUUID->"cc287a30-238e-4b8a-bafe-5016934bb222"],
Cell[2827694, 78066, 1240, 30, 59, "Output",ExpressionUUID->"3ae63459-2e9b-4f73-b3c3-632bd37f735a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2828971, 78101, 275, 7, 31, "Input",ExpressionUUID->"7947e3d4-3de1-4274-9eaf-47bdd6569680"],
Cell[2829249, 78110, 1215, 30, 59, "Output",ExpressionUUID->"7b89ef2a-3368-4a6f-8634-a36399c83651"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2830501, 78145, 277, 7, 31, "Input",ExpressionUUID->"5cb3d48f-a599-4869-b5e4-d24241a8c117"],
Cell[2830781, 78154, 1215, 30, 59, "Output",ExpressionUUID->"90f87150-eada-4f85-8b8f-140621749201"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2832057, 78191, 242, 6, 107, "Section",ExpressionUUID->"32a0bcaf-052e-4fb3-a724-488027d914f6"],
Cell[CellGroupData[{
Cell[2832324, 78201, 307, 6, 45, "Subsubsection",ExpressionUUID->"69fa5f77-e559-46f1-bd9a-623fecda5ccb"],
Cell[2832634, 78209, 266, 6, 37, "Text",ExpressionUUID->"d1846b9f-6dae-4c8d-bf4f-2377d99a9f36"],
Cell[2832903, 78217, 1174, 33, 124, "Input",ExpressionUUID->"a25d2c8c-2e6a-46aa-bf60-312699149a2c"],
Cell[2834080, 78252, 152, 3, 31, "Input",ExpressionUUID->"7c901581-f4a8-4825-8fdf-56e1f25c3bd3"],
Cell[2834235, 78257, 269, 6, 31, "Input",ExpressionUUID->"824468ef-6687-43c4-a599-56ee010d8dcb"],
Cell[CellGroupData[{
Cell[2834529, 78267, 254, 6, 31, "Input",ExpressionUUID->"78ee4dc3-567d-4c01-9f61-7d8597332f4e"],
Cell[2834786, 78275, 3645, 68, 242, "Output",ExpressionUUID->"700fcaf9-13a7-4665-a6e3-2d3713696c07"]
}, Closed]],
Cell[2838446, 78346, 355, 7, 27, "Input",ExpressionUUID->"a0eb6fdd-41d9-45fa-aab1-efc97b5aab2e"],
Cell[CellGroupData[{
Cell[2838826, 78357, 264, 7, 31, "Input",ExpressionUUID->"e95eb5a4-f387-421e-ae6d-3759fafbbbc3"],
Cell[2839093, 78366, 243, 7, 35, "Output",ExpressionUUID->"dde9f8e1-457d-4667-9ac9-36f32527d0f7"]
}, Open  ]],
Cell[2839351, 78376, 289, 7, 31, "Input",ExpressionUUID->"522f2206-df5c-4365-912d-14e400295800"],
Cell[2839643, 78385, 308, 6, 31, "Input",ExpressionUUID->"27b0dbec-18c5-46bd-be7a-f18dcf5b0d77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2839988, 78396, 413, 7, 97, "Subsubsection",ExpressionUUID->"2868eda6-ad11-4944-8b52-11a861e8d383"],
Cell[2840404, 78405, 5886, 125, 242, "Input",ExpressionUUID->"240bc202-8e00-4703-8ef8-5c078e3394b1",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2846315, 78534, 305, 8, 31, "Input",ExpressionUUID->"4e6eeb9c-51e7-4abf-9509-78a82e702d81"],
Cell[2846623, 78544, 2560, 82, 172, "Output",ExpressionUUID->"545965ab-d797-4a23-821c-450d21304c6f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2849220, 78631, 826, 25, 35, "Input",ExpressionUUID->"ae712fb2-38a1-4d4b-9b4e-a72fa4af38a7"],
Cell[2850049, 78658, 937, 31, 55, "Output",ExpressionUUID->"d0055a4e-2c44-47f4-a67a-6a1cecb0ff4c"]
}, Open  ]],
Cell[2851001, 78692, 441, 12, 31, "Input",ExpressionUUID->"1e0094ff-a2f2-4d25-9279-5fe77ac789b6"],
Cell[CellGroupData[{
Cell[2851467, 78708, 280, 6, 31, "Input",ExpressionUUID->"2a2ec4af-9732-42d3-9cf0-3ce268a2b6dc"],
Cell[2851750, 78716, 1850, 62, 172, "Output",ExpressionUUID->"9804546f-c538-41da-b975-c9caad7ab325"]
}, Open  ]],
Cell[2853615, 78781, 16311, 422, 1199, "Input",ExpressionUUID->"0df779e9-a3c8-4163-adfe-5b02ad2573f1",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2869951, 79207, 213, 5, 31, "Input",ExpressionUUID->"916d03fc-9bc9-42b1-829b-3948d06c3dc4"],
Cell[2870167, 79214, 664, 19, 35, "Output",ExpressionUUID->"6e836af4-464e-4e74-8509-3f871f6b884a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2870868, 79238, 251, 6, 31, "Input",ExpressionUUID->"dd11988c-aa5a-46df-92d9-11f3578bf623"],
Cell[2871122, 79246, 1019, 27, 59, "Output",ExpressionUUID->"e139fd6a-85c5-4463-ad26-8edf29a4c13f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2872178, 79278, 214, 5, 31, "Input",ExpressionUUID->"46fba87f-ecb5-4492-bd44-8652a3966dc3"],
Cell[2872395, 79285, 1041, 27, 59, "Output",ExpressionUUID->"0005be04-4aee-43d5-bf59-883c1c5a8506"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2873473, 79317, 309, 8, 31, "Input",ExpressionUUID->"914004c9-11fa-4446-afb2-f31733377d06"],
Cell[2873785, 79327, 311, 8, 35, "Output",ExpressionUUID->"88fc40b3-7722-482b-9f2b-f3ec3a2a5ab5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2874145, 79341, 201, 3, 45, "Subsubsection",ExpressionUUID->"432462e5-be2f-47a9-b08a-af4b2417e41b"],
Cell[CellGroupData[{
Cell[2874371, 79348, 378, 10, 31, "Input",ExpressionUUID->"a410bffc-5430-4935-9273-ee014f9298a8"],
Cell[2874752, 79360, 668, 19, 35, "Output",ExpressionUUID->"ac73e5b3-f6e1-4a76-a423-6e7c178bf6ab"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2875469, 79385, 237, 4, 45, "Subsubsection",ExpressionUUID->"73af533d-7abd-4770-904d-e412e6cdb5de"],
Cell[CellGroupData[{
Cell[2875731, 79393, 142, 3, 31, "Input",ExpressionUUID->"06370a4e-b3f2-432c-8a4f-9d4568101acd"],
Cell[2875876, 79398, 666, 19, 35, "Output",ExpressionUUID->"7f44689a-e2b1-4561-9f19-339ee9901b87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2876579, 79422, 414, 10, 78, "Input",ExpressionUUID->"d43d8a92-80c4-4ee8-bd55-e1f9e5fabeeb"],
Cell[2876996, 79434, 666, 19, 35, "Output",ExpressionUUID->"ad4ee11e-e2f2-4087-8687-af44ea2119a0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2877699, 79458, 298, 7, 31, "Input",ExpressionUUID->"635f0a44-ab0f-49b3-a2ef-fd7b24750544"],
Cell[2878000, 79467, 336, 7, 35, "Output",ExpressionUUID->"a5370445-be7c-4bb4-a2a1-8935e3bc321b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2878373, 79479, 187, 4, 31, "Input",ExpressionUUID->"ea1ab6f9-e3d1-4f96-a813-261679da8d6f"],
Cell[2878563, 79485, 317, 7, 35, "Output",ExpressionUUID->"1a65b022-a7a8-4d65-afcc-ba10ec8d27ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2878917, 79497, 233, 6, 31, "Input",ExpressionUUID->"645e4813-d9c6-4139-bdf6-415f55834fd4"],
Cell[2879153, 79505, 311, 8, 35, "Output",ExpressionUUID->"4f39a0c9-bb1f-4c21-95d4-d566f8972066"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2879525, 79520, 151, 3, 68, "Section",ExpressionUUID->"09d47710-31a7-4f36-bd93-59c343307a8f"],
Cell[CellGroupData[{
Cell[2879701, 79527, 464, 11, 31, "Input",ExpressionUUID->"0233b268-8a26-4a6f-ad5d-bc5063c0bf74"],
Cell[2880168, 79540, 2450, 70, 170, "Output",ExpressionUUID->"9c3bc960-988b-4a75-aaf0-2d002ba9f7e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2882655, 79615, 233, 6, 31, "Input",ExpressionUUID->"2015eb24-828d-42cc-a644-6d088806b10b"],
Cell[2882891, 79623, 1353, 40, 66, "Output",ExpressionUUID->"0d1d4b6f-d83a-460b-a1c6-179708cf3854"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2884281, 79668, 1381, 38, 107, "Input",ExpressionUUID->"696e4812-eb46-4d6f-be2c-10c34f23bd1c"],
Cell[2885665, 79708, 2285, 60, 151, "Output",ExpressionUUID->"11bb5624-f5aa-43f3-bd9c-f3d94dcfb4cb"]
}, Open  ]],
Cell[2887965, 79771, 441, 13, 37, "Text",ExpressionUUID->"669067b8-0d1c-44ea-9aa4-4e07ee253427"],
Cell[2888409, 79786, 1214, 31, 58, "Input",ExpressionUUID->"7c3126ec-4802-49dd-8a8b-427971215117"],
Cell[2889626, 79819, 429, 8, 37, "Text",ExpressionUUID->"94ea9652-c7e5-4337-a8b0-27f08cfae47e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[CellGroupData[{
Cell[2890080, 79831, 530, 14, 31, "Input",ExpressionUUID->"1e8cb6b0-aa89-40a9-976d-394500d6129b"],
Cell[2890613, 79847, 231, 4, 35, "Output",ExpressionUUID->"8d7a24b7-5324-476f-a015-b131d5b8f5d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2890881, 79856, 256, 6, 31, "Input",ExpressionUUID->"7274a59c-ea26-4ecb-863d-2b582f893a4e"],
Cell[2891140, 79864, 679, 17, 59, "Output",ExpressionUUID->"5293705b-0c89-4c8c-a9cc-f22386e266f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2891856, 79886, 433, 10, 31, "Input",ExpressionUUID->"968fb97e-9d0c-4bdf-a049-a4b23b5f9d7a"],
Cell[2892292, 79898, 2554, 74, 170, "Output",ExpressionUUID->"1b32cdc0-4e5d-457f-ab9e-99922770d1b1"]
}, Open  ]],
Cell[2894861, 79975, 496, 9, 58, "Text",ExpressionUUID->"e82ca50e-97f5-419d-8733-a93da837ff34"],
Cell[CellGroupData[{
Cell[2895382, 79988, 971, 25, 35, "Input",ExpressionUUID->"0ba883db-2747-4d8f-83f4-4afc9e13830e"],
Cell[2896356, 80015, 1160, 32, 59, "Output",ExpressionUUID->"a118077f-7f62-4555-9890-6937fbabb87a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2897553, 80052, 603, 20, 35, "Input",ExpressionUUID->"198fe20f-af1c-4fa9-b002-88e9b4c10fc2"],
Cell[2898159, 80074, 864, 24, 59, "Output",ExpressionUUID->"3678dd18-2b90-4642-8047-fc977dfda77d"]
}, Open  ]],
Cell[2899038, 80101, 154, 3, 31, "Input",ExpressionUUID->"64fd5a9e-abf0-4b48-a6c1-9d72f394f716"],
Cell[CellGroupData[{
Cell[2899217, 80108, 231, 4, 55, "Subsection",ExpressionUUID->"2b23e24f-021e-4d1e-be66-eb84326e5151"],
Cell[CellGroupData[{
Cell[2899473, 80116, 467, 14, 31, "Input",ExpressionUUID->"3b0f4c26-a51c-4b0a-a9e2-80b171c9fb8b"],
Cell[2899943, 80132, 34621, 876, 1342, "Output",ExpressionUUID->"4a935d7c-2882-488e-ba45-c2b680a36246"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2934625, 81015, 156, 2, 68, "Section",ExpressionUUID->"a80d2cd5-7fee-4bba-88ab-3d0ddc89456b"],
Cell[CellGroupData[{
Cell[2934806, 81021, 661, 18, 47, "Text",ExpressionUUID->"a0007cfc-d553-4d02-9cad-79baf854c4d4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2935470, 81041, 625, 15, 31, "Input",ExpressionUUID->"885e5a96-4d43-4811-9ed9-33b01d5e3924",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2936098, 81058, 467, 13, 31, "Input",ExpressionUUID->"cf64b268-437f-4c47-b289-55e1bbea4f4d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2936568, 81073, 407, 11, 35, "Output",ExpressionUUID->"a731074d-0ce4-4555-97f8-66c2174417ef",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2936978, 81086, 1044, 28, 55, "Input",ExpressionUUID->"4b419a38-b5c0-457f-ad9f-14552104bfaa",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2938025, 81116, 516, 15, 39, "Output",ExpressionUUID->"12b7fd20-e8b7-4993-8535-2eb6e6fe0a0b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2938544, 81133, 343, 8, 31, "Input",ExpressionUUID->"d363e8c1-bb2c-4e4a-b518-beb24b9e3a16",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2938890, 81143, 669, 20, 39, "Output",ExpressionUUID->"9004ac4c-960d-4f54-a54d-cdb355f8a4d4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2939562, 81165, 758, 21, 31, "Input",ExpressionUUID->"c6517c3e-a552-4c23-a53f-212e9e73740e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2940323, 81188, 623, 18, 39, "Output",ExpressionUUID->"62b09102-7a19-47e0-8d20-8c7346ce4c70",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2940949, 81208, 1013, 26, 55, "Input",ExpressionUUID->"e4ff0e76-4ce0-4762-a9c4-ec14f4f59519",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2941965, 81236, 783, 23, 39, "Output",ExpressionUUID->"6b79fd25-ee36-415a-a742-1016ca59f734",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2942751, 81261, 549, 15, 31, "Input",ExpressionUUID->"df4ec2c7-9c9b-4bb5-a5a7-0b481088e3d3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2943303, 81278, 550, 16, 39, "Output",ExpressionUUID->"ed24a996-f9bb-4714-b6db-b0d2dad54fcc",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2943856, 81296, 300, 5, 35, "Text",ExpressionUUID->"17cb2650-636f-42f1-9c71-84792bb0bd11",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2944159, 81303, 575, 15, 31, "Input",ExpressionUUID->"77d515db-cb09-4a43-9a07-554f646b3b9d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2944737, 81320, 1246, 35, 66, "Output",ExpressionUUID->"9a22414b-622c-4dd5-a5e4-b0e803cdfa2e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2945986, 81357, 662, 18, 31, "Input",ExpressionUUID->"b449b426-e1b5-40ee-8fdd-f040e1c56717",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2946651, 81377, 757, 22, 39, "Output",ExpressionUUID->"0784f127-d2b5-4da6-b343-1915522819cb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2947411, 81401, 725, 18, 55, "Input",ExpressionUUID->"24be717f-ede8-468c-a00d-d2c5b279a577",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2948139, 81421, 645, 19, 39, "Output",ExpressionUUID->"6754f1cc-ead8-4a3b-9894-6a8e714fcaf4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2948787, 81442, 928, 22, 55, "Input",ExpressionUUID->"8a330c22-738c-4ba2-8abd-f42c28de9af9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2949718, 81466, 3438, 106, 112, "Output",ExpressionUUID->"59583d9d-74ed-4216-80f3-b97deeafe9be",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2953159, 81574, 880, 23, 35, "Input",ExpressionUUID->"2a23bd89-a8cf-49a4-a8fd-81e1947d7bcb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2954042, 81599, 2733, 83, 171, "Output",ExpressionUUID->"e2d4a5eb-4463-4c6c-888b-beaae0a45d18",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[2956812, 81687, 170, 3, 55, "Subsection",ExpressionUUID->"4ccd378b-7b2e-4877-8050-37b3ff4771b6"],
Cell[CellGroupData[{
Cell[2957007, 81694, 529, 12, 31, "Input",ExpressionUUID->"d298f582-c78f-41e2-938d-46e69de090c1"],
Cell[2957539, 81708, 420, 10, 35, "Output",ExpressionUUID->"8297f02c-32ae-4ba2-af38-1e125e80000c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2957996, 81723, 831, 23, 31, "Input",ExpressionUUID->"94e79792-4568-4124-90b4-788741a682dc"],
Cell[2958830, 81748, 3797, 111, 174, "Output",ExpressionUUID->"007c6cae-74ad-4ddc-8ac0-8cac7e0e72f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2962664, 81864, 416, 11, 31, "Input",ExpressionUUID->"7c7050fb-b127-47ce-ba43-8e98661b80fc"],
Cell[2963083, 81877, 3149, 95, 120, "Output",ExpressionUUID->"ca16a347-8989-4a94-951d-2da1b41c7ea8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2966269, 81977, 537, 12, 31, "Input",ExpressionUUID->"4ed188b1-3f1e-4bf8-b818-9ab04f9c2494"],
Cell[2966809, 81991, 2214, 69, 85, "Output",ExpressionUUID->"f9c41d7d-10eb-4d80-9abe-2edd2498a128"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2969060, 82065, 200, 3, 31, "Input",ExpressionUUID->"4bd46fd2-d59a-4555-8aca-f07411f7e15b"],
Cell[2969263, 82070, 155, 2, 35, "Output",ExpressionUUID->"91123455-b586-4f62-b2a2-fc797b07518c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2969455, 82077, 438, 10, 31, "Input",ExpressionUUID->"7c0e73a4-de32-4f33-8608-9ca3c9540553"],
Cell[2969896, 82089, 408, 11, 35, "Output",ExpressionUUID->"97b54688-1f2c-4cb8-9f6a-160e4977e538"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2970341, 82105, 676, 18, 31, "Input",ExpressionUUID->"eaea894d-3617-40bb-986c-f0510859520f"],
Cell[2971020, 82125, 4394, 133, 138, "Output",ExpressionUUID->"67f3fe60-a02f-4665-b566-d44231b508ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2975451, 82263, 295, 6, 31, "Input",ExpressionUUID->"0735c3b0-0c7f-44ce-aab5-777f110c1083"],
Cell[2975749, 82271, 158, 2, 35, "Output",ExpressionUUID->"0e50e260-d8c2-4fcf-a8d8-568a3716c52c"]
}, Open  ]],
Cell[2975922, 82276, 290, 6, 31, "Input",ExpressionUUID->"b0958fd7-c384-4aea-8687-95900891919f"],
Cell[CellGroupData[{
Cell[2976237, 82286, 171, 3, 45, "Subsubsection",ExpressionUUID->"3c5b377f-c54a-4528-b61e-3ca225511422"],
Cell[2976411, 82291, 699, 19, 51, "Input",ExpressionUUID->"811a5327-370c-4962-96cb-43d826721917",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2977135, 82314, 351, 8, 31, "Input",ExpressionUUID->"e1cb6280-5ef3-4d16-8678-b2f210ff0f0e"],
Cell[2977489, 82324, 175, 2, 35, "Output",ExpressionUUID->"a29ff2ff-23ba-48f7-bbd7-77d4d3b4c16b"]
}, Open  ]],
Cell[2977679, 82329, 256, 8, 31, "Input",ExpressionUUID->"97ccaf42-4354-4283-b6d1-eb058b142856"],
Cell[CellGroupData[{
Cell[2977960, 82341, 1051, 31, 55, "Input",ExpressionUUID->"d1a7caf0-1f1f-4fbc-9969-f0dc42c3a396"],
Cell[2979014, 82374, 5801, 178, 254, "Output",ExpressionUUID->"7a8f7491-0451-4f90-bc97-8f305f283f75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2984852, 82557, 524, 12, 31, "Input",ExpressionUUID->"1f1dcd15-7163-471d-8c1f-85e5616f4ecc"],
Cell[2985379, 82571, 4084, 126, 147, "Output",ExpressionUUID->"d99c3ec6-a77e-4841-92cc-e60e5f6e8ac8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2989500, 82702, 672, 18, 31, "Input",ExpressionUUID->"e33fb621-421b-40e0-aa40-c16acb6a9181"],
Cell[2990175, 82722, 6465, 180, 238, "Output",ExpressionUUID->"033a7a64-aa37-4349-93fe-366384bcccc6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2996677, 82907, 198, 3, 31, "Input",ExpressionUUID->"b078504b-9d8a-4f9e-91a6-a415e3eb8192"],
Cell[2996878, 82912, 156, 2, 35, "Output",ExpressionUUID->"1b70b527-7be3-4a9d-bd8e-3ce70b60e290"]
}, Open  ]],
Cell[2997049, 82917, 499, 15, 62, "Text",ExpressionUUID->"f57c4268-ac10-4948-9dff-45aa4fd148c9"],
Cell[CellGroupData[{
Cell[2997573, 82936, 396, 10, 31, "Input",ExpressionUUID->"6e919e1d-5e76-4b8f-af15-3b13a6a32fe9"],
Cell[2997972, 82948, 182, 2, 35, "Output",ExpressionUUID->"1c5dacc5-b752-4bd7-ad56-45448f5d12ba"]
}, Open  ]]
}, Open  ]],
Cell[2998181, 82954, 155, 3, 45, "Subsubsection",ExpressionUUID->"acd850ae-7226-4bba-a8c0-056bd1587c5c"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2998385, 82963, 274, 4, 68, "Section",ExpressionUUID->"7cdc8766-0b55-4339-b45c-2f5b4931f7b0"],
Cell[CellGroupData[{
Cell[2998684, 82971, 166, 3, 45, "Subsubsection",ExpressionUUID->"94050e2b-3e08-4b9a-b825-941ee545f702"],
Cell[CellGroupData[{
Cell[2998875, 82978, 465, 14, 31, "Input",ExpressionUUID->"944e2b97-b31a-4fea-b5fd-185669759c40"],
Cell[2999343, 82994, 1763, 56, 59, "Output",ExpressionUUID->"161e5717-2c08-4b1f-b571-6feb2ed9c2e2"]
}, Open  ]],
Cell[3001121, 83053, 2914, 68, 186, "Input",ExpressionUUID->"f8a6cefb-0615-49be-81b6-57c9455828a9",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3004060, 83125, 521, 13, 31, "Input",ExpressionUUID->"c16a1107-106d-499d-b1cd-3d5bdf08e3ce"],
Cell[3004584, 83140, 1789, 56, 59, "Output",ExpressionUUID->"0562dd41-023a-479b-a573-c884a7f232a7"]
}, Open  ]],
Cell[3006388, 83199, 2098, 65, 94, "Input",ExpressionUUID->"987b5aea-f10c-4bed-b425-140e5fbf73e3",
 InitializationCell->True],
Cell[3008489, 83266, 254, 6, 37, "Text",ExpressionUUID->"0890b801-d0d9-40fe-b6b1-7636cf754680"],
Cell[3008746, 83274, 1312, 35, 94, "Input",ExpressionUUID->"4e7d15e1-688d-49ac-b7ec-d87b26ff7b13",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3010083, 83313, 632, 20, 31, "Input",ExpressionUUID->"fbb92218-fd0c-4f3a-9b2e-49d95dbb4612"],
Cell[3010718, 83335, 297, 9, 35, "Output",ExpressionUUID->"a3fa7bc8-853d-4461-9d8d-40f50636e463"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3011064, 83350, 166, 3, 45, "Subsubsection",ExpressionUUID->"1686d8c9-cab4-4bc1-8f7c-4402140a57d7"],
Cell[3011233, 83355, 3816, 92, 238, "Input",ExpressionUUID->"c2126542-e73d-4223-a9a7-345e21374b91",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3015074, 83451, 275, 7, 31, "Input",ExpressionUUID->"3cb3cb1e-6a6c-4a2d-ba75-0594d67dd0d8"],
Cell[3015352, 83460, 298, 8, 35, "Output",ExpressionUUID->"361b7197-b80a-4840-b1ad-f85e4472369f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3015687, 83473, 585, 14, 31, "Input",ExpressionUUID->"67f769be-f44b-4da6-a37c-9d784f98d2d0"],
Cell[3016275, 83489, 13159, 391, 520, "Output",ExpressionUUID->"9687f1ae-1847-4edd-8650-31946cc6a888"]
}, Closed]],
Cell[3029449, 83883, 14698, 409, 623, "Input",ExpressionUUID->"d1b7705e-ad10-45d9-a9a1-bdc6caa0c0f9",
 InitializationCell->True],
Cell[3044150, 84294, 283, 6, 37, "Text",ExpressionUUID->"da9ed370-9730-4aa0-a2e6-089a3606b66a"],
Cell[3044436, 84302, 1311, 35, 94, "Input",ExpressionUUID->"cfbcf68e-7a41-4395-968a-62f3d1ad0bc2",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3045772, 84341, 663, 18, 55, "Input",ExpressionUUID->"688056b7-5556-4aac-a106-d06b71c257c2"],
Cell[3046438, 84361, 156, 3, 35, "Output",ExpressionUUID->"c5e4f7be-2c0a-44ef-a3db-a76b381e3ec0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3046643, 84370, 259, 5, 45, "Subsubsection",ExpressionUUID->"47c53e63-a183-4ca8-9a56-7d5911c1f601"],
Cell[CellGroupData[{
Cell[3046927, 84379, 1048, 31, 78, "Input",ExpressionUUID->"97964103-5295-4761-8d23-21c2af5199f4"],
Cell[3047978, 84412, 1787, 56, 59, "Output",ExpressionUUID->"300cdb7b-66c2-4bdc-b673-172c4e625312"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3049802, 84473, 461, 14, 31, "Input",ExpressionUUID->"9f7c13cb-c65e-488b-8149-e1c6e19833e5"],
Cell[3050266, 84489, 296, 9, 35, "Output",ExpressionUUID->"06d658e8-99c1-4ccc-868c-58dfd2f24c7f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3050599, 84503, 1067, 30, 101, "Input",ExpressionUUID->"a5cb1ff0-e7ea-4eb8-a42d-15638275469b"],
Cell[3051669, 84535, 14249, 413, 730, "Output",ExpressionUUID->"fc618714-5d33-4cc9-8425-fc2a5be2c68a"]
}, Closed]],
Cell[CellGroupData[{
Cell[3065955, 84953, 475, 12, 27, "Input",ExpressionUUID->"f3f88609-ead6-4ff1-b0ea-9dd59672029a"],
Cell[3066433, 84967, 3069, 93, 165, "Output",ExpressionUUID->"02165591-2054-439b-93d1-e9b686cc038b"]
}, Open  ]],
Cell[3069517, 85063, 14956, 422, 763, "Input",ExpressionUUID->"23afd086-745d-4f2f-b87b-031342db5d2c",
 InitializationCell->True],
Cell[3084476, 85487, 2864, 77, 166, "Input",ExpressionUUID->"cdefac51-87ee-4c23-b372-18299ee72035"],
Cell[3087343, 85566, 2083, 56, 186, "Input",ExpressionUUID->"87981f8d-0fad-4f0a-9684-3421c5c80d34",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3089451, 85626, 776, 22, 55, "Input",ExpressionUUID->"9ec90a50-b8ed-4ef8-a268-14bebba706be"],
Cell[3090230, 85650, 591, 14, 35, "Output",ExpressionUUID->"522b499c-da93-4053-aa70-7d996ffb5c9e"]
}, Open  ]],
Cell[3090836, 85667, 1647, 44, 117, "Input",ExpressionUUID->"9faa7562-4029-45b6-aed0-7aca94a1c10b",
 InitializationCell->True],
Cell[3092486, 85713, 388, 9, 47, "Input",ExpressionUUID->"3cc92e91-917d-4b4b-9c1d-0b1a0ab3fa66",
 InitializationCell->True]
}, Open  ]],
Cell[3092889, 85725, 226, 4, 45, "Subsubsection",ExpressionUUID->"a92af388-d58b-4230-893e-d36f59d88338"],
Cell[CellGroupData[{
Cell[3093140, 85733, 393, 6, 67, "Subsection",ExpressionUUID->"edfe8e7d-6d30-4020-9f96-f6e78563e10f"],
Cell[3093536, 85741, 1142, 30, 78, "Input",ExpressionUUID->"361bc0c9-f704-4519-89fb-7d9f7032ae88"],
Cell[CellGroupData[{
Cell[3094703, 85775, 613, 15, 55, "Input",ExpressionUUID->"017f380f-f3ad-42d2-ab3b-bfbddcf61968"],
Cell[3095319, 85792, 1355, 45, 39, "Output",ExpressionUUID->"c0dda40a-a920-48d0-901a-428e666fba94"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3096711, 85842, 1018, 29, 101, "Input",ExpressionUUID->"83f98ff8-c15d-4a2f-ae1c-934854f649b4"],
Cell[3097732, 85873, 14271, 413, 653, "Output",ExpressionUUID->"bd673954-c26f-42eb-b1b7-2751c1b73d64"]
}, Closed]],
Cell[CellGroupData[{
Cell[3112040, 86291, 454, 12, 27, "Input",ExpressionUUID->"e2e21244-e0ce-42be-9252-48af6c718a6f"],
Cell[3112497, 86305, 2433, 75, 172, "Output",ExpressionUUID->"b114f2d2-11f6-4437-b992-1d1b9fdf7ba3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3114967, 86385, 527, 15, 31, "Input",ExpressionUUID->"271bf5da-6286-4b1d-8061-58cdfdc997c9"],
Cell[3115497, 86402, 553, 17, 39, "Output",ExpressionUUID->"07861cbe-3da7-4d30-af1c-4c174e8c9f04"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3116087, 86424, 869, 23, 55, "Input",ExpressionUUID->"f33993d6-2499-4188-84de-9234051746eb"],
Cell[3116959, 86449, 2583, 79, 93, "Output",ExpressionUUID->"b55fe443-3a25-4c5b-9b72-3686f504d3f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3119579, 86533, 243, 5, 31, "Input",ExpressionUUID->"d5c43cd5-49a0-4386-8dea-c045c607333e"],
Cell[3119825, 86540, 638, 20, 52, "Output",ExpressionUUID->"cb1e296a-b518-4885-9463-4a02135ec867"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3120500, 86565, 524, 15, 31, "Input",ExpressionUUID->"f16162d1-51a2-49ef-b3a4-8885716901a6"],
Cell[3121027, 86582, 588, 16, 35, "Output",ExpressionUUID->"63e6483b-6f5f-446f-92dd-0504626bd5fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3121652, 86603, 251, 5, 31, "Input",ExpressionUUID->"895e7b7b-5303-4645-a3d8-2cd2e2fee160"],
Cell[3121906, 86610, 2005, 64, 92, "Output",ExpressionUUID->"a4da0eae-6bc3-4c0f-9c35-fd08ec93a860"]
}, Open  ]]
}, Open  ]],
Cell[3123938, 86678, 244, 4, 55, "Subsection",ExpressionUUID->"d14b866b-0fe9-4da8-a54f-26a6c6df3350"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3124231, 86688, 457, 14, 141, "Subchapter",ExpressionUUID->"39d6f82b-b063-4059-b80b-73a348908f1b"],
Cell[CellGroupData[{
Cell[3124713, 86706, 161, 3, 45, "Subsubsection",ExpressionUUID->"680b7eb2-d970-4d03-8077-2f528d2e5afc"],
Cell[CellGroupData[{
Cell[3124899, 86713, 207, 4, 31, "Input",ExpressionUUID->"28233604-b000-489b-9fca-05d7cbc192a2"],
Cell[3125109, 86719, 218, 4, 35, "Output",ExpressionUUID->"b8b8837d-8c5a-4b49-a83e-7da7ee1cd1f0"]
}, Open  ]],
Cell[3125342, 86726, 465, 11, 31, "Input",ExpressionUUID->"07152547-4efc-42b1-901b-d752f91eb959"],
Cell[3125810, 86739, 464, 9, 31, "Input",ExpressionUUID->"4fb6632f-eb88-4ed3-bea0-4d4270424ceb"],
Cell[3126277, 86750, 581, 13, 55, "Input",ExpressionUUID->"29ffcf17-ac2f-4b34-adde-0a6c9af002fa"],
Cell[3126861, 86765, 640, 18, 101, "Input",ExpressionUUID->"ad3c4614-55de-42a4-9b1a-c9855a5652be"]
}, Open  ]],
Cell[3127516, 86786, 218, 4, 45, "Subsubsection",ExpressionUUID->"4be16454-e59a-4516-9d76-7f9186db295c"],
Cell[CellGroupData[{
Cell[3127759, 86794, 178, 3, 37, "Subsubsection",ExpressionUUID->"281d7328-b32e-4a95-9921-f9be027fbf54"],
Cell[3127940, 86799, 1017, 17, 147, "Input",ExpressionUUID->"04e47709-a1af-452d-8709-59ef7b43e4c1"],
Cell[3128960, 86818, 223, 5, 35, "Text",ExpressionUUID->"e7dc5c12-49d4-4667-a2e5-76a9929404ea"],
Cell[3129186, 86825, 833, 23, 94, "Input",ExpressionUUID->"a093c104-62cd-41eb-9bce-1370ca41f34c",
 InitializationCell->True],
Cell[3130022, 86850, 659, 19, 31, "Input",ExpressionUUID->"d22068ce-800e-41e0-b61f-06726aa4a0ca"],
Cell[3130684, 86871, 748, 22, 51, "Input",ExpressionUUID->"930e35c2-ccec-49f4-99ea-20c1697c6cae",
 InitializationCell->True],
Cell[3131435, 86895, 826, 24, 35, "Input",ExpressionUUID->"d2a5b725-b5ef-4e9f-adc7-d9838f205585"],
Cell[3132264, 86921, 2011, 48, 94, "Input",ExpressionUUID->"320cb707-92df-44e4-ad54-861ced6e81dd",
 InitializationCell->True],
Cell[3134278, 86971, 1419, 34, 55, "Input",ExpressionUUID->"96fca81f-ac50-4953-ad8b-d889f55c33fa"],
Cell[3135700, 87007, 129, 3, 31, "Input",ExpressionUUID->"73d041c8-7f0b-4d2a-826b-0d874ac55228"],
Cell[CellGroupData[{
Cell[3135854, 87014, 441, 8, 82, "Text",ExpressionUUID->"4cfa7922-0326-4cc5-be53-eeaf5e47be99",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3136298, 87024, 460, 14, 31, "Input",ExpressionUUID->"bddf7b4c-3f09-4a2f-b0d7-ff66ceaaa5a6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3136761, 87040, 2728, 54, 238, "Output",ExpressionUUID->"39ff9f14-6437-4e02-944b-8e09c1d129b9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3139492, 87096, 834, 23, 31, "Input",ExpressionUUID->"8d69d136-fbba-48bf-bc90-fc517f2de028",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3140329, 87121, 3159, 60, 243, "Output",ExpressionUUID->"ead6c54b-2805-4837-b470-a1f8db770d08",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3143491, 87183, 1560, 46, 78, "Input",ExpressionUUID->"56c510ba-6ecc-4d18-8374-17518496f6d1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3145054, 87231, 22520, 564, 133, "Output",ExpressionUUID->"1ade2dab-119f-4b01-838b-6b5eec8aafad",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3167577, 87797, 1283, 30, 31, "Input",ExpressionUUID->"fd8ea783-d2ba-4324-aa46-d55019370bc3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3168863, 87829, 20741, 581, 131, "Output",ExpressionUUID->"273f7535-30f1-4153-bbde-df8b9e7900f4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3189607, 88412, 1170, 27, 31, "Input",ExpressionUUID->"94b6accf-f211-4c54-88a0-3c96bc5ee7f6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3190780, 88441, 16523, 440, 131, "Output",ExpressionUUID->"a80f0352-c3af-44ce-b5bd-8dbe9f17b6b1",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3207306, 88883, 4862, 117, 216, "Input",ExpressionUUID->"a36f9607-1c6b-40ba-be81-ad71141281f8",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3212171, 89002, 8931, 161, 522, "Output",ExpressionUUID->"1e82f836-9fb2-4848-8820-b3e08d903c55",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[3221117, 89166, 387, 7, 33, "Text",ExpressionUUID->"a4d25c03-451b-4d2e-9cb1-3704b2a9ab7c"],
Cell[3221507, 89175, 1332, 36, 140, "Input",ExpressionUUID->"3571c1fb-21dd-4bf5-8ab0-3b82aace108f",
 InitializationCell->True],
Cell[3222842, 89213, 1420, 40, 140, "Input",ExpressionUUID->"89dcecb6-9065-4114-8954-81e62972e886",
 InitializationCell->True],
Cell[3224265, 89255, 1781, 50, 140, "Input",ExpressionUUID->"abdb136f-0733-47ba-9ad6-a643805240c7",
 InitializationCell->True],
Cell[3226049, 89307, 149, 3, 55, "Input",ExpressionUUID->"99f4658b-cc69-4ccb-8dc5-afc9a973d5cd"],
Cell[3226201, 89312, 614, 18, 55, "Input",ExpressionUUID->"27e9c9c0-7486-43f2-8d97-ad6f07cfcb2d"],
Cell[3226818, 89332, 4873, 119, 324, "Input",ExpressionUUID->"72da86fa-6e86-4a50-ae22-da0ac962117d",
 InitializationCell->True],
Cell[3231694, 89453, 1489, 39, 117, "Input",ExpressionUUID->"b5268fee-91ea-4668-b094-a834801c5b62",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3233208, 89496, 233, 4, 31, "Input",ExpressionUUID->"77ccda8b-30e7-4efa-950c-8fa688a7c8d2"],
Cell[3233444, 89502, 1083, 31, 59, "Output",ExpressionUUID->"183f4e4a-afbf-4f43-972f-6c14c8204bf8"]
}, Open  ]],
Cell[3234542, 89536, 310, 7, 31, "Input",ExpressionUUID->"f3d20dde-cb85-4607-bb51-e6c21cb5d4d7"],
Cell[3234855, 89545, 2032, 53, 101, "Input",ExpressionUUID->"d57d1c12-ab26-4041-b60e-d24f302e204c"],
Cell[3236890, 89600, 4453, 99, 301, "Input",ExpressionUUID->"fee3155f-8f70-48cc-9d9a-839706b9c893",
 InitializationCell->True],
Cell[3241346, 89701, 1513, 40, 117, "Input",ExpressionUUID->"53e717f1-b102-4536-8ec2-a48265330b51",
 InitializationCell->True],
Cell[3242862, 89743, 279, 7, 31, "Input",ExpressionUUID->"e346efe5-ed5a-4c6f-bb93-f2c3969f85ab"],
Cell[3243144, 89752, 2115, 55, 124, "Input",ExpressionUUID->"77cfae44-4382-475d-826f-96c98832fb2d"],
Cell[CellGroupData[{
Cell[3245284, 89811, 256, 6, 31, "Input",ExpressionUUID->"8a43360a-7b92-4e06-a5ea-a145e758bdcd"],
Cell[3245543, 89819, 580, 18, 39, "Output",ExpressionUUID->"3feab029-828f-4a8b-bc72-52db4fe8fa88"]
}, Open  ]],
Cell[3246138, 89840, 5185, 130, 308, "Input",ExpressionUUID->"ca348f60-d745-4eb7-a69c-c6bd258cc67f"],
Cell[3251326, 89972, 2165, 56, 124, "Input",ExpressionUUID->"566eff5e-8e2c-4938-991b-fcfeab667042"],
Cell[3253494, 90030, 131, 3, 31, "Input",ExpressionUUID->"14842cdd-7bbf-4bbf-923a-a641221b3948"],
Cell[3253628, 90035, 764, 21, 47, "Input",ExpressionUUID->"e2161565-66e3-4dc3-ae7e-f75b5efaa824",
 InitializationCell->True],
Cell[3254395, 90058, 1999, 48, 140, "Input",ExpressionUUID->"1f454d67-0659-4977-b59d-dea6decc395a",
 InitializationCell->True],
Cell[3256397, 90108, 2044, 51, 140, "Input",ExpressionUUID->"e084d032-4852-4637-b33c-7ee3ed661093",
 InitializationCell->True],
Cell[3258444, 90161, 2118, 55, 163, "Input",ExpressionUUID->"388fba6a-939d-4ab4-8b5a-84cdb86b8cad",
 InitializationCell->True],
Cell[3260565, 90218, 154, 3, 31, "Input",ExpressionUUID->"e085a96e-8cbf-42c2-9124-69a9355c6d44"],
Cell[3260722, 90223, 2948, 73, 215, "Input",ExpressionUUID->"c7896208-c87b-40d6-8873-da6c8557bbbd",
 InitializationCell->True],
Cell[3263673, 90298, 4295, 99, 262, "Input",ExpressionUUID->"e59586dc-2498-43d4-9fae-cd11bb48513d"],
Cell[3267971, 90399, 2952, 81, 163, "Input",ExpressionUUID->"847957dd-b725-4875-a17b-6d1d90a22c2c",
 InitializationCell->True],
Cell[3270926, 90482, 242, 5, 37, "Text",ExpressionUUID->"fde7f90d-7298-41ba-8b93-4555732ba984"],
Cell[3271171, 90489, 1013, 29, 94, "Input",ExpressionUUID->"b84886a1-a729-44b4-907f-71bcd7c10df6",
 InitializationCell->True],
Cell[3272187, 90520, 445, 11, 31, "Input",ExpressionUUID->"fbc6b6ef-fba3-47f1-898b-6db32abcfa03"],
Cell[3272635, 90533, 1134, 30, 78, "Input",ExpressionUUID->"777fcd54-c9df-44ad-ae4a-5a54d013c30c"],
Cell[3273772, 90565, 335, 7, 62, "Text",ExpressionUUID->"68aab31b-6657-41f5-99fa-41d64d93b9d7"],
Cell[CellGroupData[{
Cell[3274132, 90576, 1048, 31, 78, "Input",ExpressionUUID->"180caba5-a344-4db9-9ba3-c3bbf9ae6a55"],
Cell[3275183, 90609, 1787, 56, 59, "Output",ExpressionUUID->"96bda185-31b6-48ab-a4d7-48620f01243f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3277007, 90670, 461, 14, 31, "Input",ExpressionUUID->"d791e78a-c93c-4cdc-8084-918756ddc316"],
Cell[3277471, 90686, 296, 9, 35, "Output",ExpressionUUID->"58121889-0dfa-4c2d-a886-082b589a51c9"]
}, Open  ]],
Cell[3277782, 90698, 2727, 75, 277, "Input",ExpressionUUID->"42395769-ce99-4ba9-bc4b-64a4ce232a03",
 InitializationCell->True],
Cell[3280512, 90775, 2434, 68, 177, "Input",ExpressionUUID->"6b30b609-ab92-4138-8d2d-808983ccb0d2",
 InitializationCell->True],
Cell[3282949, 90845, 2993, 81, 204, "Input",ExpressionUUID->"ab865f7d-5c7b-4dde-aef5-5ee5a3d7b3ea",
 InitializationCell->True],
Cell[3285945, 90928, 391, 8, 62, "Text",ExpressionUUID->"7e29f097-d74c-4fb9-9403-7ddd1f9d5d99"],
Cell[3286339, 90938, 1050, 29, 78, "Input",ExpressionUUID->"45d8481c-e3e0-42dc-bf61-e6ad71558154"],
Cell[3287392, 90969, 901, 25, 58, "Input",ExpressionUUID->"3f2f69ed-64cd-4b06-b264-ccac365ea0a1"],
Cell[3288296, 90996, 1154, 36, 62, "Input",ExpressionUUID->"25026a83-b497-4598-8e6f-1fa550ae5df6"],
Cell[CellGroupData[{
Cell[3289475, 91036, 367, 9, 31, "Input",ExpressionUUID->"393f5017-c7d2-42d0-82d7-7e4cba087bdf"],
Cell[3289845, 91047, 453, 15, 39, "Output",ExpressionUUID->"0002d1dc-83e9-4393-a208-42d1e7503a09"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3290335, 91067, 480, 13, 55, "Input",ExpressionUUID->"55d4ee17-db87-405e-9320-45bf5f4dc88d"],
Cell[3290818, 91082, 673, 23, 35, "Output",ExpressionUUID->"d234b963-c93b-4ba7-aa91-bfdc2f976ef8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3291528, 91110, 242, 5, 31, "Input",ExpressionUUID->"9f1a5f2e-8d0a-448b-907b-b7df22cbccd9"],
Cell[3291773, 91117, 296, 9, 35, "Output",ExpressionUUID->"25d6ac18-c189-4aab-a1b4-67eebdaf8697"]
}, Open  ]],
Cell[3292084, 91129, 209, 5, 37, "Text",ExpressionUUID->"97e64f99-f5f5-40ea-9a53-c513b4cf4119"],
Cell[CellGroupData[{
Cell[3292318, 91138, 465, 14, 31, "Input",ExpressionUUID->"3f142ea3-7a18-44f6-af74-2949d69cbf25"],
Cell[3292786, 91154, 1763, 56, 59, "Output",ExpressionUUID->"603a50ec-15b6-4ec8-abf4-1a158de49d7e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3294586, 91215, 311, 7, 31, "Input",ExpressionUUID->"923f262f-63ce-4ada-99fb-3e8c948e89a2"],
Cell[3294900, 91224, 584, 18, 39, "Output",ExpressionUUID->"42811f8b-cdbc-4f55-a7c1-c00a3fce74b7"]
}, Open  ]],
Cell[3295499, 91245, 988, 27, 78, "Input",ExpressionUUID->"40b79cbf-3063-4463-8a3c-fbdc60fd7935"],
Cell[3296490, 91274, 1172, 42, 142, "Input",ExpressionUUID->"a271b296-f262-41db-bfe4-dde257505d5a"],
Cell[CellGroupData[{
Cell[3297687, 91320, 489, 14, 52, "Input",ExpressionUUID->"4f0563eb-a990-4f78-a198-5ce469e8dfdb"],
Cell[3298179, 91336, 934, 33, 93, "Output",ExpressionUUID->"0b64f245-2210-4a73-944d-0101d4a8d3f5"]
}, Open  ]],
Cell[3299128, 91372, 425, 8, 87, "Text",ExpressionUUID->"8a28cf65-baac-4598-8241-96d2183848ff"],
Cell[3299556, 91382, 1111, 30, 131, "Input",ExpressionUUID->"cf1fc22a-8fba-4eba-ac75-7a02e5a66576",
 InitializationCell->True],
Cell[3300670, 91414, 2117, 60, 231, "Input",ExpressionUUID->"1159eda8-58ac-4ff7-b44c-0aabfdb5bc8a",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3302812, 91478, 390, 7, 35, "Text",ExpressionUUID->"e7c6af63-0336-432b-bd2a-46d611059b45",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3303205, 91487, 471, 13, 31, "Input",ExpressionUUID->"98650a9d-371b-433e-95b6-c3edbb2bc9cb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3303679, 91502, 2247, 78, 77, "Output",ExpressionUUID->"05510cc9-ccc8-49c9-a292-46a9a2f04659",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3305929, 91582, 2985, 91, 211, "Input",ExpressionUUID->"a8595d36-47af-49f3-a3e1-c2023e63bddb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3308917, 91675, 1040, 34, 56, "Output",ExpressionUUID->"3007bab5-5675-4029-af38-f48f279fc986",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3309960, 91711, 3187, 95, 234, "Input",ExpressionUUID->"97e41bb5-dc45-4601-a58c-6c58fc8fedcf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3313150, 91808, 1065, 35, 56, "Output",ExpressionUUID->"d7179bca-d9a1-4bb5-b801-6c683a150a8e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3314218, 91845, 318, 7, 31, "Input",ExpressionUUID->"b023223b-d2de-456c-9a7a-64dfc43ed827",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[3314539, 91854, 1159, 38, 57, "Output",ExpressionUUID->"61df1630-6bba-48dd-a299-271ec15611a3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3315747, 91898, 154, 3, 45, "Subsubsection",ExpressionUUID->"e8f79def-fc64-47ce-bdb0-ffa692049cf1"],
Cell[3315904, 91903, 1108, 30, 131, "Input",ExpressionUUID->"c9aca073-c0de-4cfd-a8e6-0ccfd0f9e8d6",
 InitializationCell->True],
Cell[3317015, 91935, 1007, 26, 103, "Input",ExpressionUUID->"c048489e-5843-4888-87ba-6c362ddafdd5",
 InitializationCell->True],
Cell[3318025, 91963, 2134, 60, 231, "Input",ExpressionUUID->"d961f2f8-902d-46a7-995b-89c7044a8d2b",
 InitializationCell->True],
Cell[3320162, 92025, 1674, 45, 162, "Input",ExpressionUUID->"86bd431b-6ab7-4d60-abf4-cd67fed72707",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3321861, 92074, 392, 12, 31, "Input",ExpressionUUID->"8a8a0806-c502-440c-9fae-ab2d8883e6d7"],
Cell[3322256, 92088, 551, 18, 52, "Output",ExpressionUUID->"8746067f-4da1-4408-a647-b8b3168cff59"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3322844, 92111, 1861, 58, 111, "Input",ExpressionUUID->"be8998fe-47c3-4f9d-8773-7319c8351da8"],
Cell[3324708, 92171, 1940, 65, 185, "Output",ExpressionUUID->"02ca4c67-4286-4ced-849d-74b3f994c98f"]
}, Open  ]],
Cell[3326663, 92239, 288, 6, 37, "Text",ExpressionUUID->"462dd013-ea2c-4063-9aac-e00aab6e9d85"],
Cell[3326954, 92247, 2540, 69, 254, "Input",ExpressionUUID->"e95233ca-5726-42ce-bb3f-092c54b0b7a7",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3329519, 92320, 1411, 38, 78, "Input",ExpressionUUID->"ee124682-bb37-4e3f-a895-26c3d472ffb8"],
Cell[3330933, 92360, 3598, 104, 151, "Output",ExpressionUUID->"c358c64f-dc0d-4b69-a497-386390359925"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3334580, 92470, 166, 3, 45, "Subsubsection",ExpressionUUID->"65253d74-a922-44c8-b2a4-b30ab91aba7e"],
Cell[3334749, 92475, 1080, 27, 71, "Input",ExpressionUUID->"7a606635-d0a9-44bd-ada0-601140eec7f8",
 InitializationCell->True],
Cell[3335832, 92504, 473, 9, 87, "Text",ExpressionUUID->"e729f671-bec8-42f2-a449-ff2f6ae2c6c5"],
Cell[3336308, 92515, 2233, 65, 212, "Input",ExpressionUUID->"521113ac-0f6e-40f3-aed6-270cc1728c88",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3338566, 92584, 404, 10, 31, "Input",ExpressionUUID->"b800e23a-8140-49bc-b40a-65ccfbb5287b"],
Cell[3338973, 92596, 449, 12, 35, "Output",ExpressionUUID->"dbd4d2a8-f2bf-4901-970f-47979669da59"]
}, Open  ]],
Cell[3339437, 92611, 489, 14, 55, "Input",ExpressionUUID->"d2c76059-9a1a-4b1b-a82e-ca9481947c6c"],
Cell[CellGroupData[{
Cell[3339951, 92629, 335, 8, 31, "Input",ExpressionUUID->"6a4f0210-07ca-402d-a4c0-77011968438b"],
Cell[3340289, 92639, 257, 7, 35, "Output",ExpressionUUID->"21766c41-0d46-48c4-b299-e84d29cfc000"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3340583, 92651, 364, 8, 31, "Input",ExpressionUUID->"f04b20aa-5cf7-402e-8a74-d716e8b41682"],
Cell[3340950, 92661, 1196, 37, 59, "Output",ExpressionUUID->"6e6937c7-ce16-404e-8b36-0e1a968cf6b9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3342183, 92703, 223, 4, 31, "Input",ExpressionUUID->"ba63b517-fb03-4c54-bd1a-3d97cfa1e8bf"],
Cell[3342409, 92709, 252, 6, 35, "Output",ExpressionUUID->"bde8da90-567d-4c91-bdeb-1ad24415c219"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3342698, 92720, 583, 14, 31, "Input",ExpressionUUID->"fc37c4c5-18dd-4421-8b75-5538778db3f2"],
Cell[3343284, 92736, 878, 25, 59, "Output",ExpressionUUID->"b4d6b3ee-7055-457f-ad32-b3b4bc61afe5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3344199, 92766, 507, 15, 31, "Input",ExpressionUUID->"71678f7b-916a-47f3-984f-a58fa4aeea70"],
Cell[3344709, 92783, 608, 14, 35, "Output",ExpressionUUID->"66725eaf-19b9-4a0e-a077-dfd8f4ac7baa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3345354, 92802, 562, 16, 31, "Input",ExpressionUUID->"d55a684f-6427-40bc-986b-d05c073ac1d6"],
Cell[3345919, 92820, 474, 13, 35, "Output",ExpressionUUID->"8cb73733-e598-4731-b5cc-643252a2c948"]
}, Open  ]],
Cell[3346408, 92836, 308, 5, 66, "Text",ExpressionUUID->"36775ba2-04c1-4e03-a564-c7806e7367c5"],
Cell[3346719, 92843, 1822, 46, 124, "Input",ExpressionUUID->"e0df8b1b-33cc-4589-a032-4450cd34d4fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3348578, 92894, 179, 3, 68, "Section",ExpressionUUID->"5914fc2c-cecf-4265-9889-11de1f33e16c"],
Cell[3348760, 92899, 348, 7, 62, "Text",ExpressionUUID->"f975894f-541d-4052-a71f-9fb66c48e0f6"],
Cell[3349111, 92908, 640, 18, 101, "Input",ExpressionUUID->"cb86dce3-0848-4d35-b8f3-e603690d732a"],
Cell[CellGroupData[{
Cell[3349776, 92930, 289, 7, 31, "Input",ExpressionUUID->"5cd53975-cfc1-4e45-bb5f-1c66cfb2f621"],
Cell[3350068, 92939, 582, 16, 35, "Output",ExpressionUUID->"dcd591e7-76e8-43dc-97ea-47d56827d917"]
}, Open  ]],
Cell[3350665, 92958, 2318, 62, 147, "Input",ExpressionUUID->"41474c14-36ee-44a7-b4ec-050cdd3b1f62"],
Cell[CellGroupData[{
Cell[3353008, 93024, 14122, 336, 676, "Input",ExpressionUUID->"7c203554-6b31-43df-a9ed-86b8a52c05d1"],
Cell[3367133, 93362, 27263, 475, 518, "Output",ExpressionUUID->"01b10f25-e59b-425d-8d4e-c6f36f28d4d6"],
Cell[3394399, 93839, 2149, 31, 77, "Message",ExpressionUUID->"6dcb44cb-cfd8-40f6-af0a-ef1ed27ee1ad"],
Cell[3396551, 93872, 2149, 31, 77, "Message",ExpressionUUID->"e5f0461e-8eb8-48e5-ac9e-f6b3e6ca60f8"],
Cell[3398703, 93905, 1863, 28, 77, "Message",ExpressionUUID->"dc12dac2-fdb8-4805-a79f-3c5833457070"],
Cell[3400569, 93935, 2067, 31, 77, "Message",ExpressionUUID->"212b660d-ffaa-420b-9878-629e5cef5968"],
Cell[3402639, 93968, 1862, 28, 77, "Message",ExpressionUUID->"663f9e84-a467-4fa7-8d48-141f117088b1"],
Cell[3404504, 93998, 1862, 28, 77, "Message",ExpressionUUID->"ef408fe5-ccd6-4160-ab8c-4947e57b9cb1"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3406427, 94033, 567, 16, 141, "Subchapter",ExpressionUUID->"56619930-cd94-434b-813c-b59c824571ed"],
Cell[CellGroupData[{
Cell[3407019, 94053, 307, 6, 55, "Subsection",ExpressionUUID->"127972be-1820-4235-afcd-d754a7424828"],
Cell[3407329, 94061, 613, 18, 55, "Input",ExpressionUUID->"648e848c-6dc2-4717-8547-b5b5d8267bdf"],
Cell[3407945, 94081, 348, 7, 62, "Text",ExpressionUUID->"2cf2422d-5870-4578-8fc2-da15f3df3f69"],
Cell[3408296, 94090, 1619, 40, 117, "Input",ExpressionUUID->"60fd37ac-cc30-4fc6-8676-1fd098cf3943",
 InitializationCell->True],
Cell[3409918, 94132, 1573, 40, 117, "Input",ExpressionUUID->"fb4d3498-7e31-41d5-a663-412bf33f5bfb",
 InitializationCell->True],
Cell[3411494, 94174, 1494, 40, 140, "Input",ExpressionUUID->"64bd816f-425e-488d-b4ca-cf7f7b161112",
 InitializationCell->True],
Cell[3412991, 94216, 1832, 51, 140, "Input",ExpressionUUID->"84a74ea7-8e5b-4a53-b453-af646d2dc212",
 InitializationCell->True],
Cell[3414826, 94269, 228, 5, 37, "Text",ExpressionUUID->"4e8e687c-15ad-426c-99de-f8aca5e0f451"],
Cell[3415057, 94276, 1544, 41, 140, "Input",ExpressionUUID->"42e29011-7da9-4e77-886e-7240e30f56ae",
 InitializationCell->True],
Cell[3416604, 94319, 1880, 51, 140, "Input",ExpressionUUID->"b17ce309-5bab-46b1-91c7-5b672a35a160",
 InitializationCell->True],
Cell[3418487, 94372, 236, 5, 37, "Text",ExpressionUUID->"bf332579-aa88-4d6d-92d3-a5b837520423"],
Cell[3418726, 94379, 3842, 105, 186, "Input",ExpressionUUID->"df76ce66-0490-4857-a7ed-2c387e1d9b2d",
 InitializationCell->True],
Cell[3422571, 94486, 4873, 115, 347, "Input",ExpressionUUID->"49fcec19-76df-4888-a426-c36ce56f4bad",
 InitializationCell->True],
Cell[3427447, 94603, 2273, 60, 163, "Input",ExpressionUUID->"aeb26364-3a83-46ef-be25-44f351d8f063",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3429745, 94667, 201, 4, 31, "Input",ExpressionUUID->"c58ac530-e7d8-4b6e-8ddc-c7744728295f"],
Cell[3429949, 94673, 172, 3, 35, "Output",ExpressionUUID->"738f9f1a-ce5a-4c59-b3fe-bcc5bff822b4"]
}, Open  ]],
Cell[3430136, 94679, 3862, 98, 301, "Input",ExpressionUUID->"d4ca227a-a38b-4598-9b9b-173f967b7d41",
 InitializationCell->True],
Cell[3434001, 94779, 2640, 65, 163, "Input",ExpressionUUID->"29613bcb-cefe-4cde-aae8-b9096f7534d7",
 InitializationCell->True],
Cell[3436644, 94846, 5922, 140, 370, "Input",ExpressionUUID->"a67936f7-86fc-44f0-8cde-c15376a2dfe1",
 InitializationCell->True],
Cell[3442569, 94988, 3642, 93, 209, "Input",ExpressionUUID->"dd08feaa-5144-4235-aa2f-e98d0510e169",
 InitializationCell->True],
Cell[3446214, 95083, 216, 3, 31, "Input",ExpressionUUID->"c752cd48-dd09-4df5-876e-79193c438b58"],
Cell[3446433, 95088, 7761, 193, 504, "Input",ExpressionUUID->"c4b1cfc4-52e6-4e44-aa9e-a5aa9f3a17d9",
 InitializationCell->True],
Cell[3454197, 95283, 482, 9, 87, "Text",ExpressionUUID->"45cbf9be-0171-4b92-9c64-911190c66844"],
Cell[3454682, 95294, 644, 15, 31, "Input",ExpressionUUID->"11b915a9-7f21-4c01-9d80-131d384e2209"],
Cell[3455329, 95311, 129, 3, 31, "Input",ExpressionUUID->"97a47a3c-8a18-49a4-99f2-efad95d58712"],
Cell[CellGroupData[{
Cell[3455483, 95318, 309, 6, 31, "Input",ExpressionUUID->"a59e4bff-045c-43c2-b214-2e36dd7a4e34"],
Cell[3455795, 95326, 285, 4, 35, "Output",ExpressionUUID->"a989f0be-68d0-4bfc-807b-b7fff611ec11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3456117, 95335, 283, 5, 31, "Input",ExpressionUUID->"58291052-a463-4db6-b5e9-16a6b6218b94"],
Cell[3456403, 95342, 1519, 37, 105, "Output",ExpressionUUID->"291e0dc4-cdb2-4394-a3ea-af6dd41b2a56"]
}, Open  ]],
Cell[3457937, 95382, 469, 12, 31, "Input",ExpressionUUID->"fee65cfd-3a7b-46e8-a6d7-f3bd02a46c28"],
Cell[3458409, 95396, 129, 3, 31, "Input",ExpressionUUID->"c4955aef-3f91-4484-b0df-bc7097593b86"],
Cell[3458541, 95401, 2632, 66, 312, "Input",ExpressionUUID->"d5f8df1f-1c96-42a8-966d-5828dafba634"],
Cell[3461176, 95469, 317, 7, 37, "Text",ExpressionUUID->"5f54b0bb-3fc8-46e4-9809-a4e5baf9bddc"],
Cell[CellGroupData[{
Cell[3461518, 95480, 825, 22, 58, "Input",ExpressionUUID->"982c0389-7e33-466f-b859-c1a09d227f3a"],
Cell[3462346, 95504, 1514, 46, 88, "Output",ExpressionUUID->"b96882cc-b248-40cd-80e1-017db029cbcb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3463897, 95555, 653, 18, 55, "Input",ExpressionUUID->"067d9e27-814b-4dda-99e0-4244397c4951"],
Cell[3464553, 95575, 160, 3, 35, "Output",ExpressionUUID->"a66feb59-2a56-47aa-a48d-cbb01598244c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3464750, 95583, 320, 7, 31, "Input",ExpressionUUID->"5fd914cc-64ef-4486-b085-3f66529a6556"],
Cell[3465073, 95592, 308, 9, 52, "Output",ExpressionUUID->"fb0d7955-4faa-4cfe-9936-afe969a9bf4e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3465418, 95606, 1146, 32, 85, "Input",ExpressionUUID->"1718d140-9e24-4cea-9cf5-399f75914fd4"],
Cell[3466567, 95640, 577, 14, 35, "Output",ExpressionUUID->"ed8f8210-c80d-4821-b3a6-b9897ccab527"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3467181, 95659, 417, 10, 31, "Input",ExpressionUUID->"527780b8-78e0-4202-9ab4-057a57e4ed15"],
Cell[3467601, 95671, 350, 8, 35, "Output",ExpressionUUID->"5fa979d5-2e2c-4bbd-aedc-86f2899415de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3467988, 95684, 697, 18, 55, "Input",ExpressionUUID->"6150a6b0-0339-4b59-931a-74f896be408c"],
Cell[3468688, 95704, 350, 9, 35, "Output",ExpressionUUID->"2db55257-6395-42d7-a6d3-5c6b58062d81"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3469075, 95718, 452, 11, 31, "Input",ExpressionUUID->"8c4a4b0b-07c9-4205-a292-7971fd708746"],
Cell[3469530, 95731, 278, 7, 35, "Output",ExpressionUUID->"55dd5d98-1a83-4a7c-a44e-13ee2cfc007f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3469845, 95743, 454, 11, 31, "Input",ExpressionUUID->"24eccf4b-8038-49fc-8cd5-813d7b9b2c9f"],
Cell[3470302, 95756, 211, 4, 35, "Output",ExpressionUUID->"7854038b-7f2d-40dc-ac32-2bda60a66dee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3470550, 95765, 2924, 78, 279, "Input",ExpressionUUID->"97671d7f-3803-4c88-bb2f-8055a83d631c"],
Cell[3473477, 95845, 1183, 21, 48, "Message",ExpressionUUID->"fe6b80f7-1751-4549-b893-ca67df31cfa5"],
Cell[3474663, 95868, 1944, 58, 135, "Output",ExpressionUUID->"9e5f636a-a7d2-449b-9ed1-49d3869fc2c4"]
}, Open  ]],
Cell[3476622, 95929, 2849, 75, 263, "Input",ExpressionUUID->"7bbac4c9-3af3-40b7-a176-ab068f824aa7"],
Cell[3479474, 96006, 329, 6, 62, "Text",ExpressionUUID->"86e12368-7700-43f6-b31b-e68045c4c9c9"],
Cell[CellGroupData[{
Cell[3479828, 96016, 2873, 74, 259, "Input",ExpressionUUID->"20f2a09b-95c3-4d65-9b52-a59c01b565d8"],
Cell[3482704, 96092, 611, 14, 35, "Output",ExpressionUUID->"f1dadec2-f48f-4042-b5e7-e80692b84525"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3483352, 96111, 268, 6, 71, "Subsubsection",ExpressionUUID->"6251c880-2efe-4810-b507-5b3ad3c331f0"],
Cell[CellGroupData[{
Cell[3483645, 96121, 673, 17, 55, "Input",ExpressionUUID->"d2452fe5-0a49-40c6-84b2-653b7a669c26"],
Cell[3484321, 96140, 259, 5, 35, "Output",ExpressionUUID->"7bdfe793-253c-408b-a88a-2616d880cfb9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3484617, 96150, 942, 24, 55, "Input",ExpressionUUID->"e3c1e0ce-3ba2-43d4-8fe1-1cdba12d2b7b"],
Cell[3485562, 96176, 230, 5, 35, "Output",ExpressionUUID->"7f67fe3a-b2bd-44b2-9f80-fac5a33635ee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3485829, 96186, 986, 24, 101, "Input",ExpressionUUID->"bd431e70-b196-405d-b083-0820d2ae1cc3"],
Cell[3486818, 96212, 245, 5, 35, "Output",ExpressionUUID->"9e85e002-f956-419f-b599-0996b330b891"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3487100, 96222, 284, 6, 31, "Input",ExpressionUUID->"ac8b130e-62c7-4a82-b4ff-eb35ef2f6a24"],
Cell[3487387, 96230, 1583, 36, 82, "Output",ExpressionUUID->"869020a6-afc2-4271-a944-b1f31f2601f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3489007, 96271, 975, 25, 78, "Input",ExpressionUUID->"58722332-f0fd-4c4e-b4b9-063540bb59ee"],
Cell[3489985, 96298, 638, 15, 35, "Output",ExpressionUUID->"95f43e4b-7c67-4dcc-9bde-c4291b95b9cb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3490660, 96318, 170, 3, 31, "Input",ExpressionUUID->"faa457d2-6988-4d60-bfc7-d56f2b48a36c"],
Cell[3490833, 96323, 611, 14, 35, "Output",ExpressionUUID->"c093ebe9-5793-40af-970d-924685f91dde"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3491493, 96343, 616, 12, 175, "Subsubsection",ExpressionUUID->"bbaa7410-f06c-40fa-9337-16ea985a56e6"],
Cell[CellGroupData[{
Cell[3492134, 96359, 407, 9, 31, "Input",ExpressionUUID->"5b7bd617-1726-48d8-9f65-67a87d09739a"],
Cell[3492544, 96370, 467, 12, 35, "Output",ExpressionUUID->"f733aeca-b63d-4cde-8ec6-9620d185dfe9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3493048, 96387, 490, 11, 31, "Input",ExpressionUUID->"5ca9e8d5-16f6-48e6-9ffa-cc1151412a34"],
Cell[3493541, 96400, 1940, 49, 137, "Output",ExpressionUUID->"a148d6e3-c12f-44f9-a715-6c5a68146174"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3495518, 96454, 406, 11, 31, "Input",ExpressionUUID->"bff49646-2a47-4cf5-8615-24eaf5a0e84c"],
Cell[3495927, 96467, 582, 14, 39, "Output",ExpressionUUID->"48f699d3-d799-4082-99d5-63a64b6306cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3496546, 96486, 460, 11, 55, "Input",ExpressionUUID->"267d560f-6485-41ec-807d-dd15ae33028f"],
Cell[3497009, 96499, 172, 3, 35, "Output",ExpressionUUID->"3cb19615-2acd-48a7-9728-a0992bc380b1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3497218, 96507, 363, 9, 31, "Input",ExpressionUUID->"4e137a18-bd79-45c4-8539-3684ca08b96f"],
Cell[3497584, 96518, 169, 3, 35, "Output",ExpressionUUID->"f1975762-5e81-45f1-9786-427de9b03877"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3497790, 96526, 332, 9, 35, "Input",ExpressionUUID->"36abfddf-d9df-4cf3-a80c-0d65af7a4269"],
Cell[3498125, 96537, 243, 6, 35, "Output",ExpressionUUID->"4c6c2fa4-8bd1-466d-9806-7b449b1ba6d4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3498405, 96548, 652, 15, 55, "Input",ExpressionUUID->"dcf2e6ea-8492-4dfa-bfde-d06d381abba3"],
Cell[3499060, 96565, 299, 7, 35, "Output",ExpressionUUID->"46149735-15d8-44ff-82bb-e043f668d639"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3499396, 96577, 234, 4, 31, "Input",ExpressionUUID->"c0571139-af89-4eb6-acfd-a8a1a8c96faa"],
Cell[3499633, 96583, 172, 3, 35, "Output",ExpressionUUID->"c45045af-bb76-4078-adc1-bb7e9da0f6d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3499842, 96591, 234, 4, 31, "Input",ExpressionUUID->"eb9f582c-403a-406a-821a-82c172984114"],
Cell[3500079, 96597, 175, 3, 35, "Output",ExpressionUUID->"a35c26a3-6718-40b3-8923-225a9efcde53"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3500303, 96606, 496, 7, 97, "Subsubsection",ExpressionUUID->"9d97b5e5-f742-4b00-a166-aba42d5fea4c"],
Cell[3500802, 96615, 131, 3, 31, "Input",ExpressionUUID->"cd321480-e1c6-49f6-b64f-dec2d9758487"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3500970, 96623, 192, 3, 45, "Subsubsection",ExpressionUUID->"ef1ac928-0274-4f41-aec6-fb317232b6a8"],
Cell[CellGroupData[{
Cell[3501187, 96630, 2739, 68, 216, "Input",ExpressionUUID->"fda7f338-ad3c-417c-ad55-4e52a83e5de7"],
Cell[3503929, 96700, 512, 11, 35, "Output",ExpressionUUID->"88fe08bc-39cd-4bae-aa9e-c55a03ccd65e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3504478, 96716, 223, 3, 31, "Input",ExpressionUUID->"269e5cbf-1844-4b4d-81eb-755987ff4a33"],
Cell[3504704, 96721, 498, 14, 35, "Output",ExpressionUUID->"5a2d1101-3c71-4765-bf4c-d27ea443d077"]
}, Open  ]],
Cell[3505217, 96738, 3224, 87, 186, "Input",ExpressionUUID->"c5f40806-0e1a-4a12-8042-e370a9efe4c5",
 InitializationCell->True],
Cell[3508444, 96827, 302, 7, 31, "Input",ExpressionUUID->"7298bdbd-3b3f-4e45-8b2b-47c264b2a2d2"],
Cell[3508749, 96836, 459, 12, 31, "Input",ExpressionUUID->"bcfe0b5d-9ec9-430c-ae7f-1d22abdd16de"],
Cell[CellGroupData[{
Cell[3509233, 96852, 1864, 51, 101, "Input",ExpressionUUID->"cee325b5-45e5-4b40-90b5-2c75dbce87e7"],
Cell[3511100, 96905, 44858, 748, 393, "Output",ExpressionUUID->"a6c24e9b-e317-4c42-a2c1-b0edf86d9d03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3555995, 97658, 357, 8, 31, "Input",ExpressionUUID->"5710a258-370d-4130-86cf-46583980cae8"],
Cell[3556355, 97668, 327, 7, 35, "Output",ExpressionUUID->"db9b807a-038c-4bce-be70-af0098775adb"]
}, Open  ]],
Cell[3556697, 97678, 2358, 55, 147, "Input",ExpressionUUID->"4b32aee0-2e99-4494-a42e-40beab315e40"],
Cell[3559058, 97735, 2064, 48, 124, "Input",ExpressionUUID->"e7f6555b-2ad3-4a0f-be01-ce5e04f715ad"],
Cell[CellGroupData[{
Cell[3561147, 97787, 217, 4, 31, "Input",ExpressionUUID->"028e95bd-0142-4f1e-bb8c-e3f10d7a798a"],
Cell[3561367, 97793, 223, 4, 35, "Output",ExpressionUUID->"665c8cbc-3af6-418b-afd0-203c90e797e7"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3561651, 97804, 248, 4, 68, "Section",ExpressionUUID->"0c05b5bf-8bf9-4f67-8711-640013474e3e"],
Cell[3561902, 97810, 1937, 49, 170, "Input",ExpressionUUID->"dc8537ec-eea1-4da2-8414-6b7dd2e0be06"],
Cell[3563842, 97861, 1194, 30, 78, "Input",ExpressionUUID->"a657c39c-7ade-4b9c-b853-202bba8f451d"],
Cell[3565039, 97893, 888, 20, 55, "Input",ExpressionUUID->"2987a17c-2cdf-48bc-bfce-f282d00395d5"],
Cell[CellGroupData[{
Cell[3565952, 97917, 745, 17, 78, "Input",ExpressionUUID->"88cd970b-33a4-4938-8bb9-3a8cd85f0064"],
Cell[3566700, 97936, 542, 14, 39, "Output",ExpressionUUID->"8d9c194a-5ea6-430c-8692-49f37e36be01"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3567279, 97955, 247, 5, 31, "Input",ExpressionUUID->"d24dccfb-a6c0-4756-ad45-1ddc054e9317"],
Cell[3567529, 97962, 453, 11, 35, "Output",ExpressionUUID->"79fa975a-86cf-4f48-acb6-499eaf939f12"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3568019, 97978, 602, 18, 31, "Input",ExpressionUUID->"d48b9751-c3eb-4921-b030-cf9104f80d3b"],
Cell[3568624, 97998, 479, 12, 35, "Output",ExpressionUUID->"a996cc54-0ad9-44f2-a706-c74278c9f559"]
}, Open  ]],
Cell[3569118, 98013, 131, 3, 31, "Input",ExpressionUUID->"711d3e7c-7e2e-4574-9d5b-560f0362b3bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3569286, 98021, 257, 6, 107, "Section",ExpressionUUID->"9f5fb824-db21-4173-af59-70d1e5db8c17"],
Cell[CellGroupData[{
Cell[3569568, 98031, 282, 6, 45, "Subsubsection",ExpressionUUID->"f4ab5fcf-968b-4bca-8e11-a5cb2c4d42a3"],
Cell[3569853, 98039, 3879, 107, 308, "Input",ExpressionUUID->"04299289-4fda-46b7-ada0-45797e6099aa"],
Cell[CellGroupData[{
Cell[3573757, 98150, 725, 21, 31, "Input",ExpressionUUID->"17106221-5cb3-4aea-890a-91cc7a928f3f"],
Cell[3574485, 98173, 889, 23, 59, "Output",ExpressionUUID->"5925b092-473d-4932-8ec7-ffda31daeb4b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3575423, 98202, 195, 3, 45, "Subsubsection",ExpressionUUID->"4da445a3-b020-404c-a55f-12b3f7c16ef9"],
Cell[3575621, 98207, 213, 5, 31, "Input",ExpressionUUID->"cd2d8707-0d3a-44c3-afeb-4519dc86bf4e"],
Cell[3575837, 98214, 270, 6, 37, "Text",ExpressionUUID->"267bbbe8-a140-4be4-aa37-024bde5db8e7"],
Cell[3576110, 98222, 344, 9, 31, "Input",ExpressionUUID->"cb8d2d0b-f6f5-4b42-bf61-46a859a51c23"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3576491, 98236, 548, 9, 97, "Subsubsection",ExpressionUUID->"e91dd595-1ed8-4162-87c2-00b45a8ec09b"],
Cell[CellGroupData[{
Cell[3577064, 98249, 184, 3, 31, "Input",ExpressionUUID->"c139dbc0-70dd-4ce6-a519-b21d54c54c55"],
Cell[3577251, 98254, 1016, 30, 59, "Output",ExpressionUUID->"4756678b-22fb-4175-bbf5-ecdb8e93dea3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3578304, 98289, 533, 13, 31, "Input",ExpressionUUID->"2417d4fe-c9fb-4dfd-a8d8-816f69fa02c2"],
Cell[3578840, 98304, 697, 20, 35, "Output",ExpressionUUID->"bf1970c4-0f1a-46c8-b445-70aa595dc36d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3579574, 98329, 1208, 31, 78, "Input",ExpressionUUID->"fabc4f43-a0f0-477d-b89e-b45e25bdc35f"],
Cell[3580785, 98362, 5984, 178, 281, "Output",ExpressionUUID->"e1e58965-32d2-41d2-a0b3-4354191a9d41"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3586806, 98545, 1885, 48, 135, "Input",ExpressionUUID->"3d1087fe-da16-439f-ac9d-d0d6a1e0d1e4"],
Cell[3588694, 98595, 3870, 118, 191, "Output",ExpressionUUID->"7b3655f0-d5cd-4370-9f24-3f40761228dd"]
}, Open  ]],
Cell[3592579, 98716, 5484, 139, 286, "Input",ExpressionUUID->"45419f6b-8814-4409-bfed-7ac7277d9cbb"]
}, Closed]],
Cell[CellGroupData[{
Cell[3598100, 98860, 354, 6, 37, "Subsubsection",ExpressionUUID->"58a3bd17-dd25-4a13-a459-f16e38edf439"],
Cell[3598457, 98868, 420, 8, 62, "Text",ExpressionUUID->"1b1c9abe-6125-42de-a493-13d99a2cb15c"],
Cell[3598880, 98878, 520, 12, 31, "Input",ExpressionUUID->"86e23ef4-a188-4787-b314-c99cc6e6eb5b"],
Cell[3599403, 98892, 402, 10, 55, "Input",ExpressionUUID->"9c798536-07f7-4892-bcc4-b2342bfa2559"],
Cell[3599808, 98904, 4187, 99, 276, "Input",ExpressionUUID->"fbdc31cd-dc45-43a9-89d3-dd78f2213d3b"],
Cell[3603998, 99005, 5484, 139, 286, "Input",ExpressionUUID->"f78ee2e3-826a-4479-b8ee-eb835575c1d7"],
Cell[3609485, 99146, 1577, 44, 171, "Input",ExpressionUUID->"fa916e5e-0dd3-4c08-9536-88b51038eaf0",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3611087, 99194, 4455, 123, 232, "Input",ExpressionUUID->"91a7c7d2-059b-4dd2-ae66-483ed5882beb"],
Cell[3615545, 99319, 3312, 91, 211, "Output",ExpressionUUID->"11c8e46b-7f69-4134-b222-a7401a4c3aed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3618894, 99415, 658, 19, 31, "Input",ExpressionUUID->"4b9513b5-920b-47a4-bd5b-9b7f5f448cf6"],
Cell[3619555, 99436, 1512, 36, 59, "Output",ExpressionUUID->"286cc935-c5af-4ee0-bb79-8ebf4775b3e1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3621116, 99478, 282, 6, 71, "Subsubsection",ExpressionUUID->"651cf408-eab6-4f1b-8424-cf205efe2fce"],
Cell[3621401, 99486, 6748, 152, 398, "Input",ExpressionUUID->"a1740eaa-3d73-47b6-b990-c27dc6b119e9",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[3628186, 99643, 183, 3, 45, "Subsubsection",ExpressionUUID->"01551329-7906-48c4-90f2-334c0c0b4047"],
Cell[CellGroupData[{
Cell[3628394, 99650, 559, 13, 55, "Input",ExpressionUUID->"c25e6845-deca-442b-a630-90e688a0ce84"],
Cell[3628956, 99665, 881, 22, 59, "Output",ExpressionUUID->"1eb53303-1ab5-42ad-b0df-cb3225c8b041"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3629874, 99692, 392, 9, 31, "Input",ExpressionUUID->"85d1d273-c5d2-46a4-bdbc-0b3913dab1e0"],
Cell[3630269, 99703, 370, 8, 35, "Output",ExpressionUUID->"eb94813b-d146-4401-a1a8-75b8e4c801b6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3630676, 99716, 290, 6, 31, "Input",ExpressionUUID->"0fcfb88d-f9c3-470f-9a4d-e6f847abe1a2"],
Cell[3630969, 99724, 1142, 26, 82, "Output",ExpressionUUID->"aba50ed0-1cf5-4a02-b748-0fdbafd1a067"]
}, Open  ]],
Cell[3632126, 99753, 294, 6, 37, "Text",ExpressionUUID->"2976cdff-a8fb-4892-8e3f-5dd4b69f2d60"],
Cell[CellGroupData[{
Cell[3632445, 99763, 636, 18, 31, "Input",ExpressionUUID->"6294a625-fb00-4b3f-929e-6923be75de0b"],
Cell[3633084, 99783, 625, 16, 59, "Output",ExpressionUUID->"b65ec3db-fb02-4289-8189-988e045f46de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3633746, 99804, 222, 4, 31, "Input",ExpressionUUID->"7b7fb898-e0b1-425a-8b39-b40121235e33"],
Cell[3633971, 99810, 848, 23, 101, "Output",ExpressionUUID->"7b600acf-16e5-468d-87b8-1b25a3e75781"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3634856, 99838, 928, 24, 78, "Input",ExpressionUUID->"4255e92d-59ab-472b-bdd0-b7de8bee7f9d"],
Cell[3635787, 99864, 1486, 38, 126, "Output",ExpressionUUID->"b2597aff-6b80-4fbc-bb2b-a27a9853a86c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3637310, 99907, 412, 10, 31, "Input",ExpressionUUID->"5bc0a014-547c-4fae-ad63-25ac84ad59be"],
Cell[3637725, 99919, 643, 15, 59, "Output",ExpressionUUID->"6136a303-a372-4bd5-9a90-eb9e3193fb3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3638405, 99939, 205, 4, 31, "Input",ExpressionUUID->"8f45e89d-d425-485e-b87b-4dc150520e15"],
Cell[CellGroupData[{
Cell[3638635, 99947, 194, 4, 46, "Print",ExpressionUUID->"d0f8cdf4-2ae8-49b8-b520-e82091ec7e06",
 CellTags->"Info6723742393388-6760036"],
Cell[3638832, 99953, 6192, 144, 158, "Print",ExpressionUUID->"afb18cbe-1c63-4594-ad1c-8465f0d9deb6",
 CellTags->"Info6723742393388-6760036"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3645085, 100104, 173, 3, 45, "Subsubsection",ExpressionUUID->"16f6c189-8105-4134-ae61-61836da29714"],
Cell[3645261, 100109, 644, 16, 55, "Input",ExpressionUUID->"9bb53849-edc3-47e0-ada9-4392eff76e70"],
Cell[CellGroupData[{
Cell[3645930, 100129, 220, 4, 31, "Input",ExpressionUUID->"6867fb58-a75c-475f-b4e1-84e94b437672"],
Cell[3646153, 100135, 848, 23, 101, "Output",ExpressionUUID->"8b2e3ca4-b052-467d-b818-220d863a5e4a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3647038, 100163, 372, 8, 31, "Input",ExpressionUUID->"58ca9f24-4d99-4c7d-a807-15981fd2fbf4"],
Cell[3647413, 100173, 4252, 103, 335, "Output",ExpressionUUID->"53bcb14a-a60d-4e2c-83e2-afb1526df64d"]
}, Open  ]],
Cell[3651680, 100279, 227, 5, 37, "Text",ExpressionUUID->"7df1d327-f7a9-4da6-9847-c3414b3e8915"],
Cell[3651910, 100286, 1282, 38, 171, "Input",ExpressionUUID->"95dd2224-09f1-4341-afc8-2457ca46c450",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3653217, 100328, 262, 6, 31, "Input",ExpressionUUID->"11f0903b-16a4-47fa-8d88-43704fd2e295"],
Cell[3653482, 100336, 3887, 87, 312, "Output",ExpressionUUID->"2632640e-8417-4010-a71b-d38b5d68ca0d"]
}, Closed]],
Cell[CellGroupData[{
Cell[3657406, 100428, 414, 10, 27, "Input",ExpressionUUID->"4f4d06bd-204f-4c43-a377-5434622c493c"],
Cell[3657823, 100440, 218, 5, 35, "Output",ExpressionUUID->"06881e8f-c4a9-4649-bd7e-04d470e5d62e"]
}, Open  ]],
Cell[3658056, 100448, 1507, 43, 195, "Input",ExpressionUUID->"259e6f8a-6481-4464-af3a-6a10018490c5",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3659588, 100495, 567, 15, 55, "Input",ExpressionUUID->"c691869a-489d-4b10-8b3b-2baeb1969acd"],
Cell[3660158, 100512, 293, 6, 35, "Output",ExpressionUUID->"0d8a5d03-50e2-4371-bb94-68a9b8e8c27a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3660500, 100524, 169, 3, 45, "Subsubsection",ExpressionUUID->"5c90505d-522e-4ae9-9795-0543b85001dc"],
Cell[CellGroupData[{
Cell[3660694, 100531, 417, 10, 31, "Input",ExpressionUUID->"abd48738-efde-4dce-a369-78d56605b12f"],
Cell[3661114, 100543, 496, 14, 52, "Output",ExpressionUUID->"4b824bba-a811-4df1-b00b-9019a9b53bba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3661647, 100562, 492, 13, 31, "Input",ExpressionUUID->"8fc2f937-897a-4bc5-ae20-c8e3796542e2"],
Cell[3662142, 100577, 3795, 104, 272, "Output",ExpressionUUID->"3d6e3fdb-6b3c-4031-8554-340569fd59f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3665974, 100686, 303, 7, 31, "Input",ExpressionUUID->"52032332-b26f-4c8d-9c93-28d433fc1c15"],
Cell[3666280, 100695, 892, 25, 92, "Output",ExpressionUUID->"ecff95c6-758a-4c50-be7b-d5ce7512ce94"]
}, Open  ]],
Cell[3667187, 100723, 746, 18, 55, "Input",ExpressionUUID->"b07fda96-5b7e-4484-9077-380d25c5cc61"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3667970, 100746, 182, 3, 45, "Subsubsection",ExpressionUUID->"d73fddf7-b9d5-4568-bf69-1b5551a8c03f"],
Cell[CellGroupData[{
Cell[3668177, 100753, 982, 23, 78, "Input",ExpressionUUID->"4d941590-3158-49fc-94a5-868b2a581a49"],
Cell[3669162, 100778, 380, 9, 35, "Output",ExpressionUUID->"04881e9f-c427-4926-b981-1477aa7ad549"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3669579, 100792, 266, 5, 31, "Input",ExpressionUUID->"df14731c-0a73-4562-b4b6-bc35a79ae1eb"],
Cell[3669848, 100799, 439, 11, 35, "Output",ExpressionUUID->"7ff6228a-1d0e-41b4-8577-d6d7fea6f65f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3670324, 100815, 313, 8, 31, "Input",ExpressionUUID->"54864593-6b2e-4c33-8d8c-ac8b58e257e9"],
Cell[3670640, 100825, 169, 3, 35, "Output",ExpressionUUID->"39a483c1-3cc3-4ac8-813b-c1fec3e2c444"]
}, Open  ]],
Cell[3670824, 100831, 520, 12, 31, "Input",ExpressionUUID->"e6995b01-daed-467e-8fa1-5d15f46b2020"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3671381, 100848, 223, 4, 45, "Subsubsection",ExpressionUUID->"bc7d658f-8a11-4c78-af26-0bbaf0ca77ff"],
Cell[3671607, 100854, 750, 21, 31, "Input",ExpressionUUID->"30046e85-5060-4aa8-8f7b-d43fb53b8d61"],
Cell[3672360, 100877, 232, 6, 31, "Input",ExpressionUUID->"30359b9b-b96f-4bc4-91a0-a842ff749860"],
Cell[3672595, 100885, 191, 4, 31, "Input",ExpressionUUID->"0f5541c1-1d33-4278-97ef-4e05bddd1f24"],
Cell[CellGroupData[{
Cell[3672811, 100893, 747, 16, 55, "Input",ExpressionUUID->"15d0ea75-a6e0-4ccb-9bfc-76a8998ddc9c"],
Cell[3673561, 100911, 439, 11, 39, "Output",ExpressionUUID->"bd6b7431-0098-445b-9b1e-e9037b0b7576"]
}, Open  ]],
Cell[3674015, 100925, 514, 11, 31, "Input",ExpressionUUID->"f6a5c867-e094-44ec-9cec-34f691fdf253"],
Cell[3674532, 100938, 768, 20, 55, "Input",ExpressionUUID->"4641cb7b-710a-4355-8c53-e6e8a043951b"],
Cell[3675303, 100960, 445, 10, 31, "Input",ExpressionUUID->"29ab5af1-ec04-4421-92d7-93a3f6d3df20"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3675797, 100976, 441, 12, 107, "Section",ExpressionUUID->"14c63ff0-cca3-4295-b97e-1478048ca260"],
Cell[3676241, 100990, 533, 14, 31, "Input",ExpressionUUID->"8ef57942-a327-4ee3-a006-c2c2600024a7"],
Cell[3676777, 101006, 415, 10, 31, "Input",ExpressionUUID->"cefb0e75-97cd-4990-90c6-6d844ad777dd"],
Cell[3677195, 101018, 129, 3, 31, "Input",ExpressionUUID->"86b959d7-05d4-4084-9136-51d342a2843b"],
Cell[3677327, 101023, 274, 6, 31, "Input",ExpressionUUID->"15f9a4cd-0b5f-4fd9-8372-c94bad4fd37b"],
Cell[3677604, 101031, 368, 9, 31, "Input",ExpressionUUID->"65076c31-4c36-4c87-987a-ebcd08e7f5ac"]
}, Open  ]]
}, Open  ]]
}
]
*)

